@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: contour.cpp,v 1.6 2006/03/03 03:49:38 fwarmerdam Exp $
+ * $Id: contour.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Contour Generation
  * Purpose:  Core algorithm implementation for contour line generation. 
@@ -26,34 +26,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: contour.cpp,v $
- * Revision 1.6  2006/03/03 03:49:38  fwarmerdam
- * Do not perterb nodata values even if they fall on a contour interval.
- *
- * Revision 1.5  2003/10/16 17:47:06  warmerda
- * Added algorithm details to GDALContourGenerate().
- *
- * Revision 1.4  2003/10/16 17:41:13  warmerda
- * Added docs for GDALContourGenerate()
- *
- * Revision 1.3  2003/10/16 16:44:05  warmerda
- * added support for fixed levels
- *
- * Revision 1.2  2003/10/15 20:40:58  warmerda
- * reworked to avoid quadratic behavior in the number of contours
- *
- * Revision 1.1  2003/10/10 19:44:46  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "gdal_priv.h"
 #include "gdal_alg.h"
 #include "ogr_api.h"
 
-CPL_CVSID("$Id: contour.cpp,v 1.6 2006/03/03 03:49:38 fwarmerdam Exp $");
+CPL_CVSID("$Id: contour.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 // The amount of a contour interval that pixels should be fudged by if they
 // match a contour level exactly.
