@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdal_alg.h,v 1.22 2005/08/02 22:19:41 fwarmerdam Exp $
+ * $Id: gdal_alg.h 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GDAL Image Processing Algorithms
  * Purpose:  Prototypes, and definitions for various GDAL based algorithms.
@@ -25,75 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: gdal_alg.h,v $
- * Revision 1.22  2005/08/02 22:19:41  fwarmerdam
- * approx transformer now can own its subtransformer
- *
- * Revision 1.21  2005/04/11 17:36:53  fwarmerdam
- * added GDALDestroyTransformer
- *
- * Revision 1.20  2005/04/04 15:24:16  fwarmerdam
- * added CPL_STDCALL to some functions
- *
- * Revision 1.19  2004/12/26 16:12:21  fwarmerdam
- * thin plate spline support now implemented
- *
- * Revision 1.18  2004/08/11 19:00:06  warmerda
- * added GDALSetGenImgProjTransformerDstGeoTransform
- *
- * Revision 1.17  2004/08/09 14:38:27  warmerda
- * added serialize/deserialize support for warpoptions and transformers
- *
- * Revision 1.16  2003/12/15 15:59:25  warmerda
- * added CPL_DLL on contour stuff.
- *
- * Revision 1.15  2003/10/16 16:44:05  warmerda
- * added support for fixed levels
- *
- * Revision 1.14  2003/10/15 20:22:16  warmerda
- * removed C++ contour definitions
- *
- * Revision 1.13  2003/10/14 15:25:01  warmerda
- * added contour stuff
- *
- * Revision 1.12  2003/06/03 19:42:20  warmerda
- * modified rpc api
- *
- * Revision 1.11  2003/06/03 17:36:47  warmerda
- * Added RPC entry points
- *
- * Revision 1.10  2003/03/02 05:24:35  warmerda
- * added GDALChecksumImage
- *
- * Revision 1.9  2002/12/09 18:56:10  warmerda
- * added missing CPL_DLL
- *
- * Revision 1.8  2002/12/09 16:08:32  warmerda
- * added approximating transformer
- *
- * Revision 1.7  2002/12/07 22:58:42  warmerda
- * added initialization support for simple warper
- *
- * Revision 1.6  2002/12/07 17:09:38  warmerda
- * added order flag to GenImgProjTransformer
- *
- * Revision 1.5  2002/12/06 21:43:12  warmerda
- * tweak prototypes
- *
- * Revision 1.4  2002/12/05 21:44:35  warmerda
- * fixed prototype
- *
- * Revision 1.3  2002/12/05 05:43:28  warmerda
- * added warp/transformer definition
- *
- * Revision 1.2  2001/02/02 21:19:25  warmerda
- * added CPL_DLL for functions
- *
- * Revision 1.1  2001/01/22 22:30:59  warmerda
- * New
- */
+ ****************************************************************************/
 
 #ifndef GDAL_ALG_H_INCLUDED
 #define GDAL_ALG_H_INCLUDED
@@ -106,6 +38,7 @@
 
 #include "gdal.h"
 #include "cpl_minixml.h"
+#include "ogr_api.h"
 
 CPL_C_START
 
@@ -204,6 +137,17 @@ int CPL_DLL GDALRPCTransform(
     void *pTransformArg, int bDstToSrc, int nPointCount,
     double *x, double *y, double *z, int *panSuccess );
 
+/* Geolocation transformer */
+
+void CPL_DLL *
+GDALCreateGeoLocTransformer( GDALDatasetH hBaseDS, 
+                             char **papszGeolocationInfo,
+                             int bReversed );
+void CPL_DLL GDALDestroyGeoLocTransformer( void *pTransformArg );
+int CPL_DLL GDALGeoLocTransform( 
+    void *pTransformArg, int bDstToSrc, int nPointCount,
+    double *x, double *y, double *z, int *panSuccess );
+
 /* Approximate transformer */
 void CPL_DLL *
 GDALCreateApproxTransformer( GDALTransformerFunc pfnRawTransformer, 
@@ -234,6 +178,14 @@ GDALSuggestedWarpOutput( GDALDatasetH hSrcDS,
                          void *pTransformArg,
                          double *padfGeoTransformOut, 
                          int *pnPixels, int *pnLines );
+CPLErr CPL_DLL CPL_STDCALL
+GDALSuggestedWarpOutput2( GDALDatasetH hSrcDS, 
+                          GDALTransformerFunc pfnTransformer,
+                          void *pTransformArg,
+                          double *padfGeoTransformOut, 
+                          int *pnPixels, int *pnLines,
+                          double *padfExtents, 
+                          int nOptions );
 
 CPLXMLNode CPL_DLL *
 GDALSerializeTransformer( GDALTransformerFunc pfnFunc, void *pTransformArg );
@@ -282,6 +234,32 @@ GDALContourGenerate( GDALRasterBandH hBand,
                             void *hLayer, int iIDField, int iElevField,
                             GDALProgressFunc pfnProgress, void *pProgressArg );
 
+/* -------------------------------------------------------------------- */
+/*      Low level rasterizer API.                                       */
+/* -------------------------------------------------------------------- */
+typedef void (*llScanlineFunc)( void *pCBData, int nY, int nXStart, int nXEnd);
+
+
+void GDALdllImageFilledPolygon(int nRasterXSize, int nRasterYSize, 
+                               int nPartCount, int *panPartSize, 
+                               double *padfX, double *padfY,
+                               llScanlineFunc pfnScanlineFunc, void *pCBData );
+
+/* -------------------------------------------------------------------- */
+/*      High level API - GvShapes burned into GDAL raster.              */
+/* -------------------------------------------------------------------- */
+
+CPLErr CPL_DLL 
+GDALRasterizeGeometries( GDALDatasetH hDS, 
+                         int nBandCount, int *panBandList, 
+                         int nGeomCount, OGRGeometryH *pahGeometries,
+                         GDALTransformerFunc pfnTransformer, 
+                         void *pTransformArg, 
+                         double *padfGeomBurnValue,
+                         char **papszOptions,
+                         GDALProgressFunc pfnProgress, 
+                         void * pProgressArg );
+
 CPL_C_END
                             
 #endif /* ndef GDAL_ALG_H_INCLUDED */
