@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdal_crs.c,v 1.8 2004/12/26 16:12:21 fwarmerdam Exp $
+ * $Id: gdal_crs.c 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Mapinfo Image Warper
  * Purpose:  Implemention of the GDALTransformer wrapper around CRS.C functions
@@ -48,41 +48,14 @@
     FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
     DEALINGS IN THE SOFTWARE.
 
- ***************************************************************************
- *
- * $Log: gdal_crs.c,v $
- * Revision 1.8  2004/12/26 16:12:21  fwarmerdam
- * thin plate spline support now implemented
- *
- * Revision 1.7  2004/08/11 19:01:56  warmerda
- * default to 2nd order if we have enough points for 3rd order but 0 requested
- *
- * Revision 1.6  2004/08/09 14:38:27  warmerda
- * added serialize/deserialize support for warpoptions and transformers
- *
- * Revision 1.5  2004/03/19 15:22:02  warmerda
- * Fixed double free of padfRasterX. Submitted by Scott Reynolds.
- *
- * Revision 1.4  2002/12/07 17:09:50  warmerda
- * re-enable 3rd order even though unstable
- *
- * Revision 1.3  2002/12/06 17:58:00  warmerda
- * fix a few bugs
- *
- * Revision 1.2  2002/12/05 05:46:08  warmerda
- * fixed linkage problem
- *
- * Revision 1.1  2002/12/05 05:43:23  warmerda
- * New
- * 
- */
+ ****************************************************************************/
 
 #include "gdal_alg.h"
 #include "cpl_conv.h"
 #include "cpl_minixml.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: gdal_crs.c,v 1.8 2004/12/26 16:12:21 fwarmerdam Exp $");
+CPL_CVSID("$Id: gdal_crs.c 10646 2007-01-18 02:38:10Z warmerdam $");
 
 #define MAXORDER 3
 
@@ -107,6 +80,15 @@ static int CRS_georef(double, double, double *, double *,
 static int CRS_compute_georef_equations(struct Control_Points *,
     double [], double [], double [], double [], int);
 
+
+static char *CRS_error_message[] = {
+    "Failed to compute GCP transform: Not enough points available",
+    "Failed to compute GCP transform: Transform is not solvable",
+    "Failed to compute GCP transform: Not enough memory"
+    "Failed to compute GCP transform: Parameter error",
+    "Failed to compute GCP transform: Internal error"
+};
+
 typedef struct
 {
     GDALTransformerInfo sTI;
@@ -164,6 +146,7 @@ void *GDALCreateGCPTransformer( int nGCPCount, const GDAL_GCP *pasGCPList,
     GCPTransformInfo *psInfo;
     double *padfGeoX, *padfGeoY, *padfRasterX, *padfRasterY;
     int    *panStatus, iGCP;
+    int    nCRSresult;
     struct Control_Points sPoints;
 
     if( nReqOrder == 0 )
@@ -217,14 +200,13 @@ void *GDALCreateGCPTransformer( int nGCPCount, const GDAL_GCP *pasGCPList,
 /* -------------------------------------------------------------------- */
 /*      Compute the forward and reverse polynomials.                    */
 /* -------------------------------------------------------------------- */
-    if( CRS_compute_georef_equations( &sPoints,
+    nCRSresult = CRS_compute_georef_equations( &sPoints,
                                       psInfo->adfToGeoX, psInfo->adfToGeoY,
                                       psInfo->adfFromGeoX, psInfo->adfFromGeoY,
-                                      nReqOrder ) != 1 )
+                                      nReqOrder );
+    if (nCRSresult != 1)
     {
-        CPLError( CE_Failure, CPLE_AppDefined,
-                  "Failed to compute polynomial equations of desired order\n"
-                  "for provided control points." );
+        CPLError( CE_Failure, CPLE_AppDefined, CRS_error_message[-nCRSresult]);
         goto CleanupAfterError;
     }
     
@@ -305,6 +287,12 @@ int GDALGCPTransform( void *pTransformArg, int bDstToSrc,
     
     for( i = 0; i < nPointCount; i++ )
     {
+        if( x[i] == HUGE_VAL || y[i] == HUGE_VAL )
+        {
+            panSuccess[i] = FALSE;
+            continue;
+        }
+
         if( bDstToSrc )
         {
             CRS_georef( x[i], y[i], x + i, y + i, 
