@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdal_rpc.cpp,v 1.3 2004/12/26 16:12:21 fwarmerdam Exp $
+ * $Id: gdal_rpc.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Image Warper
  * Purpose:  Implements a rational polynomail (RPC) based transformer. 
@@ -25,25 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: gdal_rpc.cpp,v $
- * Revision 1.3  2004/12/26 16:12:21  fwarmerdam
- * thin plate spline support now implemented
- *
- * Revision 1.2  2003/06/03 19:41:58  warmerda
- * working implmentation, but inverse is still not iteratively solved
- *
- * Revision 1.1  2003/06/03 17:36:43  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "gdal_priv.h"
 #include "gdal_alg.h"
 #include "ogr_spatialref.h"
 
-CPL_CVSID("$Id: gdal_rpc.cpp,v 1.3 2004/12/26 16:12:21 fwarmerdam Exp $");
+CPL_CVSID("$Id: gdal_rpc.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                          RPCComputeTerms()                           */
