@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdalgeoloc.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: gdalgeoloc.cpp 12447 2007-10-16 20:36:35Z warmerdam $
  *
  * Project:  GDAL
  * Purpose:  Implements Geolocation array based transformer.
@@ -37,7 +37,7 @@ SHPHandle hSHP = NULL;
 DBFHandle hDBF = NULL;
 #endif
 
-CPL_CVSID("$Id: gdalgeoloc.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: gdalgeoloc.cpp 12447 2007-10-16 20:36:35Z warmerdam $");
 
 /************************************************************************/
 /* ==================================================================== */
@@ -170,9 +170,9 @@ static int GeoLocGenerateBackMap( GDALGeoLocTransformInfo *psTransform )
                               / dfTargetPixels);
     int nBMXSize, nBMYSize;
 
-    nBMXSize = psTransform->nBackMapHeight = 
+    nBMYSize = psTransform->nBackMapHeight = 
         (int) ((dfMaxY - dfMinY) / dfPixelSize + 1);
-    nBMYSize= psTransform->nBackMapWidth =  
+    nBMXSize= psTransform->nBackMapWidth =  
         (int) ((dfMaxX - dfMinX) / dfPixelSize + 1);
 
     dfMinX -= dfPixelSize/2.0;
@@ -251,51 +251,55 @@ static int GeoLocGenerateBackMap( GDALGeoLocTransformInfo *psTransform )
 /*      Now, loop over the backmap trying to fill in holes with         */
 /*      nearby values.                                                  */
 /* -------------------------------------------------------------------- */
-    
-    for( iBMY = 1; iBMY < nBMYSize-1; iBMY++ )
+    int iIter;
+
+    for( iIter = 0; iIter < 3; iIter++ )
     {
-        for( iBMX = 1; iBMX < nBMXSize-1; iBMX++ )
+        for( iBMY = 1; iBMY < nBMYSize-1; iBMY++ )
         {
-            // if this point is already set, ignore it. 
-            if( pabyValidFlag[iBMX + iBMY*nBMXSize] )
-                continue;
+            for( iBMX = 1; iBMX < nBMXSize-1; iBMX++ )
+            {
+                // if this point is already set, ignore it. 
+                if( pabyValidFlag[iBMX + iBMY*nBMXSize] )
+                    continue;
 
-            int nCount = 0;
-            double dfXSum = 0.0, dfYSum = 0.0;
+                int nCount = 0;
+                double dfXSum = 0.0, dfYSum = 0.0;
 
-            // left?
-            if( iBMX > 0 && pabyValidFlag[iBMX-1+iBMY*nBMXSize] )
-            {
-                dfXSum += psTransform->pafBackMapX[iBMX-1+iBMY*nBMXSize];
-                dfYSum += psTransform->pafBackMapY[iBMX-1+iBMY*nBMXSize];
-                nCount++;
-            }
-            // right?
-            if( iBMX < nBMXSize-1 && pabyValidFlag[iBMX+1+iBMY*nBMXSize] )
-            {
-                dfXSum += psTransform->pafBackMapX[iBMX+1+iBMY*nBMXSize];
-                dfYSum += psTransform->pafBackMapY[iBMX+1+iBMY*nBMXSize];
-                nCount++;
-            }
-            // top?
-            if( iBMY > 0 && pabyValidFlag[iBMX+(iBMY-1)*nBMXSize] )
-            {
-                dfXSum += psTransform->pafBackMapX[iBMX+(iBMY-1)*nBMXSize];
-                dfYSum += psTransform->pafBackMapY[iBMX+(iBMY-1)*nBMXSize];
-                nCount++;
-            }
-            // bottom?
-            if( iBMY < nBMYSize-1 && pabyValidFlag[iBMX+(iBMY+1)*nBMXSize] )
-            {
-                dfXSum += psTransform->pafBackMapX[iBMX+(iBMY+1)*nBMXSize];
-                dfYSum += psTransform->pafBackMapY[iBMX+(iBMY+1)*nBMXSize];
-                nCount++;
-            }
+                // left?
+                if( iBMX > 0 && pabyValidFlag[iBMX-1+iBMY*nBMXSize] )
+                {
+                    dfXSum += psTransform->pafBackMapX[iBMX-1+iBMY*nBMXSize];
+                    dfYSum += psTransform->pafBackMapY[iBMX-1+iBMY*nBMXSize];
+                    nCount++;
+                }
+                // right?
+                if( iBMX < nBMXSize-1 && pabyValidFlag[iBMX+1+iBMY*nBMXSize] )
+                {
+                    dfXSum += psTransform->pafBackMapX[iBMX+1+iBMY*nBMXSize];
+                    dfYSum += psTransform->pafBackMapY[iBMX+1+iBMY*nBMXSize];
+                    nCount++;
+                }
+                // top?
+                if( iBMY > 0 && pabyValidFlag[iBMX+(iBMY-1)*nBMXSize] )
+                {
+                    dfXSum += psTransform->pafBackMapX[iBMX+(iBMY-1)*nBMXSize];
+                    dfYSum += psTransform->pafBackMapY[iBMX+(iBMY-1)*nBMXSize];
+                    nCount++;
+                }
+                // bottom?
+                if( iBMY < nBMYSize-1 && pabyValidFlag[iBMX+(iBMY+1)*nBMXSize] )
+                {
+                    dfXSum += psTransform->pafBackMapX[iBMX+(iBMY+1)*nBMXSize];
+                    dfYSum += psTransform->pafBackMapY[iBMX+(iBMY+1)*nBMXSize];
+                    nCount++;
+                }
 
-            if( nCount > 0 )
-            {
-                psTransform->pafBackMapX[iBMX + iBMY * nBMXSize] = (float)(dfXSum/nCount);
-                psTransform->pafBackMapY[iBMX + iBMY * nBMXSize] = (float)(dfYSum/nCount);
+                if( nCount > 0 )
+                {
+                    psTransform->pafBackMapX[iBMX + iBMY * nBMXSize] = (float)(dfXSum/nCount);
+                    psTransform->pafBackMapY[iBMX + iBMY * nBMXSize] = (float)(dfYSum/nCount);
+                }
             }
         }
     }
