@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdalmediancut.cpp,v 1.6 2005/04/04 15:24:16 fwarmerdam Exp $
+ * $Id: gdalmediancut.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  CIETMap Phase 2
  * Purpose:  Use median cut algorithm to generate an near-optimal PCT for a 
@@ -34,31 +34,12 @@
  *      "Color  Image Quantization for Frame Buffer Display", Paul
  *      Heckbert, SIGGRAPH proceedings, 1982, pp. 297-307.
  * 
- * $Log: gdalmediancut.cpp,v $
- * Revision 1.6  2005/04/04 15:24:16  fwarmerdam
- * added CPL_STDCALL to some functions
- *
- * Revision 1.5  2003/07/08 15:28:32  warmerda
- * avoid warnings
- *
- * Revision 1.4  2003/02/06 04:56:35  warmerda
- * added documentation
- *
- * Revision 1.3  2002/04/16 17:48:36  warmerda
- * Ensure everything is initialized.
- *
- * Revision 1.2  2001/07/18 04:43:13  warmerda
- * added CPL_CVSID
- *
- * Revision 1.1  2001/01/22 22:30:59  warmerda
- * New
- *
  */
 
 #include "gdal_priv.h"
 #include "gdal_alg.h"
 
-CPL_CVSID("$Id: gdalmediancut.cpp,v 1.6 2005/04/04 15:24:16 fwarmerdam Exp $");
+CPL_CVSID("$Id: gdalmediancut.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 #define	MAX_CMAP_SIZE	256
 
@@ -295,6 +276,7 @@ GDALComputeMedianCutPCT( GDALRasterBandH hRed,
         sEntry.c1 = (GByte) (((ptr->rmin + ptr->rmax) << COLOR_SHIFT) / 2);
         sEntry.c2 = (GByte) (((ptr->gmin + ptr->gmax) << COLOR_SHIFT) / 2);
         sEntry.c3 = (GByte) (((ptr->bmin + ptr->bmax) << COLOR_SHIFT) / 2);
+        sEntry.c4 = 255;
         GDALSetColorEntry( hColorTable, i, &sEntry );
     }
     
