@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdalwarper.cpp,v 1.19 2005/04/11 17:20:40 fwarmerdam Exp $
+ * $Id: gdalwarper.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  High Performance Image Reprojector
  * Purpose:  Implementation of high level convenience APIs for warper.
@@ -25,76 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: gdalwarper.cpp,v $
- * Revision 1.19  2005/04/11 17:20:40  fwarmerdam
- * ensure dstnodata is duplicate in clonewarpoptions: bug 821
- *
- * Revision 1.18  2005/04/04 15:24:16  fwarmerdam
- * added CPL_STDCALL to some functions
- *
- * Revision 1.17  2004/12/31 02:11:20  fwarmerdam
- * Avoid warning.
- *
- * Revision 1.16  2004/10/07 15:50:18  fwarmerdam
- * added preliminary alpha band support
- *
- * Revision 1.15  2004/08/11 21:20:47  warmerda
- * avoid crash if transformer does not serialize
- *
- * Revision 1.14  2004/08/09 14:38:27  warmerda
- * added serialize/deserialize support for warpoptions and transformers
- *
- * Revision 1.13  2004/04/01 18:58:41  warmerda
- * fixed GDALReprojectImage() -- pass on eResampleAlg
- *
- * Revision 1.12  2004/03/28 21:20:39  warmerda
- * fixed initialization of nodata values
- *
- * Revision 1.11  2004/03/19 15:54:42  warmerda
- * Fixed another place where "2" was used instead of 0 as the default
- * polynomial order.
- *
- * Revision 1.10  2004/03/19 05:06:00  warmerda
- * Pass 0 for order to GDALCreateGenImgProjTransformer() from
- * GDALCreateAndReprojectImage() so that the default will be to figure
- * out the best order instead of defaulting to 2nd order.
- *
- * Revision 1.9  2004/02/25 19:51:00  warmerda
- * Fixed nodata check in GDT_Int16 case (from Manuel Massing).
- *
- * Revision 1.8  2003/07/26 17:32:16  warmerda
- * Added info on new warp options.
- *
- * Revision 1.7  2003/05/06 18:31:35  warmerda
- * added WRITE_FLUSH comment
- *
- * Revision 1.6  2003/04/22 19:41:24  dron
- * Fixed problem in GDALWarpNoDataMasker(): missed breaks in switch.
- *
- * Revision 1.5  2003/03/02 05:25:26  warmerda
- * added GDALWarpNoDataMasker
- *
- * Revision 1.4  2003/02/22 02:04:11  warmerda
- * added dfMaxError to reproject function
- *
- * Revision 1.3  2003/02/21 15:41:55  warmerda
- * rename data member
- *
- * Revision 1.2  2003/02/20 21:53:06  warmerda
- * partial implementation
- *
- * Revision 1.1  2003/02/18 17:25:50  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "gdalwarper.h"
 #include "cpl_string.h"
 #include "cpl_minixml.h"
 
-CPL_CVSID("$Id: gdalwarper.cpp,v 1.19 2005/04/11 17:20:40 fwarmerdam Exp $");
+CPL_CVSID("$Id: gdalwarper.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                         GDALReprojectImage()                         */
@@ -694,6 +631,12 @@ GDALWarpDstAlphaMasker( void *pMaskFuncArg, int nBandCount, GDALDataType eType,
  * of extra seeking around the disk, and reduced IO throughput.  The default
  * at this time is NO.
  *
+ * - SKIP_NOSOURCE=YES/NO: Skip all processing for chunks for which there
+ * is no corresponding input data.  This will disable initializing the 
+ * destination (INIT_DEST) and all other processing, and so should be used
+ * careful.  Mostly useful to short circuit a lot of extra work in mosaicing 
+ * situations.
+ *
  * Normally when computing the source raster data to 
  * load to generate a particular output area, the warper samples transforms
  * 21 points along each edge of the destination region back onto the source
@@ -845,6 +788,27 @@ GDALSerializeWarpOptions( const GDALWarpOptions *psWO )
         psTree, "WorkingDataType", 
         GDALGetDataTypeName( psWO->eWorkingDataType ) );
 
+/* -------------------------------------------------------------------- */
+/*      Name/value warp options.                                        */
+/* -------------------------------------------------------------------- */
+    int iWO;
+
+    for( iWO = 0; psWO->papszWarpOptions != NULL 
+             && psWO->papszWarpOptions[iWO] != NULL; iWO++ )
+    {
+        char *pszName = NULL;
+        const char *pszValue = 
+            CPLParseNameValue( psWO->papszWarpOptions[iWO], &pszName );
+
+        CPLXMLNode *psOption = 
+            CPLCreateXMLElementAndValue( 
+                psTree, "Option", pszValue );
+
+        CPLCreateXMLNode( 
+            CPLCreateXMLNode( psOption, CXT_Attribute, "name" ),
+            CXT_Text, pszName );
+    }
+
 /* -------------------------------------------------------------------- */
 /*      Source and Destination Data Source                              */
 /* -------------------------------------------------------------------- */
@@ -1002,6 +966,28 @@ GDALWarpOptions * CPL_STDCALL GDALDeserializeWarpOptions( CPLXMLNode *psTree )
         GDALGetDataTypeByName(
             CPLGetXMLValue(psTree,"WorkingDataType","Unknown"));
 
+/* -------------------------------------------------------------------- */
+/*      Name/value warp options.                                        */
+/* -------------------------------------------------------------------- */
+    CPLXMLNode *psItem; 
+
+    for( psItem = psTree->psChild; psItem != NULL; psItem = psItem->psNext )
+    {
+        if( psItem->eType == CXT_Element 
+            && EQUAL(psItem->pszValue,"Option") )
+        {
+            const char *pszName = CPLGetXMLValue(psItem, "Name", NULL );
+            const char *pszValue = CPLGetXMLValue(psItem, "", NULL );
+
+            if( pszName != NULL && pszValue != NULL )
+            {
+                psWO->papszWarpOptions = 
+                    CSLSetNameValue( psWO->papszWarpOptions, 
+                                     pszName, pszValue );
+            }
+        }
+    }
+    
 /* -------------------------------------------------------------------- */
 /*      Source Dataset.                                                 */
 /* -------------------------------------------------------------------- */
