@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdalwarpoperation.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: gdalwarpoperation.cpp 12613 2007-11-03 04:24:59Z warmerdam $
  *
  * Project:  High Performance Image Reprojector
  * Purpose:  Implementation of the GDALWarpOperation class.
@@ -31,7 +31,7 @@
 #include "cpl_string.h"
 #include "cpl_multiproc.h"
 
-CPL_CVSID("$Id: gdalwarpoperation.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: gdalwarpoperation.cpp 12613 2007-11-03 04:24:59Z warmerdam $");
 
 /************************************************************************/
 /* ==================================================================== */
@@ -1424,6 +1424,46 @@ CPLErr GDALWarpOperation::WarpRegionToBuffer(
         }
     }
 
+/* -------------------------------------------------------------------- */
+/*      If we have destination nodata values create, or update the      */
+/*      validity mask.                                                  */
+/* -------------------------------------------------------------------- */
+    if( eErr == CE_None && psOptions->padfDstNoDataReal != NULL )
+    {
+        GUInt32 *panBandMask = NULL;
+        int     nMaskWords = (oWK.nDstXSize * oWK.nDstYSize + 31)/32;
+
+        eErr = CreateKernelMask( &oWK, 0, "DstValid" );
+        if( eErr == CE_None )
+            panBandMask = (GUInt32 *) CPLMalloc(nMaskWords*4);
+
+        if( eErr == CE_None && panBandMask != NULL )
+        {
+            int iBand, iWord;
+
+            memset( oWK.panDstValid, 0, nMaskWords * 4 );
+            for( iBand = 0; iBand < psOptions->nBandCount; iBand++ )
+            {
+                double adfNoData[2];
+            
+                adfNoData[0] = psOptions->padfDstNoDataReal[iBand];
+                adfNoData[1] = psOptions->padfDstNoDataImag[iBand];
+            
+                eErr = 
+                    GDALWarpNoDataMasker( adfNoData, 1, 
+                                          psOptions->eWorkingDataType,
+                                          oWK.nDstXOff, oWK.nDstYOff, 
+                                          oWK.nDstXSize, oWK.nDstYSize,
+                                          oWK.papabyDstImage + iBand,
+                                          FALSE, panBandMask );
+
+                for( iWord = nMaskWords - 1; iWord >= 0; iWord-- )
+                    oWK.panDstValid[iWord] |= panBandMask[iWord];
+            }
+            CPLFree( panBandMask );
+        }
+    }
+        
 /* -------------------------------------------------------------------- */
 /*      Release IO Mutex, and acquire warper mutex.                     */
 /* -------------------------------------------------------------------- */
