@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: llrasterize.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: llrasterize.cpp 12557 2007-10-27 17:04:09Z mloskot $
  *
  * Project:  GDAL
  * Purpose:  Vector polygon rasterization code.
@@ -200,7 +200,7 @@ No known bug
 		    horizontal_x1 = (int) floor(padfX[ind2]+0.5);
 		    horizontal_x2 = (int) floor(padfX[ind1]+0.5);
 		
-                    if  ( (horizontal_x1 >  maxx) ||  (horizontal_x2 < minx) )
+                    if  ( (horizontal_x1 >  maxx) ||  (horizontal_x2 <= minx) )
                         continue;
 
 		    /*fill the horizontal segment (separately from the rest)*/
@@ -230,7 +230,7 @@ No known bug
 
         for (i=0; (i < (ints)); i+=2) {
 
-            if( polyInts[i] <= maxx && polyInts[i+1] >= minx )
+            if( polyInts[i] <= maxx && polyInts[i+1] > minx )
             {
                 pfnScanlineFunc( pCBData, y, polyInts[i], polyInts[i+1] - 1 );
                 
