@@ -1,5 +1,5 @@
 /* ****************************************************************************
- * $Id: gdal_translate.cpp,v 1.33 2006/04/25 14:29:28 fwarmerdam Exp $
+ * $Id: gdal_translate.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GDAL Utilities
  * Purpose:  GDAL Image Translator Program
@@ -25,145 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- * ****************************************************************************
- *
- * $Log: gdal_translate.cpp,v $
- * Revision 1.33  2006/04/25 14:29:28  fwarmerdam
- * Avoid warning.
- *
- * Revision 1.32  2005/05/17 19:04:47  fwarmerdam
- * Make sure nodata value is set after copycommoninfo.
- *
- * Revision 1.31  2005/05/09 14:31:56  fwarmerdam
- * Added optional elevation in -gcp usage message.
- *
- * Revision 1.30  2005/04/26 20:38:52  fwarmerdam
- * Added main/ProxyMain distinction since calling main does not work on
- * some platforms.
- *
- * Revision 1.29  2005/04/12 14:37:47  fwarmerdam
- * Added the -a_nodata switch to assign nodata values to output bands.
- *
- * Revision 1.28  2005/01/27 20:58:11  fwarmerdam
- * Added -a_ullr switch.
- *
- * Revision 1.27  2005/01/24 18:01:18  fwarmerdam
- * Added -sds option for copying subdatasets.
- *
- * Revision 1.26  2004/10/12 14:15:22  fwarmerdam
- * Added srcwin checking.
- *
- * Revision 1.25  2004/08/19 15:49:52  warmerda
- * Don't continue if the srcwin falls outside the raster.
- *
- * Revision 1.24  2004/08/11 19:06:48  warmerda
- * use CopyCommonInfoFrom() method on band
- *
- * Revision 1.23  2004/07/28 17:56:00  warmerda
- * use return instead of exit() to avoid lame warnings on windows
- *
- * Revision 1.22  2004/07/28 17:51:09  warmerda
- * updated to use VRTSourcedRasterBand
- *
- * Revision 1.21  2004/04/23 22:18:40  warmerda
- * Another memory leak.
- *
- * Revision 1.20  2004/04/23 22:18:07  warmerda
- * Avoid argument, and creation option memory leak.
- *
- * Revision 1.19  2004/04/02 17:33:22  warmerda
- * added GDALGeneralCmdLineProcessor()
- *
- * Revision 1.18  2003/09/30 06:10:08  dron
- * Copy NoData value over the virtual dataset.
- *
- * Revision 1.17  2003/09/19 18:30:02  warmerda
- * Added -gcp switch to attached GCPs to an image.
- *
- * Revision 1.16  2003/08/28 13:42:20  warmerda
- * support multiple -b switches to select a set of bands
- *
- * Revision 1.15  2003/07/27 12:31:14  dron
- * Few memory leaks fixed.
- *
- * Revision 1.14  2003/04/17 12:55:40  dron
- * Few memory leaks fixed.
- *
- * Revision 1.13  2003/03/03 16:29:35  warmerda
- * Added the -quiet flag.
- *
- * Revision 1.12  2002/12/03 03:40:11  warmerda
- * Avoid initialization warning.
- *
- * Revision 1.11  2002/11/24 04:26:42  warmerda
- * Use AddComplexSource() for scaling, rid of Create() altogether.
- *
- * Revision 1.10  2002/11/21 21:07:37  warmerda
- * ensure gcps are transformed as needed
- *
- * Revision 1.9  2002/11/21 20:48:06  warmerda
- * added GCP copying when creating virtual dataset
- *
- * Revision 1.8  2002/11/06 15:05:55  warmerda
- * added -a_srs
- *
- * Revision 1.7  2002/10/24 02:55:18  warmerda
- * added the -mo to add metadata
- *
- * Revision 1.6  2002/10/04 20:47:31  warmerda
- * fixed type override going through virtual db
- *
- * Revision 1.5  2002/09/11 14:22:33  warmerda
- * make an effort to preserve band descriptions
- *
- * Revision 1.4  2002/08/27 16:49:28  dron
- * Check for subdatasets in input file.
- *
- * Revision 1.3  2002/08/07 02:17:10  warmerda
- * Fixed -projwin messages.
- *
- * Revision 1.2  2002/08/06 17:47:54  warmerda
- * added the -projwin switch
- *
- * Revision 1.1  2002/06/24 19:59:57  warmerda
- * New
- *
- * Revision 1.27  2002/06/24 19:36:25  warmerda
- * carry over colortable
- *
- * Revision 1.26  2002/06/12 21:07:55  warmerda
- * test create and createcopy capability
- *
- * Revision 1.25  2002/04/16 17:17:18  warmerda
- * Ensure variables initialized.
- *
- * Revision 1.24  2002/04/16 14:00:25  warmerda
- * added GDALVersionInfo
- *
- * Revision 1.23  2002/02/07 20:24:18  warmerda
- * added -scale option
- *
- * Revision 1.22  2001/12/12 21:01:01  warmerda
- * fixed bug in windowing logic
- *
- * Revision 1.21  2001/09/24 15:55:11  warmerda
- * added cleanup percent done
- *
- * Revision 1.20  2001/08/23 03:23:46  warmerda
- * added the -not_strict switch
- *
- * Revision 1.19  2001/07/18 05:05:12  warmerda
- * added CPL_CSVID
- *
- * Revision 1.18  2001/03/21 15:00:49  warmerda
- * Escape % signs in printf() format.
- *
- * Revision 1.17  2001/03/20 20:20:14  warmerda
- * Added % handling, fixed completion, fixed adGeoTransform (Mark Salazar)
- *
- * Revision 1.16  2001/02/19 15:12:17  warmerda
- * fixed windowing problem with -srcwin
- */
+ ****************************************************************************/
 
 #include "cpl_vsi.h"
 #include "cpl_conv.h"
@@ -172,7 +34,7 @@
 #include "ogr_spatialref.h"
 #include "vrt/vrtdataset.h"
 
-CPL_CVSID("$Id: gdal_translate.cpp,v 1.33 2006/04/25 14:29:28 fwarmerdam Exp $");
+CPL_CVSID("$Id: gdal_translate.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 static int ArgIsNumeric( const char * );
 static void AttachMetadata( GDALDatasetH, char ** );
@@ -553,6 +415,13 @@ static int ProxyMain( int argc, char ** argv )
     if( nBandCount == 0 )
     {
         nBandCount = GDALGetRasterCount( hDataset );
+        if( nBandCount == 0 )
+        {
+            fprintf( stderr, "Input file has no bands, and so cannot be translated.\n" );
+            GDALDestroyDriverManager();
+            exit(1 );
+        }
+
         panBandList = (int *) CPLMalloc(sizeof(int)*nBandCount);
         for( i = 0; i < nBandCount; i++ )
             panBandList[i] = i+1;
