@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdaltindex.c,v 1.7 2005/04/06 13:05:19 fwarmerdam Exp $
+ * $Id: gdaltindex.c 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  MapServer
  * Purpose:  Commandline App to build tile index for raster files.
@@ -25,37 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: gdaltindex.c,v $
- * Revision 1.7  2005/04/06 13:05:19  fwarmerdam
- * Print out "creating new index" message to help unconfuse people who
- * see the error message about failing to open the index file.
- *
- * Revision 1.6  2004/04/02 17:33:22  warmerda
- * added GDALGeneralCmdLineProcessor()
- *
- * Revision 1.5  2003/12/02 16:54:18  warmerda
- * fixed include paths now that shapelib is gone
- *
- * Revision 1.4  2003/10/24 13:33:38  warmerda
- * Changed include path again, so it will work on unix and windows.
- *
- * Revision 1.3  2003/10/24 13:32:28  warmerda
- * Fixed include path to work with GNUmakefile.
- *
- * Revision 1.2  2001/07/18 05:05:12  warmerda
- * added CPL_CSVID
- *
- * Revision 1.1  2001/04/25 17:30:19  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogrsf_frmts/shape/shapefil.h"
 #include "gdal.h"
 
-CPL_CVSID("$Id: gdaltindex.c,v 1.7 2005/04/06 13:05:19 fwarmerdam Exp $");
+CPL_CVSID("$Id: gdaltindex.c 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                               Usage()                                */
