@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: multireadtest.cpp,v 1.4 2006/05/01 13:37:11 fwarmerdam Exp $
+ * $Id: multireadtest.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GDAL Utilities
  * Purpose:  Multithreading test application.
@@ -25,23 +25,14 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: multireadtest.cpp,v $
- * Revision 1.4  2006/05/01 13:37:11  fwarmerdam
- * Cleanup on exit to facility leak and corruption testing.
- *
- * Revision 1.3  2006/03/21 21:34:43  fwarmerdam
- * cleanup headers
- *
- */
+ ****************************************************************************/
 
 #include "gdal.h"
 #include "gdal_alg.h"
 #include "cpl_multiproc.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: multireadtest.cpp,v 1.4 2006/05/01 13:37:11 fwarmerdam Exp $");
+CPL_CVSID("$Id: multireadtest.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 static int nThreadCount = 4, nIterations = 1, bLockOnOpen = TRUE;
 static int nOpenIterations = 1;
@@ -194,7 +185,7 @@ static void WorkerFunc( void * )
 
             if( nMyChecksum != nChecksum )
             {
-                printf( "Checksum error in worker thread.\n" );
+                printf( "Checksum ERROR in worker thread!\n" );
                 break;
             }
         }
