@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: aigdataset.cpp,v 1.26 2005/11/24 20:25:32 fwarmerdam Exp $
+ * $Id: aigdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Arc/Info Binary Grid Driver
  * Purpose:  Implements GDAL interface to underlying library.
@@ -25,98 +25,14 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- *****************************************************************************
- *
- * $Log: aigdataset.cpp,v $
- * Revision 1.26  2005/11/24 20:25:32  fwarmerdam
- * Test for hdf.adf and w001001x.adf in ::Open() method, so we don't
- * have to suppress error messages for AIGOpen().  Added error checking
- * in the AIGReadBlockIndex() to recognise corrupted files.
- *
- * Revision 1.25  2005/09/16 20:38:19  fwarmerdam
- * added overview support
- *
- * Revision 1.24  2005/05/05 15:52:48  fwarmerdam
- * PAM Enabled
- *
- * Revision 1.23  2005/02/21 03:04:18  fwarmerdam
- * fixed for files in arcseconds (bug 775)
- *
- * Revision 1.22  2004/02/02 15:34:05  warmerda
- * Use CPLFormCIFilename() to get PRJ.ADF as well as prj.adf.
- * http://bugzilla.remotesensing.org/show_bug.cgi?id=480
- *
- * Revision 1.21  2003/07/08 15:35:22  warmerda
- * avoid warnings
- *
- * Revision 1.20  2003/04/09 13:45:12  warmerda
- * added limited colortable support
- *
- * Revision 1.19  2003/03/03 15:27:54  warmerda
- * The ULX and ULY values are edges, not pixel centers.  Fixed geotransform.
- *
- * Revision 1.18  2003/02/13 17:22:37  warmerda
- * updated email
- *
- * Revision 1.17  2002/11/05 03:29:29  warmerda
- * added GInt16 handling
- *
- * Revision 1.16  2002/11/05 03:19:29  warmerda
- * remap nodata to 255, and only use byte type if max < 255
- *
- * Revision 1.15  2002/09/04 06:50:36  warmerda
- * avoid static driver pointers
- *
- * Revision 1.14  2002/07/10 17:43:20  warmerda
- * Fixed error supression.
- *
- * Revision 1.13  2002/06/12 21:12:24  warmerda
- * update to metadata based driver info
- *
- * Revision 1.12  2002/02/21 15:38:32  warmerda
- * fixed nodata value for floats
- *
- * Revision 1.11  2001/11/11 23:50:59  warmerda
- * added required class keyword to friend declarations
- *
- * Revision 1.10  2001/09/11 13:46:25  warmerda
- * return nodata value
- *
- * Revision 1.9  2001/07/18 04:51:56  warmerda
- * added CPL_CVSID
- *
- * Revision 1.8  2001/03/13 19:39:24  warmerda
- * changed short name to AIG, added help link
- *
- * Revision 1.7  2000/11/09 06:22:51  warmerda
- * fixed geotransform, added limited projection support
- *
- * Revision 1.6  2000/04/20 14:05:16  warmerda
- * added support for provided min/max
- *
- * Revision 1.5  2000/02/28 16:32:19  warmerda
- * use SetBand method
- *
- * Revision 1.4  1999/08/13 03:27:50  warmerda
- * added support for GDT_Int32 and GDT_Float32 access
- *
- * Revision 1.3  1999/07/23 14:28:26  warmerda
- * supress errors in AIGOpen() since we don't know if it's really AIG yet
- *
- * Revision 1.2  1999/06/26 21:00:38  warmerda
- * Relax checking that filename is a directory ... AIGOpen() now handles.
- *
- * Revision 1.1  1999/02/04 22:15:44  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "gdal_pam.h"
 #include "cpl_string.h"
 #include "ogr_spatialref.h"
 #include "aigrid.h"
 
-CPL_CVSID("$Id: aigdataset.cpp,v 1.26 2005/11/24 20:25:32 fwarmerdam Exp $");
+CPL_CVSID("$Id: aigdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 CPL_C_START
 void	GDALRegister_AIGrid(void);
@@ -420,15 +336,30 @@ GDALDataset *AIGDataset::Open( GDALOpenInfo * poOpenInfo )
     
     osTestName.Printf( "%s/hdr.adf", osCoverName.c_str() );
     if( VSIStatL( osTestName, &sStatBuf ) != 0 )
-        return NULL;
+
+    {
+        osTestName.Printf( "%s/HDR.ADF", osCoverName.c_str() );
+        if( VSIStatL( osTestName, &sStatBuf ) != 0 )
+            return NULL;
+    }
 
     osTestName.Printf( "%s/w001001x.adf", osCoverName.c_str() );
     if( VSIStatL( osTestName, &sStatBuf ) != 0 )
-        return NULL;
+
+    {
+        osTestName.Printf( "%s/W001001X.ADF", osCoverName.c_str() );
+        if( VSIStatL( osTestName, &sStatBuf ) != 0 )
+            return NULL;
+    }
 
     osTestName.Printf( "%s/w001001.adf", osCoverName.c_str() );
     if( VSIStatL( osTestName, &sStatBuf ) != 0 )
-        return NULL;
+
+    {
+        osTestName.Printf( "%s/W001001.ADF", osCoverName.c_str() );
+        if( VSIStatL( osTestName, &sStatBuf ) != 0 )
+            return NULL;
+    }
     
 /* -------------------------------------------------------------------- */
 /*      Open the file.                                                  */
@@ -456,23 +387,47 @@ GDALDataset *AIGDataset::Open( GDALOpenInfo * poOpenInfo )
 /* -------------------------------------------------------------------- */
     int  iFile;
     char **papszFiles = CPLReadDir( psInfo->pszCoverName );
-
+    CPLString osClrFilename;
+    CPLString osCleanPath = CPLCleanTrailingSlash( psInfo->pszCoverName );
+  
+    // first check for any .clr in coverage dir.
     for( iFile = 0; papszFiles != NULL && papszFiles[iFile] != NULL; iFile++ )
     {
-        const char *pszClrFilename;
-
-        if( !EQUAL(CPLGetExtension(papszFiles[iFile]),"clr") )
+        if( !EQUAL(CPLGetExtension(papszFiles[iFile]),"clr") && !EQUAL(CPLGetExtension(papszFiles[iFile]),"CLR"))
             continue;
-
-        pszClrFilename = CPLFormFilename( psInfo->pszCoverName, 
-                                          papszFiles[iFile], NULL );
-
-        poDS->TranslateColorTable( pszClrFilename );
+      
+        osClrFilename = CPLFormFilename( psInfo->pszCoverName,
+                                         papszFiles[iFile], NULL );
         break;
     }
-
+  
     CSLDestroy( papszFiles );
+  
+    // Look in parent if we don't find a .clr in the coverage dir.
+    if( strlen(osClrFilename) == 0 )
+    {
+        osTestName.Printf( "%s/../%s.clr",
+                           psInfo->pszCoverName,
+                           CPLGetFilename( osCleanPath ) );
+      
+        if( VSIStatL( osTestName, &sStatBuf ) != 0 )
 
+	{
+            osTestName.Printf( "%s/../%s.CLR",
+                               psInfo->pszCoverName,
+                               CPLGetFilename( osCleanPath ) );
+      
+            if( !VSIStatL( osTestName, &sStatBuf ) )
+                osClrFilename = osTestName;
+        }
+        else
+            osClrFilename = osTestName;
+    }
+    
+  
+    if( strlen(osClrFilename) > 0 )
+        poDS->TranslateColorTable( osClrFilename );
+  
 /* -------------------------------------------------------------------- */
 /*      Establish raster info.                                          */
 /* -------------------------------------------------------------------- */
