@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: airsardataset.cpp,v 1.6 2005/05/05 15:52:48 fwarmerdam Exp $
+ * $Id: airsardataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  AirSAR Reader
  * Purpose:  Implements read support for AirSAR Polarimetric data.
@@ -25,35 +25,14 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- * 
- * $Log: airsardataset.cpp,v $
- * Revision 1.6  2005/05/05 15:52:48  fwarmerdam
- * PAM Enabled
- *
- * Revision 1.5  2004/11/11 00:16:01  gwalter
- * Polarmetric->Polarimetric.
- *
- * Revision 1.4  2004/10/12 15:42:25  fwarmerdam
- * Change all bands to be complex so that overviews will build properly
- *
- * Revision 1.3  2004/10/08 12:22:09  fwarmerdam
- * Cast bytes passed to fabs(): Martin Daly
- *
- * Revision 1.2  2004/10/05 18:25:45  fwarmerdam
- * Added help pointer.
- *
- * Revision 1.1  2004/10/05 18:12:26  fwarmerdam
- * New
- *
- */
+ ****************************************************************************/
 
 #include "gdal_pam.h"
 #include "cpl_string.h"
 #include "cpl_conv.h"
 #include "cpl_vsi.h"
 
-CPL_CVSID("$Id: airsardataset.cpp,v 1.6 2005/05/05 15:52:48 fwarmerdam Exp $");
+CPL_CVSID("$Id: airsardataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 CPL_C_START
 void	GDALRegister_AirSAR(void);
