@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: bmpdataset.cpp,v 1.40 2006/03/18 18:43:03 dron Exp $
+ * $Id: bmpdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Microsoft Windows Bitmap
  * Purpose:  Read/write MS Windows Device Independent Bitmap (DIB) files
@@ -26,111 +26,20 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: bmpdataset.cpp,v $
- * Revision 1.40  2006/03/18 18:43:03  dron
- * Fixed absolute mode decoding of RLE comressed images.
- *
- * Revision 1.39  2006/03/02 12:12:15  dron
- * Avoid warnings.
- *
- * Revision 1.38  2006/02/22 01:37:57  fwarmerdam
- * added support for 32bit images with bitfields compression (pgao)
- *
- * Revision 1.37  2005/10/31 13:03:42  dron
- * Check for integer overflow conditions when calculating nScanSize.
- *
- * Revision 1.36  2005/10/11 23:34:02  fwarmerdam
- * fixed up handling of pszFilename
- *
- * Revision 1.35  2005/07/05 18:00:10  dron
- * Add support for reading external overviews.
- *
- * Revision 1.34  2005/05/17 15:12:24  fwarmerdam
- * Cleanup out residual flushcache and projections support for
- * better pam support.
- *
- * Revision 1.33  2005/05/05 14:01:36  fwarmerdam
- * PAM Enable
- *
- * Revision 1.32  2004/09/28 14:18:06  fwarmerdam
- * A few more additions to improve error handling.  The "create" write
- * error checks don't work (at least on Linux) because of the buffering.
- *
- * Revision 1.31  2004/09/28 14:05:21  fwarmerdam
- * Try to strategically check the success of VSIFWriteL() calls in
- * the Create() method as per:
- * http://bugzilla.remotesensing.org/show_bug.cgi?id=619
- *
- * Revision 1.30  2004/06/08 15:53:08  dron
- * Even more fixes.
- *
- * Revision 1.29  2004/06/08 13:38:16  dron
- * Few minor fixes.
- *
- * Revision 1.28  2004/01/06 10:56:54  dron
- * Few optimizations in IReadBlock().
- *
- * Revision 1.27  2003/11/07 13:12:38  dron
- * Handle 32-bit BMPs properly.
- *
- * Revision 1.26  2003/10/24 20:31:53  warmerda
- * Added extension metadata.
- *
- * Revision 1.25  2003/09/22 17:17:50  warmerda
- * added support for .bpw and .bmpw worldfiles
- *
- * Revision 1.24  2003/09/11 19:55:15  warmerda
- * avoid warnings
- *
- * Revision 1.23  2003/06/17 17:59:03  dron
- * Do not close GDALOpenInfo::fp handler before reopening.
- *
- * Revision 1.22  2003/05/30 05:26:56  dron
- * Fixed problem with scanline numbering.
- *
- * Revision 1.21  2003/05/29 14:58:01  dron
- * Workaround for files with extra bytes at the end of data stream.
- *
- * Revision 1.20  2003/05/20 08:59:10  dron
- * BMPDataset::IRasterIO() method added.
- *
- * Revision 1.19  2003/05/01 17:40:43  dron
- * Report colour interpretation GCI_PaletteIndex for 1-bit images.
- *
- * Revision 1.18  2003/03/27 15:51:06  dron
- * Improvements in update state handling in IReadBlock().
- *
- * Revision 1.17  2003/03/27 13:24:53  dron
- * Fixes for large file support.
- *
- * Revision 1.16  2003/02/15 14:23:09  dron
- * Fix in GetGeoTransform().
- *
- * Revision 1.15  2003/02/03 18:40:15  dron
- * Type of input data checked in Create() method now.
- *
- * Revision 1.14  2002/12/15 15:24:41  dron
- * Typos fixed.
- *
- * Revision 1.13  2002/12/15 15:13:33  dron
- * BMP structures extended.
- *
- * Revision 1.12  2002/12/13 14:15:50  dron
- * IWriteBlock() fixed, CreateCopy() removed, added RLE4 decoding and OS/2 BMP
- * support.
- */
+ ****************************************************************************/
 
 #include "gdal_pam.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: bmpdataset.cpp,v 1.40 2006/03/18 18:43:03 dron Exp $");
+CPL_CVSID("$Id: bmpdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 CPL_C_START
 void    GDALRegister_BMP(void);
 CPL_C_END
 
+// Enable if you want to see lots of BMP debugging output.
+// #define BMP_DEBUG    
+
 enum BMPType
 {
     BMPT_WIN4,      // BMP used in Windows 3.0/NT 3.51/95
@@ -268,6 +177,31 @@ typedef struct
     GByte       bReserved;      // Must be 0
 } BMPColorEntry;
 
+/*****************************************************************/
+
+int countonbits(GUInt32 dw)
+{
+    int r = 0;
+    for(int x = 0; x < 32; x++)
+    {
+        if((dw & (1 << x)) != 0)
+            r++;
+    }
+    return r;
+}
+
+
+int findfirstonbit(GUInt32 n)
+{
+    for(int x = 0; x < 32; x++)
+    {
+        if((n & (1 << x)) != 0)
+            return x;
+    }
+    return -1;
+}
+
+
 /************************************************************************/
 /* ==================================================================== */
 /*                              BMPDataset                              */
@@ -354,7 +288,7 @@ BMPRasterBand::BMPRasterBand( BMPDataset *poDS, int nBand )
         ((poDS->GetRasterXSize() * poDS->sInfoHeader.iBitCount + 31) & ~31) / 8;
     nBlockYSize = 1;
 
-#ifdef DEBUG
+#ifdef BMP_DEBUG
     CPLDebug( "BMP",
               "Band %d: set nBlockXSize=%d, nBlockYSize=%d, nScanSize=%d",
               nBand, nBlockXSize, nBlockYSize, nScanSize );
@@ -392,7 +326,7 @@ CPLErr BMPRasterBand::IReadBlock( int nBlockXOff, int nBlockYOff,
     if ( VSIFSeekL( poGDS->fp, iScanOffset, SEEK_SET ) < 0 )
     {
         // XXX: We will not report error here, because file just may be
-	// in update state and data for this block will be available later
+    // in update state and data for this block will be available later
         if( poGDS->eAccess == GA_Update )
         {
             memset( pImage, 0, nBlockXSize );
@@ -444,23 +378,80 @@ CPLErr BMPRasterBand::IReadBlock( int nBlockXOff, int nBlockYOff,
     }
     else if ( poGDS->sInfoHeader.iBitCount == 16 )
     {
+        // rcg, oct 7/06: Byteswap if necessary, use int16
+        // references to file pixels, expand samples to
+        // 8-bit, support BMPC_BITFIELDS channel mask indicators,
+        // and generalize band handling.
+
+        GUInt16* pScan16 = (GUInt16*)pabyScan;
+#ifdef CPL_MSB
+        GDALSwapWords( pScan16, sizeof(GUInt16), nBlockXSize, 0);
+#endif
+
+        // todo: make these band members and precompute.
+        int mask[3], shift[3], size[3];
+        float fTo8bit[3];
+
+        if(poGDS->sInfoHeader.iCompression == BMPC_RGB)
+        {
+            mask[0] = 0x7c00;
+            mask[1] = 0x03e0;
+            mask[2] = 0x001f;
+        }
+        else if(poGDS->sInfoHeader.iCompression == BMPC_BITFIELDS)
+        {
+            mask[0] = poGDS->sInfoHeader.iRedMask;
+            mask[1] = poGDS->sInfoHeader.iGreenMask;
+            mask[2] = poGDS->sInfoHeader.iBlueMask;
+        }
+        else
+        {
+            CPLError( CE_Failure, CPLE_FileIO,
+                      "Unknown 16-bit compression %d.",
+                      poGDS->sInfoHeader.iCompression);
+            return CE_Failure;
+        }
+
+        for(i = 0; i < 3; i++)
+        {
+            shift[i] = findfirstonbit(mask[i]);
+            size[i]  = countonbits(mask[i]);
+            if(size[i] > 14 || size[i] == 0)
+            {
+                CPLError( CE_Failure, CPLE_FileIO,
+                          "Bad 16-bit channel mask %8x.",
+                          mask[i]);
+                return CE_Failure;
+            }
+            fTo8bit[i] = 255.0f / ((1 << size[i])-1);
+        }
+
         for ( i = 0; i < nBlockXSize; i++ )
         {
+            ((GByte *) pImage)[i] = (GByte)
+                (0.5f + fTo8bit[nBand-1] * 
+                    ((pScan16[i] & mask[nBand-1]) >> shift[nBand-1]));
+#if 0
+        // original code    
             switch ( nBand )
             {
-                case 1:
+                case 1: // Red
                 ((GByte *) pImage)[i] = pabyScan[i + 1] & 0x1F;
                 break;
-                case 2:
-                ((GByte *) pImage)[i] = ((pabyScan[i] & 0x03) << 3) |
-                                        ((pabyScan[i + 1] & 0xE0) >> 5);
+
+                case 2: // Green
+                ((GByte *) pImage)[i] = 
+                    ((pabyScan[i] & 0x03) << 3) |
+                    ((pabyScan[i + 1] & 0xE0) >> 5);
                 break;
-                case 3:
+
+                case 3: // Blue
                 ((GByte *) pImage)[i] = (pabyScan[i] & 0x7c) >> 2;
                 break;
                 default:
                 break;
             }
+#endif // 0
         }
     }
     else if ( poGDS->sInfoHeader.iBitCount == 4 )
@@ -812,6 +803,11 @@ BMPComprRasterBand::BMPComprRasterBand( BMPDataset *poDS, int nBand )
             }
         }
     }
+    // rcg, release compressed buffer here.
+    if ( pabyComprBuf )
+        CPLFree( pabyComprBuf );
+    pabyComprBuf = NULL;
+
 }
 
 /************************************************************************/
@@ -985,7 +981,7 @@ GDALDataset *BMPDataset::Open( GDALOpenInfo * poOpenInfo )
 #endif
     poDS->sFileHeader.iSize = sStat.st_size;
 
-#ifdef DEBUG
+#ifdef BMP_DEBUG
     CPLDebug( "BMP", "File size %d bytes.", poDS->sFileHeader.iSize );
     CPLDebug( "BMP", "Image offset 0x%x bytes from file start.",
               poDS->sFileHeader.iOffBits );
@@ -1024,6 +1020,17 @@ GDALDataset *BMPDataset::Open( GDALOpenInfo * poOpenInfo )
         VSIFReadL( &poDS->sInfoHeader.iYPelsPerMeter, 1, 4, poDS->fp );
         VSIFReadL( &poDS->sInfoHeader.iClrUsed, 1, 4, poDS->fp );
         VSIFReadL( &poDS->sInfoHeader.iClrImportant, 1, 4, poDS->fp );
+
+        // rcg, read win4/5 fields. If we're reading a
+        // legacy header that ends at iClrImportant, it turns 
+        // out that the three DWORD color table entries used 
+        // by the channel masks start here anyway.
+        if(poDS->sInfoHeader.iCompression == BMPC_BITFIELDS)
+        {
+            VSIFReadL( &poDS->sInfoHeader.iRedMask, 1, 4, poDS->fp );
+            VSIFReadL( &poDS->sInfoHeader.iGreenMask, 1, 4, poDS->fp );
+            VSIFReadL( &poDS->sInfoHeader.iBlueMask, 1, 4, poDS->fp );
+        }
 #ifdef CPL_MSB
         CPL_SWAP32PTR( &poDS->sInfoHeader.iWidth );
         CPL_SWAP32PTR( &poDS->sInfoHeader.iHeight );
@@ -1035,6 +1042,10 @@ GDALDataset *BMPDataset::Open( GDALOpenInfo * poOpenInfo )
         CPL_SWAP32PTR( &poDS->sInfoHeader.iYPelsPerMeter );
         CPL_SWAP32PTR( &poDS->sInfoHeader.iClrUsed );
         CPL_SWAP32PTR( &poDS->sInfoHeader.iClrImportant );
+        // rcg, swap win4/5 fields.
+        CPL_SWAP32PTR( &poDS->sInfoHeader.iRedMask );
+        CPL_SWAP32PTR( &poDS->sInfoHeader.iGreenMask );
+        CPL_SWAP32PTR( &poDS->sInfoHeader.iBlueMask );
 #endif
         poDS->nColorElems = 4;
     }
@@ -1071,7 +1082,7 @@ GDALDataset *BMPDataset::Open( GDALOpenInfo * poOpenInfo )
         return NULL;
     }
 
-#ifdef DEBUG
+#ifdef BMP_DEBUG
     CPLDebug( "BMP", "Windows Device Independent Bitmap parameters:\n"
               " info header size: %d bytes\n"
               " width: %d\n height: %d\n planes: %d\n bpp: %d\n"
