@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ceosopen.c,v 1.5 2006/04/04 00:34:40 fwarmerdam Exp $
+ * $Id: ceosopen.c 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  CEOS Translator
  * Purpose:  Implementation of non-GDAL dependent CEOS support.
@@ -25,30 +25,11 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ceosopen.c,v $
- * Revision 1.5  2006/04/04 00:34:40  fwarmerdam
- * updated contact info
- *
- * Revision 1.4  2003/07/08 15:34:04  warmerda
- * avoid warnings
- *
- * Revision 1.3  2001/10/29 17:48:34  warmerda
- * Change sequence number check to a warning since the sequence numbers are
- * apparently screwy in some otherwise interesting ESA/CEOS Landsat 7 files.
- *
- * Revision 1.2  2001/07/18 04:51:56  warmerda
- * added CPL_CVSID
- *
- * Revision 1.1  1999/05/05 17:32:38  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ceosopen.h"
 
-CPL_CVSID("$Id: ceosopen.c,v 1.5 2006/04/04 00:34:40 fwarmerdam Exp $");
+CPL_CVSID("$Id: ceosopen.c 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                            CEOSScanInt()                             */
