@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ecwdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: ecwdataset.cpp 12463 2007-10-17 19:13:56Z warmerdam $
  *
  * Project:  GDAL 
  * Purpose:  ECW (ERMapper Wavelet Compression Format) Driver
@@ -38,7 +38,7 @@
 #include "ogr_api.h"
 #include "ogr_geometry.h"
 
-CPL_CVSID("$Id: ecwdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: ecwdataset.cpp 12463 2007-10-17 19:13:56Z warmerdam $");
 
 #ifdef FRMT_ecw
 
@@ -926,6 +926,7 @@ CPLErr ECWDataset::IRasterIO( GDALRWFlag eRWFlag,
                                             (void **) papabyBIL );
         if( eRStatus != NCSECW_READ_OK )
         {
+            CPLFree( papabyBIL );
             CPLFree( pabyBILScanline );
             CPLError( CE_Failure, CPLE_AppDefined,
                       "NCScbmReadViewLineBIL failed." );
@@ -943,6 +944,9 @@ CPLErr ECWDataset::IRasterIO( GDALRWFlag eRWFlag,
         }
     }
 
+    CPLFree( pabyBILScanline );
+    CPLFree( papabyBIL );
+
     return CE_None;
 }
 
