@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: fitdataset.cpp,v 1.23 2006/02/17 17:37:41 fwarmerdam Exp $
+ * $Id: fitdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  FIT Driver
  * Purpose:  Implement FIT Support - not using the SGI iflFIT library.
@@ -25,96 +25,14 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- * 
- * $Log: fitdataset.cpp,v $
- * Revision 1.23  2006/02/17 17:37:41  fwarmerdam
- * Removed class qualifier on constructor of FITRasterBand.
- *
- * Revision 1.22  2005/07/05 17:10:52  fwarmerdam
- * give swap funcs unique names
- *
- * Revision 1.21  2005/05/05 14:02:57  fwarmerdam
- * PAM Enable
- *
- * Revision 1.20  2004/03/22 23:45:41  aubin
- * wrap endian swapping functions in namespace to limit scope
- *
- * Revision 1.19  2004/02/25 19:04:19  warmerda
- * Modified a few calls in the create code to use VSI*L API as well.
- * Untested as of yet.
- *
- * Revision 1.18  2004/02/24 23:50:14  aubin
- * replace previous bad checkin due to windows vs. unix cr/lf differences
- *
- * Revision 1.17  2004/02/24 23:16:11  aubin
- * Fixed Win32 file I/O.  Re-open file with VSIFOpenL(), 
- * and use VSIFReadL() instead of fread().  
- * Added some memory guard objects to catch a few memory leaks.
- *
- * Revision 1.16  2004/02/24 22:00:50  warmerda
- * test commit
- *
- * Revision 1.15  2002/11/23 18:54:17  warmerda
- * added CREATIONDATATYPES metadata for drivers
- *
- * Revision 1.14  2002/09/04 06:50:37  warmerda
- * avoid static driver pointers
- *
- * Revision 1.13  2002/06/15 00:07:23  aubin
- * mods to enable 64bit file i/o
- *
- * Revision 1.12  2002/06/12 21:12:25  warmerda
- * update to metadata based driver info
- *
- * Revision 1.11  2001/11/11 23:50:59  warmerda
- * added required class keyword to friend declarations
- *
- * Revision 1.10  2001/07/25 17:21:56  nemec
- * Fixed another bug with partial tiles (relating to different image origins)
- * Added more debugging info for simpler bug reports
- *
- * Revision 1.9  2001/07/25 01:25:47  nemec
- * Changes with values used for padding - now all zeros but without overhead of
- * zeroing memory all the time.
- *
- * Revision 1.8  2001/07/18 04:51:56  warmerda
- * added CPL_CVSID
- *
- * Revision 1.7  2001/07/12 22:08:13  nemec
- * Change check if 64-bit seek is needed.  Should work on all systems (no longer
- * comparing to a 64 bit constant).
- * Also improved calculation to account for files whose dimensions aren't exact
- * multiples of the page size.
- *
- * Revision 1.6  2001/07/12 18:59:36  warmerda
- * Avoid strings.h and bzero() -- not on NT.  Use memset() instead.
- * Some odd problem with initializing i in a for loop in a case statement avoided.
- * Don't use LL suffix to indicate long long constants ... doesn't work on NT.
- *
- * Revision 1.5  2001/07/10 02:12:40  nemec
- * Fixed writing of files whose dimensions aren't exact multiples of the page size
- *
- * Revision 1.4  2001/07/07 01:03:35  nemec
- * Fixed math on check if 64 bit seek is needed
- *
- * Revision 1.3  2001/07/06 22:02:55  nemec
- * Fixed some bugs related to large files (fseek64 when available, trap otherwise)
- * Better support for different file layouts (upper left, lower left, etc.)
- * Fixed files with dimensinos that aren't exact multiples of the page size
- *
- * Revision 1.2  2001/07/06 18:46:25  nemec
- * Cleanup files - improve Windows build, make proper copyright notice
- *
- *
- */
+ ****************************************************************************/
 
 #include "fit.h"
 #include "gstEndian.h"
 #include "gdal_pam.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: fitdataset.cpp,v 1.23 2006/02/17 17:37:41 fwarmerdam Exp $");
+CPL_CVSID("$Id: fitdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 CPL_C_START
  
@@ -877,6 +795,8 @@ FITDataset::~FITDataset()
     FlushCache();
     if (info)
         delete(info);
+    if(fp)
+        VSIFCloseL(fp);
 }
 
 // simple guard object to delete memory 
