@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdalallregister.cpp,v 1.87 2006/04/20 13:51:51 fwarmerdam Exp $
+ * $Id: gdalallregister.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GDAL Core
  * Purpose:  Implementation of GDALAllRegister(), primary format registration.
@@ -25,92 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: gdalallregister.cpp,v $
- * Revision 1.87  2006/04/20 13:51:51  fwarmerdam
- * added terragen support
- *
- * Revision 1.86  2006/04/03 23:25:10  fwarmerdam
- * Fixup header formatting.
- *
- * Revision 1.85  2006/03/31 02:59:57  fwarmerdam
- * added idrisi
- *
- * Revision 1.84  2006/02/07 21:44:43  fwarmerdam
- * DIPX->DIPEx
- *
- * Revision 1.83  2006/02/01 17:22:19  fwarmerdam
- * added DIPX driver
- *
- * Revision 1.82  2005/12/20 16:16:57  fwarmerdam
- * added sgi format
- *
- * Revision 1.81  2005/10/20 13:46:07  fwarmerdam
- * added Leveller
- *
- * Revision 1.80  2005/08/17 15:34:23  fwarmerdam
- * added RIK driver
- *
- * Revision 1.79  2005/07/12 16:56:56  denad21
- * added hdf5 support
- *
- * Revision 1.78  2005/07/07 23:35:44  fwarmerdam
- * added msgn support
- *
- * Revision 1.77  2005/05/19 20:41:14  dron
- * Added RMF format.
- *
- * Revision 1.76  2005/04/04 15:25:26  fwarmerdam
- * GDALAllRegister() now CPL_STDCALL
- *
- * Revision 1.75  2005/01/15 07:46:53  fwarmerdam
- * added GDALRegister_JP2ECW
- *
- * Revision 1.74  2005/01/06 20:27:35  fwarmerdam
- * added NDF driver
- *
- * Revision 1.73  2004/12/26 16:17:31  fwarmerdam
- * added ida format
- *
- * Revision 1.72  2004/12/09 16:37:18  fwarmerdam
- * re-enable ILWIS
- *
- * Revision 1.71  2004/12/02 15:58:58  fwarmerdam
- * temporarily disable ilwis driver
- *
- * Revision 1.70  2004/11/30 17:02:37  lichun
- * Added ILWIS driver support
- *
- * Revision 1.69  2004/10/22 14:15:23  fwarmerdam
- * Added PCRaster support.
- *
- * Revision 1.68  2004/10/21 20:04:46  fwarmerdam
- * added Register_RS2
- *
- * Revision 1.67  2004/10/16 14:58:01  fwarmerdam
- * added GMT
- *
- * Revision 1.66  2004/09/16 18:24:13  fwarmerdam
- * added airsar
- *
- * Revision 1.65  2004/09/03 19:06:50  warmerda
- * added CPG driver
- *
- * Revision 1.64  2004/05/26 17:45:39  warmerda
- * added LAN format
- *
- * Revision 1.63  2004/04/05 21:30:44  warmerda
- * moved ECW down so other jpeg2000 drivers used in preference
- *
- * Revision 1.62  2004/01/07 20:06:34  warmerda
- * Added netcdf support
- */
+ ****************************************************************************/
 
 #include "gdal_priv.h"
 #include "gdal_frmts.h"
 
-CPL_CVSID("$Id: gdalallregister.cpp,v 1.87 2006/04/20 13:51:51 fwarmerdam Exp $");
+CPL_CVSID("$Id: gdalallregister.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 #ifdef notdef
 // we may have a use for this some day
@@ -265,10 +185,6 @@ void CPL_STDCALL GDALAllRegister()
     GDALRegister_ILWIS();
 #endif
 
-#ifdef FRMT_rik
-    GDALRegister_RIK();
-#endif
-
 #ifdef FRMT_sgi
     GDALRegister_SGI();
 #endif
@@ -310,6 +226,7 @@ void CPL_STDCALL GDALAllRegister()
     GDALRegister_NDF();
     GDALRegister_DIPEx();
     GDALRegister_ISIS2();
+    GDALRegister_PDS();
 #endif
 
 #ifdef FRMT_jp2kak
@@ -345,6 +262,10 @@ void CPL_STDCALL GDALAllRegister()
     GDALRegister_RMF();
 #endif
 
+#ifdef FRMT_wcs
+    GDALRegister_WCS();
+#endif
+
 #ifdef FRMT_msgn
     GDALRegister_MSGN();
 #endif
@@ -357,6 +278,10 @@ void CPL_STDCALL GDALAllRegister()
 /*      Our test for the following is weak or expensive so we try       */
 /*      them last.                                                      */
 /* -------------------------------------------------------------------- */
+#ifdef FRMT_rik
+    GDALRegister_RIK();
+#endif
+
 #ifdef FRMT_usgsdem
     GDALRegister_USGSDEM();
 #endif
