@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gifdataset.cpp,v 1.25 2005/10/11 18:59:35 fwarmerdam Exp $
+ * $Id: gifdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GIF Driver
  * Purpose:  Implement GDAL GIF Support using libungif code.  
@@ -25,94 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- * 
- * $Log: gifdataset.cpp,v $
- * Revision 1.25  2005/10/11 18:59:35  fwarmerdam
- * remove CPL_DLL attribute on EGifOpen
- *
- * Revision 1.24  2005/10/07 20:58:43  fwarmerdam
- * Fall through to pam for getgeotransform if we don't have a world file.
- * Use VSI*L virtual file io layer allowing memory buffer access.
- *
- * Revision 1.23  2005/08/04 18:44:33  fwarmerdam
- * Report background as metadata rather than NODATA.  It was causing too
- * many problems.
- *
- * Revision 1.22  2005/05/05 14:05:03  fwarmerdam
- * PAM Enable
- *
- * Revision 1.21  2004/08/20 17:33:06  warmerda
- * Support overviews.
- *
- * Revision 1.20  2003/12/09 16:47:17  warmerda
- * Make sure GetGeoTransform() still initializes the geotransform array.
- *
- * Revision 1.19  2003/11/07 18:33:10  warmerda
- * additional transparent hack for AUG
- *
- * Revision 1.18  2003/10/15 14:02:07  warmerda
- * treat background color as NODATA
- *
- * Revision 1.17  2003/07/08 21:14:16  warmerda
- * avoid warnings
- *
- * Revision 1.16  2003/03/13 16:39:53  warmerda
- * Added support for .gfw.
- *
- * Revision 1.15  2002/11/26 02:36:38  warmerda
- * Use first saved image to set the width and height.  One sample image
- * (wmt.cgi.gif) has a disagreement between this value and the "screen" size.
- * See http://mapserver.gis.umn.edu/bugs/show_bug.cgi?id=235
- *
- * Revision 1.14  2002/11/23 18:54:17  warmerda
- * added CREATIONDATATYPES metadata for drivers
- *
- * Revision 1.13  2002/10/28 19:25:00  warmerda
- * Ensure that MakeMapObject is called with sizes that are powers of 2.
- *
- * Revision 1.12  2002/09/04 06:50:37  warmerda
- * avoid static driver pointers
- *
- * Revision 1.11  2002/07/13 04:16:39  warmerda
- * added WORLDFILE support
- *
- * Revision 1.10  2002/06/12 21:12:25  warmerda
- * update to metadata based driver info
- *
- * Revision 1.9  2001/11/11 23:50:59  warmerda
- * added required class keyword to friend declarations
- *
- * Revision 1.8  2001/08/22 20:53:01  warmerda
- * added support for reading transparent value
- *
- * Revision 1.7  2001/08/22 17:12:49  warmerda
- * added world file support
- *
- * Revision 1.6  2001/07/18 04:51:56  warmerda
- * added CPL_CVSID
- *
- * Revision 1.5  2001/01/10 15:37:58  warmerda
- * Fixed help topic name.
- *
- * Revision 1.4  2001/01/10 15:36:44  warmerda
- * implement interlacing support
- *
- * Revision 1.3  2001/01/10 05:32:17  warmerda
- * Added GIFCreateCopy() implementation.
- *
- * Revision 1.2  2001/01/10 05:00:32  warmerda
- * Only check against GIF87/GIF89, not GIF87a/GIF89a.
- *
- * Revision 1.1  2001/01/10 04:40:15  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "gdal_pam.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: gifdataset.cpp,v 1.25 2005/10/11 18:59:35 fwarmerdam Exp $");
+CPL_CVSID("$Id: gifdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 CPL_C_START
 #include "gif_lib.h"
