@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: epsg_to_wkt.cpp,v 1.4 2006/04/05 00:06:14 fwarmerdam Exp $
+ * $Id: epsg_to_wkt.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  EPSG To WKT Translator
  * Purpose:  Mainline for EPSG to WKT Translator
@@ -25,22 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: epsg_to_wkt.cpp,v $
- * Revision 1.4  2006/04/05 00:06:14  fwarmerdam
- * fix contact info
- *
- * Revision 1.3  2001/07/18 04:51:56  warmerda
- * added CPL_CVSID
- *
- * Revision 1.2  1999/09/10 13:42:30  warmerda
- * converted to adams new format, added comparitors
- *
- * Revision 1.1  1999/09/09 13:55:43  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -52,7 +37,7 @@
 #include "cpl_csv.h"
 #include "ogr_spatialref.h"
 
-CPL_CVSID("$Id: epsg_to_wkt.cpp,v 1.4 2006/04/05 00:06:14 fwarmerdam Exp $");
+CPL_CVSID("$Id: epsg_to_wkt.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 static char *PCSToOGISDefn( int, int );
 static void ProcessAllPCSCodes();
