@@ -1,4 +1,4 @@
-/* $Id: tif_jpeg.c,v 1.50 2006/10/12 18:02:52 dron Exp $ */
+/* $Id: tif_jpeg.c,v 1.50.2.2 2007/04/07 14:58:30 dron Exp $ */
 
 /*
  * Copyright (c) 1994-1997 Sam Leffler
@@ -1864,8 +1864,18 @@ static int JPEGInitializeLibJPEG( TIFF * tif, int force_encode, int force_decode
     int     data_is_empty = TRUE;
     int     decompress;
 
+
     if(sp->cinfo_initialized)
-        return 1;
+    {
+        if( force_encode && sp->cinfo.comm.is_decompressor )
+            TIFFjpeg_destroy( sp );
+        else if( force_decode && !sp->cinfo.comm.is_decompressor )
+            TIFFjpeg_destroy( sp );
+        else
+            return 1;
+
+        sp->cinfo_initialized = 0;
+    }
 
     /*
      * Do we have tile data already?  Make sure we initialize the
@@ -1920,6 +1930,16 @@ TIFFInitJPEG(TIFF* tif, int scheme)
 
 	assert(scheme == COMPRESSION_JPEG);
 
+	/*
+	 * Merge codec-specific tag information.
+	 */
+	if (!_TIFFMergeFieldInfo(tif, jpegFieldInfo, N(jpegFieldInfo))) {
+		TIFFErrorExt(tif->tif_clientdata,
+			     "TIFFInitJPEG",
+			     "Merging JPEG codec-specific tags failed");
+		return 0;
+	}
+
 	/*
 	 * Allocate state block so tag methods have storage to record values.
 	 */
@@ -1928,18 +1948,16 @@ TIFFInitJPEG(TIFF* tif, int scheme)
 	if (tif->tif_data == NULL) {
 		TIFFErrorExt(tif->tif_clientdata,
 			     "TIFFInitJPEG", "No space for JPEG state block");
-		return (0);
+		return 0;
 	}
-        _TIFFmemset( tif->tif_data, 0, sizeof(JPEGState));
+        _TIFFmemset(tif->tif_data, 0, sizeof(JPEGState));
 
 	sp = JState(tif);
 	sp->tif = tif;				/* back link */
 
 	/*
-	 * Merge codec-specific tag information and override parent get/set
-	 * field methods.
+	 * Override parent get/set field methods.
 	 */
-	_TIFFMergeFieldInfo(tif, jpegFieldInfo, N(jpegFieldInfo));
 	sp->vgetparent = tif->tif_tagmethods.vgetfield;
 	tif->tif_tagmethods.vgetfield = JPEGVGetField; /* hook for codec tags */
 	sp->vsetparent = tif->tif_tagmethods.vsetfield;
