@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gxf_ogcwkt.c,v 1.4 2006/04/04 17:25:27 fwarmerdam Exp $
+ * $Id: gxf_ogcwkt.c 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GXF Reader
  * Purpose:  Handle GXF to OGC WKT projection transformation.
@@ -25,26 +25,11 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: gxf_ogcwkt.c,v $
- * Revision 1.4  2006/04/04 17:25:27  fwarmerdam
- * updated contact info
- *
- * Revision 1.3  2004/04/07 02:08:11  warmerda
- * SPHEROID belongs inside DATUM
- *
- * Revision 1.2  2001/07/18 04:51:57  warmerda
- * added CPL_CVSID
- *
- * Revision 1.1  1999/10/29 17:26:48  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "gxfopen.h"
 
-CPL_CVSID("$Id: gxf_ogcwkt.c,v 1.4 2006/04/04 17:25:27 fwarmerdam Exp $");
+CPL_CVSID("$Id: gxf_ogcwkt.c 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /* -------------------------------------------------------------------- */
 /* the following #defines come from ogr_spatialref.h in the GDAL/OGR	*/
