@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gxf_proj4.c,v 1.4 2006/04/04 17:25:27 fwarmerdam Exp $
+ * $Id: gxf_proj4.c 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GXF Reader
  * Purpose:  Handle GXF to PROJ.4 projection transformation.
@@ -26,26 +26,11 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: gxf_proj4.c,v $
- * Revision 1.4  2006/04/04 17:25:27  fwarmerdam
- * updated contact info
- *
- * Revision 1.3  2001/07/18 04:51:57  warmerda
- * added CPL_CVSID
- *
- * Revision 1.2  1999/10/29 17:30:03  warmerda
- * added documentation
- *
- * Revision 1.1  1999/10/27 20:23:05  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "gxfopen.h"
 
-CPL_CVSID("$Id: gxf_proj4.c,v 1.4 2006/04/04 17:25:27 fwarmerdam Exp $");
+CPL_CVSID("$Id: gxf_proj4.c 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                     GXFGetMapProjectionAsPROJ4()                     */
