@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gctp_wrap.c,v 1.3 2006/04/20 13:45:13 dron Exp $
+ * $Id: gctp_wrap.c 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Hierarchical Data Format Release 4 (HDF4)
  * Purpose:  This is the wrapper code to use OGR Coordinate Transformation
@@ -26,17 +26,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- * 
- * $Log: gctp_wrap.c,v $
- * Revision 1.3  2006/04/20 13:45:13  dron
- * Definitions for for_init() and inv_init() changed to be fully compatible
- * with HDF-EOS code.
- *
- * Revision 1.2  2006/04/06 14:22:02  dron
- * Added explicit copyright statement.
- *
- */
+ ****************************************************************************/
 
 #include "ogr_srs_api.h"
 #include "mfhdf.h"
@@ -92,8 +82,6 @@ int32 (*for_trans[])(double, double, double *, double *))
     pdfOutparm = outparm;
     iOutdatum = outdatum;
     for_trans[iOutsys] = osr_for;
-
-    return 0;
 }
 
 int32 osr_inv(
@@ -143,7 +131,5 @@ int32 (*inv_trans[])(double, double, double*, double*))
     pdfInparm = inparm; 
     iIndatum = indatum;
     inv_trans[insys] = osr_inv;
-
-    return 0;
 }
 
