@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: hdf5imagedataset.cpp,v 1.15 2006/01/21 17:51:50 dnadeau Exp $
+ * $Id: hdf5imagedataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Hierarchical Data Format Release 5 (HDF5)
  * Purpose:  Read subdatasets of HDF5 file.
@@ -25,49 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- * 
- * $Log: hdf5imagedataset.cpp,v $
- * Revision 1.15  2006/01/21 17:51:50  dnadeau
- * added find object by path where space are changed with underscore.  Fix up pszProjections problem.
- *
- * Revision 1.14  2005/10/12 20:16:10  fwarmerdam
- * use SetMetadata()
- *
- * Revision 1.13  2005/09/13 02:34:58  fwarmerdam
- * Cleanup more carefully in ::Open() to avoid leaks.
- *
- * Revision 1.12  2005/08/25 15:35:57  fwarmerdam
- * Handle offset type to hyperslab based on lib version
- *
- * Revision 1.11  2005/08/24 22:08:28  fwarmerdam
- * fixed header attribution
- *
- * Revision 1.10  2005/08/24 15:53:52  dron
- * The type of start offset array fixed again (goes away in the last commit).
- *
- * Revision 1.9  2005/08/23 20:11:30  dnadeau
- * HDF5 add Metadata
- *
- * Revision 1.8  2005/08/19 15:03:20  dron
- * Fixed type of start offset array in IReadBlock().
- *
- * Revision 1.7  2005/08/13 02:22:01  dnadeau
- * check for windows drive letter in filename
- *
- * Revision 1.6  2005/08/12 23:39:50  dnadeau
- * add GCPs and projection class members
- *
- * Revision 1.5  2005/07/29 15:44:01  fwarmerdam
- * minor formatting change
- *
- * Revision 1.4  2005/07/27 16:41:46  dnadeau
- * take care of memory leak
- *
- * Revision 1.3  2005/07/20 21:16:10  dnadeau
- * fix commit problem with file
- *
- */
+ ****************************************************************************/
 #include "hdf5.h"
 
 #include "gdal_pam.h"
@@ -76,7 +34,7 @@
 #include "hdf5dataset.h"
 #include "ogr_spatialref.h"
 
-CPL_CVSID("$Id: hdf5imagedataset.cpp,v 1.15 2006/01/21 17:51:50 dnadeau Exp $");
+CPL_CVSID("$Id: hdf5imagedataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 CPL_C_START
 void    GDALRegister_HDF5Image(void);
@@ -311,18 +269,18 @@ CPLErr HDF5ImageRasterBand::IReadBlock( int nBlockXOff, int nBlockYOff,
 
     if( poGDS->ndims == 3 ){
 	rank=3;
-	offset[2] = nBand-1;
-	count[2]  = 1;
-	col_dims[2] = 1;
+	offset[0]   = nBand-1;
+	count[0]    = 1;
+	col_dims[0] = 1;
     }
 
-    offset[0] = nBlockYOff;
-    offset[1] = nBlockXOff;
-    count[0]  = 1;
-    count[1]  = poGDS->GetRasterXSize( );
+    offset[poGDS->ndims - 2] = nBlockYOff;
+    offset[poGDS->ndims - 1] = nBlockXOff;
+    count[poGDS->ndims - 2]  = 1;
+    count[poGDS->ndims - 1]  = poGDS->GetRasterXSize( );
 
     nSizeOfData = H5Tget_size( poGDS->native );
-    memset( pImage,0,count[1]-offset[1]*nSizeOfData );
+    memset( pImage,0,count[poGDS->ndims-1]-offset[poGDS->ndims-1]*nSizeOfData );
 
 /* -------------------------------------------------------------------- */
 /*      Select 1 line                                                   */
@@ -332,13 +290,12 @@ CPLErr HDF5ImageRasterBand::IReadBlock( int nBlockXOff, int nBlockYOff,
 				  offset, NULL, 
 				  count, NULL );
    
-
 /* -------------------------------------------------------------------- */
 /*      Create memory space to receive the data                         */
 /* -------------------------------------------------------------------- */
-    col_dims[0]=count[1];
-    col_dims[1]=1;
-    memspace = H5Screate_simple( rank,col_dims, NULL );
+    col_dims[poGDS->ndims-2]=1;
+    col_dims[poGDS->ndims-1]=count[poGDS->ndims-1];
+    memspace = H5Screate_simple( rank, col_dims, NULL );
 
     status = H5Dread ( poGDS->dataset_id,
 		      poGDS->native, 
@@ -460,12 +417,12 @@ GDALDataset *HDF5ImageDataset::Open( GDALOpenInfo * poOpenInfo )
     poDS->address = H5Dget_offset( poDS->dataset_id );
     poDS->native  = H5Tget_native_type( poDS->datatype, H5T_DIR_ASCEND );
 
-    poDS->nRasterYSize=poDS->dims[0];
-    poDS->nRasterXSize=poDS->dims[1];
+    poDS->nRasterYSize=poDS->dims[poDS->ndims-2];   // Y
+    poDS->nRasterXSize=poDS->dims[poDS->ndims-1];   // X alway last
 
     poDS->nBands=1;
 
-    if( poDS->ndims == 3 ) poDS->nBands=poDS->dims[poDS->ndims-1];
+    if( poDS->ndims == 3 ) poDS->nBands=poDS->dims[0];
 
 
     for(  i = 1; i <= poDS->nBands; i++ ) {
