@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: hfa_p.h 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: hfa_p.h 11718 2007-07-02 20:59:04Z warmerdam $
  *
  * Project:  Erdas Imagine (.img) Translator
  * Purpose:  Private class declarations for the HFA classes used to read
@@ -305,7 +305,7 @@ class HFAField
                      GByte *pabyData, GUInt32 nDataOffset, int nDataSize,
                      const char *pszPrefix = NULL );
     
-    int		GetInstBytes( GByte * pabyData );
+    int		GetInstBytes( GByte *, int );
     int		GetInstCount( GByte * pabyData );
 };
 
@@ -335,7 +335,7 @@ class HFAType
 
     void	Dump( FILE * );
 
-    int		GetInstBytes( GByte * pabyData );
+    int		GetInstBytes( GByte *, int );
     int         GetInstCount( const char *pszField, 
                           GByte *pabyData, GUInt32 nDataOffset, int nDataSize);
     int         ExtractInstValue( const char * pszField,
