@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: hfaband.cpp 11142 2007-04-01 19:11:17Z warmerdam $
+ * $Id: hfaband.cpp 12304 2007-10-03 04:33:59Z warmerdam $
  *
  * Project:  Erdas Imagine (.img) Translator
  * Purpose:  Implementation of the HFABand, for accessing one Eimg_Layer.
@@ -32,7 +32,7 @@
 
 /* include the compression code */
 
-CPL_CVSID("$Id: hfaband.cpp 11142 2007-04-01 19:11:17Z warmerdam $");
+CPL_CVSID("$Id: hfaband.cpp 12304 2007-10-03 04:33:59Z warmerdam $");
 
 /************************************************************************/
 /*                              HFABand()                               */
@@ -1577,7 +1577,11 @@ int HFABand::CreateOverview( int nOverviewLevel )
 
     // TODO: Need to add to end of array (thats pretty hard).
     if( poRRDNamesList->SetStringField( szName, osLayerName ) != CE_None )
-        return -1;
+    {
+        poRRDNamesList->MakeData( poRRDNamesList->GetDataSize() + 3000 );
+        if( poRRDNamesList->SetStringField( szName, osLayerName ) != CE_None )
+            return -1;
+    }
 
 /* -------------------------------------------------------------------- */
 /*      Add to the list of overviews for this band.                     */
