@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: hfacompress.cpp,v 1.3 2005/09/23 14:53:48 fwarmerdam Exp $
+ * $Id: hfacompress.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Name:     hfadataset.cpp
  * Project:  Erdas Imagine Driver
@@ -26,23 +26,11 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- *****************************************************************************
- *
- * $Log: hfacompress.cpp,v $
- * Revision 1.3  2005/09/23 14:53:48  fwarmerdam
- * Bug 928: Fix initialization size of m_pCounts and m_pValues.
- *
- * Revision 1.2  2005/08/20 23:46:28  fwarmerdam
- * bug 858: fix for double compression
- *
- * Revision 1.1  2005/01/10 17:40:40  fwarmerdam
- * New
- *
- */
+ ****************************************************************************/
 
 #include "hfa_p.h"
 
-CPL_CVSID("$Id: hfacompress.cpp,v 1.3 2005/09/23 14:53:48 fwarmerdam Exp $");
+CPL_CVSID("$Id: hfacompress.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 HFACompress::HFACompress( void *pData, GUInt32 nBlockSize, int nDataType )
 {
