@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: hfaentry.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: hfaentry.cpp 12391 2007-10-13 03:45:14Z warmerdam $
  *
  * Project:  Erdas Imagine (.img) Translator
  * Purpose:  Implementation of the HFAEntry class for reading and relating
@@ -37,7 +37,7 @@
 #include "hfa_p.h"
 #include "cpl_conv.h"
 
-CPL_CVSID("$Id: hfaentry.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: hfaentry.cpp 12391 2007-10-13 03:45:14Z warmerdam $");
 
 /************************************************************************/
 /*                              HFAEntry()                              */
@@ -227,6 +227,23 @@ HFAEntry *HFAEntry::GetNext()
 /* -------------------------------------------------------------------- */
     if( poNext == NULL && nNextPos != 0 )
     {
+        // Check if we have a loop on the next node in this sibling chain.
+        HFAEntry *poPast;
+
+        for( poPast = this; 
+             poPast != NULL && poPast->nFilePos != nNextPos; 
+             poPast = poPast->poPrev ) {}
+
+        if( poPast != NULL )
+        {
+            CPLError( CE_Warning, CPLE_AppDefined,
+                      "Corrupt (looping) entry in %s, ignoring some entries after %s.",
+                      psHFA->pszFilename, 
+                      szName );
+            nNextPos = 0;
+            return NULL;
+        }
+             
         poNext = new HFAEntry( psHFA, nNextPos, poParent, this );
     }
 
@@ -302,6 +319,21 @@ GByte *HFAEntry::MakeData( int nSize )
         nDataSize = nSize;
 
         MarkDirty();
+
+/* -------------------------------------------------------------------- */
+/*      If the data already had a file position, we now need to         */
+/*      clear that, forcing it to be rewritten at the end of the        */
+/*      file.  Referencing nodes will need to be marked dirty so        */
+/*      they are rewritten.                                             */
+/* -------------------------------------------------------------------- */
+        if( nFilePos != 0 )
+        {
+            nFilePos = 0;
+            if (poPrev != NULL) poPrev->MarkDirty(); 
+            if (poNext != NULL) poNext->MarkDirty(); 
+            if (poChild != NULL) poChild->MarkDirty(); 
+            if (poParent != NULL) poParent->MarkDirty(); 
+        }
     }
 
     return pabyData;
