@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: hfafield.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: hfafield.cpp 12304 2007-10-03 04:33:59Z warmerdam $
  *
  * Project:  Erdas Imagine (.img) Translator
  * Purpose:  Implementation of the HFAField class for managing information
@@ -30,7 +30,7 @@
 
 #include "hfa_p.h"
 
-CPL_CVSID("$Id: hfafield.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: hfafield.cpp 12304 2007-10-03 04:33:59Z warmerdam $");
 
 #define MAX_ENTRY_REPORT   16
                            
@@ -646,15 +646,17 @@ HFAField::SetInstValue( const char * pszField, int nIndexValue,
             else
             {
                 for( iIndexCounter = 0;
-                     iIndexCounter < nIndexValue;
+                     iIndexCounter < nIndexValue && nExtraOffset < nDataSize;
                      iIndexCounter++ )
                 {
                     nExtraOffset +=
-                        poItemObjectType->GetInstBytes(pabyData+nExtraOffset);
+                        poItemObjectType->GetInstBytes(pabyData + nExtraOffset,
+                                                       nDataSize - nExtraOffset);
                 }
             }
 
-            if( pszField != NULL && strlen(pszField) > 0 )
+            if( pszField != NULL && strlen(pszField) > 0
+                && nExtraOffset < nDataSize )
             {
                 return( poItemObjectType->
                             SetInstValue( pszField, pabyData + nExtraOffset,
@@ -662,6 +664,11 @@ HFAField::SetInstValue( const char * pszField, int nIndexValue,
                                           nDataSize - nExtraOffset,
                                           chReqType, pValue ) );
             }
+            else
+            {
+                CPLAssert( FALSE );
+                return CE_Failure;
+            }
         }
         break;
 
@@ -915,7 +922,8 @@ HFAField::ExtractInstValue( const char * pszField, int nIndexValue,
                      iIndexCounter++ )
                 {
                     nExtraOffset +=
-                        poItemObjectType->GetInstBytes(pabyData+nExtraOffset);
+                        poItemObjectType->GetInstBytes(pabyData + nExtraOffset,
+                                                       nDataSize - nExtraOffset);
                 }
             }
 
@@ -984,7 +992,7 @@ HFAField::ExtractInstValue( const char * pszField, int nIndexValue,
 /*      portion.                                                        */
 /************************************************************************/
 
-int HFAField::GetInstBytes( GByte * pabyData )
+int HFAField::GetInstBytes( GByte *pabyData, int nDataSize )
 
 {
     int		nCount;
@@ -1033,7 +1041,9 @@ int HFAField::GetInstBytes( GByte * pabyData )
         {
             int	nThisBytes;
 
-            nThisBytes = poItemObjectType->GetInstBytes( pabyData );
+            nThisBytes =
+                poItemObjectType->GetInstBytes( pabyData,
+                                                nDataSize - nInstBytes );
             nInstBytes += nThisBytes;
             pabyData += nThisBytes;
         }
