@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ddffielddefn.cpp,v 1.24 2006/03/07 04:21:34 fwarmerdam Exp $
+ * $Id: ddffielddefn.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  ISO 8211 Access
  * Purpose:  Implements the DDFFieldDefn class.
@@ -25,91 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ddffielddefn.cpp,v $
- * Revision 1.24  2006/03/07 04:21:34  fwarmerdam
- * Added support for AR2D which has repeating structures with substructures
- *
- * Revision 1.23  2005/10/17 14:51:24  fwarmerdam
- * Removed extra newlines from error messages.
- *
- * Revision 1.22  2005/10/17 14:27:10  fwarmerdam
- * Failure to parse field defns is now a warning, not error
- *
- * Revision 1.21  2004/02/18 14:10:07  warmerda
- * doc fixups
- *
- * Revision 1.20  2004/01/06 18:59:18  warmerda
- * make enum identifiers more unique
- *
- * Revision 1.19  2004/01/06 18:53:41  warmerda
- * made data_type_code and data_struct_code global for HP C++ builds
- *
- * Revision 1.18  2003/12/15 20:24:58  warmerda
- * expand tabs
- *
- * Revision 1.17  2003/09/17 21:11:34  warmerda
- * fixed handling of the field terminator on write
- *
- * Revision 1.16  2003/09/15 20:45:47  warmerda
- * initialize nFixedWidth
- *
- * Revision 1.15  2003/09/05 19:13:02  warmerda
- * added repeating support when creating fields
- *
- * Revision 1.14  2003/09/03 20:36:26  warmerda
- * added subfield writing support
- *
- * Revision 1.13  2003/07/18 20:45:30  warmerda
- * be careful to avoid pszDest buffer overrun
- *
- * Revision 1.12  2003/07/03 15:38:46  warmerda
- * some write capabilities added
- *
- * Revision 1.11  2003/05/22 19:44:26  warmerda
- * Fixed another bug like the last.
- *
- * Revision 1.10  2003/05/22 19:14:51  warmerda
- * Fixed possible problem with writing one byte past end of
- * pszDest in ExpandFormat() as reported by Ben Discoe.
- *
- * Revision 1.9  2003/02/06 03:21:04  warmerda
- * Modified ExpandFormat() to dynamically allocate the target buffer. It was
- * overrunning the 400 character szDest buffer on some files, such as
- * the data/sdts/gainsville/BEDRCATD.DDF dataset.
- *
- * Revision 1.8  2001/07/18 04:51:57  warmerda
- * added CPL_CVSID
- *
- * Revision 1.7  2001/06/22 19:22:16  warmerda
- * Made some oddidies in field definitions non-fatal.
- *
- * Revision 1.6  2000/11/30 20:33:18  warmerda
- * make having more formats than data items a warning, not an error
- *
- * Revision 1.5  2000/06/16 18:05:02  warmerda
- * expanded tabs
- *
- * Revision 1.4  2000/01/31 18:03:38  warmerda
- * completely rewrote format expansion to make more general
- *
- * Revision 1.3  1999/11/18 19:03:04  warmerda
- * expanded tabs
- *
- * Revision 1.2  1999/09/20 19:29:16  warmerda
- * make forgiving of UNIT/FIELD terminator mixup in Tiger SDTS files
- *
- * Revision 1.1  1999/04/27 18:45:05  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "iso8211.h"
 #include "cpl_string.h"
 #include <ctype.h>
 
-CPL_CVSID("$Id: ddffielddefn.cpp,v 1.24 2006/03/07 04:21:34 fwarmerdam Exp $");
+CPL_CVSID("$Id: ddffielddefn.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 #define CPLE_DiscardedFormat   1301
 
