@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ddfrecord.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: ddfrecord.cpp 11592 2007-06-04 18:57:26Z warmerdam $
  *
  * Project:  ISO 8211 Access
  * Purpose:  Implements the DDFRecord class.
@@ -30,7 +30,7 @@
 #include "iso8211.h"
 #include "cpl_conv.h"
 
-CPL_CVSID("$Id: ddfrecord.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: ddfrecord.cpp 11592 2007-06-04 18:57:26Z warmerdam $");
 
 static const size_t nLeaderSize = 24;
 
@@ -480,11 +480,13 @@ int DDFRecord::ReadHeader()
         }
         while(DDF_FIELD_TERMINATOR != tmpBuf[0]);
 
-        // Now, rewind a little.  Only the TERMINATOR should have been read:
+        // --------------------------------------------------------------------
+        // Now, rewind a little.  Only the TERMINATOR should have been read
+        // --------------------------------------------------------------------
         int rewindSize = nFieldEntryWidth - 1;
         FILE *fp = poModule->GetFP();
-        long pos = ftell(fp) - rewindSize;
-        fseek(fp, pos, SEEK_SET);
+        vsi_l_offset pos = VSIFTellL(fp) - rewindSize;
+        VSIFSeekL(fp, pos, SEEK_SET);
         nDataSize -= rewindSize;
 
         // --------------------------------------------------------------------
