@@ -1,5 +1,5 @@
 /* ****************************************************************************
- * $Id: mkcatalog.cpp,v 1.3 2003/09/15 20:50:04 warmerda Exp $
+ * $Id: mkcatalog.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  ISO8211 Library
  * Purpose:  Test ISO8211 writing capability.
@@ -25,23 +25,11 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: mkcatalog.cpp,v $
- * Revision 1.3  2003/09/15 20:50:04  warmerda
- * updated
- *
- * Revision 1.2  2003/09/03 20:36:26  warmerda
- * added subfield writing support
- *
- * Revision 1.1  2003/07/03 15:40:13  warmerda
- * new
- *
- */
+ ****************************************************************************/
 
 #include "iso8211.h"
 
-CPL_CVSID("$Id: mkcatalog.cpp,v 1.3 2003/09/15 20:50:04 warmerda Exp $");
+CPL_CVSID("$Id: mkcatalog.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 
 /************************************************************************/
