@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: jp2kakdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: jp2kakdataset.cpp 11732 2007-07-10 18:14:51Z warmerdam $
  *
  * Project:  JPEG-2000
  * Purpose:  Implementation of the ISO/IEC 15444-1 standard based on Kakadu.
@@ -72,7 +72,7 @@
 #  define kdu_client void
 #endif
 
-CPL_CVSID("$Id: jp2kakdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: jp2kakdataset.cpp 11732 2007-07-10 18:14:51Z warmerdam $");
 
 CPL_C_START
 CPLErr CPL_DLL GTIFMemBufFromWkt( const char *pszWKT, 
@@ -184,7 +184,8 @@ class JP2KAKRasterBand : public GDALPamRasterBand
 
     void        ApplyPalette( jp2_palette oJP2Palette );
     void        ProcessYCbCrTile(kdu_tile tile, GByte *pabyBuffer, 
-                                 int nBlockXOff, int nBlockYOff );
+                                 int nBlockXOff, int nBlockYOff,
+                                 int nTileOffsetX, int nTileOffsetY );
     void        ProcessTile(kdu_tile tile, GByte *pabyBuffer );
 };
 
@@ -556,18 +557,21 @@ CPLErr JP2KAKRasterBand::IReadBlock( int nBlockXOff, int nBlockYOff,
                 kdu_dims tile_dims; res.get_dims(tile_dims);
                 kdu_coords offset = tile_dims.pos - dims.pos;
 
-                GByte *pabyDest;
-
-                pabyDest = ((GByte *)pImage) 
-                    + (offset.x + offset.y*nBlockXSize) * nWordSize;
-
                 try 
                 {
                     if( tile.get_ycc() && nBand < 4 )
-                        ProcessYCbCrTile( tile, pabyDest, 
-                                          nBlockXOff, nBlockYOff );
+                        ProcessYCbCrTile( tile, (GByte *) pImage,
+                                          nBlockXOff, nBlockYOff,
+                                          offset.x, offset.y );
                     else
+                    {
+                        GByte *pabyDest;
+                        
+                        pabyDest = ((GByte *)pImage) 
+                            + (offset.x + offset.y*nBlockXSize) * nWordSize;
+
                         ProcessTile( tile, pabyDest );
+                    }
                     tile.close();
                 }
                 catch( ... )
@@ -649,7 +653,8 @@ void JP2KAKRasterBand::ProcessTile( kdu_tile tile, GByte *pabyDest )
 /************************************************************************/
 
 void JP2KAKRasterBand::ProcessYCbCrTile( kdu_tile tile, GByte *pabyDest, 
-                                         int nTileXOff, int nTileYOff )
+                                         int nBlockXOff, int nBlockYOff,
+                                         int nTileOffsetX, int nTileOffsetY )
 
 {
     // Open tile-components and create processing engines and resources
@@ -714,7 +719,7 @@ void JP2KAKRasterBand::ProcessYCbCrTile( kdu_tile tile, GByte *pabyDest,
             }
 
             apoBlocks[iBand] = 
-                poBand->GetLockedBlockRef( nTileXOff, nTileYOff, TRUE );
+                poBand->GetLockedBlockRef( nBlockXOff, nBlockYOff, TRUE );
             apabyBandDest[iBand] = (GByte *) apoBlocks[iBand]->GetDataRef();
         }
     }
@@ -758,7 +763,8 @@ void JP2KAKRasterBand::ProcessYCbCrTile( kdu_tile tile, GByte *pabyDest,
         kdu_convert_ycc_to_rgb(line[0], line[1], line[2]);
 
         for( iBand = 0; iBand < 3; iBand++ )
-            transfer_bytes(apabyBandDest[iBand] + y * nBlockXSize * nWordSize,
+            transfer_bytes(apabyBandDest[iBand] 
+                           + (nTileOffsetX+(y+nTileOffsetY)*nBlockXSize)*nWordSize,
                            line[iBand], nWordSize, bit_depth, eDataType );
     }
 
