@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: subfile_source.h,v 1.2 2004/07/29 16:37:56 warmerda Exp $
+ * $Id: subfile_source.h 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  JPEG-2000
  * Purpose:  Implements read-only virtual io on a subregion of a file.
@@ -25,16 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- * 
- * $Log: subfile_source.h,v $
- * Revision 1.2  2004/07/29 16:37:56  warmerda
- * fixed parsing of subfile definition to handle spaces properly
- *
- * Revision 1.1  2004/07/23 19:14:00  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "kdu_file_io.h"
 #include "cpl_error.h"
@@ -76,7 +67,7 @@ class subfile_source : public kdu_compressed_source {
           if( real_filename != NULL )
               real_filename = strstr(real_filename+1,",");
           if( real_filename != NULL )
-              real_filename = real_filename++;
+              real_filename++;
           else
           {
               kdu_error e;
