@@ -1,14 +1,14 @@
 /******************************************************************************
- * $Id: l1bdataset.cpp,v 1.27 2006/02/16 05:14:46 fwarmerdam Exp $
+ * $Id: l1bdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  NOAA Polar Orbiter Level 1b Dataset Reader (AVHRR)
  * Purpose:  Can read NOAA-9(F)-NOAA-17(M) AVHRR datasets
- * Author:   Andrey Kiselev, dron@remotesensing.org
+ * Author:   Andrey Kiselev, dron@ak4719.spb.edu
  *
  * Some format info at: http://www.sat.dundee.ac.uk/noaa1b.html
  *
  ******************************************************************************
- * Copyright (c) 2002, Andrey Kiselev <dron@remotesensing.org>
+ * Copyright (c) 2002, Andrey Kiselev <dron@ak4719.spb.edu>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -27,99 +27,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- * 
- * $Log: l1bdataset.cpp,v $
- * Revision 1.27  2006/02/16 05:14:46  fwarmerdam
- * Fixed byte swapping of NOAA9 GCPS.
- *
- * Revision 1.26  2005/07/31 01:00:08  fwarmerdam
- * Moved CPL_LSB variables into #ifdef.
- *
- * Revision 1.25  2005/05/05 15:54:48  fwarmerdam
- * PAM Enabled
- *
- * Revision 1.24  2005/02/07 20:19:11  fwarmerdam
- * Parametrized sampling rates.
- *
- * Revision 1.23  2005/02/07 19:22:35  fwarmerdam
- * Patched problem in parsing negative lat and long values in GCP handling.
- *
- * Revision 1.22  2005/02/07 17:22:14  fwarmerdam
- * Hacked to emit only 11x20 GCPs.  Eventually we should make this
- * controllable.
- *
- * Revision 1.21  2005/01/28 20:29:37  fwarmerdam
- * added format info url.
- *
- * Revision 1.20  2003/07/08 21:23:23  warmerda
- * avoid warnings
- *
- * Revision 1.19  2003/06/19 12:28:45  dron
- * More fixes in GCP extraction.
- *
- * Revision 1.18  2003/06/19 09:36:13  dron
- * Fixed reading number of meaningful GCPs for NOAA-9/NOAA-14 data format.
- *
- * Revision 1.17  2003/04/17 12:54:21  dron
- * Fixed small memory leak.
- *
- * Revision 1.16  2003/04/05 15:16:29  dron
- * Simplified process of georeference determination.
- *
- * Revision 1.15  2002/11/27 13:45:45  dron
- * Fixed problem with L1B signature handling.
- *
- * Revision 1.14  2002/10/04 16:23:56  dron
- * Memory leak fixed.
- *
- * Revision 1.13  2002/09/04 06:50:37  warmerda
- * avoid static driver pointers
- *
- * Revision 1.12  2002/08/31 10:01:36  dron
- * Fixes in function declarations
- *
- * Revision 1.11  2002/08/29 17:05:22  dron
- * Fixes in channels description.
- *
- * Revision 1.10  2002/08/28 15:16:31  dron
- * Band descriptions added
- *
- * Revision 1.9  2002/06/26 12:28:36  dron
- * 8-bit selective extract subsets supported
- *
- * Revision 1.8  2002/06/25 18:11:26  dron
- * Added support for 16-bit selective extract subsets
- *
- * Revision 1.7  2002/06/12 21:12:25  warmerda
- * update to metadata based driver info
- *
- * Revision 1.6  2002/06/07 18:02:41  warmerda
- * don't redeclare i
- *
- * Revision 1.5  2002/06/04 16:02:28  dron
- * Fixes in georeferencing, metadata, NOAA-K/L/M support.
- * Many thanks to Markus Neteler for intensive testing.
- *
- * Revision 1.4  2002/05/21 17:37:09  dron
- * Additional meteadata.
- *
- * Revision 1.3  2002/05/18 14:01:21  dron
- * NOAA-15 fixes, georeferencing
- *
- * Revision 1.2  2002/05/16 01:26:57  warmerda
- * move up variable declaration to avoid VC++ error
- *
- * Revision 1.1  2002/05/08 16:32:20  dron
- * NOAA Polar Orbiter Dataset reader added (not full implementation yet).
- *
- *
- */
+ ****************************************************************************/
 
 #include "gdal_pam.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: l1bdataset.cpp,v 1.27 2006/02/16 05:14:46 fwarmerdam Exp $");
+CPL_CVSID("$Id: l1bdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 CPL_C_START
 void    GDALRegister_L1B(void);
@@ -250,8 +163,7 @@ class L1BDataset : public GDALPamDataset
     int         iGCPOffset;
     int         iGCPCodeOffset;
     int         nGCPsPerLine;
-    int         iLocationIndicator;
-    double      dfGCPStart, dfGCPStep;
+    int         iLocationIndicator, iGCPStart, iGCPStep;
 
     int         nBufferSize;
     int         iSpacecraftID;
@@ -329,9 +241,7 @@ CPLErr L1BRasterBand::IReadBlock( int nBlockXOff, int nBlockYOff,
 {
     L1BDataset  *poGDS = (L1BDataset *) poDS;
     GUInt32     iword, jword;
-    GUInt32     *iRawScan = NULL;               // Packed scanline buffer
-    GUInt16     *iScan1 = NULL, *iScan2 = NULL; // Unpacked 16-bit scanline buffers
-    GByte       *byScan = NULL;                 // Unpacked 8-bit scanline buffer
+    GUInt16     *iScan = NULL;          // Unpacked 16-bit scanline buffer
     int         iDataOffset, i, j;
             
 /* -------------------------------------------------------------------- */
@@ -349,68 +259,81 @@ CPLErr L1BRasterBand::IReadBlock( int nBlockXOff, int nBlockYOff,
     switch (poGDS->iDataFormat)
     {
         case PACKED10BIT:
-        // Read packed scanline
-        iRawScan = (GUInt32 *)CPLMalloc(poGDS->nRecordSize);
-        VSIFRead(iRawScan, 1, poGDS->nRecordSize, poGDS->fp);
-        iScan1 = (GUInt16 *)CPLMalloc(poGDS->nBufferSize);
-        j = 0;
-        for(i = poGDS->nRecordDataStart / (int)sizeof(iRawScan[0]);
-            i < poGDS->nRecordDataEnd / (int)sizeof(iRawScan[0]); i++)
-        {
-            iword = iRawScan[i];
+            {
+                // Read packed scanline
+                GUInt32 *iRawScan = (GUInt32 *)CPLMalloc(poGDS->nRecordSize);
+                VSIFRead( iRawScan, 1, poGDS->nRecordSize, poGDS->fp );
+
+                iScan = (GUInt16 *)CPLMalloc(poGDS->nBufferSize);
+                j = 0;
+                for(i = poGDS->nRecordDataStart / (int)sizeof(iRawScan[0]);
+                    i < poGDS->nRecordDataEnd / (int)sizeof(iRawScan[0]); i++)
+                {
+                    iword = iRawScan[i];
 #ifdef CPL_LSB
-            CPL_SWAP32PTR(&iword);
+                    CPL_SWAP32PTR(&iword);
 #endif
-            jword = iword & 0x3FF00000;
-            iScan1[j++] = (GUInt16) (jword >> 20);
-            jword = iword & 0x000FFC00;
-            iScan1[j++] = (GUInt16) (jword >> 10);
-            iScan1[j++] = (GUInt16) (iword & 0x000003FF);
-        }
-        CPLFree(iRawScan);
-        break;
+                    jword = iword & 0x3FF00000;
+                    iScan[j++] = (GUInt16) (jword >> 20);
+                    jword = iword & 0x000FFC00;
+                    iScan[j++] = (GUInt16) (jword >> 10);
+                    iScan[j++] = (GUInt16) (iword & 0x000003FF);
+                }
+                CPLFree(iRawScan);
+            }
+            break;
         case UNPACKED16BIT:
-        iScan1 = (GUInt16 *)CPLMalloc(poGDS->GetRasterXSize()
-                                      * poGDS->nBands * sizeof(GUInt16));
-        iScan2 = (GUInt16 *)CPLMalloc(poGDS->nRecordSize);
-        VSIFRead(iScan2, 1, poGDS->nRecordSize, poGDS->fp);
-        for (i = 0; i < poGDS->GetRasterXSize() * poGDS->nBands; i++)
-        {
-            iScan1[i] = iScan2[poGDS->nRecordDataStart / (int)sizeof(iScan2[0]) + i];
+            {
+                // Read unpacked scanline
+                GUInt16 *iRawScan = (GUInt16 *)CPLMalloc(poGDS->nRecordSize);
+                VSIFRead( iRawScan, 1, poGDS->nRecordSize, poGDS->fp );
+
+                iScan = (GUInt16 *)CPLMalloc(poGDS->GetRasterXSize()
+                                             * poGDS->nBands * sizeof(GUInt16));
+                for (i = 0; i < poGDS->GetRasterXSize() * poGDS->nBands; i++)
+                {
+                    iScan[i] = iRawScan[poGDS->nRecordDataStart
+                        / (int)sizeof(iRawScan[0]) + i];
 #ifdef CPL_LSB
-            CPL_SWAP16PTR(&iScan1[i]);
+                    CPL_SWAP16PTR(&iScan[i]);
 #endif
-        }
-        CPLFree(iScan2);
-        break;
+                }
+                CPLFree(iRawScan);
+            }
+            break;
         case UNPACKED8BIT:
-        iScan1 = (GUInt16 *)CPLMalloc(poGDS->GetRasterXSize()
-                                      * poGDS->nBands * sizeof(GUInt16));
-        byScan = (GByte *)CPLMalloc(poGDS->nRecordSize);
-        VSIFRead(byScan, 1, poGDS->nRecordSize, poGDS->fp);
-        for (i = 0; i < poGDS->GetRasterXSize() * poGDS->nBands; i++)
-            iScan1[i] = byScan[poGDS->nRecordDataStart / (int)sizeof(byScan[0]) + i];
-        CPLFree(byScan);
-        break;
+            {
+                // Read 8-bit unpacked scanline
+                GByte   *byRawScan = (GByte *)CPLMalloc(poGDS->nRecordSize);
+                VSIFRead( byRawScan, 1, poGDS->nRecordSize, poGDS->fp );
+                
+                iScan = (GUInt16 *)CPLMalloc(poGDS->GetRasterXSize()
+                                             * poGDS->nBands * sizeof(GUInt16));
+                for (i = 0; i < poGDS->GetRasterXSize() * poGDS->nBands; i++)
+                    iScan[i] = byRawScan[poGDS->nRecordDataStart
+                        / (int)sizeof(byRawScan[0]) + i];
+                CPLFree(byRawScan);
+            }
+            break;
         default: // NOTREACHED
-        break;
+            break;
     }
     
     int nBlockSize = nBlockXSize * nBlockYSize;
     if (poGDS->iLocationIndicator == DESCEND)
         for( i = 0, j = 0; i < nBlockSize; i++ )
         {
-            ((GUInt16 *) pImage)[i] = iScan1[j + nBand - 1];
+            ((GUInt16 *) pImage)[i] = iScan[j + nBand - 1];
             j += poGDS->nBands;
         }
     else
         for ( i = nBlockSize - 1, j = 0; i >= 0; i-- )
         {
-            ((GUInt16 *) pImage)[i] = iScan1[j + nBand - 1];
+            ((GUInt16 *) pImage)[i] = iScan[j + nBand - 1];
             j += poGDS->nBands;
         }
     
-    CPLFree(iScan1);
+    CPLFree(iScan);
     return CE_None;
 }
 
@@ -442,14 +365,7 @@ L1BDataset::~L1BDataset()
 
     if( nGCPCount > 0 )
     {
-        for( int i = 0; i < nGCPCount; i++ )
-        {
-            if ( pasGCPList[i].pszId )
-                CPLFree( pasGCPList[i].pszId );
-            if ( pasGCPList[i].pszInfo )
-                CPLFree( pasGCPList[i].pszInfo );
-        }
-
+        GDALDeinitGCPs( nGCPCount, pasGCPList );
         CPLFree( pasGCPList );
     }
     if ( pszGCPProjection )
@@ -500,11 +416,14 @@ void L1BDataset::FetchNOAA9TimeCode( TimeCode *psTime, GByte *piRecordHeader,
     GUInt32 lTemp;
 
     lTemp = ((piRecordHeader[2] >> 1) & 0x7F);
-    psTime->SetYear((lTemp > 77)?(lTemp + 1900):(lTemp + 2000)); // Avoid `Year 2000' problem
-    psTime->SetDay((GUInt32)(piRecordHeader[2] & 0x01) << 8 | (GUInt32)piRecordHeader[3]);
-    psTime->SetMillisecond(
-        ((GUInt32)(piRecordHeader[4] & 0x07) << 24) | ((GUInt32)piRecordHeader[5] << 16) |
-        ((GUInt32)piRecordHeader[6] << 8) | (GUInt32)piRecordHeader[7]);
+    psTime->SetYear((lTemp > 77) ? 
+        (lTemp + 1900) : (lTemp + 2000)); // Avoid `Year 2000' problem
+    psTime->SetDay((GUInt32)(piRecordHeader[2] & 0x01) << 8
+                   | (GUInt32)piRecordHeader[3]);
+    psTime->SetMillisecond( ((GUInt32)(piRecordHeader[4] & 0x07) << 24)
+        | ((GUInt32)piRecordHeader[5] << 16)
+        | ((GUInt32)piRecordHeader[6] << 8)
+        | (GUInt32)piRecordHeader[7] );
     *iLocInd = ((piRecordHeader[8] & 0x02) == 0) ? ASCEND : DESCEND;
 }
 
@@ -545,16 +464,17 @@ void L1BDataset::FetchNOAA9GCPs( GDAL_GCP *pasGCPList,
     int         nGoodGCPs, iGCPPos, j;
     double      dfPixel;
     
-    nGoodGCPs = (*((GByte *)piRecordHeader + iGCPCodeOffset) <= nGCPsPerLine)?
-            *((GByte *)piRecordHeader + iGCPCodeOffset):nGCPsPerLine;
+    nGoodGCPs = (*((GByte *)piRecordHeader + iGCPCodeOffset) <= nGCPsPerLine) ?
+            *((GByte *)piRecordHeader + iGCPCodeOffset) : nGCPsPerLine;
 
 #ifdef DEBUG
     CPLDebug( "L1B", "iGCPCodeOffset=%d, nGCPsPerLine=%d, nGoodGCPs=%d",
               iGCPCodeOffset, nGCPsPerLine, nGoodGCPs );
 #endif
 
-    dfPixel = (iLocationIndicator == DESCEND)?
-        dfGCPStart:(GetRasterXSize() - dfGCPStart);
+    // GCPs are located at center of pixel, so we will add a half pixel offset
+    dfPixel = (iLocationIndicator == DESCEND) ?
+        iGCPStart + 0.5 : (GetRasterXSize() - (iGCPStart + 0.5));
     j = iGCPOffset / (int)sizeof(piRecordHeader[0]);
     iGCPPos = iGCPOffset / (int)sizeof(piRecordHeader[0]) + 2 * nGoodGCPs;
     while ( j < iGCPPos )
@@ -577,10 +497,10 @@ void L1BDataset::FetchNOAA9GCPs( GDAL_GCP *pasGCPList,
 
         pasGCPList[nGCPCount].dfGCPZ = 0.0;
         pasGCPList[nGCPCount].dfGCPPixel = dfPixel;
-        dfPixel += (iLocationIndicator == DESCEND)?dfGCPStep:-dfGCPStep;
+        dfPixel += (iLocationIndicator == DESCEND) ? iGCPStep : -iGCPStep;
         pasGCPList[nGCPCount].dfGCPLine =
-            (double)((iLocationIndicator == DESCEND)?
-            iLine:GetRasterYSize() - iLine - 1) + 0.5;
+            (double)((iLocationIndicator == DESCEND) ?
+            iLine : GetRasterYSize() - iLine - 1) + 0.5;
         nGCPCount++;
     }
 }
@@ -594,9 +514,10 @@ void L1BDataset::FetchNOAA15GCPs( GDAL_GCP *pasGCPList,
 {
     int         j, iGCPPos;
     double      dfPixel;
-    
-    dfPixel = (iLocationIndicator == DESCEND)?
-        dfGCPStart:(GetRasterXSize() - dfGCPStart);
+
+    // GCPs are located at center of pixel, so we will add a half pixel offset
+    dfPixel = (iLocationIndicator == DESCEND) ?
+        iGCPStart + 0.5 : (GetRasterXSize() - (iGCPStart + 0.5));
     j = iGCPOffset / (int)sizeof(piRecordHeader[0]);
     iGCPPos = iGCPOffset / (int)sizeof(piRecordHeader[0]) + 2 * nGCPsPerLine;
     while ( j < iGCPPos )
@@ -620,10 +541,10 @@ void L1BDataset::FetchNOAA15GCPs( GDAL_GCP *pasGCPList,
         }
         pasGCPList[nGCPCount].dfGCPZ = 0.0;
         pasGCPList[nGCPCount].dfGCPPixel = dfPixel;
-        dfPixel += (iLocationIndicator == DESCEND)?dfGCPStep:-dfGCPStep;
+        dfPixel += (iLocationIndicator == DESCEND) ? iGCPStep : -iGCPStep;
         pasGCPList[nGCPCount].dfGCPLine =
-            (double)((iLocationIndicator == DESCEND)?
-            iLine:GetRasterYSize() - iLine - 1) + 0.5;
+            (double)((iLocationIndicator == DESCEND) ?
+            iLine : GetRasterYSize() - iLine - 1) + 0.5;
         nGCPCount++;
     }
 }
@@ -688,7 +609,7 @@ void L1BDataset::ProcessRecordHeaders()
         VSIFSeek( fp, nDataStartOffset + iLine * nRecordSize, SEEK_SET );
         VSIFRead( piRecordHeader, 1, nRecordDataStart, fp );
 
-        if (iSpacecraftID <= NOAA14)
+        if ( iSpacecraftID <= NOAA14 )
             FetchNOAA9GCPs( pasGCPList, (GInt16 *)piRecordHeader, iLine );
         else
             FetchNOAA15GCPs( pasGCPList, (GInt32 *)piRecordHeader, iLine );
@@ -719,6 +640,12 @@ void L1BDataset::ProcessRecordHeaders()
         nGCPCount = nOrigGCPs + nDesiredGCPsPerLine;
     }
 
+    if( nGCPCount < nTargetLines * nGCPsPerLine )
+    {
+        GDALDeinitGCPs( nTargetLines * nGCPsPerLine - nGCPCount, 
+                        pasGCPList + nGCPCount );
+    }
+
     CPLFree( piRecordHeader );
 }
 
@@ -769,6 +696,7 @@ GDALDataset *L1BDataset::Open( GDALOpenInfo * poOpenInfo )
 /* -------------------------------------------------------------------- */
     L1BDataset  *poDS;
     VSIStatBuf  sStat;
+    const char  *pszFilename = poOpenInfo->pszFilename;
 
     poDS = new L1BDataset();
 
@@ -833,7 +761,7 @@ GDALDataset *L1BDataset::Open( GDALOpenInfo * poOpenInfo )
     else
          goto bad;
 
-    // Get revolution number (as string, we don't need this value for processing)
+    // Get revolution number as string, we don't need this value for processing
     memcpy(poDS->pszRevolution, poDS->pabyTBMHeader + 62, 5);
     poDS->pszRevolution[5] = 0;
 
@@ -884,8 +812,8 @@ GDALDataset *L1BDataset::Open( GDALOpenInfo * poOpenInfo )
         case LAC:
             poDS->nRasterXSize = 2048;
             poDS->nBufferSize = 20484;
-            poDS->dfGCPStart = 25.5; // GCPs are located at center of pixel
-            poDS->dfGCPStep = 40;
+            poDS->iGCPStart = 25;
+            poDS->iGCPStep = 40;
             poDS->nGCPsPerLine = 51;
             if (poDS->iSpacecraftID <= NOAA14)
             {
@@ -1021,8 +949,8 @@ GDALDataset *L1BDataset::Open( GDALOpenInfo * poOpenInfo )
         case GAC:
             poDS->nRasterXSize = 409;
             poDS->nBufferSize = 4092;
-            poDS->dfGCPStart = 5.5; // FIXME: depends to scan direction
-            poDS->dfGCPStep = 8;
+            poDS->iGCPStart = 5; // FIXME: depends of scan direction
+            poDS->iGCPStep = 8;
             poDS->nGCPsPerLine = 51;
             if (poDS->iSpacecraftID <= NOAA14)
             {
@@ -1158,7 +1086,7 @@ GDALDataset *L1BDataset::Open( GDALOpenInfo * poOpenInfo )
     }
     // Compute number of lines dinamycally, so we can read partially
     // downloaded files
-    CPLStat(poOpenInfo->pszFilename, &sStat);
+    CPLStat(pszFilename, &sStat);
     poDS->nRasterYSize =
         (sStat.st_size - poDS->nDataStartOffset) / poDS->nRecordSize;
 
@@ -1231,6 +1159,28 @@ GDALDataset *L1BDataset::Open( GDALOpenInfo * poOpenInfo )
     if ( EQUALN((const char *)poDS->pabyTBMHeader + 96, "Y", 1) )
     {
         poDS->ProcessRecordHeaders();
+
+#if 0
+        Temporarily disabled.
+        CPLString  osTMP;
+
+        poDS->SetMetadataItem( "SRS", poDS->pszGCPProjection, "GEOLOCATION" );
+        
+        osTMP.Printf( "L1BGCPS:\"%s\"", pszFilename );
+        poDS->SetMetadataItem( "X_DATASET", osTMP, "GEOLOCATION" );
+        poDS->SetMetadataItem( "X_BAND", "1" , "GEOLOCATION" );
+        poDS->SetMetadataItem( "Y_DATASET", osTMP, "GEOLOCATION" );
+        poDS->SetMetadataItem( "Y_BAND", "2" , "GEOLOCATION" );
+
+        osTMP.Printf( "%d", (poDS->iLocationIndicator == DESCEND) ?
+            poDS->iGCPStart : (poDS->nRasterXSize - poDS->iGCPStart) );
+        poDS->SetMetadataItem( "PIXEL_OFFSET", osTMP, "GEOLOCATION" );
+        osTMP.Printf( "%d", (poDS->iLocationIndicator == DESCEND) ? poDS->iGCPStep : -poDS->iGCPStep );
+        poDS->SetMetadataItem( "PIXEL_STEP", osTMP, "GEOLOCATION" );
+
+        poDS->SetMetadataItem( "LINE_OFFSET", "0", "GEOLOCATION" );
+        poDS->SetMetadataItem( "LINE_STEP", "1", "GEOLOCATION" );
+#endif        
     }
 
 /* -------------------------------------------------------------------- */
