@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: msg_reader_core.cpp,v 1.4 2006/04/04 12:59:28 fwarmerdam Exp $
+ * $Id: msg_reader_core.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  MSG Native Reader
  * Purpose:  Base class for reading in the headers of MSG native images
@@ -25,13 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: msg_reader_core.cpp,v $
- * Revision 1.4  2006/04/04 12:59:28  fwarmerdam
- * added headers with explicit permission from Frans
- *
- */
+ ****************************************************************************/
 
 #include "msg_reader_core.h"
 #include "msg_basic_types.h"
@@ -48,7 +42,7 @@
 #ifdef GDAL_SUPPORT
 #include "cpl_vsi.h"
 
-CPL_CVSID("$Id: msg_reader_core.cpp,v 1.4 2006/04/04 12:59:28 fwarmerdam Exp $");
+CPL_CVSID("$Id: msg_reader_core.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 #else
 #define VSIFSeek(fp, pos, ref)    fseek(fp, pos, ref)
