@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: netcdfdataset.cpp,v 1.23 2006/04/28 19:28:45 dnadeau Exp $
+ * $Id: netcdfdataset.cpp 11179 2007-04-02 22:09:51Z warmerdam $
  *
  * Project:  netCDF read/write Driver
  * Purpose:  GDAL bindings over netCDF library.
@@ -25,95 +25,11 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- * 
- * $Log: netcdfdataset.cpp,v $
- * Revision 1.23  2006/04/28 19:28:45  dnadeau
- * CreateCopy added.
- * Generate CF compliant netCDF files.
- * Generation on the fly of geolocation arrays.
- *
- * Revision 1.22  2006/04/10 20:25:21  dnadeau
- * generalized identification of the X and Y; 
- * collaping all dimension  
- * other than X and Y into bands when reading; 
- * SUBDATASET mechanism for datasets having multiple geospatial data arrays;  
- * identify (via metadata) geolocation data
- *
- * Revision 1.21  2005/10/12 20:14:30  fwarmerdam
- * Use SetMetadataItem() for bands.
- *
- * Revision 1.20  2005/08/29 16:26:41  hobu
- * move the declaration up instead of having it
- * inlined so it is easy to find
- *
- * Revision 1.19  2005/08/29 16:16:31  hobu
- * according to msvc 7.1, var on line 1099 was already
- * declared on line 946.  removed the declaration and it
- * builds fine now
- *
- * Revision 1.18  2005/08/27 19:46:59  dnadeau
- * add rint function for Windows
- *
- * Revision 1.17  2005/08/26 22:37:22  dnadeau
- * add WGS84 for lat/lon data
- *
- * Revision 1.16  2005/08/26 22:02:09  fwarmerdam
- * Changed to use # instead of : as the separator between variable name
- * and attribute name in metadata, since : is reserved.
- * Set WGS84 as the GEOGCS for projected coordinate systems.
- * Don't set WGS84 as a GEOGCS if we don't recognise the projection.
- *
- * Revision 1.15  2005/08/26 21:34:53  dnadeau
- * support projections (UTM and LCC)
- *
- * Revision 1.14  2005/08/25 23:10:44  dnadeau
- * add metadata for all bands
- *
- * Revision 1.13  2005/08/25 22:38:44  dnadeau
- * add xdim and ydim as label for x and y dimension
- *
- * Revision 1.12  2005/08/19 20:07:55  dnadeau
- * add netcdf band metadata info
- *
- * Revision 1.11  2005/08/18 17:00:31  dnadeau
- * fix latitude/longitude variable name identification
- *
- * Revision 1.9  2005/08/17 21:43:16  dnadeau
- * support CF convention and lat/long proj.
- *
- * Revision 1.8  2005/07/29 16:21:37  fwarmerdam
- * use CPLIsNan, and float.h
- *
- * Revision 1.7  2005/07/29 02:33:32  dnadeau
- * enhance netcdf to conform to CF convention.  
- * Allow multidimensionnal array and read metatdata
- *
- * Revision 1.6  2005/05/05 15:54:49  fwarmerdam
- * PAM Enabled
- *
- * Revision 1.5  2004/10/16 14:57:31  fwarmerdam
- * Substantial rewrite by Radim to sometimes handle COARDS style datasets
- * but really only under some circumstances.   CreateCopy() removed since
- * no COARDS implementation is available.
- *
- * Revision 1.4  2004/10/14 14:51:31  fwarmerdam
- * Fixed last fix.
- *
- * Revision 1.3  2004/10/14 13:59:13  fwarmerdam
- * Added error for non-GMT netCDF files.
- *
- * Revision 1.2  2004/01/07 21:02:19  warmerda
- * fix up driver metadata
- *
- * Revision 1.1  2004/01/07 20:05:53  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "netcdfdataset.h"
 
-CPL_CVSID("$Id: netcdfdataset.cpp,v 1.23 2006/04/28 19:28:45 dnadeau Exp $");
+CPL_CVSID("$Id: netcdfdataset.cpp 11179 2007-04-02 22:09:51Z warmerdam $");
 
 
 /************************************************************************/
@@ -556,13 +472,14 @@ CPLErr netCDFRasterBand::IReadBlock( int nBlockXOff, int nBlockYOff,
                                   void * pImage )
 
 {
-    int    nErr;
+    int    nErr=-1;
     int    cdfid = ( ( netCDFDataset * ) poDS )->cdfid;
     size_t start[ MAX_NC_DIMS ];
     size_t edge[ MAX_NC_DIMS ];
     char   pszName[ MAX_STR_LEN ];
     int    i,j;
-    int    Sum,Taken;
+    int    Sum=-1;
+    int    Taken=-1;
     int    nd;
 
     *pszName='\0';
@@ -754,7 +671,7 @@ void netCDFDataset::SetProjection( int var )
 
     const char *pszWKT;
     const char *pszGeoTransform;
-    char **papszGeoTransform;
+    char **papszGeoTransform=NULL;
 
 
     netCDFDataset * poDS;
@@ -1091,6 +1008,9 @@ void netCDFDataset::SetProjection( int var )
 	pdfXCoord = (double *) CPLCalloc( xdim, sizeof(double) );
 	pdfYCoord = (double *) CPLCalloc( ydim, sizeof(double) );
     
+/* -------------------------------------------------------------------- */
+/*      Is pixel spacing is uniform accross the map?                    */
+/* -------------------------------------------------------------------- */
 	start[0] = 0;
 	edge[0]  = xdim;
 	
@@ -1101,9 +1021,10 @@ void netCDFDataset::SetProjection( int var )
                                      start, edge, pdfYCoord);
 
 /* -------------------------------------------------------------------- */
-/*      Is pixel spacing is uniform accross the map?                    */
+/*      Check Longitude                                                 */
 /* -------------------------------------------------------------------- */
-	nSpacingBegin   = (int) poDS->rint((pdfXCoord[1]-pdfXCoord[0]) * 1000); 
+
+	nSpacingBegin   = (int) poDS->rint((pdfXCoord[1]-pdfXCoord[0]) * 1000);
 	
 	nSpacingMiddle  = (int) poDS->rint((pdfXCoord[xdim / 2] - 
 				      pdfXCoord[(xdim / 2) + 1]) * 1000);
@@ -1114,23 +1035,58 @@ void netCDFDataset::SetProjection( int var )
 	if( ( abs( nSpacingBegin ) == abs( nSpacingLast )) &&
 	    ( abs( nSpacingBegin ) == abs( nSpacingMiddle )) &&
 	    ( abs( nSpacingMiddle ) == abs( nSpacingLast )) ) {
+
+/* -------------------------------------------------------------------- */
+/*      Longitude is equaly spaced, check lattitde                      */
+/* -------------------------------------------------------------------- */
+	    nSpacingBegin   = (int) poDS->rint((pdfYCoord[1]-pdfYCoord[0]) * 
+					       1000); 
 	    
+	    nSpacingMiddle  = (int) poDS->rint((pdfYCoord[ydim / 2] - 
+						pdfYCoord[(ydim / 2) + 1]) * 
+					       1000);
+	    
+	    nSpacingLast    = (int) poDS->rint((pdfYCoord[ydim - 2] - 
+						pdfYCoord[ydim-1]) * 
+					       1000);
+	    
+
+	    if( ( abs( nSpacingBegin ) == abs( nSpacingLast )) &&
+		( abs( nSpacingBegin ) == abs( nSpacingMiddle )) &&
+		( abs( nSpacingMiddle ) == abs( nSpacingLast )) ) {
+/* -------------------------------------------------------------------- */
+/*      We have gridded data s we can set the Gereferencing info.       */
+/* -------------------------------------------------------------------- */
+
 /* -------------------------------------------------------------------- */
 /*      Enable GeoTransform                                             */
 /* -------------------------------------------------------------------- */
- 	    poDS->bGotGeoTransform = TRUE;
+		    poDS->bGotGeoTransform = TRUE;
+		    
+		    poDS->adfGeoTransform[0] = pdfXCoord[0];
+		    poDS->adfGeoTransform[3] = pdfYCoord[0];
+		    poDS->adfGeoTransform[2] = 0;
+		    poDS->adfGeoTransform[4] = 0;
+		    poDS->adfGeoTransform[1] = (( pdfXCoord[xdim-1] - 
+						  pdfXCoord[0] ) / 
+						( poDS->nRasterXSize - 1 ));
 
-	    poDS->adfGeoTransform[0] = pdfXCoord[0];
-	    poDS->adfGeoTransform[3] = pdfYCoord[0];
-	    poDS->adfGeoTransform[2] = 0;
-	    poDS->adfGeoTransform[4] = 0;
-	    poDS->adfGeoTransform[1] = (( pdfXCoord[xdim-1] - pdfXCoord[0] ) / 
-					poDS->nRasterXSize);
-	    poDS->adfGeoTransform[5] = (( pdfYCoord[ydim-1] - pdfYCoord[0] ) / 
-					poDS->nRasterYSize);
-	    oSRS.exportToWkt( &(poDS->pszProjection) );
-	    
-	} 
+		    poDS->adfGeoTransform[5] = (( pdfYCoord[ydim-1] - 
+						  pdfYCoord[0] ) / 
+						( poDS->nRasterYSize - 1 ));
+/* -------------------------------------------------------------------- */
+/*     Compute the center of the pixel                                  */
+/* -------------------------------------------------------------------- */
+                  poDS->adfGeoTransform[0] = pdfXCoord[0]
+                      - (poDS->adfGeoTransform[1] / 2);
+
+                  poDS->adfGeoTransform[3] = pdfYCoord[0]
+                      - (poDS->adfGeoTransform[5] / 2);
+
+		    oSRS.exportToWkt( &(poDS->pszProjection) );
+		    
+	    } 
+	}
 	CPLFree( pdfXCoord );
 	CPLFree( pdfYCoord );
 
@@ -1213,12 +1169,23 @@ void netCDFDataset::SetProjection( int var )
 		}
 		
 		adfGeoTransform[0] = dfWE;
-		adfGeoTransform[1] = (dfEE - dfWE) / poDS->GetRasterXSize();
+		adfGeoTransform[1] = (dfEE - dfWE) / 
+		    ( poDS->GetRasterXSize() - 1 );
 		adfGeoTransform[2] = 0.0;
 		adfGeoTransform[3] = dfNN;
 		adfGeoTransform[4] = 0.0;
-		adfGeoTransform[5] = (dfSN - dfNN) / poDS->GetRasterYSize();
-		
+		adfGeoTransform[5] = (dfSN - dfNN) / 
+		    ( poDS->GetRasterYSize() - 1 );
+/* -------------------------------------------------------------------- */
+/*     Compute the center of the pixel                                  */
+/* -------------------------------------------------------------------- */
+              adfGeoTransform[0] = dfWE
+                      - (adfGeoTransform[1] / 2);
+
+              adfGeoTransform[3] = dfNN
+                      - (adfGeoTransform[5] / 2);
+
+
 		bGotGeoTransform = TRUE;
 	    }
 	    CSLDestroy( papszGeoTransform );
@@ -1241,6 +1208,10 @@ CPLErr netCDFDataset::GetGeoTransform( double * padfTransform )
         return CE_Failure;
 }
 
+/************************************************************************/
+/*                                rint()                                */
+/************************************************************************/
+
 double netCDFDataset::rint( double dfX)
 {
     if( dfX > 0 ) {
@@ -1411,7 +1382,7 @@ void netCDFDataset::CreateSubDatasetList( )
 	    szDim[0]='\0';
 	    for( i = 0; i < nDims; i++ ) {
 		nc_inq_dimlen ( cdfid, ponDimIds[i], &nDimLen );
-		sprintf(szTemp, "%d", nDimLen);
+		sprintf(szTemp, "%d", (int) nDimLen);
 		strcat(szTemp,  "x" );
 		strcat(szDim,   szTemp);
 	    }
@@ -1493,6 +1464,13 @@ GDALDataset *netCDFDataset::Open( GDALOpenInfo * poOpenInfo )
     char         attname[NC_MAX_NAME];
     int          ndims, nvars, ngatts, unlimdimid;
 
+/* -------------------------------------------------------------------- */
+/*      Does this appear to be a netcdf file?                           */
+/* -------------------------------------------------------------------- */
+    if( !EQUALN(poOpenInfo->pszFilename,"NETCDF:",7)
+        && ( poOpenInfo->nHeaderBytes < 5 
+             || !EQUALN((const char *) (poOpenInfo->pabyHeader),"CDF\001",5)))
+        return NULL;
 
 /* -------------------------------------------------------------------- */
 /*       Check if filename start with NETCDF: tag                       */
@@ -1582,7 +1560,8 @@ GDALDataset *netCDFDataset::Open( GDALOpenInfo * poOpenInfo )
     poDS->cdfid = cdfid;
 
     poDS->ReadAttributes( cdfid, NC_GLOBAL );	
-    if( !EQUAL( poDS->papszName[0], "NETCDF" ) ) {
+
+    if( ( !EQUAL( poDS->papszName[0], "NETCDF" ) ) ) {
 	poDS->CreateSubDatasetList( );
 	poDS->SetMetadata( poDS->papszMetadata );
 	return( poDS );
@@ -1604,7 +1583,7 @@ GDALDataset *netCDFDataset::Open( GDALOpenInfo * poOpenInfo )
 
 	
 /* -------------------------------------------------------------------- */
-/*      Check somebody tried to pass a variable with less than 2D       */
+/*      Check fi somebody tried to pass a variable with less than 2D    */
 /* -------------------------------------------------------------------- */
 
     if ( nd < 2 ) {
@@ -1884,6 +1863,96 @@ NCDFCreateCopy( const char * pszFilename, GDALDataset *poSrcDS,
     if( pszWKT != NULL )
 	oSRS.importFromWkt( &pszWKT );
 
+    if( oSRS.IsGeographic() ) {
+
+	int status;
+	int i;
+	int NCDFVarID;
+
+	double dfNN=0.0;
+	double dfSN=0.0;
+	double dfEE=0.0;
+	double dfWE=0.0;
+	double adfGeoTransform[6];
+	char   szGeoTransform[ MAX_STR_LEN ];
+	char   szTemp[ MAX_STR_LEN ];
+
+
+/* -------------------------------------------------------------------- */
+/*      Copy GeoTransform array from source                             */
+/* -------------------------------------------------------------------- */
+	poSrcDS->GetGeoTransform( adfGeoTransform );
+        bWriteGeoTransform = TRUE;
+
+	*szGeoTransform = '\0';
+	for( i=0; i<6; i++ ) {
+	    sprintf( szTemp, "%g ",
+		     adfGeoTransform[i] );
+	    strcat( szGeoTransform, szTemp );
+	}
+	CPLDebug( "GDAL_netCDF", "szGeoTranform = %s", szGeoTransform );
+	strcpy( pszNetcdfProjection, "GDAL_Geographics" );
+
+	status = nc_def_var( fpImage, 
+			     pszNetcdfProjection, 
+			     NC_CHAR, 
+			     0, NULL, &NCDFVarID );
+	
+	dfNN = adfGeoTransform[3];
+	dfSN = ( adfGeoTransform[5] * nYSize ) + dfNN;
+	dfWE = adfGeoTransform[0];
+	dfEE = ( adfGeoTransform[1] * nXSize ) + dfWE;
+
+        status = nc_put_att_double( fpImage,
+				    NCDFVarID, 
+				    "Northernmost_Northing",
+				    NC_DOUBLE,
+				    1,
+				    &dfNN );
+        status = nc_put_att_double( fpImage,
+				    NCDFVarID, 
+				    "Southernmost_Northing",
+				    NC_DOUBLE,
+				    1,
+				    &dfSN );
+	status = nc_put_att_double( fpImage,
+				    NCDFVarID,
+				    "Easternmost_Easting",
+				    NC_DOUBLE,
+				    1,
+				    &dfEE );
+	status = nc_put_att_double( fpImage,
+				    NCDFVarID,
+				    "Westernmost_Easting",
+				    NC_DOUBLE,
+				    1,
+				    &dfWE );
+	pszWKT = (char *) poSrcDS->GetProjectionRef() ;
+
+	nc_put_att_text( fpImage, 
+			 NCDFVarID, 
+			 "spatial_ref",
+			 strlen( pszWKT ),
+			 pszWKT );
+
+	nc_put_att_text( fpImage, 
+			 NCDFVarID, 
+			 "GeoTransform",
+			 strlen( szGeoTransform ),
+			 szGeoTransform );
+
+	nc_put_att_text( fpImage, 
+			 NCDFVarID, 
+			 GRD_MAPPING_NAME,
+			 30,
+			 "Geographics Coordinate System" );
+	nc_put_att_text( fpImage, 
+			 NCDFVarID, 
+			 LNG_NAME,
+			 14,
+			 "Grid_latitude" );
+    }
+
     if( oSRS.IsProjected() )
     {
 	const char *pszParamStr, *pszParamVal;
@@ -2046,6 +2115,10 @@ NCDFCreateCopy( const char * pszFilename, GDALDataset *poSrcDS,
 	size_t    count[ GDALNBDIM ];
 	size_t    nBandNameLen;
 	double    dfNoDataValue;
+	unsigned char      cNoDataValue;
+	float     fNoDataValue;
+	int       nlNoDataValue;
+	short     nsNoDataValue;
 	GDALRasterBandH	hBand;
 
 	GDALRasterBand *poSrcBand = poSrcDS->GetRasterBand( i );
@@ -2058,26 +2131,14 @@ NCDFCreateCopy( const char * pszFilename, GDALDataset *poSrcDS,
 	anBandDims[1] = nXDimID;
 	CPLErr      eErr = CE_None;
 
+	dfNoDataValue = poSrcBand->GetNoDataValue(0);
+
 	if( eDT == GDT_Byte ) {
 	    CPLDebug( "GDAL_netCDF", "%s = GDT_Byte ", szBandName );
 
 	    status = nc_def_var( fpImage, szBandName, NC_BYTE, 
 				 GDALNBDIM, anBandDims, &NCDFVarID );
 
-/* -------------------------------------------------------------------- */
-/*      Write Projection for band                                       */
-/* -------------------------------------------------------------------- */
-	    if( bWriteGeoTransform == TRUE ) {
-		nc_put_att_text( fpImage, NCDFVarID, 
-				 COORDINATES,
-				 7,
-				 LONLAT );
-
-		nc_put_att_text( fpImage, NCDFVarID, 
-				 GRD_MAPPING,
-				 strlen( pszNetcdfProjection ),
-				 pszNetcdfProjection );
-	    }
 
 /* -------------------------------------------------------------------- */
 /*      Write data line per line                                        */
@@ -2094,6 +2155,18 @@ NCDFCreateCopy( const char * pszFilename, GDALDataset *poSrcDS,
 					    pabScanline, nXSize, 1, GDT_Byte,
 					    0,0);
 
+/* -------------------------------------------------------------------- */
+/*      Write Fill Value                                                */
+/* -------------------------------------------------------------------- */
+
+	    cNoDataValue=(unsigned char) dfNoDataValue;
+	    nc_put_att_uchar( fpImage,
+			       NCDFVarID,
+			       _FillValue,
+			       NC_CHAR,
+			       1,
+			       &cNoDataValue );
+			   
 /* -------------------------------------------------------------------- */
 /*      Write Data from Band i                                          */
 /* -------------------------------------------------------------------- */
@@ -2121,17 +2194,27 @@ NCDFCreateCopy( const char * pszFilename, GDALDataset *poSrcDS,
 /*      Int16                                                           */
 /* -------------------------------------------------------------------- */
 
-	} else if( eDT == GDT_UInt16 ) {
-	    CPLDebug( "GDAL_netCDF", "%s = GDT_UInt16 ",szBandName );
+	} else if( ( eDT == GDT_UInt16 ) || ( eDT == GDT_Int16 ) ) {
+	    CPLDebug( "GDAL_netCDF", "%s = GDT_Int16 ",szBandName );
 	    status = nc_def_var( fpImage, szBandName, NC_SHORT, 
 				 GDALNBDIM, anBandDims, &NCDFVarID );
 
 	    pasScanline = (GInt16 *) CPLMalloc( nBands * nXSize * nYSize *
 						sizeof( GInt16 ) );
+/* -------------------------------------------------------------------- */
+/*      Write Fill Value                                                */
+/* -------------------------------------------------------------------- */
+	    nsNoDataValue= (GInt16) dfNoDataValue;
+	    nc_put_att_short( fpImage,
+			       NCDFVarID,
+			       _FillValue,
+			       NC_SHORT,
+			       1,
+			       &nsNoDataValue );
 	    for( int iLine = 0; iLine < nYSize && eErr == CE_None; iLine++ )  {
 
 		eErr = poSrcBand->RasterIO( GF_Read, 0, iLine, nXSize, 1, 
-					    pasScanline, nXSize, 1, GDT_Byte,
+					    pasScanline, nXSize, 1, GDT_Int16,
 					    0,0);
 
 		start[0]=iLine;
@@ -2157,6 +2240,19 @@ NCDFCreateCopy( const char * pszFilename, GDALDataset *poSrcDS,
 
 	    panScanline = (GInt32 *) CPLMalloc( nBands * nXSize * nYSize *
 						sizeof( GInt32 ) );
+/* -------------------------------------------------------------------- */
+/*      Write Fill Value                                                */
+/* -------------------------------------------------------------------- */
+	    nlNoDataValue= (GInt32) dfNoDataValue;
+
+	    nc_put_att_int( fpImage,
+			       NCDFVarID,
+			       _FillValue,
+			       NC_INT,
+			       1,
+			       &nlNoDataValue );
+
+
 	    for( int iLine = 0; iLine < nYSize && eErr == CE_None; iLine++ )  {
 
 		eErr = poSrcBand->RasterIO( GF_Read, 0, iLine, nXSize, 1, 
@@ -2186,6 +2282,17 @@ NCDFCreateCopy( const char * pszFilename, GDALDataset *poSrcDS,
 	    pafScanline = (float *) CPLMalloc( nBands * nXSize * nYSize *
 					       sizeof( float ) );
 
+/* -------------------------------------------------------------------- */
+/*      Write Fill Value                                                */
+/* -------------------------------------------------------------------- */
+	    fNoDataValue= (float) dfNoDataValue;
+	    nc_put_att_float( fpImage,
+			       NCDFVarID,
+			       _FillValue,
+			       NC_FLOAT,
+			       1,
+			       &fNoDataValue );
+			   
 	    for( int iLine = 0; iLine < nYSize && eErr == CE_None; iLine++ )  {
 
 		eErr = poSrcBand->RasterIO( GF_Read, 0, iLine, nXSize, 1, 
@@ -2215,6 +2322,17 @@ NCDFCreateCopy( const char * pszFilename, GDALDataset *poSrcDS,
 
 	    padScanline = (double *) CPLMalloc( nBands * nXSize * nYSize *
 						sizeof( double ) );
+/* -------------------------------------------------------------------- */
+/*      Write Fill Value                                                */
+/* -------------------------------------------------------------------- */
+		
+	    nc_put_att_double( fpImage,
+			       NCDFVarID,
+			       _FillValue,
+			       NC_DOUBLE,
+			       1,
+			       &dfNoDataValue );
+
 	    for( int iLine = 0; iLine < nYSize && eErr == CE_None; iLine++ )  {
 
 		eErr = poSrcBand->RasterIO( GF_Read, 0, iLine, nXSize, 1, 
@@ -2236,6 +2354,21 @@ NCDFCreateCopy( const char * pszFilename, GDALDataset *poSrcDS,
 	    CPLFree( padScanline );
 	}
 	
+/* -------------------------------------------------------------------- */
+/*      Write Projection for band                                       */
+/* -------------------------------------------------------------------- */
+	if( bWriteGeoTransform == TRUE ) {
+	    /*	    nc_put_att_text( fpImage, NCDFVarID, 
+			     COORDINATES,
+			     7,
+			     LONLAT );
+	    */
+	    nc_put_att_text( fpImage, NCDFVarID, 
+			     GRD_MAPPING,
+			     strlen( pszNetcdfProjection ),
+			     pszNetcdfProjection );
+	}
+
 	sprintf( szBandName, "GDAL Band Number %d", i);
 	nBandNameLen = strlen( szBandName );
 	nc_put_att_text( fpImage, 
@@ -2246,13 +2379,6 @@ NCDFCreateCopy( const char * pszFilename, GDALDataset *poSrcDS,
 
 	CopyMetadata( (void *) hBand, fpImage, NCDFVarID );
 
-	dfNoDataValue = poSrcBand->GetNoDataValue(0);
-	nc_put_att_double( fpImage,
-			   NCDFVarID,
-			   _FillValue,
-			   NC_DOUBLE,
-			   1,
-			   &dfNoDataValue );
 			   
 
     }
