@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: nitfdump.c,v 1.7 2004/05/06 14:58:06 warmerda Exp $
+ * $Id: nitfdump.c 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  NITF Read/Write Library
  * Purpose:  Simple test mainline to dump info about NITF file. 
@@ -25,36 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: nitfdump.c,v $
- * Revision 1.7  2004/05/06 14:58:06  warmerda
- * added USE00A and STDIDC parsing and reporting as metadata
- *
- * Revision 1.6  2003/05/29 19:50:10  warmerda
- * added RPC (and more general TRE) reporting
- *
- * Revision 1.5  2002/12/18 21:18:38  warmerda
- * report corners more sensibly
- *
- * Revision 1.4  2002/12/17 05:26:26  warmerda
- * implement basic write support
- *
- * Revision 1.3  2002/12/03 18:07:40  warmerda
- * added VQLUT reporting
- *
- * Revision 1.2  2002/12/03 04:43:54  warmerda
- * lots of work
- *
- * Revision 1.1  2002/12/02 06:09:29  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "nitflib.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: nitfdump.c,v 1.7 2004/05/06 14:58:06 warmerda Exp $");
+CPL_CVSID("$Id: nitfdump.c 10646 2007-01-18 02:38:10Z warmerdam $");
 
 static void DumpRPC( NITFImage *psImage, NITFRPC00BInfo *psRPC );
 static void DumpMetadata( const char *, const char *, char ** );
@@ -67,137 +43,44 @@ int main( int nArgc, char ** papszArgv )
 
 {
     NITFFile	*psFile;
-    int          iSegment;
+    int          iSegment, iFile;
     char         szTemp[100];
 
     if( nArgc < 2 )
     {
-        printf( "Usage: nitfdump <nitf_filename>\n" );
+        printf( "Usage: nitfdump <nitf_filename>*\n" );
         exit( 1 );
     }
 
+/* ==================================================================== */
+/*      Loop over all files.                                            */
+/* ==================================================================== */
+    for( iFile = 1; iFile < nArgc; iFile++ )
+    {
 /* -------------------------------------------------------------------- */
 /*      Open the file.                                                  */
 /* -------------------------------------------------------------------- */
-    psFile = NITFOpen( papszArgv[1], FALSE );
-    if( psFile == NULL )
-        exit( 2 );
+        psFile = NITFOpen( papszArgv[iFile], FALSE );
+        if( psFile == NULL )
+            exit( 2 );
+
+        printf( "Dump for %s\n", papszArgv[iFile] );
 
 /* -------------------------------------------------------------------- */
 /*      Dump first TRE list.                                            */
 /* -------------------------------------------------------------------- */
-    if( psFile->pachTRE != NULL )
-    {
-        int nTREBytes = psFile->nTREBytes;
-        const char *pszTREData = psFile->pachTRE;
-
-
-        printf( "File TREs:" );
-
-        while( nTREBytes > 10 )
+        if( psFile->pachTRE != NULL )
         {
-            int nThisTRESize = atoi(NITFGetField(szTemp, pszTREData, 6, 5 ));
+            int nTREBytes = psFile->nTREBytes;
+            const char *pszTREData = psFile->pachTRE;
 
-            printf( " %6.6s(%d)", pszTREData, nThisTRESize );
-            pszTREData += nThisTRESize + 11;
-            nTREBytes -= (nThisTRESize + 11);
-        }
-        printf( "\n" );
-    }
 
-/* -------------------------------------------------------------------- */
-/*      Report info from location table, if found.                      */
-/* -------------------------------------------------------------------- */
-    if( psFile->nLocCount > 0 )
-    {
-        int i;
-        printf( "Location Table\n" );
-        for( i = 0; i < psFile->nLocCount; i++ )
-        {
-            printf( "  LocId=%d, Offset=%d, Size=%d\n", 
-                    psFile->pasLocations[i].nLocId,
-                    psFile->pasLocations[i].nLocOffset,
-                    psFile->pasLocations[i].nLocSize );
-        }
-        printf( "\n" );
-    }
+            printf( "File TREs:" );
 
-/* -------------------------------------------------------------------- */
-/*      Dump Metadata                                                   */
-/* -------------------------------------------------------------------- */
-    DumpMetadata( "File Metadata:", "  ", psFile->papszMetadata );
-
-/* -------------------------------------------------------------------- */
-/*      Dump general info about segments.                               */
-/* -------------------------------------------------------------------- */
-    for( iSegment = 0; iSegment < psFile->nSegmentCount; iSegment++ )
-    {
-        NITFSegmentInfo *psSegInfo = psFile->pasSegmentInfo + iSegment;
-
-        printf( "Segment %d (Type=%s):\n", 
-                iSegment + 1, psSegInfo->szSegmentType );
-
-        printf( "  HeaderStart=%d, HeaderSize=%d, DataStart=%d, DataSize=%d\n",
-                psSegInfo->nSegmentHeaderStart,
-                psSegInfo->nSegmentHeaderSize, 
-                psSegInfo->nSegmentStart,
-                psSegInfo->nSegmentSize );
-        printf( "\n" );
-    }
-
-/* -------------------------------------------------------------------- */
-/*      Report details of images.                                       */
-/* -------------------------------------------------------------------- */
-    for( iSegment = 0; iSegment < psFile->nSegmentCount; iSegment++ )
-    {
-        NITFSegmentInfo *psSegInfo = psFile->pasSegmentInfo + iSegment;
-        NITFImage *psImage;
-        NITFRPC00BInfo sRPCInfo;
-        int iBand;
-        char **papszMD;
-
-        if( !EQUAL(psSegInfo->szSegmentType,"IM") )
-            continue;
-        
-        psImage = NITFImageAccess( psFile, iSegment );
-        if( psImage == NULL )
-        {
-            printf( "NITFAccessImage(%d) failed!\n", iSegment );
-            continue;
-        }
-
-        printf( "Image Segment %d, %dPx%dLx%dB x %dbits:\n", 
-                iSegment, psImage->nRows, psImage->nCols, psImage->nBands,
-                psImage->nBitsPerSample );
-        printf( "  PVTYPE=%s, IREP=%s, ICAT=%s, IMODE=%c, IC=%s, COMRAT=%s, ICORDS=%c\n", 
-                psImage->szPVType, psImage->szIREP, psImage->szICAT,
-                psImage->chIMODE, psImage->szIC, psImage->szCOMRAT,
-                psImage->chICORDS );
-        if( psImage->chICORDS != ' ' )
-        {
-            printf( "  UL=(%g,%g), UR=(%g,%g)\n  LL=(%g,%g), LR=(%g,%g)\n", 
-                    psImage->dfULX, psImage->dfULY,
-                    psImage->dfURX, psImage->dfURY,
-                    psImage->dfLLX, psImage->dfLLY,
-                    psImage->dfLRX, psImage->dfLRY );
-        }
-
-        printf( "  %d x %d blocks of size %d x %d\n",
-                psImage->nBlocksPerRow, psImage->nBlocksPerColumn,
-                psImage->nBlockWidth, psImage->nBlockHeight );
-        
-        if( psImage->pachTRE != NULL )
-        {
-            int nTREBytes = psImage->nTREBytes;
-            const char *pszTREData = psImage->pachTRE;
-            
-            
-            printf( "  Image TREs:" );
-            
             while( nTREBytes > 10 )
             {
                 int nThisTRESize = atoi(NITFGetField(szTemp, pszTREData, 6, 5 ));
-                
+
                 printf( " %6.6s(%d)", pszTREData, nThisTRESize );
                 pszTREData += nThisTRESize + 11;
                 nTREBytes -= (nThisTRESize + 11);
@@ -205,44 +88,157 @@ int main( int nArgc, char ** papszArgv )
             printf( "\n" );
         }
 
-        if( strlen(psImage->pszComments) > 0 )
-            printf( "  Comments:\n%s\n", psImage->pszComments );
+/* -------------------------------------------------------------------- */
+/*      Dump Metadata                                                   */
+/* -------------------------------------------------------------------- */
+        DumpMetadata( "File Metadata:", "  ", psFile->papszMetadata );
 
-        for( iBand = 0; iBand < psImage->nBands; iBand++ )
+/* -------------------------------------------------------------------- */
+/*      Dump general info about segments.                               */
+/* -------------------------------------------------------------------- */
+        for( iSegment = 0; iSegment < psFile->nSegmentCount; iSegment++ )
         {
-            NITFBandInfo *psBandInfo = psImage->pasBandInfo + iBand;
+            NITFSegmentInfo *psSegInfo = psFile->pasSegmentInfo + iSegment;
 
-            printf( "  Band %d: IREPBAND=%s, ISUBCAT=%s, %d LUT entries.\n",
-                    iBand + 1, psBandInfo->szIREPBAND, psBandInfo->szISUBCAT,
-                    psBandInfo->nSignificantLUTEntries );
+            printf( "Segment %d (Type=%s):\n", 
+                    iSegment + 1, psSegInfo->szSegmentType );
+
+            printf( "  HeaderStart=%d, HeaderSize=%d, DataStart=%d, DataSize=%d\n",
+                    psSegInfo->nSegmentHeaderStart,
+                    psSegInfo->nSegmentHeaderSize, 
+                    psSegInfo->nSegmentStart,
+                    psSegInfo->nSegmentSize );
+            printf( "\n" );
         }
 
-        if( NITFReadRPC00B( psImage, &sRPCInfo ) )
+/* -------------------------------------------------------------------- */
+/*      Report details of images.                                       */
+/* -------------------------------------------------------------------- */
+        for( iSegment = 0; iSegment < psFile->nSegmentCount; iSegment++ )
         {
-            DumpRPC( psImage, &sRPCInfo );
-        }
+            NITFSegmentInfo *psSegInfo = psFile->pasSegmentInfo + iSegment;
+            NITFImage *psImage;
+            NITFRPC00BInfo sRPCInfo;
+            int iBand;
+            char **papszMD;
 
-        papszMD = NITFReadUSE00A( psImage );
-        if( papszMD != NULL )
-        {
-            DumpMetadata( "  USE00A TRE:", "    ", papszMD );
-            CSLDestroy( papszMD );
-        }
+            if( !EQUAL(psSegInfo->szSegmentType,"IM") )
+                continue;
+        
+            psImage = NITFImageAccess( psFile, iSegment );
+            if( psImage == NULL )
+            {
+                printf( "NITFAccessImage(%d) failed!\n", iSegment );
+                continue;
+            }
 
-        papszMD = NITFReadSTDIDC( psImage );
-        if( papszMD != NULL )
-        {
-            DumpMetadata( "  STDIDC TRE:", "    ", papszMD );
-            CSLDestroy( papszMD );
-        }
+            printf( "Image Segment %d, %dPx%dLx%dB x %dbits:\n", 
+                    iSegment, psImage->nCols, psImage->nRows, 
+                    psImage->nBands, psImage->nBitsPerSample );
+            printf( "  PVTYPE=%s, IREP=%s, ICAT=%s, IMODE=%c, IC=%s, COMRAT=%s, ICORDS=%c\n", 
+                    psImage->szPVType, psImage->szIREP, psImage->szICAT,
+                    psImage->chIMODE, psImage->szIC, psImage->szCOMRAT,
+                    psImage->chICORDS );
+            if( psImage->chICORDS != ' ' )
+            {
+                printf( "  UL=(%g,%g), UR=(%g,%g)\n  LL=(%g,%g), LR=(%g,%g)\n", 
+                        psImage->dfULX, psImage->dfULY,
+                        psImage->dfURX, psImage->dfURY,
+                        psImage->dfLLX, psImage->dfLLY,
+                        psImage->dfLRX, psImage->dfLRY );
+            }
+            if( psImage->nILOCRow != 0 )
+            {
+                printf( "  IDLVL=%d, IALVL=%d, ILOC R=%d,C=%d, IMAG=%s\n",
+                        psImage->nIDLVL, psImage->nIALVL, 
+                        psImage->nILOCRow, psImage->nILOCColumn, 
+                        psImage->szIMAG );
+            }
 
-        DumpMetadata( "  Image Metadata:", "    ", psImage->papszMetadata );
-    }
+            printf( "  %d x %d blocks of size %d x %d\n",
+                    psImage->nBlocksPerRow, psImage->nBlocksPerColumn,
+                    psImage->nBlockWidth, psImage->nBlockHeight );
+        
+            if( psImage->pachTRE != NULL )
+            {
+                int nTREBytes = psImage->nTREBytes;
+                const char *pszTREData = psImage->pachTRE;
+            
+            
+                printf( "  Image TREs:" );
+            
+                while( nTREBytes > 10 )
+                {
+                    int nThisTRESize = atoi(NITFGetField(szTemp, pszTREData, 6, 5 ));
+                
+                    printf( " %6.6s(%d)", pszTREData, nThisTRESize );
+                    pszTREData += nThisTRESize + 11;
+                    nTREBytes -= (nThisTRESize + 11);
+                }
+                printf( "\n" );
+            }
+
+            /* Report info from location table, if found.                  */
+            if( psImage->nLocCount > 0 )
+            {
+                int i;
+                printf( "  Location Table\n" );
+                for( i = 0; i < psImage->nLocCount; i++ )
+                {
+                    printf( "    LocId=%d, Offset=%d, Size=%d\n", 
+                            psImage->pasLocations[i].nLocId,
+                            psImage->pasLocations[i].nLocOffset,
+                            psImage->pasLocations[i].nLocSize );
+                }
+                printf( "\n" );
+            }
+
+            if( strlen(psImage->pszComments) > 0 )
+                printf( "  Comments:\n%s\n", psImage->pszComments );
+
+            for( iBand = 0; iBand < psImage->nBands; iBand++ )
+            {
+                NITFBandInfo *psBandInfo = psImage->pasBandInfo + iBand;
+
+                printf( "  Band %d: IREPBAND=%s, ISUBCAT=%s, %d LUT entries.\n",
+                        iBand + 1, psBandInfo->szIREPBAND, psBandInfo->szISUBCAT,
+                        psBandInfo->nSignificantLUTEntries );
+            }
+
+            if( NITFReadRPC00B( psImage, &sRPCInfo ) )
+            {
+                DumpRPC( psImage, &sRPCInfo );
+            }
+
+            papszMD = NITFReadUSE00A( psImage );
+            if( papszMD != NULL )
+            {
+                DumpMetadata( "  USE00A TRE:", "    ", papszMD );
+                CSLDestroy( papszMD );
+            }
+
+            papszMD = NITFReadBLOCKA( psImage );
+            if( papszMD != NULL )
+            {
+                DumpMetadata( "  BLOCKA TRE:", "    ", papszMD );
+                CSLDestroy( papszMD );
+            }
+
+            papszMD = NITFReadSTDIDC( psImage );
+            if( papszMD != NULL )
+            {
+                DumpMetadata( "  STDIDC TRE:", "    ", papszMD );
+                CSLDestroy( papszMD );
+            }
+
+            DumpMetadata( "  Image Metadata:", "    ", psImage->papszMetadata );
+        }
 
 /* -------------------------------------------------------------------- */
 /*      Close.                                                          */
 /* -------------------------------------------------------------------- */
-    NITFClose( psFile );
+        NITFClose( psFile );
+    }
 
     exit( 0 );
 }
