@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: nitffile.c,v 1.21 2005/09/21 16:11:21 fwarmerdam Exp $
+ * $Id: nitffile.c 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  NITF Read/Write Library
  * Purpose:  Module responsible for opening NITF file, populating NITFFile
@@ -26,88 +26,19 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: nitffile.c,v $
- * Revision 1.21  2005/09/21 16:11:21  fwarmerdam
- * Compute complexity level (Brent Fraser)
- *
- * Revision 1.20  2005/07/28 20:00:57  fwarmerdam
- * upgrade to support 2-4GB files, use large file api
- *
- * Revision 1.19  2004/12/10 21:35:00  fwarmerdam
- * preliminary support for writing JPEG2000 compressed data
- *
- * Revision 1.18  2004/04/30 17:38:28  warmerda
- * clean up metadata
- *
- * Revision 1.17  2004/04/28 16:43:23  warmerda
- * added simplified geocentric to geodetic cvonersion
- *
- * Revision 1.16  2004/04/16 15:26:04  warmerda
- * completed metadata support
- *
- * Revision 1.15  2004/04/15 20:52:44  warmerda
- * added metadata extraction
- *
- * Revision 1.14  2003/09/11 19:51:55  warmerda
- * avoid type casting warnings
- *
- * Revision 1.13  2003/06/23 18:31:39  warmerda
- * fixed field alignment for a few fields on write
- *
- * Revision 1.12  2003/06/06 17:10:14  warmerda
- * Improved header size test to support large headers, even those as large as
- * the whole file.
- *
- * Revision 1.11  2003/06/06 16:52:32  warmerda
- * changes based on better understanding of conditional FSDEVT field
- *
- * Revision 1.10  2003/06/06 15:07:53  warmerda
- * fixed security area sizing for NITF 2.0 images, its like NITF 1.1.
- *
- * Revision 1.9  2003/05/29 19:50:39  warmerda
- * added improved TRE handling
- *
- * Revision 1.8  2003/05/05 17:57:54  warmerda
- * added blocked writing support
- *
- * Revision 1.7  2002/12/18 20:16:20  warmerda
- * allow lots of fields to be overridden with passed in options
- *
- * Revision 1.6  2002/12/17 21:23:15  warmerda
- * implement LUT reading and writing
- *
- * Revision 1.5  2002/12/17 20:03:08  warmerda
- * added rudimentary NITF 1.1 support
- *
- * Revision 1.4  2002/12/17 05:26:26  warmerda
- * implement basic write support
- *
- * Revision 1.3  2002/12/03 18:07:59  warmerda
- * load VQLUTs
- *
- * Revision 1.2  2002/12/03 04:43:54  warmerda
- * lots of work
- *
- * Revision 1.1  2002/12/02 06:09:29  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "nitflib.h"
 #include "cpl_vsi.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: nitffile.c,v 1.21 2005/09/21 16:11:21 fwarmerdam Exp $");
+CPL_CVSID("$Id: nitffile.c 10646 2007-01-18 02:38:10Z warmerdam $");
 
 static int 
 NITFCollectSegmentInfo( NITFFile *psFile, int nOffset, char *pszType,
                         int nHeaderLenSize, int nDataLenSize, 
                         int *pnNextData );
-static void NITFLoadLocationTable( NITFFile *psFile );
-static int NITFLoadVQTables( NITFFile *psFile );
 
 /************************************************************************/
 /*                              NITFOpen()                              */
@@ -298,7 +229,8 @@ NITFFile *NITFOpen( const char *pszFilename, int bUpdatable )
 
     nOffset = NITFCollectSegmentInfo( psFile, nOffset, "GR", 4, 6, &nNextData);
 
-    nOffset += 3; /* NUMX reserved field */
+    /* LA Called NUMX in NITF 2.1 */
+    nOffset = NITFCollectSegmentInfo( psFile, nOffset, "LA", 4, 3, &nNextData);
 
     nOffset = NITFCollectSegmentInfo( psFile, nOffset, "TX", 4, 5, &nNextData);
 
@@ -321,12 +253,6 @@ NITFFile *NITFOpen( const char *pszFilename, int bUpdatable )
         psFile->nTREBytes -= 3;
     }
 
-/* -------------------------------------------------------------------- */
-/*      Are the VQ tables to load up?                                   */
-/* -------------------------------------------------------------------- */
-    NITFLoadLocationTable( psFile );
-    NITFLoadVQTables( psFile );
-
     return psFile;
 }
 
@@ -337,7 +263,7 @@ NITFFile *NITFOpen( const char *pszFilename, int bUpdatable )
 void NITFClose( NITFFile *psFile )
 
 {
-    int  iSegment, i;
+    int  iSegment;
 
     for( iSegment = 0; iSegment < psFile->nSegmentCount; iSegment++ )
     {
@@ -355,10 +281,6 @@ void NITFClose( NITFFile *psFile )
     }
 
     CPLFree( psFile->pasSegmentInfo );
-    CPLFree( psFile->pasLocations );
-    for( i = 0; i < 4; i++ )
-        CPLFree( psFile->apanVQLUT[i] );
-
     if( psFile->fp != NULL )
         VSIFCloseL( psFile->fp );
     CPLFree( psFile->pachHeader );
@@ -586,9 +508,9 @@ int NITFCreate( const char *pszFilename,
         }
 
         PLACE(pachIMHDR+nOffset+ 0, IREPBANDn, pszIREPBAND                 );
-        PLACE(pachIMHDR+nOffset+ 2, ISUBCATn, ""                           );
+//      PLACE(pachIMHDR+nOffset+ 2, ISUBCATn, ""                           );
         PLACE(pachIMHDR+nOffset+ 8, IFCn  , "N"                            );
-        PLACE(pachIMHDR+nOffset+ 9, IMFLTn, ""                             );
+//      PLACE(pachIMHDR+nOffset+ 9, IMFLTn, ""                             );
 
         if( !EQUAL(pszIREP,"RGB/LUT") )
         {
@@ -749,113 +671,6 @@ NITFCollectSegmentInfo( NITFFile *psFile, int nOffset, char *pszType,
     return nOffset + nSegDefSize + 3;
 }
 
-/************************************************************************/
-/*                       NITFLoadLocationTable()                        */
-/************************************************************************/
-
-static void NITFLoadLocationTable( NITFFile *psFile )
-
-{
-    GUInt32  nLocTableOffset;
-    GUInt16  nLocCount;
-    int      iLoc;
-    const char *pszTRE;
-
-/* -------------------------------------------------------------------- */
-/*      Get the location table position from within the RPFHDR TRE      */
-/*      structure.                                                      */
-/* -------------------------------------------------------------------- */
-    pszTRE= NITFFindTRE( psFile->pachTRE, psFile->nTREBytes, "RPFHDR", NULL );
-    if( pszTRE == NULL )
-        return;
-
-    memcpy( &nLocTableOffset, pszTRE + 44, 4 );
-    nLocTableOffset = CPL_MSBWORD32( nLocTableOffset );
-    
-    if( nLocTableOffset == 0 )
-        return;
-
-/* -------------------------------------------------------------------- */
-/*      Read the count of entries in the location table.                */
-/* -------------------------------------------------------------------- */
-    VSIFSeekL( psFile->fp, nLocTableOffset + 6, SEEK_SET );
-    VSIFReadL( &nLocCount, 1, 2, psFile->fp );
-    nLocCount = CPL_MSBWORD16( nLocCount );
-    psFile->nLocCount = nLocCount;
-
-    psFile->pasLocations = (NITFLocation *) 
-        CPLCalloc(sizeof(NITFLocation), nLocCount);
-    
-/* -------------------------------------------------------------------- */
-/*      Process the locations.                                          */
-/* -------------------------------------------------------------------- */
-    VSIFSeekL( psFile->fp, 6, SEEK_CUR );
-    for( iLoc = 0; iLoc < nLocCount; iLoc++ )
-    {
-        unsigned char abyEntry[10];
-        
-        VSIFReadL( abyEntry, 1, 10, psFile->fp );
-        
-        psFile->pasLocations[iLoc].nLocId = abyEntry[0] * 256 + abyEntry[1];
-
-        CPL_MSBPTR32( abyEntry + 2 );
-        memcpy( &(psFile->pasLocations[iLoc].nLocSize), abyEntry + 2, 4 );
-
-        CPL_MSBPTR32( abyEntry + 6 );
-        memcpy( &(psFile->pasLocations[iLoc].nLocOffset), abyEntry + 6, 4 );
-    }
-}
-
-/************************************************************************/
-/*                          NITFLoadVQTables()                          */
-/************************************************************************/
-
-static int NITFLoadVQTables( NITFFile *psFile )
-
-{
-    int     i, nVQOffset=0, nVQSize=0;
-
-/* -------------------------------------------------------------------- */
-/*      Do we already have the VQ tables?                               */
-/* -------------------------------------------------------------------- */
-    if( psFile->apanVQLUT[0] != NULL )
-        return TRUE;
-
-/* -------------------------------------------------------------------- */
-/*      Do we have the location information?                            */
-/* -------------------------------------------------------------------- */
-    for( i = 0; i < psFile->nLocCount; i++ )
-    {
-        if( psFile->pasLocations[i].nLocId == 132 )
-        {
-            nVQOffset = psFile->pasLocations[i].nLocOffset;
-            nVQSize = psFile->pasLocations[i].nLocSize;
-        }
-    }
-
-    if( nVQOffset == 0 )
-        return FALSE;
-
-/* -------------------------------------------------------------------- */
-/*      Load the tables.                                                */
-/* -------------------------------------------------------------------- */
-    for( i = 0; i < 4; i++ )
-    {
-        GUInt32 nVQVector;
-
-        psFile->apanVQLUT[i] = (GUInt32 *) CPLCalloc(4096,sizeof(GUInt32));
-
-        VSIFSeekL( psFile->fp, nVQOffset + 6 + i*14 + 10, SEEK_SET );
-        VSIFReadL( &nVQVector, 1, 4, psFile->fp );
-        nVQVector = CPL_MSBWORD32( nVQVector );
-        
-        VSIFSeekL( psFile->fp, nVQOffset + nVQVector, SEEK_SET );
-        VSIFReadL( psFile->apanVQLUT[i], 4, 4096, psFile->fp );
-    }
-
-    return TRUE;
-}
-
 /************************************************************************/
 /*                            NITFGetField()                            */
 /*                                                                      */
@@ -902,6 +717,42 @@ const char *NITFFindTRE( const char *pszTREData, int nTREBytes,
     return NULL;
 }
 
+/************************************************************************/
+/*                     NITFFindTREByIndex()                             */
+/************************************************************************/
+
+const char *NITFFindTREByIndex( const char *pszTREData, int nTREBytes,
+                                const char *pszTag, int nTreIndex,
+                                int *pnFoundTRESize )
+
+{
+    char szTemp[100];
+
+    while( nTREBytes >= 11 )
+    {
+        int nThisTRESize = atoi(NITFGetField(szTemp, pszTREData, 6, 5 ));
+
+        if( EQUALN(pszTREData,pszTag,6) )
+        {
+            if ( nTreIndex <= 0)
+            {
+                if( pnFoundTRESize != NULL )
+                    *pnFoundTRESize = nThisTRESize;
+
+                return pszTREData + 11;
+            }
+
+            /* Found a prevoius one - skip it ... */
+            nTreIndex--;
+        }
+
+        nTREBytes -= (nThisTRESize + 11);
+        pszTREData += (nThisTRESize + 11);
+    }
+
+    return NULL;
+}
+
 /************************************************************************/
 /*                        NITFExtractMetadata()                         */
 /************************************************************************/
