@@ -1,6 +1,6 @@
 /*
  * setvtmv.c
-$Log: setvtmv.c,v $
+$Log$
 Revision 1.3  2006/02/07 10:17:15  kdejong
 Fixed endian compile problem
 some rcs issues of Kor, I guess
