@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: pcrasterdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: pcrasterdataset.cpp 12512 2007-10-23 13:55:47Z mloskot $
  *
  * Project:  PCRaster Integration
  * Purpose:  PCRaster CSF 2.0 raster file driver
@@ -29,7 +29,7 @@
 
 #include "gdal_pam.h"
 
-CPL_CVSID("$Id: pcrasterdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: pcrasterdataset.cpp 12512 2007-10-23 13:55:47Z mloskot $");
 
 #ifndef INCLUDED_PCRASTERDATASET
 #include "pcrasterdataset.h"
@@ -307,9 +307,9 @@ PCRasterDataset::PCRasterDataset(MAP* map)
   d_north = static_cast<double>(RgetYUL(d_map));
   d_cellSize = static_cast<double>(RgetCellSize(d_map));
   d_cellRepresentation = RgetUseCellRepr(d_map);
-  assert(d_cellRepresentation != CR_UNDEFINED);
+  CPLAssert(d_cellRepresentation != CR_UNDEFINED);
   d_valueScale = RgetValueScale(d_map);
-  assert(d_valueScale != VS_UNDEFINED);
+  CPLAssert(d_valueScale != VS_UNDEFINED);
   d_missingValue = ::missingValue(d_cellRepresentation);
 
   // Create band information objects.
