@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: dipxdataset.cpp,v 1.4 2006/02/09 05:38:56 fwarmerdam Exp $
+ * $Id: dipxdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GDAL
  * Purpose:  Implementation for ELAS DIPEx format variant.
@@ -25,28 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: dipxdataset.cpp,v $
- * Revision 1.4  2006/02/09 05:38:56  fwarmerdam
- * Added SRID support.
- *
- * Revision 1.3  2006/02/07 21:44:43  fwarmerdam
- * DIPX->DIPEx
- *
- * Revision 1.2  2006/02/07 01:22:57  fwarmerdam
- * Switch XOffset and YOffset per email from Drew.
- *
- * Revision 1.1  2006/02/01 17:22:34  fwarmerdam
- * New
- *
- */
+ ****************************************************************************/
 
 #include "rawdataset.h"
 #include "cpl_string.h"
 #include "ogr_spatialref.h"
 
-CPL_CVSID("$Id: dipxdataset.cpp,v 1.4 2006/02/09 05:38:56 fwarmerdam Exp $");
+CPL_CVSID("$Id: dipxdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 CPL_C_START
 void	GDALRegister_DIPEx(void);
