@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: doq1dataset.cpp,v 1.15 2005/07/25 18:07:48 fwarmerdam Exp $
+ * $Id: doq1dataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  USGS DOQ Driver (First Generation Format)
  * Purpose:  Implementation of DOQ1Dataset
@@ -25,59 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: doq1dataset.cpp,v $
- * Revision 1.15  2005/07/25 18:07:48  fwarmerdam
- * Fixed up description handling.
- *
- * Revision 1.14  2005/05/05 13:55:41  fwarmerdam
- * PAM Enable
- *
- * Revision 1.13  2002/09/17 13:09:28  warmerda
- * fix zone in WKT description - bugzilla 199
- *
- * Revision 1.12  2002/09/16 16:17:53  warmerda
- * XY_ORIGIN is the top left corner of pixel!
- *
- * Revision 1.11  2002/09/04 06:50:37  warmerda
- * avoid static driver pointers
- *
- * Revision 1.10  2002/06/25 14:57:43  warmerda
- * Added overview support.
- *
- * Revision 1.9  2002/06/12 21:12:25  warmerda
- * update to metadata based driver info
- *
- * Revision 1.8  2001/07/18 04:51:57  warmerda
- * added CPL_CVSID
- *
- * Revision 1.7  2000/09/25 21:20:13  warmerda
- * avoid initialization warnings
- *
- * Revision 1.6  2000/08/15 19:28:26  warmerda
- * added help topic
- *
- * Revision 1.5  2000/02/28 16:32:20  warmerda
- * use SetBand method
- *
- * Revision 1.4  2000/01/24 03:08:16  shadow
- * add description reading
- *
- * Revision 1.3  2000/01/06 20:58:21  warmerda
- * Fixed initial poOpenInfo check.
- *
- * Revision 1.2  1999/12/30 02:39:43  warmerda
- * Added projections support.
- *
- * Revision 1.1  1999/12/29 20:43:05  warmerda
- * New
- */
+ ****************************************************************************/
 
 #include "rawdataset.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: doq1dataset.cpp,v 1.15 2005/07/25 18:07:48 fwarmerdam Exp $");
+CPL_CVSID("$Id: doq1dataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 static double DOQGetField( unsigned char *, int );
 static void DOQGetDescription( GDALDataset *, unsigned char * );
