@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: envidataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: envidataset.cpp 11614 2007-06-07 17:20:06Z warmerdam $
  *
  * Project:  ENVI .hdr Driver
  * Purpose:  Implementation of ENVI .hdr labelled raw raster support.
@@ -31,7 +31,7 @@
 #include "ogr_spatialref.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: envidataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: envidataset.cpp 11614 2007-06-07 17:20:06Z warmerdam $");
 
 CPL_C_START
 void	GDALRegister_ENVI(void);
@@ -432,7 +432,7 @@ void ENVIDataset::FlushCache()
                 pszHemisphere = "South";
                 dfPixelY = adfGeoTransform[5];
             }
-  	    VSIFPrintf( fp, "map info = {UTM, 1, 1, %f, %f, %f, %f, %d, %s}\n",
+  	    VSIFPrintf( fp, "map info = {UTM, 1, 1, %.15g, %.15g, %.15g, %.15g, %d, %s}\n",
                         adfGeoTransform[0], adfGeoTransform[3], adfGeoTransform[1],
                         dfPixelY, iUTMZone, pszHemisphere);
         }
