@@ -1,12 +1,12 @@
 /******************************************************************************
- * $Id: fastdataset.cpp,v 1.19 2005/12/20 20:07:30 dron Exp $
+ * $Id: fastdataset.cpp 10938 2007-03-12 14:24:02Z dron $
  *
  * Project:  EOSAT FAST Format reader
  * Purpose:  Reads Landsat FAST-L7A, IRS 1C/1D
- * Author:   Andrey Kiselev, dron@at1895.spb.edu
+ * Author:   Andrey Kiselev, dron@ak4719.spb.edu
  *
  ******************************************************************************
- * Copyright (c) 2002, Andrey Kiselev <dron@at1895.spb.edu>
+ * Copyright (c) 2002, Andrey Kiselev <dron@ak4719.spb.edu>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -25,90 +25,14 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- * 
- * $Log: fastdataset.cpp,v $
- * Revision 1.19  2005/12/20 20:07:30  dron
- * Added support for 16-bit data.
- *
- * Revision 1.18  2005/09/14 13:18:32  dron
- * Avoid warnings.
- *
- * Revision 1.17  2005/05/05 13:55:42  fwarmerdam
- * PAM Enable
- *
- * Revision 1.16  2004/07/12 18:24:23  gwalter
- * Fixed geotransform calculation.
- *
- * Revision 1.15  2004/04/27 14:25:41  warmerda
- * Cast to avoid warning on Solaris.
- *
- * Revision 1.14  2004/03/16 18:27:39  dron
- * Fixes in projection parameters parsing code.
- *
- * Revision 1.13  2004/02/18 20:22:10  dron
- * Create RawRasterBand objects in "large" mode; more datums and ellipsoids.
- *
- * Revision 1.12  2004/02/17 08:05:45  dron
- * Do not calculate projection definition if corner coordinates are not set.
- *
- * Revision 1.11  2004/02/03 20:38:50  dron
- * Fixes in coordinate hadling; recognize more projections.
- *
- * Revision 1.10  2004/02/01 17:29:34  dron
- * Format parsing logic completely rewritten. Start using importFromUSGS().
- *
- * Revision 1.9  2003/10/17 07:08:21  dron
- * Use locale selection option in CPLScanDouble().
- *
- * Revision 1.8  2003/10/05 15:31:00  dron
- * TM projection support implemented.
- *
- * Revision 1.7  2003/07/08 21:10:19  warmerda
- * avoid warnings
- *
- * Revision 1.6  2003/03/14 17:28:10  dron
- * CPLFormCIFilename() used instead of CPLFormFilename() for FAST-L7 datasets.
- *
- * Revision 1.5  2003/03/05 15:49:59  dron
- * Fixed typo when reading SENSOR metadata record.
- *
- * Revision 1.4  2003/02/18 15:07:49  dron
- * IRS-1C/1D support added.
- *
- * Revision 1.3  2003/02/14 21:05:40  warmerda
- * Don't use path for rawdataset.h.
- *
- * Revision 1.2  2002/12/30 14:55:01  dron
- * SetProjCS() removed, added unit setting.
- *
- * Revision 1.1  2002/10/05 12:35:31  dron
- * FAST driver moved to the RAW directory.
- *
- * Revision 1.5  2002/10/04 16:06:06  dron
- * Some redundancy removed.
- *
- * Revision 1.4  2002/10/04 12:33:02  dron
- * Added calibration coefficients extraction.
- *
- * Revision 1.3  2002/09/04 06:50:37  warmerda
- * avoid static driver pointers
- *
- * Revision 1.2  2002/08/15 09:35:50  dron
- * Fixes in georeferencing
- *
- * Revision 1.1  2002/08/13 16:55:41  dron
- * Initial release
- *
- *
- */
+ ****************************************************************************/
 
 #include "cpl_string.h"
 #include "cpl_conv.h"
 #include "ogr_spatialref.h"
 #include "rawdataset.h"
 
-CPL_CVSID("$Id: fastdataset.cpp,v 1.19 2005/12/20 20:07:30 dron Exp $");
+CPL_CVSID("$Id: fastdataset.cpp 10938 2007-03-12 14:24:02Z dron $");
 
 CPL_C_START
 void	GDALRegister_FAST(void);
@@ -117,46 +41,49 @@ CPL_C_END
 #define ADM_STD_HEADER_SIZE	4608    // XXX: Format specification says it
 #define ADM_HEADER_SIZE		5000    // should be 4608, but some vendors
                                         // ship broken large datasets.
+#define ADM_MIN_HEADER_SIZE     1536    // ...and sometimes it can be
+                                        // even 1/3 of standard size
 
-#define ACQUISITION_DATE        "ACQUISITION DATE ="
+#define ACQUISITION_DATE        "ACQUISITION DATE"
 #define ACQUISITION_DATE_SIZE   8
 
-#define SATELLITE_NAME          "SATELLITE ="
+#define SATELLITE_NAME          "SATELLITE"
 #define SATELLITE_NAME_SIZE     10
 
-#define SENSOR_NAME             "SENSOR ="
+#define SENSOR_NAME             "SENSOR"
 #define SENSOR_NAME_SIZE        10
 
-#define FILENAME                "FILENAME ="
+#define FILENAME                "FILENAME"
 #define FILENAME_SIZE           29
 
-#define PIXELS                  "PIXELS PER LINE ="
+#define PIXELS                  "PIXELS PER LINE"
 #define PIXELS_SIZE             5
 
-#define LINES                   "LINES PER BAND ="
+#define LINES1                  "LINES PER BAND"
+#define LINES2                  "LINES PER IMAGE"
 #define LINES_SIZE              5
 
-#define BITS_PER_PIXEL          "OUTPUT BITS PER PIXEL ="
+#define BITS_PER_PIXEL          "OUTPUT BITS PER PIXEL"
 #define BITS_PER_PIXEL_SIZE     2
 
-#define PROJECTION_NAME         "MAP PROJECTION ="
+#define PROJECTION_NAME         "MAP PROJECTION"
 #define PROJECTION_NAME_SIZE    4
 
-#define ELLIPSOID_NAME          "ELLIPSOID ="
+#define ELLIPSOID_NAME          "ELLIPSOID"
 #define ELLIPSOID_NAME_SIZE     18
 
-#define DATUM_NAME              "DATUM ="
+#define DATUM_NAME              "DATUM"
 #define DATUM_NAME_SIZE         6
 
-#define ZONE_NUMBER             "USGS MAP ZONE ="
+#define ZONE_NUMBER             "USGS MAP ZONE"
 #define ZONE_NUMBER_SIZE        6
 
-#define USGS_PARAMETERS         "USGS PROJECTION PARAMETERS ="
+#define USGS_PARAMETERS         "USGS PROJECTION PARAMETERS"
 
-#define CORNER_UPPER_LEFT       "UL ="
-#define CORNER_UPPER_RIGHT      "UR ="
-#define CORNER_LOWER_LEFT       "LL ="
-#define CORNER_LOWER_RIGHT      "LR ="
+#define CORNER_UPPER_LEFT       "UL "
+#define CORNER_UPPER_RIGHT      "UR "
+#define CORNER_LOWER_LEFT       "LL "
+#define CORNER_LOWER_RIGHT      "LR "
 #define CORNER_VALUE_SIZE       13
 
 #define VALUE_SIZE              24
@@ -312,81 +239,89 @@ FILE *FASTDataset::FOpenChannel( char *pszFilename, int iBand )
     switch ( iSatellite )
     {
 	case LANDSAT:
-	if ( pszFilename && !EQUAL( pszFilename, "" ) )
-	{
-	    pszChannelFilename =
-                CPLFormCIFilename( pszDirname, pszFilename, NULL );
-	    fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
-	}
-	else
-	    fpChannels[iBand] = NULL;
-	break;
+            if ( pszFilename && !EQUAL( pszFilename, "" ) )
+            {
+                pszChannelFilename =
+                    CPLFormCIFilename( pszDirname, pszFilename, NULL );
+                fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
+                if ( !fpChannels[iBand] )
+                {
+                    pszChannelFilename =
+                        CPLFormFilename( pszDirname,
+                                CPLSPrintf( "%s.b%02d", pszPrefix, iBand + 1 ),
+                                NULL );
+                    fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
+                }
+            }
+            else
+                fpChannels[iBand] = NULL;
+            break;
 	case IRS:
 	default:
-	pszChannelFilename = CPLFormFilename( pszDirname,
-	    CPLSPrintf( "%s.%d", pszPrefix, iBand + 1 ), pszSuffix );
-	fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
-	if ( fpChannels[iBand] )
-	    break;
-	pszChannelFilename = CPLFormFilename( pszDirname,
-	    CPLSPrintf( "IMAGERY%d", iBand + 1 ), pszSuffix );
-	fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
-	if ( fpChannels[iBand] )
-	    break;
-	pszChannelFilename = CPLFormFilename( pszDirname,
-	    CPLSPrintf( "imagery%d", iBand + 1 ), pszSuffix );
-	fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
-	if ( fpChannels[iBand] )
-	    break;
-	pszChannelFilename = CPLFormFilename( pszDirname,
-	    CPLSPrintf( "IMAGERY%d.DAT", iBand + 1 ), NULL );
-	fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
-	if ( fpChannels[iBand] )
-	    break;
-	pszChannelFilename = CPLFormFilename( pszDirname,
-	    CPLSPrintf( "imagery%d.dat", iBand + 1 ), NULL );
-	fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
-	if ( fpChannels[iBand] )
-	    break;
-	pszChannelFilename = CPLFormFilename( pszDirname,
-	    CPLSPrintf( "IMAGERY%d.dat", iBand + 1 ), NULL );
-	fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
-	if ( fpChannels[iBand] )
-	    break;
-	pszChannelFilename = CPLFormFilename( pszDirname,
-	    CPLSPrintf( "imagery%d.DAT", iBand + 1 ), NULL );
-	fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
-	if ( fpChannels[iBand] )
-	    break;
-	pszChannelFilename = CPLFormFilename( pszDirname,
-	    CPLSPrintf( "BAND%d", iBand + 1 ), pszSuffix );
-	fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
-	if ( fpChannels[iBand] )
-	    break;
-	pszChannelFilename = CPLFormFilename( pszDirname,
-	    CPLSPrintf( "band%d", iBand + 1 ), pszSuffix );
-	fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
-	if ( fpChannels[iBand] )
-	    break;
-	pszChannelFilename = CPLFormFilename( pszDirname,
-	    CPLSPrintf( "BAND%d.DAT", iBand + 1 ), NULL );
-	fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
-	if ( fpChannels[iBand] )
-	    break;
-	pszChannelFilename = CPLFormFilename( pszDirname,
-	    CPLSPrintf( "band%d.dat", iBand + 1 ), NULL );
-	fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
-	if ( fpChannels[iBand] )
-	    break;
-	pszChannelFilename = CPLFormFilename( pszDirname,
-	    CPLSPrintf( "BAND%d.dat", iBand + 1 ), NULL );
-	fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
-	if ( fpChannels[iBand] )
-	    break;
-	pszChannelFilename = CPLFormFilename( pszDirname,
-	    CPLSPrintf( "band%d.DAT", iBand + 1 ), NULL );
-	fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
-	break;
+            pszChannelFilename = CPLFormFilename( pszDirname,
+                CPLSPrintf( "%s.%d", pszPrefix, iBand + 1 ), pszSuffix );
+            fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
+            if ( fpChannels[iBand] )
+                break;
+            pszChannelFilename = CPLFormFilename( pszDirname,
+                CPLSPrintf( "IMAGERY%d", iBand + 1 ), pszSuffix );
+            fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
+            if ( fpChannels[iBand] )
+                break;
+            pszChannelFilename = CPLFormFilename( pszDirname,
+                CPLSPrintf( "imagery%d", iBand + 1 ), pszSuffix );
+            fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
+            if ( fpChannels[iBand] )
+                break;
+            pszChannelFilename = CPLFormFilename( pszDirname,
+                CPLSPrintf( "IMAGERY%d.DAT", iBand + 1 ), NULL );
+            fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
+            if ( fpChannels[iBand] )
+                break;
+            pszChannelFilename = CPLFormFilename( pszDirname,
+                CPLSPrintf( "imagery%d.dat", iBand + 1 ), NULL );
+            fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
+            if ( fpChannels[iBand] )
+                break;
+            pszChannelFilename = CPLFormFilename( pszDirname,
+                CPLSPrintf( "IMAGERY%d.dat", iBand + 1 ), NULL );
+            fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
+            if ( fpChannels[iBand] )
+                break;
+            pszChannelFilename = CPLFormFilename( pszDirname,
+                CPLSPrintf( "imagery%d.DAT", iBand + 1 ), NULL );
+            fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
+            if ( fpChannels[iBand] )
+                break;
+            pszChannelFilename = CPLFormFilename( pszDirname,
+                CPLSPrintf( "BAND%d", iBand + 1 ), pszSuffix );
+            fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
+            if ( fpChannels[iBand] )
+                break;
+            pszChannelFilename = CPLFormFilename( pszDirname,
+                CPLSPrintf( "band%d", iBand + 1 ), pszSuffix );
+            fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
+            if ( fpChannels[iBand] )
+                break;
+            pszChannelFilename = CPLFormFilename( pszDirname,
+                CPLSPrintf( "BAND%d.DAT", iBand + 1 ), NULL );
+            fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
+            if ( fpChannels[iBand] )
+                break;
+            pszChannelFilename = CPLFormFilename( pszDirname,
+                CPLSPrintf( "band%d.dat", iBand + 1 ), NULL );
+            fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
+            if ( fpChannels[iBand] )
+                break;
+            pszChannelFilename = CPLFormFilename( pszDirname,
+                CPLSPrintf( "BAND%d.dat", iBand + 1 ), NULL );
+            fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
+            if ( fpChannels[iBand] )
+                break;
+            pszChannelFilename = CPLFormFilename( pszDirname,
+                CPLSPrintf( "band%d.DAT", iBand + 1 ), NULL );
+            fpChannels[iBand] = VSIFOpenL( pszChannelFilename, "rb" );
+            break;
     }
     
     CPLDebug( "FAST", "Band %d filename=%s", iBand + 1, pszChannelFilename);
@@ -407,7 +342,14 @@ static char *GetValue( const char *pszString, const char *pszName,
 
     if ( pszTemp )
     {
+        // Skip the parameter name
         pszTemp += strlen( pszName );
+        // Skip whitespaces and equal signs
+        while ( *pszTemp == ' ' )
+            pszTemp++;
+        while ( *pszTemp == '=' )
+            pszTemp++;
+
         pszTemp = CPLScanString( pszTemp, iValueSize, TRUE, iNormalize );
     }
 
@@ -501,6 +443,8 @@ GDALDataset *FASTDataset::Open( GDALOpenInfo * poOpenInfo )
         return NULL;
 
     if( !EQUALN((const char *) poOpenInfo->pabyHeader + 52,
+		"ACQUISITION DATE =", 18)
+        && !EQUALN((const char *) poOpenInfo->pabyHeader + 36,
 		"ACQUISITION DATE =", 18) )
         return NULL;
     
@@ -525,7 +469,7 @@ GDALDataset *FASTDataset::Open( GDALOpenInfo * poOpenInfo )
  
     VSIFSeek( poDS->fpHeader, 0, SEEK_SET );
     nBytesRead = VSIFRead( pszHeader, 1, ADM_HEADER_SIZE, poDS->fpHeader );
-    if ( nBytesRead < ADM_STD_HEADER_SIZE )
+    if ( nBytesRead < ADM_MIN_HEADER_SIZE )
     {
 	CPLDebug( "FAST", "Header file too short. Reading failed" );
 	delete poDS;
@@ -566,7 +510,13 @@ GDALDataset *FASTDataset::Open( GDALOpenInfo * poOpenInfo )
             pszTemp = strstr( pszTemp, FILENAME );
         if ( pszTemp )
         {
+            // Skip the parameter name
             pszTemp += strlen(FILENAME);
+            // Skip whitespaces and equal signs
+            while ( *pszTemp == ' ' )
+                pszTemp++;
+            while ( *pszTemp == '=' )
+                pszTemp++;
             pszFilename = CPLScanString( pszTemp, FILENAME_SIZE, TRUE, FALSE );
         }
         else
@@ -585,10 +535,12 @@ GDALDataset *FASTDataset::Open( GDALOpenInfo * poOpenInfo )
     }
 
     // Read number of pixels/lines and bit depth
-    pszTemp = strstr( pszHeader, PIXELS );
+    pszTemp = GetValue( pszHeader, PIXELS, PIXELS_SIZE, FALSE );
     if ( pszTemp )
-        poDS->nRasterXSize = CPLScanLong( pszTemp + strlen(PIXELS),
-                                          PIXELS_SIZE );
+    {
+        poDS->nRasterXSize = atoi( pszTemp );
+        CPLFree( pszTemp );
+    }
     else
     {
         CPLDebug( "FAST", "Failed to find number of pixels in line." );
@@ -596,9 +548,14 @@ GDALDataset *FASTDataset::Open( GDALOpenInfo * poOpenInfo )
 	return NULL;
     }
 
-    pszTemp = strstr( pszHeader, LINES );
+    pszTemp = GetValue( pszHeader, LINES1, LINES_SIZE, FALSE );
+    if ( !pszTemp )
+        pszTemp = GetValue( pszHeader, LINES2, LINES_SIZE, FALSE );
     if ( pszTemp )
-        poDS->nRasterYSize = CPLScanLong( pszTemp + strlen(LINES), LINES_SIZE );
+    {
+        poDS->nRasterYSize = atoi( pszTemp );
+        CPLFree( pszTemp );
+    }
     else
     {
         CPLDebug( "FAST", "Failed to find number of lines in raster." );
@@ -606,47 +563,67 @@ GDALDataset *FASTDataset::Open( GDALOpenInfo * poOpenInfo )
 	return NULL;
     }
 
-    pszTemp = strstr( pszHeader, BITS_PER_PIXEL );
-    switch( CPLScanLong(pszTemp+strlen(BITS_PER_PIXEL), BITS_PER_PIXEL_SIZE) )
+    pszTemp = GetValue( pszHeader, BITS_PER_PIXEL, BITS_PER_PIXEL_SIZE, FALSE );
+    if ( pszTemp )
     {
-	case 8:
-        default:
-	    poDS->eDataType = GDT_Byte;
-	    break;
-	case 16:
-	    poDS->eDataType = GDT_UInt16;
-	    break;
+        switch( atoi(pszTemp) )
+        {
+            case 8:
+            default:
+                poDS->eDataType = GDT_Byte;
+                break;
+            case 16:
+                poDS->eDataType = GDT_UInt16;
+                break;
+        }
+        CPLFree( pszTemp );
     }
+    else
+        poDS->eDataType = GDT_Byte;
 
 /* -------------------------------------------------------------------- */
 /*  Read radiometric record.    					*/
 /* -------------------------------------------------------------------- */
+    char    *pszFirst, *pszSecond;
+
     // Read gains and biases. This is a trick!
     pszTemp = strstr( pszHeader, "BIASES" );// It may be "BIASES AND GAINS"
                                             // or "GAINS AND BIASES"
+    if ( pszTemp > strstr( pszHeader, "GAINS" ) )
+    {
+        pszFirst = "GAIN%d";
+        pszSecond = "BIAS%d";
+    }
+    else
+    {
+        pszFirst = "BIAS%d";
+        pszSecond = "GAIN%d";
+    }
+
     // Now search for the first number occurance after that string
     for ( i = 1; i <= poDS->nBands; i++ )
     {
-        char *pszValue = NULL;
+        char    *pszValue = NULL;
+        size_t  nValueLen = VALUE_SIZE;
 
         pszTemp = strpbrk( pszTemp, "-.0123456789" );
         if ( pszTemp )
         {
-            pszValue = CPLScanString( pszTemp, VALUE_SIZE, TRUE, TRUE );
-            poDS->SetMetadataItem( CPLSPrintf("BIAS%d", i ), pszValue );
-        }
-        pszTemp += VALUE_SIZE;
-        if ( pszValue )
+            nValueLen = strspn( pszTemp, "+-.0123456789" );
+            pszValue = CPLScanString( pszTemp, nValueLen, TRUE, TRUE );
+            poDS->SetMetadataItem( CPLSPrintf(pszFirst, i ), pszValue );
             CPLFree( pszValue );
+        }
+        pszTemp += nValueLen;
         pszTemp = strpbrk( pszTemp, "-.0123456789" );
         if ( pszTemp )
         {
-            pszValue = CPLScanString( pszTemp, VALUE_SIZE, TRUE, TRUE );
-            poDS->SetMetadataItem( CPLSPrintf("GAIN%d", i ), pszValue );
-        }
-        pszTemp += VALUE_SIZE;
-        if ( pszValue )
+            nValueLen = strspn( pszTemp, "+-.0123456789" );
+            pszValue = CPLScanString( pszTemp, nValueLen, TRUE, TRUE );
+            poDS->SetMetadataItem( CPLSPrintf(pszSecond, i ), pszValue );
             CPLFree( pszValue );
+        }
+        pszTemp += nValueLen;
     }
 
 /* -------------------------------------------------------------------- */
@@ -685,6 +662,9 @@ GDALDataset *FASTDataset::Open( GDALOpenInfo * poOpenInfo )
     else
         iZone = 0L;
     CPLFree( pszTemp );
+#if DEBUG
+    CPLDebug("FAST", "USGS zone number %ld.", iZone);
+#endif
 
     // Read 15 USGS projection parameters
     for ( i = 0; i < 15; i++ )
@@ -707,41 +687,56 @@ GDALDataset *FASTDataset::Open( GDALOpenInfo * poOpenInfo )
         }
     }
 
+    // Coordinates should follow the word "PROJECTION", otherwise we can
+    // be confused by other occurences of the corner keywords.
+    char        *pszGeomRecord = strstr( pszHeader, "PROJECTION" );
     // Read corner coordinates
-    pszTemp = strstr( pszHeader, CORNER_UPPER_LEFT );
+    pszTemp = strstr( pszGeomRecord, CORNER_UPPER_LEFT );
     if ( pszTemp && !EQUAL( pszTemp, "" ) )
     {
         pszTemp += strlen( CORNER_UPPER_LEFT ) + 28;
         dfULX = CPLScanDouble( pszTemp, CORNER_VALUE_SIZE, "C" );
         pszTemp += CORNER_VALUE_SIZE + 1;
         dfULY = CPLScanDouble( pszTemp, CORNER_VALUE_SIZE, "C" );
+#if DEBUG
+        CPLDebug("FAST", "Upper left coordinates: %f, %f.", dfULX, dfULY);
+#endif
     }
 
-    pszTemp = strstr( pszHeader, CORNER_UPPER_RIGHT );
+    pszTemp = strstr( pszGeomRecord, CORNER_UPPER_RIGHT );
     if ( pszTemp && !EQUAL( pszTemp, "" ) )
     {
         pszTemp += strlen( CORNER_UPPER_RIGHT ) + 28;
         dfURX = CPLScanDouble( pszTemp, CORNER_VALUE_SIZE, "C" );
         pszTemp += CORNER_VALUE_SIZE + 1;
         dfURY = CPLScanDouble( pszTemp, CORNER_VALUE_SIZE, "C" );
+#if DEBUG
+        CPLDebug("FAST", "Upper right coordinates: %f, %f.", dfURX, dfURY);
+#endif
     }
 
-    pszTemp = strstr( pszHeader, CORNER_LOWER_LEFT );
+    pszTemp = strstr( pszGeomRecord, CORNER_LOWER_LEFT );
     if ( pszTemp && !EQUAL( pszTemp, "" ) )
     {
         pszTemp += strlen( CORNER_LOWER_LEFT ) + 28;
         dfLLX = CPLScanDouble( pszTemp, CORNER_VALUE_SIZE, "C" );
         pszTemp += CORNER_VALUE_SIZE + 1;
         dfLLY = CPLScanDouble( pszTemp, CORNER_VALUE_SIZE, "C" );
+#if DEBUG
+        CPLDebug("FAST", "Lower left coordinates: %f, %f.", dfLLX, dfLLY);
+#endif
     }
 
-    pszTemp = strstr( pszHeader, CORNER_LOWER_RIGHT );
+    pszTemp = strstr( pszGeomRecord, CORNER_LOWER_RIGHT );
     if ( pszTemp && !EQUAL( pszTemp, "" ) )
     {
         pszTemp += strlen( CORNER_LOWER_RIGHT ) + 28;
         dfLRX = CPLScanDouble( pszTemp, CORNER_VALUE_SIZE, "C" );
         pszTemp += CORNER_VALUE_SIZE + 1;
         dfLRY = CPLScanDouble( pszTemp, CORNER_VALUE_SIZE, "C" );
+#if DEBUG
+        CPLDebug("FAST", "Lower right coordinates: %f, %f.", dfLRX, dfLRY);
+#endif
     }
 
     if ( dfULX != 0.0 && dfULY != 0.0
@@ -763,22 +758,35 @@ GDALDataset *FASTDataset::Open( GDALOpenInfo * poOpenInfo )
             dfLRX -= (double)iZone * 1000000.0;
 
         // Create projection definition
-        oSRS.importFromUSGS( iProjSys, iZone, adfProjParms, iDatum );
+        OGRErr eErr =
+            oSRS.importFromUSGS( iProjSys, iZone, adfProjParms, iDatum );
+        if ( eErr != OGRERR_NONE )
+            CPLDebug("FAST", "Import projection from USGS failed: %d", eErr);
         oSRS.SetLinearUnits( SRS_UL_METER, 1.0 );
         
         // Read datum name
         pszTemp = GetValue( pszHeader, DATUM_NAME, DATUM_NAME_SIZE, FALSE );
-        if ( EQUAL( pszTemp, "WGS84" ) )
+        if ( pszTemp )
+        {
+            if ( EQUAL( pszTemp, "WGS84" ) )
+                oSRS.SetWellKnownGeogCS( "WGS84" );
+            else if ( EQUAL( pszTemp, "NAD27" ) )
+                oSRS.SetWellKnownGeogCS( "NAD27" );
+            else if ( EQUAL( pszTemp, "NAD83" ) )
+                oSRS.SetWellKnownGeogCS( "NAD83" );
+            CPLFree( pszTemp );
+        }
+        else
+        {
+            // Reasonable fallback
             oSRS.SetWellKnownGeogCS( "WGS84" );
-        else if ( EQUAL( pszTemp, "NAD27" ) )
-            oSRS.SetWellKnownGeogCS( "NAD27" );
-        else if ( EQUAL( pszTemp, "NAD83" ) )
-            oSRS.SetWellKnownGeogCS( "NAD83" );
-        CPLFree( pszTemp );
+        }
 
         if ( poDS->pszProjection )
             CPLFree( poDS->pszProjection );
-        oSRS.exportToWkt( &poDS->pszProjection );
+        eErr = oSRS.exportToWkt( &poDS->pszProjection );
+        if ( eErr != OGRERR_NONE )
+            CPLDebug("FAST", "Export projection to WKT USGS failed: %d", eErr);
 
         // Generate GCPs
         pasGCPList = (GDAL_GCP *) CPLCalloc( sizeof( GDAL_GCP ), 4 );
@@ -810,7 +818,8 @@ GDALDataset *FASTDataset::Open( GDALOpenInfo * poOpenInfo )
         pasGCPList[3].dfGCPLine = poDS->nRasterYSize-0.5;
 
         // Calculate transformation matrix, if accurate
-        transform_ok = GDALGCPsToGeoTransform(4,pasGCPList,poDS->adfGeoTransform,0);
+        transform_ok =
+            GDALGCPsToGeoTransform(4,pasGCPList,poDS->adfGeoTransform,0);
         if (transform_ok == FALSE)
         {
             
@@ -833,11 +842,16 @@ GDALDataset *FASTDataset::Open( GDALOpenInfo * poOpenInfo )
     int nLineOffset = poDS->nRasterXSize * nPixelOffset;
 
     for( i = 1; i <= poDS->nBands; i++ )
+    {
         poDS->SetBand( i, new FASTRasterBand( poDS, i, poDS->fpChannels[i - 1],
 	    0, nPixelOffset, nLineOffset, poDS->eDataType, TRUE));
+    }
 
     CPLFree( pszHeader );
 
+    // opens overviews.
+    poDS->oOvManager.Initialize(poDS, poDS->pszFilename);
+
 /* -------------------------------------------------------------------- */
 /*      Initialize any PAM information.                                 */
 /* -------------------------------------------------------------------- */
