@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: fujibasdataset.cpp,v 1.5 2005/05/05 13:55:42 fwarmerdam Exp $
+ * $Id: fujibasdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  eCognition
  * Purpose:  Implementation of FUJI BAS Format
@@ -25,30 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: fujibasdataset.cpp,v $
- * Revision 1.5  2005/05/05 13:55:42  fwarmerdam
- * PAM Enable
- *
- * Revision 1.4  2002/09/04 06:50:37  warmerda
- * avoid static driver pointers
- *
- * Revision 1.3  2002/06/12 21:12:25  warmerda
- * update to metadata based driver info
- *
- * Revision 1.2  2001/07/18 04:51:57  warmerda
- * added CPL_CVSID
- *
- * Revision 1.1  2001/05/15 13:20:45  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "rawdataset.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: fujibasdataset.cpp,v 1.5 2005/05/05 13:55:42 fwarmerdam Exp $");
+CPL_CVSID("$Id: fujibasdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 CPL_C_START
 void	GDALRegister_FujiBAS(void);
