@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gscdataset.cpp,v 1.3 2005/05/05 13:55:42 fwarmerdam Exp $
+ * $Id: gscdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GSC Geogrid format driver.
  * Purpose:  Implements support for reading and writing GSC Geogrid format.
@@ -25,24 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: gscdataset.cpp,v $
- * Revision 1.3  2005/05/05 13:55:42  fwarmerdam
- * PAM Enable
- *
- * Revision 1.2  2002/10/03 06:07:31  warmerda
- * Added nodata support.
- *
- * Revision 1.1  2002/10/03 05:40:48  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "rawdataset.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: gscdataset.cpp,v 1.3 2005/05/05 13:55:42 fwarmerdam Exp $");
+CPL_CVSID("$Id: gscdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /* ==================================================================== */
