@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: hkvdataset.cpp,v 1.40 2006/04/10 16:27:16 fwarmerdam Exp $
+ * $Id: hkvdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GView
  * Purpose:  Implementation of Atlantis HKV labelled blob support
@@ -25,131 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: hkvdataset.cpp,v $
- * Revision 1.40  2006/04/10 16:27:16  fwarmerdam
- * Fixed contact info.
- *
- * Revision 1.39  2006/01/16 20:28:56  gwalter
- * Fixed cplusplus misuse.
- *
- * Revision 1.38  2006/01/05 16:21:56  gwalter
- * Added nodata write support.
- *
- * Revision 1.37  2005/12/22 22:08:35  gwalter
- * Update MFF2 documentation; Atlantis->Vexcel.
- *
- * Revision 1.36  2005/05/05 13:55:42  fwarmerdam
- * PAM Enable
- *
- * Revision 1.35  2004/01/23 18:55:01  gwalter
- * Remove unnecessary print statement.
- *
- * Revision 1.34  2003/08/12 15:37:40  gwalter
- * Make sure wgs-84 and wgs_84 treated the same way.
- *
- * Revision 1.33  2003/08/12 15:26:09  gwalter
- * Bug fix for wgs_84 LL projection case.
- *
- * Revision 1.32  2003/07/08 21:10:19  warmerda
- * avoid warnings
- *
- * Revision 1.31  2003/04/10 22:13:40  gwalter
- * Updated spheroids: some applications use _ instead of - in spheroid names.
- *
- * Revision 1.30  2003/04/02 18:46:45  gwalter
- * Fixed one-off error in number of spheroids.
- *
- * Revision 1.29  2003/03/20 19:12:35  gwalter
- * Fix identity geotransform check in hkvdataset.cpp.
- *
- * Revision 1.28  2003/03/18 19:03:44  gwalter
- * Add flushing, fix coordinate interpretation.
- *
- * Revision 1.27  2003/03/13 18:34:02  gwalter
- * Fix data type determination in CreateCopy.
- *
- * Revision 1.26  2003/03/11 21:00:30  gwalter
- * More georeferencing-related updates.
- *
- * Revision 1.25  2003/03/03 20:10:05  gwalter
- * Updated MFF and HKV (MFF2) georeferencing support.
- *
- * Revision 1.24  2002/11/23 18:54:17  warmerda
- * added CREATIONDATATYPES metadata for drivers
- *
- * Revision 1.23  2002/09/04 06:50:37  warmerda
- * avoid static driver pointers
- *
- * Revision 1.22  2002/06/19 18:21:08  warmerda
- * removed stat buf from GDALOpenInfo
- *
- * Revision 1.21  2002/06/12 21:12:25  warmerda
- * update to metadata based driver info
- *
- * Revision 1.20  2002/04/24 19:27:00  warmerda
- * Added HKV nodata read support (pixel.no_data).
- *
- * Revision 1.19  2001/12/12 18:15:46  warmerda
- * preliminary update for large raw file support
- *
- * Revision 1.18  2001/12/12 17:19:06  warmerda
- * Use CPLStat for directories.
- *
- * Revision 1.17  2001/12/08 04:45:59  warmerda
- * fixed south setting for UTM
- *
- * Revision 1.16  2001/11/11 23:51:00  warmerda
- * added required class keyword to friend declarations
- *
- * Revision 1.15  2001/07/18 04:51:57  warmerda
- * added CPL_CVSID
- *
- * Revision 1.14  2001/07/11 18:09:06  warmerda
- * Correct corner GCPs. BOTTOM_RIGHT actually refers to the top left corner of
- * the bottom right pixel!
- *
- * Revision 1.13  2001/06/20 16:10:02  warmerda
- * overhauled to TIFF style overviews
- *
- * Revision 1.12  2001/06/13 19:42:10  warmerda
- * Changed blob->image_data, and HKV to MFF2.
- *
- * Revision 1.11  2000/12/14 17:34:13  warmerda
- * Added dataset delete method.
- *
- * Revision 1.10  2000/12/05 22:40:09  warmerda
- * Added very limited SetProjection support, includes Bessel
- *
- * Revision 1.9  2000/11/29 21:31:28  warmerda
- * added support for writing georef on SetGeoTransform
- *
- * Revision 1.8  2000/08/16 15:51:39  warmerda
- * added support for reading overviews
- *
- * Revision 1.7  2000/08/15 19:28:26  warmerda
- * added help topic
- *
- * Revision 1.6  2000/07/12 19:21:59  warmerda
- * added support for _reading_ georef file
- *
- * Revision 1.5  2000/06/05 17:24:06  warmerda
- * added real complex support
- *
- * Revision 1.4  2000/05/15 14:18:27  warmerda
- * added COMPLEX_INTERPRETATION metadata
- *
- * Revision 1.3  2000/04/05 19:28:48  warmerda
- * Fixed MSB case.
- *
- * Revision 1.2  2000/03/13 14:34:42  warmerda
- * avoid const problem on write
- *
- * Revision 1.1  2000/03/07 21:33:42  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "rawdataset.h"
 #include "cpl_string.h"
@@ -157,7 +33,7 @@
 #include "ogr_spatialref.h"
 #include "atlsci_spheroid.h"
 
-CPL_CVSID("$Id: hkvdataset.cpp,v 1.40 2006/04/10 16:27:16 fwarmerdam Exp $");
+CPL_CVSID("$Id: hkvdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 CPL_C_START
 void	GDALRegister_HKV(void);
