@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: idadataset.cpp,v 1.9 2005/09/14 01:12:00 fwarmerdam Exp $
+ * $Id: idadataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  IDA Raster Driver
  * Purpose:  Implemenents IDA driver/dataset/rasterband.
@@ -25,42 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: idadataset.cpp,v $
- * Revision 1.9  2005/09/14 01:12:00  fwarmerdam
- * Fixed creation data types and help link.
- *
- * Revision 1.8  2005/08/23 16:21:25  fwarmerdam
- * Fixed help link, dont barf in open if fp null.
- *
- * Revision 1.7  2005/05/05 13:55:42  fwarmerdam
- * PAM Enable
- *
- * Revision 1.6  2005/02/08 20:22:39  fwarmerdam
- * Added SetProjection support.
- *
- * Revision 1.5  2005/01/15 16:11:12  fwarmerdam
- * lots of work on create support
- *
- * Revision 1.4  2005/01/04 22:14:33  fwarmerdam
- * Nailed down open checking fairly closely.
- *
- * Revision 1.3  2004/12/26 21:25:36  fwarmerdam
- * avoid spurious opens
- *
- * Revision 1.2  2004/12/26 17:37:46  fwarmerdam
- * fix unix/dos format
- *
- * Revision 1.1  2004/12/26 16:17:00  fwarmerdam
- * New
- *
- */
+ ****************************************************************************/
 
 #include "rawdataset.h"
 #include "ogr_spatialref.h"
+#include "gdal_rat.h"
 
-CPL_CVSID("$Id: idadataset.cpp,v 1.9 2005/09/14 01:12:00 fwarmerdam Exp $");
+CPL_CVSID("$Id: idadataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 CPL_C_START
 void	GDALRegister_IDA(void);
@@ -109,6 +80,8 @@ class IDADataset : public RawDataset
 
     GByte       abyHeader[512];
     int         bHeaderDirty;
+
+    void        ReadColorTable();
     
   public:
     		IDADataset();
@@ -139,10 +112,16 @@ class IDARasterBand : public RawRasterBand
 {
     friend class IDADataset;
 
+    GDALRasterAttributeTable *poRAT;
+    GDALColorTable       *poColorTable;
+
   public:
     		IDARasterBand( IDADataset *poDSIn, FILE *fpRaw, int nXSize );
     virtual     ~IDARasterBand();
 
+    virtual const GDALRasterAttributeTable *GetDefaultRAT();
+    virtual GDALColorInterp GetColorInterpretation();
+    virtual GDALColorTable *GetColorTable();
     virtual double GetOffset( int *pbSuccess = NULL );
     virtual CPLErr SetOffset( double dfNewValue );
     virtual double GetScale( int *pbSuccess = NULL );
@@ -160,6 +139,8 @@ IDARasterBand::IDARasterBand( IDADataset *poDSIn,
                          GDT_Byte, FALSE, FALSE )
 
 {
+    poColorTable = NULL;
+    poRAT = NULL;
 }
 
 /************************************************************************/
@@ -169,6 +150,8 @@ IDARasterBand::IDARasterBand( IDADataset *poDSIn,
 IDARasterBand::~IDARasterBand()
 
 {
+    delete poColorTable;
+    delete poRAT;
 }
 
 /************************************************************************/
@@ -215,7 +198,7 @@ CPLErr IDARasterBand::SetOffset( double dfNewValue )
     }
 
     poIDS->dfB = dfNewValue;
-    c2tp( dfNewValue, poIDS->abyHeader + 178 );
+    c2tp( dfNewValue, poIDS->abyHeader + 177 );
     poIDS->bHeaderDirty = TRUE;
 
     return CE_None;
@@ -253,12 +236,51 @@ CPLErr IDARasterBand::SetScale( double dfNewValue )
     }
 
     poIDS->dfM = dfNewValue;
-    c2tp( dfNewValue, poIDS->abyHeader + 172 );
+    c2tp( dfNewValue, poIDS->abyHeader + 171 );
     poIDS->bHeaderDirty = TRUE;
 
     return CE_None;
 }
 
+/************************************************************************/
+/*                           GetColorTable()                            */
+/************************************************************************/
+
+GDALColorTable *IDARasterBand::GetColorTable()
+
+{
+    if( poColorTable )
+        return poColorTable;
+    else
+        return RawRasterBand::GetColorTable();
+}
+
+/************************************************************************/
+/*                       GetColorInterpretation()                       */
+/************************************************************************/
+
+GDALColorInterp IDARasterBand::GetColorInterpretation()
+
+{
+    if( poColorTable )
+        return GCI_PaletteIndex;
+    else
+        return RawRasterBand::GetColorInterpretation();
+}
+
+/************************************************************************/
+/*                           GetDefaultRAT()                            */
+/************************************************************************/
+
+const GDALRasterAttributeTable *IDARasterBand::GetDefaultRAT() 
+
+{
+    if( poRAT )
+        return poRAT;
+    else
+        return RawRasterBand::GetDefaultRAT();
+}
+
 /************************************************************************/
 /* ==================================================================== */
 /*				IDADataset				*/
@@ -532,6 +554,127 @@ CPLErr IDADataset::SetProjection( const char *pszWKTIn )
     return CE_None;
 }
 
+/************************************************************************/
+/*                           ReadColorTable()                           */
+/************************************************************************/
+
+void IDADataset::ReadColorTable()
+
+{
+/* -------------------------------------------------------------------- */
+/*      Decide what .clr file to look for and try to open.              */
+/* -------------------------------------------------------------------- */
+    CPLString osCLRFilename;
+
+    osCLRFilename = CPLGetConfigOption( "IDA_COLOR_FILE", "" );
+    if( strlen(osCLRFilename) == 0 )
+        osCLRFilename = CPLResetExtension(GetDescription(), "clr" );
+
+
+    FILE *fp = VSIFOpen( osCLRFilename, "r" );
+    if( fp == NULL )
+    {
+        osCLRFilename = CPLResetExtension(osCLRFilename, "CLR" );
+        fp = VSIFOpen( osCLRFilename, "r" );
+    }
+
+    if( fp == NULL )
+        return;
+
+/* -------------------------------------------------------------------- */
+/*      Skip first line, with the column titles.                        */
+/* -------------------------------------------------------------------- */
+    CPLReadLine( fp );
+
+/* -------------------------------------------------------------------- */
+/*      Create a RAT to populate.                                       */
+/* -------------------------------------------------------------------- */
+    GDALRasterAttributeTable *poRAT = new GDALRasterAttributeTable();
+
+    poRAT->CreateColumn( "FROM", GFT_Integer, GFU_Min );
+    poRAT->CreateColumn( "TO", GFT_Integer, GFU_Max );
+    poRAT->CreateColumn( "RED", GFT_Integer, GFU_Red );
+    poRAT->CreateColumn( "GREEN", GFT_Integer, GFU_Green );
+    poRAT->CreateColumn( "BLUE", GFT_Integer, GFU_Blue );
+    poRAT->CreateColumn( "LEGEND", GFT_String, GFU_Name );
+
+/* -------------------------------------------------------------------- */
+/*      Apply lines.                                                    */
+/* -------------------------------------------------------------------- */
+    const char *pszLine = CPLReadLine( fp );
+    int iRow = 0;
+
+    while( pszLine != NULL )
+    {
+        char **papszTokens = 
+            CSLTokenizeStringComplex( pszLine, " \t", FALSE, FALSE );
+        
+        if( CSLCount( papszTokens ) >= 5 )
+        {
+            poRAT->SetValue( iRow, 0, atoi(papszTokens[0]) );
+            poRAT->SetValue( iRow, 1, atoi(papszTokens[1]) );
+            poRAT->SetValue( iRow, 2, atoi(papszTokens[2]) );
+            poRAT->SetValue( iRow, 3, atoi(papszTokens[3]) );
+            poRAT->SetValue( iRow, 4, atoi(papszTokens[4]) );
+
+            // find name, first nonspace after 5th token. 
+            const char *pszName = pszLine;
+
+            // skip from
+            while( *pszName == ' ' || *pszName == '\t' )
+                pszName++;
+            while( *pszName != ' ' && *pszName != '\t' && *pszName != '\0' )
+                pszName++;
+            
+            // skip to
+            while( *pszName == ' ' || *pszName == '\t' )
+                pszName++;
+            while( *pszName != ' ' && *pszName != '\t' && *pszName != '\0' )
+                pszName++;
+            
+            // skip red
+            while( *pszName == ' ' || *pszName == '\t' )
+                pszName++;
+            while( *pszName != ' ' && *pszName != '\t' && *pszName != '\0' )
+                pszName++;
+            
+            // skip green
+            while( *pszName == ' ' || *pszName == '\t' )
+                pszName++;
+            while( *pszName != ' ' && *pszName != '\t' && *pszName != '\0' )
+                pszName++;
+            
+            // skip blue
+            while( *pszName == ' ' || *pszName == '\t' )
+                pszName++;
+            while( *pszName != ' ' && *pszName != '\t' && *pszName != '\0' )
+                pszName++;
+
+            // skip pre-name white space
+            while( *pszName == ' ' || *pszName == '\t' )
+                pszName++;
+
+            poRAT->SetValue( iRow, 5, pszName );
+            
+            iRow++;
+        }
+
+        CSLDestroy( papszTokens );
+        pszLine = CPLReadLine( fp );
+    }
+
+/* -------------------------------------------------------------------- */
+/*      Attach RAT to band.                                             */
+/* -------------------------------------------------------------------- */
+    ((IDARasterBand *) GetRasterBand( 1 ))->poRAT = poRAT;
+
+/* -------------------------------------------------------------------- */
+/*      Build a conventional color table from this.                     */
+/* -------------------------------------------------------------------- */
+    ((IDARasterBand *) GetRasterBand( 1 ))->poColorTable = 
+        poRAT->TranslateToColorTable();
+}
+
 /************************************************************************/
 /*                                Open()                                */
 /************************************************************************/
@@ -773,6 +916,12 @@ CALCULATED =200
     poDS->SetBand( 1, new IDARasterBand( poDS, poDS->fpRaw, 
                                          poDS->nRasterXSize ) );
 
+/* -------------------------------------------------------------------- */
+/*      Check for a color table.                                        */
+/* -------------------------------------------------------------------- */
+    poDS->SetDescription( poOpenInfo->pszFilename );
+    poDS->ReadColorTable();
+
 /* -------------------------------------------------------------------- */
 /*      Check for overviews.                                            */
 /* -------------------------------------------------------------------- */
@@ -781,7 +930,6 @@ CALCULATED =200
 /* -------------------------------------------------------------------- */
 /*      Initialize any PAM information.                                 */
 /* -------------------------------------------------------------------- */
-    poDS->SetDescription( poOpenInfo->pszFilename );
     poDS->TryLoadXML();
 
     return( poDS );
