@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: mffdataset.cpp,v 1.29 2006/01/05 16:20:34 gwalter Exp $
+ * $Id: mffdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GView
  * Purpose:  Implementation of Atlantis MFF Support
@@ -25,95 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: mffdataset.cpp,v $
- * Revision 1.29  2006/01/05 16:20:34  gwalter
- * Atlantis->Vexcel in long name.
- *
- * Revision 1.28  2005/05/05 13:55:42  fwarmerdam
- * PAM Enable
- *
- * Revision 1.27  2003/04/02 19:05:59  dron
- * Large file support.
- *
- * Revision 1.26  2003/03/18 19:03:44  gwalter
- * Add flushing, fix coordinate interpretation.
- *
- * Revision 1.25  2003/03/13 18:34:02  gwalter
- * Fix data type determination in CreateCopy.
- *
- * Revision 1.24  2003/03/12 16:02:28  gwalter
- * Fix spheroid support.
- *
- * Revision 1.22  2003/03/03 20:10:06  gwalter
- * Updated MFF and HKV (MFF2) georeferencing support.
- *
- * Revision 1.21  2002/11/23 18:54:17  warmerda
- * added CREATIONDATATYPES metadata for drivers
- *
- * Revision 1.20  2002/09/04 06:50:37  warmerda
- * avoid static driver pointers
- *
- * Revision 1.19  2002/06/12 21:12:25  warmerda
- * update to metadata based driver info
- *
- * Revision 1.18  2001/11/11 23:51:00  warmerda
- * added required class keyword to friend declarations
- *
- * Revision 1.17  2001/07/18 04:51:57  warmerda
- * added CPL_CVSID
- *
- * Revision 1.16  2001/07/11 18:08:14  warmerda
- * Fixed pixel interpretation again.  TOP_LEFT is really 0.0,0.0 but
- * BOTTOM_RIGHT is the top left corner of the bottom right pixel!
- *
- * Revision 1.15  2001/07/11 18:00:57  warmerda
- * Fixed off-by-half-pixel issues with MFF GCPs.
- *
- * Revision 1.14  2000/10/11 16:06:51  warmerda
- * added read support for GCPn and NUM_GCPs keywords
- *
- * Revision 1.13  2000/09/25 21:20:13  warmerda
- * avoid initialization warnings
- *
- * Revision 1.12  2000/08/24 14:26:09  warmerda
- * improved handling of read-only file sets
- *
- * Revision 1.11  2000/08/15 19:28:26  warmerda
- * added help topic
- *
- * Revision 1.10  2000/07/26 21:05:21  warmerda
- * added support for reading tiled MFF files
- *
- * Revision 1.9  2000/07/12 19:21:34  warmerda
- * fixed cleanup of GCPs
- *
- * Revision 1.8  2000/06/05 17:24:06  warmerda
- * added real complex support
- *
- * Revision 1.7  2000/05/18 22:06:03  warmerda
- * added gcp and metadata support
- *
- * Revision 1.6  2000/05/15 14:18:27  warmerda
- * added COMPLEX_INTERPRETATION metadata
- *
- * Revision 1.5  2000/04/21 21:59:26  warmerda
- * added overview support
- *
- * Revision 1.4  2000/03/24 20:00:46  warmerda
- * Don't require IMAGE_FILE_FORMAT.
- *
- * Revision 1.3  2000/03/13 14:34:42  warmerda
- * avoid const problem on write
- *
- * Revision 1.2  2000/03/06 21:51:32  warmerda
- * fixed docs
- *
- * Revision 1.1  2000/03/06 19:23:20  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "rawdataset.h"
 #include "cpl_string.h"
@@ -121,7 +33,7 @@
 #include "ogr_spatialref.h"
 #include "atlsci_spheroid.h"
 
-CPL_CVSID("$Id: mffdataset.cpp,v 1.29 2006/01/05 16:20:34 gwalter Exp $");
+CPL_CVSID("$Id: mffdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 CPL_C_START
 void	GDALRegister_MFF(void);
