@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ndfdataset.cpp,v 1.4 2005/05/05 13:55:42 fwarmerdam Exp $
+ * $Id: ndfdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  NDF Driver
  * Purpose:  Implementation of NLAPS Data Format read support.
@@ -25,28 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ndfdataset.cpp,v $
- * Revision 1.4  2005/05/05 13:55:42  fwarmerdam
- * PAM Enable
- *
- * Revision 1.3  2005/03/05 17:27:00  fwarmerdam
- * updated to support NDF1 and rotated datasets
- *
- * Revision 1.2  2005/03/05 17:07:30  fwarmerdam
- * Fixed up an off-by-half-a-pixel error in geotransform.
- *
- * Revision 1.1  2005/01/06 20:27:22  fwarmerdam
- * New
- *
- */
+ ****************************************************************************/
 
 #include "rawdataset.h"
 #include "ogr_spatialref.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ndfdataset.cpp,v 1.4 2005/05/05 13:55:42 fwarmerdam Exp $");
+CPL_CVSID("$Id: ndfdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /* ==================================================================== */
