@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: pnmdataset.cpp,v 1.17 2005/05/05 13:55:42 fwarmerdam Exp $
+ * $Id: pnmdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  PNM Driver
  * Purpose:  Portable anymap file format imlementation
@@ -25,65 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: pnmdataset.cpp,v $
- * Revision 1.17  2005/05/05 13:55:42  fwarmerdam
- * PAM Enable
- *
- * Revision 1.16  2004/02/04 21:47:31  warmerda
- * use VSIFClose() to close openinfo file, not VSIFCloseL()
- *
- * Revision 1.15  2003/10/24 14:22:49  warmerda
- * Added worldfile read support (but not write/export).
- *
- * Revision 1.14  2003/03/27 11:34:25  dron
- * Fixes for large file support.
- *
- * Revision 1.13  2003/03/25 13:52:18  dron
- * CREATIONOPTIONLIST added, fixed problem with MIMETYPE.
- *
- * Revision 1.12  2003/02/13 22:00:26  dron
- * Added creation option MAXVAL.
- *
- *
- * Revision 1.10  2003/02/06 20:27:09  dron
- * More PNM standard complience in header reading.
- *
- * Revision 1.9  2003/02/03 11:14:24  dron
- * Added support for reading and writing 16-bit images.
- *
- * Revision 1.8  2002/11/23 18:54:17  warmerda
- * added CREATIONDATATYPES metadata for drivers
- *
- * Revision 1.7  2002/09/19 21:10:02  warmerda
- * Fixed GetDriverByName call.
- *
- * Revision 1.6  2002/09/04 06:50:37  warmerda
- * avoid static driver pointers
- *
- * Revision 1.5  2002/06/12 21:12:25  warmerda
- * update to metadata based driver info
- *
- * Revision 1.4  2002/04/16 17:52:35  warmerda
- * Initialize variables.
- *
- * Revision 1.3  2001/07/18 19:04:10  warmerda
- * Removed debug printf.
- *
- * Revision 1.2  2001/07/18 04:51:57  warmerda
- * added CPL_CVSID
- *
- * Revision 1.1  2001/01/03 18:53:36  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "rawdataset.h"
 #include "cpl_string.h"
 #include <ctype.h>
 
-CPL_CVSID("$Id: pnmdataset.cpp,v 1.17 2005/05/05 13:55:42 fwarmerdam Exp $");
+CPL_CVSID("$Id: pnmdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 CPL_C_START
 void    GDALRegister_PNM(void);
