@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: rawdataset.cpp,v 1.27 2005/05/23 06:53:45 fwarmerdam Exp $
+ * $Id: rawdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Generic Raw Binary Driver
  * Purpose:  Implementation of RawDataset and RawRasterBand classes.
@@ -25,99 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: rawdataset.cpp,v $
- * Revision 1.27  2005/05/23 06:53:45  fwarmerdam
- * Avoid IsBlockCached()
- *
- * Revision 1.26  2004/11/02 20:21:38  fwarmerdam
- * added support for category names
- *
- * Revision 1.25  2004/06/02 20:57:55  warmerda
- * centralize initialization
- *
- * Revision 1.24  2004/06/02 20:54:42  warmerda
- * Ensure poCT and eInterp are initialize in the *other* constructor.
- *
- * Revision 1.23  2004/05/28 18:16:22  warmerda
- * Added support for hold colortable and interp on RawRasterBand
- *
- * Revision 1.22  2004/04/06 19:25:31  dron
- * Use GDALRasterBand::IsBlockCached() instead of GDALRasterBlock::IsCached().
- *
- * Revision 1.21  2003/07/27 11:08:19  dron
- * Added some heuristic to switch between cached and direct IRasterIO()
- * implementations.
- *
- * Revision 1.20  2003/07/16 19:29:09  warmerda
- * use overviews in IRasterIO() on reads when appropriate
- *
- * Revision 1.19  2003/07/08 21:10:19  warmerda
- * avoid warnings
- *
- * Revision 1.18  2003/05/18 11:05:07  dron
- * Fixed problem in IRasterIO().
- *
- * Revision 1.17  2003/05/02 16:00:17  dron
- * Implemented RawRasterBand::IRasterIO() method. Introduced `dirty' flag.
- *
- * Revision 1.16  2003/03/18 05:59:41  warmerda
- * Added FlushCache() implementation that uses fflush() to force
- * everything out.
- *
- * Revision 1.15  2002/11/23 18:54:47  warmerda
- * added setnodatavalue
- *
- * Revision 1.14  2002/02/07 15:14:59  warmerda
- * ensure that no more bytes are read or written than necessary
- *
- * Revision 1.13  2001/12/14 19:18:38  ldjohn
- * Typecast offset parameter to Seek for large file support.
- *
- * Revision 1.12  2001/12/12 18:41:33  warmerda
- * don't pass vsi_l_offset values in debug calls
- *
- * Revision 1.11  2001/12/12 18:15:46  warmerda
- * preliminary update for large raw file support
- *
- * Revision 1.10  2001/07/18 04:51:57  warmerda
- * added CPL_CVSID
- *
- * Revision 1.9  2001/03/26 18:31:55  warmerda
- * Fixed nodata handling in first constructor.
- *
- * Revision 1.8  2001/03/23 03:25:32  warmerda
- * Added nodata support
- *
- * Revision 1.7  2001/01/03 18:54:25  warmerda
- * improved seek error message
- *
- * Revision 1.6  2000/08/16 15:51:17  warmerda
- * allow floating (datasetless) raw bands
- *
- * Revision 1.5  2000/08/09 16:26:27  warmerda
- * improved error checking
- *
- * Revision 1.4  2000/06/05 17:24:06  warmerda
- * added real complex support
- *
- * Revision 1.3  2000/03/31 13:36:40  warmerda
- * RawRasterBand no longer depends on RawDataset
- *
- * Revision 1.2  1999/08/13 02:36:57  warmerda
- * added write support
- *
- * Revision 1.1  1999/07/23 19:34:34  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "rawdataset.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: rawdataset.cpp,v 1.27 2005/05/23 06:53:45 fwarmerdam Exp $");
+CPL_CVSID("$Id: rawdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                           RawRasterBand()                            */
