@@ -1,13 +1,13 @@
 /******************************************************************************
- * $Id: rmfdataset.cpp,v 1.11 2006/03/09 10:41:15 dron Exp $
+ * $Id: rmfdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Raster Matrix Format
- * Purpose:  Read/write raster files used in GIS "Integration"
- *           (also known as "Panorama" GIS). 
- * Author:   Andrey Kiselev, dron@remotesensing.org
+ * Purpose:  Read/write raster files used in GIS "Integratsia"
+ *           (also known as "Panorama" GIS).
+ * Author:   Andrey Kiselev, dron@ak4719.spb.edu
  *
  ******************************************************************************
- * Copyright (c) 2005, Andrey Kiselev <dron@remotesensing.org>
+ * Copyright (c) 2005, Andrey Kiselev <dron@ak4719.spb.edu>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -26,195 +26,28 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: rmfdataset.cpp,v $
- * Revision 1.11  2006/03/09 10:41:15  dron
- * Fixed problem with writing incomplete last blocks.
- *
- * Revision 1.10  2006/03/08 21:53:40  dron
- * Mark header dirty when color table changed.
- *
- * Revision 1.9  2006/03/08 21:50:14  dron
- * Do not forget to mark header dirty when changed.
- *
- * Revision 1.8  2005/10/19 16:39:31  dron
- * Export projection info in newly created datasets.
- *
- * Revision 1.7  2005/10/12 12:07:46  dron
- * Remove old projection handling code.
- *
- * Revision 1.6  2005/10/12 11:36:20  dron
- * Fetch prohjection definition using the "Panorama" OSR interface.
- *
- * Revision 1.5  2005/08/12 13:22:46  fwarmerdam
- * avoid initialization warning.
- *
- * Revision 1.4  2005/08/12 13:21:10  fwarmerdam
- * Avoid warning about unused variable.
- *
- * Revision 1.3  2005/06/09 19:32:01  dron
- * Fixed compilation on big-endian arch.
- *
- * Revision 1.2  2005/05/20 19:25:11  dron
- * Fixed problem with the last line of tiles.
- *
- * Revision 1.1  2005/05/19 20:42:03  dron
- * New.
- *
- */
+ ****************************************************************************/
 
-#include "gdal_priv.h"
 #include "ogr_spatialref.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: rmfdataset.cpp,v 1.11 2006/03/09 10:41:15 dron Exp $");
+#include "rmfdataset.h"
+
+CPL_CVSID("$Id: rmfdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 CPL_C_START
 void    GDALRegister_RMF(void);
 CPL_C_END
 
-enum RMFType
-{
-    RMFT_RSW,       // Raster map
-    RMFT_MTW        // Digital elevation model
-};
-
 #define RMF_DEFAULT_BLOCKXSIZE 256
 #define RMF_DEFAULT_BLOCKYSIZE 256
 
-typedef struct
-{
-#define RMF_SIGNATURE_SIZE 4
-    char        szSignature[RMF_SIGNATURE_SIZE];    // "RSW" for raster
-                                                // map or "MTW" for DEM
-    GUInt32     iVersion;
-    GUInt32     nSize;                          // File size in bytes
-    GUInt32     nOvrOffset;                     // Offset to overview
-    GUInt32     iUserID;
-#define RMF_NAME_SIZE 32
-    GByte       byName[RMF_NAME_SIZE];
-    GUInt32     nBitDepth;                      // Number of bits per pixel
-    GUInt32     nHeight;                        // Image length
-    GUInt32     nWidth;                         // Image width
-    GUInt32     nXTiles;                        // Number of tiles in line
-    GUInt32     nYTiles;                        // Number of tiles in column
-    GUInt32     nTileHeight;
-    GUInt32     nTileWidth;
-    GUInt32     nLastTileHeight;
-    GUInt32     nLastTileWidth;
-    GUInt32     nROIOffset;
-    GUInt32     nROISize;
-    GUInt32     nClrTblOffset;                  // Position and size
-    GUInt32     nClrTblSize;                    // of the colour table
-    GUInt32     nTileTblOffset;                 // Position and size of the
-    GUInt32     nTileTblSize;                   // tile offsets/sizes table 
-    GInt32      iMapType;
-    GInt32      iProjection;
-    double      dfScale;
-    double      dfResolution;
-    double      dfPixelSize;
-    double      dfLLX;
-    double      dfLLY;
-    double      dfStdP1;
-    double      dfStdP2;
-    double      dfCenterLong;
-    double      dfCenterLat;
-    GByte       iCompression;
-    GByte       iMaskType;
-    GByte       iMaskStep;
-    GByte       iFrameFlag;
-    GUInt32     nFlagsTblOffset;
-    GUInt32     nFlagsTblSize;
-    GUInt32     nFileSize0;
-    GUInt32     nFileSize1;
-    GByte       iUnknown;
-    GByte       iGeorefFlag;
-    GByte       iInverse;
-#define RMF_INVISIBLE_COLORS_SIZE 32
-    GByte       abyInvisibleColors[RMF_INVISIBLE_COLORS_SIZE];
-    double      dfElevMinMax[2];
-    double      dfNoData;
-    GUInt32     iElevationUnit;
-    GByte       iElevationType;
-} RMFHeader;
-
-/************************************************************************/
-/* ==================================================================== */
-/*                              RMFDataset                              */
-/* ==================================================================== */
-/************************************************************************/
-
-class RMFDataset : public GDALDataset
-{
-    friend class RMFRasterBand;
-
-#define RMF_HEADER_SIZE 320
-    GByte           abyHeader[RMF_HEADER_SIZE];
-    RMFHeader       sHeader;
-    RMFType         eRMFType;
-    GUInt32         nXTiles;
-    GUInt32         nYTiles;
-    GUInt32         *paiTiles;
-    
-    GUInt32         nColorTableSize;
-    GByte           *pabyColorTable;
-    GDALColorTable  *poColorTable;
-    double          adfGeoTransform[6];
-    char            *pszProjection;
-
-    int             bHeaderDirty;
-
-    const char      *pszFilename;
-    FILE            *fp;
-
-  protected:
-    CPLErr              WriteHeader();
-
-  public:
-                RMFDataset();
-                ~RMFDataset();
-
-    static GDALDataset  *Open( GDALOpenInfo * );
-    static GDALDataset  *Create( const char *, int, int, int,
-                                 GDALDataType, char ** );
-    virtual void        FlushCache( void );
-
-    virtual CPLErr      GetGeoTransform( double * padfTransform );
-    virtual CPLErr      SetGeoTransform( double * );
-    virtual const char  *GetProjectionRef();
-    virtual CPLErr      SetProjection( const char * );
-};
-
 /************************************************************************/
 /* ==================================================================== */
 /*                            RMFRasterBand                             */
 /* ==================================================================== */
 /************************************************************************/
 
-class RMFRasterBand : public GDALRasterBand
-{
-    friend class RMFDataset;
-
-  protected:
-
-    unsigned int    iBytesPerSample;
-    GUInt32         nBlockSize, nBlockBytes;
-    GUInt32         nLastTileXBytes;
-    int             nDataSize;
-
-  public:
-
-                RMFRasterBand( RMFDataset *, int, GDALDataType );
-                ~RMFRasterBand();
-
-    virtual CPLErr          IReadBlock( int, int, void * );
-    virtual CPLErr          IWriteBlock( int, int, void * );
-    virtual GDALColorInterp GetColorInterpretation();
-    virtual GDALColorTable  *GetColorTable();
-    CPLErr                  SetColorTable( GDALColorTable * );
-};
-
 /************************************************************************/
 /*                           RMFRasterBand()                            */
 /************************************************************************/
@@ -224,25 +57,26 @@ RMFRasterBand::RMFRasterBand( RMFDataset *poDS, int nBand,
 {
     this->poDS = poDS;
     this->nBand = nBand;
-    eDataType = eType;
-    iBytesPerSample = poDS->sHeader.nBitDepth / 8;
 
+    eDataType = eType;
+    nBytesPerPixel = poDS->sHeader.nBitDepth / 8;
+    nDataSize = GDALGetDataTypeSize( eDataType ) / 8;
     nBlockXSize = poDS->sHeader.nTileWidth;
     nBlockYSize = poDS->sHeader.nTileHeight;
     nBlockSize = nBlockXSize * nBlockYSize;
-    nDataSize = GDALGetDataTypeSize( eDataType ) / 8;
     nBlockBytes = nBlockSize * nDataSize;
     nLastTileXBytes =
         (poDS->GetRasterXSize() % poDS->sHeader.nTileWidth) * nDataSize;
+    nLastTileHeight = poDS->GetRasterYSize() % poDS->sHeader.nTileHeight;
 
 #if DEBUG
     CPLDebug( "RMF",
               "Band %d: tile width is %d, tile height is %d, "
               " last tile width %d, last tile height %d, "
-              "bytes per sample is %d, data type size is %d",
+              "bytes per pixel is %d, data type size is %d",
               nBand, nBlockXSize, nBlockYSize,
               poDS->sHeader.nLastTileWidth, poDS->sHeader.nLastTileHeight,
-              iBytesPerSample, nDataSize );
+              nBytesPerPixel, nDataSize );
 #endif
 }
 
@@ -308,7 +142,9 @@ CPLErr RMFRasterBand::IReadBlock( int nBlockXOff, int nBlockYOff,
                 CPLError( CE_Failure, CPLE_FileIO,
                           "Can't read from offset %ld in input file.",
                           poGDS->paiTiles[2 * nTile] );
-                return CE_Failure;
+                // XXX: Do not fail here, just return empty block and continue
+                // reading.
+                return CE_None;
             }
         }
 
@@ -354,44 +190,91 @@ CPLErr RMFRasterBand::IReadBlock( int nBlockXOff, int nBlockYOff,
                 CPLError( CE_Failure, CPLE_FileIO,
                           "Can't read from offset %ld in input file.",
                           poGDS->paiTiles[2 * nTile] );
+                // XXX: Do not fail here, just return empty block and continue
+                // reading.
                 CPLFree( pabyTile );
-                return CE_Failure;
+                return CE_None;
             }
         }
 
+/* -------------------------------------------------------------------- */
+/*  If buffer was compressed, decompress it first.                      */
+/* -------------------------------------------------------------------- */
+        GUInt32 nRawBytes;
+        if ( nLastTileXBytes && (GUInt32) nBlockXOff == poGDS->nXTiles - 1 )
+        {
+            nRawBytes = nLastTileXBytes;
+            if (nLastTileHeight && (GUInt32) nBlockYOff == poGDS->nYTiles - 1)
+                nRawBytes *= nLastTileHeight;
+            else
+                nRawBytes *= nBlockYSize;
+        }
+        else
+        {
+            nRawBytes = poGDS->nBands * nBlockXSize * nDataSize;
+            if (nLastTileHeight && (GUInt32) nBlockYOff == poGDS->nYTiles - 1)
+                nRawBytes *= nLastTileHeight;
+            else
+                nRawBytes *= nBlockYSize;
+        }
+
+        if (poGDS->Decompress && nRawBytes > nTileBytes)
+        {
+            GByte *pszRawBuf = (GByte *)CPLMalloc(nRawBytes);
+
+            (*poGDS->Decompress)(pabyTile, nTileBytes, pszRawBuf, nRawBytes);
+            CPLFree(pabyTile);
+            pabyTile = pszRawBuf;
+            nTileBytes = nRawBytes;
+        }
+
+/* -------------------------------------------------------------------- */
+/*  Deinterleave pixels from input buffer.                              */
+/* -------------------------------------------------------------------- */
         if ( poGDS->sHeader.nBitDepth == 24 || poGDS->sHeader.nBitDepth == 32 )
         {
-            GUInt32 nTileSize = nTileBytes / iBytesPerSample;
+            GUInt32 nTileSize = nTileBytes / nBytesPerPixel;
+
+            if ( nTileSize > nBlockSize )
+                nTileSize = nBlockSize;
+
             for ( i = 0; i < nTileSize; i++ )
             {
                 // Colour triplets in RMF file organized in reverse order:
-                // blue, green, red. When we have 32-bit BMP the forth byte
+                // blue, green, red. When we have 32-bit RMF the forth byte
                 // in quadriplet should be discarded as it has no meaning.
                 // That is why we always use 3 byte count in the following
                 // pabyTemp index.
                 ((GByte *) pImage)[i] =
-                    pabyTile[i * iBytesPerSample + 3 - nBand];
+                    pabyTile[i * nBytesPerPixel + 3 - nBand];
             }
         }
 
         else if ( poGDS->sHeader.nBitDepth == 16 )
         {
-            for ( i = 0; i < nBlockSize; i++ )
+            GUInt32 nTileSize = nTileBytes / nBytesPerPixel;
+
+            if ( nTileSize > nBlockSize )
+                nTileSize = nBlockSize;
+
+            for ( i = 0; i < nTileSize; i++ )
             {
                 switch ( nBand )
                 {
                     case 1:
-                    ((GByte *) pImage)[i] = pabyTile[i + 1] & 0x1F;
-                    break;
+                        ((GByte *) pImage)[i] =
+                            (GByte)((((GUInt16*)pabyTile)[i] & 0x7c00) >> 7);
+                        break;
                     case 2:
-                    ((GByte *) pImage)[i] = ((pabyTile[i] & 0x03) << 3) |
-                                            ((pabyTile[i + 1] & 0xE0) >> 5);
-                    break;
+                        ((GByte *) pImage)[i] =
+                            (GByte)((((GUInt16*)pabyTile)[i] & 0x03e0) >> 2);
+                        break;
                     case 3:
-                    ((GByte *) pImage)[i] = (pabyTile[i] & 0x7c) >> 2;
-                    break;
+                        ((GByte *) pImage)[i] =
+                            (GByte)(((GUInt16*)pabyTile)[i] & 0x1F) << 3;
+                        break;
                     default:
-                    break;
+                        break;
                 }
             }
         }
@@ -419,31 +302,31 @@ CPLErr RMFRasterBand::IReadBlock( int nBlockXOff, int nBlockYOff,
                 switch ( i & 0x7 )
                 {
                     case 0:
-                    ((GByte *) pImage)[i] = (*pabyTemp & 0x80) >> 7;
-                    break;
+                        ((GByte *) pImage)[i] = (*pabyTemp & 0x80) >> 7;
+                        break;
                     case 1:
-                    ((GByte *) pImage)[i] = (*pabyTemp & 0x40) >> 6;
-                    break;
+                        ((GByte *) pImage)[i] = (*pabyTemp & 0x40) >> 6;
+                        break;
                     case 2:
-                    ((GByte *) pImage)[i] = (*pabyTemp & 0x20) >> 5;
-                    break;
+                        ((GByte *) pImage)[i] = (*pabyTemp & 0x20) >> 5;
+                        break;
                     case 3:
-                    ((GByte *) pImage)[i] = (*pabyTemp & 0x10) >> 4;
-                    break;
+                        ((GByte *) pImage)[i] = (*pabyTemp & 0x10) >> 4;
+                        break;
                     case 4:
-                    ((GByte *) pImage)[i] = (*pabyTemp & 0x08) >> 3;
-                    break;
+                        ((GByte *) pImage)[i] = (*pabyTemp & 0x08) >> 3;
+                        break;
                     case 5:
-                    ((GByte *) pImage)[i] = (*pabyTemp & 0x04) >> 2;
-                    break;
+                        ((GByte *) pImage)[i] = (*pabyTemp & 0x04) >> 2;
+                        break;
                     case 6:
-                    ((GByte *) pImage)[i] = (*pabyTemp & 0x02) >> 1;
-                    break;
+                        ((GByte *) pImage)[i] = (*pabyTemp & 0x02) >> 1;
+                        break;
                     case 7:
-                    ((GByte *) pImage)[i] = *pabyTemp++ & 0x01;
-                    break;
+                        ((GByte *) pImage)[i] = *pabyTemp++ & 0x01;
+                        break;
                     default:
-                    break;
+                        break;
                 }
             }
         }
@@ -558,10 +441,10 @@ CPLErr RMFRasterBand::IWriteBlock( int nBlockXOff, int nBlockYOff,
 
             for ( iRow = 0; iRow < nCurBlockYSize; iRow++ )
             {
-                for ( iInPixel = 0, iOutPixel = iBytesPerSample - nBand;
-                      iOutPixel < nLastTileXBytes;
+                for ( iInPixel = 0, iOutPixel = nBytesPerPixel - nBand;
+                      iOutPixel < nLastTileXBytes * poGDS->nBands;
                       iInPixel++, iOutPixel += poGDS->nBands )
-                    (pabyTile + iRow * nLastTileXBytes)[iOutPixel] =
+                    (pabyTile + iRow * nLastTileXBytes * poGDS->nBands)[iOutPixel] =
                         ((GByte *) pImage + nBlockXSize * iRow * nDataSize)[iInPixel];
             }
         }
@@ -579,7 +462,7 @@ CPLErr RMFRasterBand::IWriteBlock( int nBlockXOff, int nBlockYOff,
                 VSIFSeekL( poGDS->fp, poGDS->paiTiles[2 * nTile], SEEK_SET );
             }
 
-            for ( iInPixel = 0, iOutPixel = iBytesPerSample - nBand;
+            for ( iInPixel = 0, iOutPixel = nBytesPerPixel - nBand;
                   iOutPixel < nTileBytes;
                   iInPixel++, iOutPixel += poGDS->nBands )
                 pabyTile[iOutPixel] = ((GByte *) pImage)[iInPixel];
@@ -704,6 +587,12 @@ GDALColorInterp RMFRasterBand::GetColorInterpretation()
     }
 }
 
+/************************************************************************/
+/* ==================================================================== */
+/*                              RMFDataset                              */
+/* ==================================================================== */
+/************************************************************************/
+
 /************************************************************************/
 /*                           RMFDataset()                               */
 /************************************************************************/
@@ -773,6 +662,8 @@ CPLErr RMFDataset::SetGeoTransform( double * padfTransform )
 {
     memcpy( adfGeoTransform, padfTransform, sizeof(double) * 6 );
     sHeader.dfPixelSize = adfGeoTransform[1];
+    if ( sHeader.dfPixelSize != 0.0 )
+        sHeader.dfResolution = sHeader.dfScale / sHeader.dfPixelSize;
     sHeader.dfLLX = adfGeoTransform[0];
     sHeader.dfLLY = adfGeoTransform[3] - nRasterYSize * sHeader.dfPixelSize;
     sHeader.iGeorefFlag = 1;
@@ -1131,13 +1022,12 @@ GDALDataset *RMFDataset::Open( GDALOpenInfo * poOpenInfo )
                 {
                     // Allocate memory for colour table and read it
                     poDS->nColorTableSize = 1 << poDS->sHeader.nBitDepth;
-                    if ( poDS->nColorTableSize * 4
-                         > poDS->sHeader.nClrTblSize )
+                    if ( poDS->nColorTableSize * 4 > poDS->sHeader.nClrTblSize )
                     {
                         CPLDebug( "RMF",
-                                "Wrong color table size. Expected %d, got %d.",
-                                poDS->nColorTableSize * 4,
-                                poDS->sHeader.nClrTblSize );
+                                  "Wrong color table size. Expected %d, got %d.",
+                                  poDS->nColorTableSize * 4,
+                                  poDS->sHeader.nClrTblSize );
                         delete poDS;
                         return NULL;
                     }
@@ -1146,8 +1036,7 @@ GDALDataset *RMFDataset::Open( GDALOpenInfo * poOpenInfo )
                     if ( VSIFSeekL( poDS->fp, poDS->sHeader.nClrTblOffset,
                                     SEEK_SET ) < 0 )
                     {
-                        CPLDebug( "RMF",
-                                  "Can't seek to color table location." );
+                        CPLDebug( "RMF", "Can't seek to color table location." );
                         delete poDS;
                         return NULL;
                     }
@@ -1202,6 +1091,14 @@ GDALDataset *RMFDataset::Open( GDALOpenInfo * poOpenInfo )
               poDS->nXTiles, poDS->nYTiles );
 #endif
 
+/* -------------------------------------------------------------------- */
+/*  Choose compression scheme.                                          */
+/* -------------------------------------------------------------------- */
+    if (poDS->sHeader.iCompression == 1)
+        poDS->Decompress = &LZWDecompress;
+    else
+        poDS->Decompress = NULL;
+
 /* -------------------------------------------------------------------- */
 /*  Create band information objects.                                    */
 /* -------------------------------------------------------------------- */
@@ -1217,7 +1114,9 @@ GDALDataset *RMFDataset::Open( GDALOpenInfo * poOpenInfo )
     {
         OGRSpatialReference oSRS;
 
-        oSRS.importFromPanorama( poDS->sHeader.iProjection, 0, 0, 0,
+        // XXX: Ellipsoid and datum are not specified in RMF file, but they
+        // are always Krassovsky/Pulkovo, 1942.
+        oSRS.importFromPanorama( poDS->sHeader.iProjection, 1, 1, 0,
                                  poDS->sHeader.dfStdP1, poDS->sHeader.dfStdP2,
                                  poDS->sHeader.dfCenterLat,
                                  poDS->sHeader.dfCenterLong );
