@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: rs2dataset.cpp,v 1.5 2005/05/05 15:54:49 fwarmerdam Exp $
+ * $Id: rs2dataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Polarimetric Workstation
  * Purpose:  Radarsat 2 - XML Products (product.xml) driver
@@ -25,31 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: rs2dataset.cpp,v $
- * Revision 1.5  2005/05/05 15:54:49  fwarmerdam
- * PAM Enabled
- *
- * Revision 1.4  2004/11/11 00:16:01  gwalter
- * Polarmetric->Polarimetric.
- *
- * Revision 1.3  2004/11/02 19:38:19  fwarmerdam
- * set help topic
- *
- * Revision 1.2  2004/10/30 18:54:58  fwarmerdam
- * Added support for UInt16 data (magnitude detected), and also fixed
- * so that the new "32bit void" tiff files can be read as CInt16.
- *
- * Revision 1.1  2004/10/21 20:03:09  fwarmerdam
- * New
- *
- */
+ ****************************************************************************/
 
 #include "gdal_pam.h"
 #include "cpl_minixml.h"
 
-CPL_CVSID("$Id: rs2dataset.cpp,v 1.5 2005/05/05 15:54:49 fwarmerdam Exp $");
+CPL_CVSID("$Id: rs2dataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 CPL_C_START
 void	GDALRegister_RS2(void);
