@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: sdtsattrreader.cpp,v 1.12 2006/04/10 16:34:18 fwarmerdam Exp $
+ * $Id: sdtsattrreader.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  SDTS Translator
  * Purpose:  Implementation of SDTSAttrReader class.
@@ -25,47 +25,11 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: sdtsattrreader.cpp,v $
- * Revision 1.12  2006/04/10 16:34:18  fwarmerdam
- * updated contact info
- *
- * Revision 1.11  2001/07/18 04:51:57  warmerda
- * added CPL_CVSID
- *
- * Revision 1.10  2001/01/19 21:20:29  warmerda
- * expanded tabs
- *
- * Revision 1.9  1999/09/03 14:13:48  warmerda
- * ensure DDFRecords are duplicated when needed
- *
- * Revision 1.8  1999/09/03 13:34:45  warmerda
- * added duplicate flag on GetNextRecord
- *
- * Revision 1.7  1999/09/03 13:01:39  warmerda
- * added docs
- *
- * Revision 1.6  1999/09/02 03:40:03  warmerda
- * added indexed readers
- *
- * Revision 1.5  1999/08/16 15:45:46  warmerda
- * added IsSecondary()
- *
- * Revision 1.4  1999/08/16 13:58:30  warmerda
- * added support for secondary attribute modules
- *
- * Revision 1.3  1999/05/07 13:45:01  warmerda
- * major upgrade to use iso8211lib
- *
- * Revision 1.2  1999/03/23 15:59:40  warmerda
- * implemented and working
- *
- */
+ ****************************************************************************/
 
 #include "sdts_al.h"
 
-CPL_CVSID("$Id: sdtsattrreader.cpp,v 1.12 2006/04/10 16:34:18 fwarmerdam Exp $");
+CPL_CVSID("$Id: sdtsattrreader.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 
 /************************************************************************/
