@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: sdtsiref.cpp,v 1.7 2006/04/10 16:34:19 fwarmerdam Exp $
+ * $Id: sdtsiref.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  SDTS Translator
  * Purpose:  Implementation of SDTS_IREF class for reading IREF module.
@@ -25,35 +25,11 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: sdtsiref.cpp,v $
- * Revision 1.7  2006/04/10 16:34:19  fwarmerdam
- * updated contact info
- *
- * Revision 1.6  2001/07/18 04:51:57  warmerda
- * added CPL_CVSID
- *
- * Revision 1.5  2001/01/19 21:20:29  warmerda
- * expanded tabs
- *
- * Revision 1.4  1999/09/21 17:26:31  warmerda
- * generalized SADR reading
- *
- * Revision 1.3  1999/06/03 14:03:34  warmerda
- * Added offset/res info from iref
- *
- * Revision 1.2  1999/05/07 13:45:01  warmerda
- * major upgrade to use iso8211lib
- *
- * Revision 1.1  1999/03/23 13:56:13  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "sdts_al.h"
 
-CPL_CVSID("$Id: sdtsiref.cpp,v 1.7 2006/04/10 16:34:19 fwarmerdam Exp $");
+CPL_CVSID("$Id: sdtsiref.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                             SDTS_IREF()                              */
