@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: sdtsxref.cpp,v 1.4 2006/04/10 16:34:19 fwarmerdam Exp $
+ * $Id: sdtsxref.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  SDTS Translator
  * Purpose:  Implementation of SDTS_XREF class for reading XREF module.
@@ -25,26 +25,11 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: sdtsxref.cpp,v $
- * Revision 1.4  2006/04/10 16:34:19  fwarmerdam
- * updated contact info
- *
- * Revision 1.3  2001/07/18 04:51:57  warmerda
- * added CPL_CVSID
- *
- * Revision 1.2  2001/01/19 21:20:29  warmerda
- * expanded tabs
- *
- * Revision 1.1  1999/06/03 14:02:36  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "sdts_al.h"
 
-CPL_CVSID("$Id: sdtsxref.cpp,v 1.4 2006/04/10 16:34:19 fwarmerdam Exp $");
+CPL_CVSID("$Id: sdtsxref.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                             SDTS_XREF()                              */
