@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: sgidataset.cpp,v 1.2 2006/02/26 14:26:10 fwarmerdam Exp $
+ * $Id: sgidataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  SGI Image Driver
  * Purpose:  Implement SGI Image Support based on Paul Bourke's SGI Image code.
@@ -28,23 +28,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- *****************************************************************************
- *
- * $Log: sgidataset.cpp,v $
- * Revision 1.2  2006/02/26 14:26:10  fwarmerdam
- * Optimizations from Mike.
- * http://bugzilla.remotesensing.org/show_bug.cgi?id=1046
- *
- * Revision 1.1  2005/12/20 16:20:31  fwarmerdam
- * New
- *
- */
+ ****************************************************************************/
 
 #include "gdal_pam.h"
 #include "cpl_port.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: sgidataset.cpp,v 1.2 2006/02/26 14:26:10 fwarmerdam Exp $");
+CPL_CVSID("$Id: sgidataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 CPL_C_START
 void	GDALRegister_SGI(void);
 CPL_C_END
