@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: vrtdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: vrtdataset.cpp 12515 2007-10-23 14:46:32Z mloskot $
  *
  * Project:  Virtual GDAL Datasets
  * Purpose:  Implementation of VRTDataset
@@ -32,7 +32,7 @@
 #include "cpl_minixml.h"
 #include "ogr_spatialref.h"
 
-CPL_CVSID("$Id: vrtdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: vrtdataset.cpp 12515 2007-10-23 14:46:32Z mloskot $");
 
 /************************************************************************/
 /*                            VRTDataset()                             */
@@ -149,7 +149,8 @@ CPLXMLNode *VRTDataset::SerializeToXML( const char *pszVRTPath )
     /* -------------------------------------------------------------------- */
     /*      Setup root node and attributes.                                 */
     /* -------------------------------------------------------------------- */
-    CPLXMLNode *psDSTree, *psMD;
+    CPLXMLNode *psDSTree = NULL;
+    CPLXMLNode *psMD = NULL;
     char       szNumber[128];
 
     psDSTree = CPLCreateXMLNode( NULL, CXT_Element, "VRTDataset" );
