@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: vrtrasterband.cpp,v 1.22 2006/02/08 06:12:08 fwarmerdam Exp $
+ * $Id: vrtrasterband.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Virtual GDAL Datasets
  * Purpose:  Implementation of VRTRasterBand
@@ -25,88 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: vrtrasterband.cpp,v $
- * Revision 1.22  2006/02/08 06:12:08  fwarmerdam
- * Override SetMetadata methods so that metadata can be preserved.
- * Support saving histograms in VRT per bug 1060.
- *
- * Revision 1.21  2005/05/05 13:56:14  fwarmerdam
- * moved metadata handling to PAM
- *
- * Revision 1.20  2004/08/11 18:46:45  warmerda
- * pass pszVRTPath through serialize methods
- *
- * Revision 1.19  2004/07/28 16:55:08  warmerda
- * split alot of functionality out into VRTSourcedRasterBand
- *
- * Revision 1.18  2004/04/15 18:54:38  warmerda
- * added UnitType, Offset, Scale and CategoryNames support
- *
- * Revision 1.17  2004/03/16 18:34:35  warmerda
- * added support for relativeToVRT attribute on SourceFilename
- *
- * Revision 1.16  2003/12/10 15:44:42  warmerda
- * Fix problem with NULL pszDomain values.
- *
- * Revision 1.15  2003/07/17 20:29:15  warmerda
- * Moved all the sources implementations out.
- * Improved error checking and returning when initializing from XML.
- * Added vrt_sources (and new_vrt_sources) metadata domains to permit
- * management of sources via XML passed in/out of the metadata methods.
- *
- * Revision 1.14  2003/06/10 19:59:33  warmerda
- * added new Func based source type for passthrough to a callback
- *
- * Revision 1.13  2003/03/14 10:31:22  dron
- * Check return value of the VRTSimpleSource::XMLInit() in VRTRasterBand::XMLInit().
- *
- * Revision 1.12  2003/03/13 20:39:25  dron
- * Improved block initialization logic in IRasterIO().
- *
- * Revision 1.11  2003/01/15 21:30:48  warmerda
- * some rounding tweaks when adjusting output size in GetSrcDstWindow
- *
- * Revision 1.10  2002/12/13 15:07:07  warmerda
- * fixed bug in IReadBlock
- *
- * Revision 1.9  2002/12/04 03:12:57  warmerda
- * Fixed some bugs in last change.
- *
- * Revision 1.8  2002/12/03 15:21:19  warmerda
- * finished up window computations for odd cases
- *
- * Revision 1.7  2002/11/24 04:29:02  warmerda
- * Substantially rewrote VRTSimpleSource.  Now VRTSource is base class, and
- * sources do their own SerializeToXML(), and XMLInit().  New VRTComplexSource
- * supports scaling and nodata values.
- *
- * Revision 1.6  2002/07/15 18:51:46  warmerda
- * ensure even unshared datasets are dereferenced properly
- *
- * Revision 1.5  2002/05/29 18:13:44  warmerda
- * added nodata handling for averager
- *
- * Revision 1.4  2002/05/29 16:06:05  warmerda
- * complete detailed band metadata
- *
- * Revision 1.3  2001/12/06 19:53:58  warmerda
- * added write check to rasterio
- *
- * Revision 1.2  2001/11/16 21:38:07  warmerda
- * try to work even if bModified
- *
- * Revision 1.1  2001/11/16 21:14:31  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "vrtdataset.h"
 #include "cpl_minixml.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: vrtrasterband.cpp,v 1.22 2006/02/08 06:12:08 fwarmerdam Exp $");
+CPL_CVSID("$Id: vrtrasterband.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /* ==================================================================== */
@@ -375,7 +300,7 @@ CPLErr VRTRasterBand::XMLInit( CPLXMLNode * psTree,
 /* -------------------------------------------------------------------- */
 /*      Apply any band level metadata.                                  */
 /* -------------------------------------------------------------------- */
-    PamApplyMetadata( psTree, this );
+    oMDMD.XMLInit( psTree, TRUE );
 
 /* -------------------------------------------------------------------- */
 /*      Collect various other items of metadata.                        */
@@ -495,7 +420,7 @@ CPLXMLNode *VRTRasterBand::SerializeToXML( const char *pszVRTPath )
     if( nBand > 0 )
         CPLSetXMLValue( psTree, "#band", CPLSPrintf( "%d", GetBand() ) );
 
-    psMD = PamSerializeMetadata( this );
+    psMD = oMDMD.Serialize();
     if( psMD != NULL )
         CPLAddXMLChild( psTree, psMD );
 
