@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: vrtsources.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: vrtsources.cpp 11621 2007-06-08 04:05:14Z warmerdam $
  *
  * Project:  Virtual GDAL Datasets
  * Purpose:  Implementation of VRTSimpleSource, VRTFuncSource and 
@@ -32,7 +32,7 @@
 #include "cpl_minixml.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: vrtsources.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: vrtsources.cpp 11621 2007-06-08 04:05:14Z warmerdam $");
 
 /************************************************************************/
 /* ==================================================================== */
@@ -58,6 +58,7 @@ VRTSimpleSource::VRTSimpleSource()
 
 {
     poRasterBand = NULL;
+    bNoDataSet = FALSE;
 }
 
 /************************************************************************/
@@ -263,6 +264,8 @@ CPLErr VRTSimpleSource::XMLInit( CPLXMLNode *psSrc, const char *pszVRTPath )
 
 /************************************************************************/
 /*                              SrcToDst()                              */
+/*                                                                      */
+/*      Note: this is a no-op if the dst window is -1,-1,-1,-1.         */
 /************************************************************************/
 
 void VRTSimpleSource::SrcToDst( double dfX, double dfY,
@@ -275,6 +278,8 @@ void VRTSimpleSource::SrcToDst( double dfX, double dfY,
 
 /************************************************************************/
 /*                              DstToSrc()                              */
+/*                                                                      */
+/*      Note: this is a no-op if the dst window is -1,-1,-1,-1.         */
 /************************************************************************/
 
 void VRTSimpleSource::DstToSrc( double dfX, double dfY,
@@ -298,18 +303,25 @@ VRTSimpleSource::GetSrcDstWindow( int nXOff, int nYOff, int nXSize, int nYSize,
                                   int *pnOutXSize, int *pnOutYSize )
 
 {
-/* -------------------------------------------------------------------- */
-/*      Translate requested region in virtual file into the source      */
-/*      band coordinates.                                               */
-/* -------------------------------------------------------------------- */
-    double      dfScaleX = nSrcXSize / (double) nDstXSize;
-    double      dfScaleY = nSrcYSize / (double) nDstYSize;
+    int bSrcWinSet = nSrcXOff != -1 || nSrcXSize != -1 
+        || nSrcYOff != -1 || nSrcYSize != -1;
+    int bDstWinSet = nDstXOff != -1 || nDstXSize != -1 
+        || nDstYOff != -1 || nDstYSize != -1;
 
-    *pnReqXOff = (int) floor((nXOff - nDstXOff) * dfScaleX + nSrcXOff);
-    *pnReqYOff = (int) floor((nYOff - nDstYOff) * dfScaleY + nSrcYOff);
+    CPLAssert( bSrcWinSet == bDstWinSet );
 
-    *pnReqXSize = (int) floor(nXSize * dfScaleX + 0.5);
-    *pnReqYSize = (int) floor(nYSize * dfScaleY + 0.5);
+/* -------------------------------------------------------------------- */
+/*      If the input window completely misses the portion of the        */
+/*      virtual dataset provided by this source we have nothing to do.  */
+/* -------------------------------------------------------------------- */
+    if( bDstWinSet )
+    {
+        if( nXOff > nDstXOff + nDstXSize
+            || nYOff > nDstYOff + nDstYSize
+            || nXOff + nXSize < nDstXOff
+            || nYOff + nYSize < nDstYOff )
+            return FALSE;
+    }
 
 /* -------------------------------------------------------------------- */
 /*      This request window corresponds to the whole output buffer.     */
@@ -320,10 +332,62 @@ VRTSimpleSource::GetSrcDstWindow( int nXOff, int nYOff, int nXSize, int nYSize,
     *pnOutYSize = nBufYSize;
 
 /* -------------------------------------------------------------------- */
-/*      Clamp within the bounds of the available source data.           */
+/*      If the input window extents outside the portion of the on       */
+/*      the virtual file that this source can set, then clip down       */
+/*      the requested window.                                           */
 /* -------------------------------------------------------------------- */
     int bModifiedX = FALSE, bModifiedY = FALSE;
+    int nRXOff = nXOff;
+    int nRYOff = nYOff;
+    int nRXSize = nXSize;
+    int nRYSize = nYSize;
 
+
+    if( bDstWinSet )
+    {
+        if( nRXOff < nDstXOff )
+        {
+            nRXSize = nRXSize + nRXOff - nDstXOff;
+            nRXOff = nDstXOff;
+            bModifiedX = TRUE;
+        }
+
+        if( nRYOff < nDstYOff )
+        {
+            nRYSize = nRYSize + nRYOff - nDstYOff;
+            nRYOff = nDstYOff;
+            bModifiedY = TRUE;
+        }
+
+        if( nRXOff + nRXSize > nDstXOff + nDstXSize )
+        {
+            nRXSize = nDstXOff + nDstXSize - nRXOff;
+            bModifiedX = TRUE;
+        }
+
+        if( nRYOff + nRYSize > nDstYOff + nDstYSize )
+        {
+            nRYSize = nDstYOff + nDstYSize - nRYOff;
+            bModifiedY = TRUE;
+        }
+    }
+
+/* -------------------------------------------------------------------- */
+/*      Translate requested region in virtual file into the source      */
+/*      band coordinates.                                               */
+/* -------------------------------------------------------------------- */
+    double      dfScaleX = nSrcXSize / (double) nDstXSize;
+    double      dfScaleY = nSrcYSize / (double) nDstYSize;
+
+    *pnReqXOff = (int) floor((nRXOff - nDstXOff) * dfScaleX + nSrcXOff);
+    *pnReqYOff = (int) floor((nRYOff - nDstYOff) * dfScaleY + nSrcYOff);
+
+    *pnReqXSize = (int) floor(nRXSize * dfScaleX + 0.5);
+    *pnReqYSize = (int) floor(nRYSize * dfScaleY + 0.5);
+
+/* -------------------------------------------------------------------- */
+/*      Clamp within the bounds of the available source data.           */
+/* -------------------------------------------------------------------- */
     if( *pnReqXOff < 0 )
     {
         *pnReqXSize += *pnReqXOff;
@@ -412,7 +476,6 @@ VRTSimpleSource::GetSrcDstWindow( int nXOff, int nYOff, int nXSize, int nYSize,
             *pnOutYSize = nBufYSize - *pnOutYOff;
     }
 
-
     if( *pnOutXSize < 1 || *pnOutYSize < 1 )
         return FALSE;
     else
