@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdal_frmts.h,v 1.39 2005/08/17 15:33:46 fwarmerdam Exp $
+ * $Id: gdal_frmts.h 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GDAL
  * Purpose:  Prototypes for all format specific driver initializations.
@@ -25,127 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: gdal_frmts.h,v $
- * Revision 1.39  2005/08/17 15:33:46  fwarmerdam
- * added rik driver
- *
- * Revision 1.38  2005/07/12 16:58:06  denad21
- * added hdf5 support
- *
- * Revision 1.37  2005/07/07 23:36:14  fwarmerdam
- * added msgn support
- *
- * Revision 1.36  2005/05/19 20:43:08  dron
- * Added RMF format.
- *
- * Revision 1.35  2005/01/06 20:27:51  fwarmerdam
- * added NDF driver
- *
- * Revision 1.34  2004/12/26 16:16:33  fwarmerdam
- * added ida format
- *
- * Revision 1.33  2004/12/20 16:14:00  fwarmerdam
- * added GDALRegister_JP2ECW()
- *
- * Revision 1.32  2004/11/30 16:59:37  lichun
- * Added ILWIS
- *
- * Revision 1.31  2004/10/22 14:14:49  fwarmerdam
- * Added PCRaster.
- *
- * Revision 1.30  2004/10/21 19:22:41  fwarmerdam
- * Added GDALRegister_RS2().
- *
- * Revision 1.29  2004/10/16 14:39:04  fwarmerdam
- * added GMT format
- *
- * Revision 1.28  2004/09/16 18:23:42  fwarmerdam
- * added airsar
- *
- * Revision 1.27  2004/09/03 19:06:03  warmerda
- * added CPG driver
- *
- * Revision 1.26  2004/05/26 14:15:56  warmerda
- * Added LAN (.LAN/.GIS format).
- *
- * Revision 1.25  2004/01/07 20:06:12  warmerda
- * Added netCDF register
- *
- * Revision 1.24  2003/12/13 00:00:07  jimg
- * Added GDALRegister_DODS().
- *
- * Revision 1.23  2003/12/11 06:18:43  warmerda
- * added BT driver
- *
- * Revision 1.22  2003/09/09 12:14:25  dron
- * Added PCIDSK driver.
- *
- * Revision 1.21  2003/04/23 12:24:26  dron
- * MrSID driver added, EFF removed.
- *
- * Revision 1.20  2002/12/03 19:02:39  dron
- * Added BMP driver.
- *
- * Revision 1.19  2002/12/03 04:41:16  warmerda
- * added NITF
- *
- * Revision 1.18  2002/10/03 05:41:27  warmerda
- * added GSC Geogrid format
- *
- * Revision 1.17  2002/09/26 18:10:59  warmerda
- * added JP2KAK
- *
- * Revision 1.16  2002/09/19 14:49:54  warmerda
- * added jpeg2000
- *
- * Revision 1.15  2002/08/13 16:59:53  dron
- * New driver: EOSAT FAST format
- *
- * Revision 1.14  2002/07/16 13:30:27  dron
- * New driver: HDF4 dataset.
- *
- * Revision 1.13  2002/05/08 16:33:25  dron
- * NOAA Polar Orbiter Dataset reader added
- *
- * Revision 1.12  2002/04/12 20:19:15  warmerda
- * added xpm
- *
- * Revision 1.11  2002/03/04 21:54:30  warmerda
- * added envi format
- *
- * Revision 1.10  2001/12/08 04:44:23  warmerda
- * added BSB
- *
- * Revision 1.9  2001/11/27 14:39:02  warmerda
- * added usgsdem
- *
- * Revision 1.8  2001/11/16 21:14:03  warmerda
- * added VRT dataset
- *
- * Revision 1.7  2001/09/19 15:26:14  warmerda
- * added doq2
- *
- * Revision 1.6  2001/07/05 23:53:53  nemec
- * Add FIT file format
- *
- * Revision 1.5  2001/05/15 13:20:32  warmerda
- * added fujibas
- *
- * Revision 1.4  2001/04/02 17:12:01  warmerda
- * Added ecw support.
- *
- * Revision 1.3  2001/03/12 15:17:03  warmerda
- * added aaigrid
- *
- * Revision 1.2  2001/03/06 03:53:44  sperkins
- * Added FITS format support.
- *
- * Revision 1.1  2001/02/06 16:30:05  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #ifndef GDAL_FRMTS_H_INCLUDED
 #define GDAL_FRMTS_H_INCLUDED
@@ -219,6 +99,14 @@ void CPL_DLL GDALRegister_HDF5(void);
 void CPL_DLL GDALRegister_HDF5Image(void);
 void CPL_DLL GDALRegister_MSGN(void);
 void CPL_DLL GDALRegister_RIK(void);
+void CPL_DLL GDALRegister_Leveller(void);
+void CPL_DLL GDALRegister_SGI(void);
+void CPL_DLL GDALRegister_DIPEx(void);
+void CPL_DLL GDALRegister_ISIS2(void);
+void CPL_DLL GDALRegister_PDS(void);
+void CPL_DLL GDALRegister_IDRISI(void);
+void CPL_DLL GDALRegister_Terragen(void);
+void CPL_DLL GDALRegister_WCS(void);
 CPL_C_END
 
 #endif /* ndef GDAL_FRMTS_H_INCLUDED */
