@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdal_misc.cpp,v 1.78 2006/03/03 19:43:44 fwarmerdam Exp $
+ * $Id: gdal_misc.cpp 11186 2007-04-03 01:07:32Z mloskot $
  *
  * Project:  GDAL Core
  * Purpose:  Free standing functions for GDAL.
@@ -25,100 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: gdal_misc.cpp,v $
- * Revision 1.78  2006/03/03 19:43:44  fwarmerdam
- * added --locale switch to force a locale
- *
- * Revision 1.77  2006/03/02 11:33:31  dron
- * Unused variable in GDALFindAssociatedAuxFile() removed.
- *
- * Revision 1.76  2006/01/23 15:23:45  fwarmerdam
- * Modified GDALTermProgress to output "." on 2.5% intervals except
- * integral ones.
- *
- * Revision 1.75  2005/12/06 21:51:01  fwarmerdam
- * before calling GDALOpen on a .aux file, verify it is HFA
- *
- * Revision 1.74  2005/10/07 13:31:26  dron
- * Allow pixel width/height to be zero when rotation is present
- * (GDALReadWorldFile).
- *
- * Revision 1.73  2005/09/26 15:52:03  fwarmerdam
- * centralized .aux opening logic
- *
- * Revision 1.72  2005/09/11 21:07:54  fwarmerdam
- * Changed worldfile reading to use large file API.
- *
- * Revision 1.71  2005/09/11 19:16:31  fwarmerdam
- * Use CPLString for safer string manipulation.
- *
- * Revision 1.70  2005/07/15 13:28:00  fwarmerdam
- * Fixed another big raster int overflow problem in GDALGetRasterSampleOverview
- *
- * Revision 1.69  2005/07/13 17:21:10  fwarmerdam
- * Avoiding 32bit overflow in GDALGetRasterSampleOverview().
- *
- * Revision 1.68  2005/07/08 18:59:54  fwarmerdam
- * Don't use thread local storage for GDALTermProgress() last complete, or
- * the GDALVersionInfo() static buffer.
- *
- * Revision 1.67  2005/05/23 06:44:31  fwarmerdam
- * Updated for locking of block refs
- *
- * Revision 1.66  2005/04/04 15:24:48  fwarmerdam
- * Most C entry points now CPL_STDCALL
- *
- * Revision 1.65  2005/03/21 16:12:08  fwarmerdam
- * Trimmed log.
- *
- * Revision 1.64  2005/03/21 16:11:32  fwarmerdam
- * Added special case for simple 4 corners, non-rotated case in
- * GDALGCPsToGeoTransform().
- *
- * Revision 1.63  2005/02/10 04:30:29  fwarmerdam
- * added support for YCbCr color space
- *
- * Revision 1.62  2004/11/23 19:54:07  fwarmerdam
- * Fixed initialization bug in szDerivedExtension in GDALReadWorldFile().
- *
- * Revision 1.61  2004/10/26 15:59:06  fwarmerdam
- * Added rw+ for formats with Create().
- *
- * Revision 1.60  2004/08/09 14:40:41  warmerda
- * return name for GDT_Unknown
- *
- * Revision 1.59  2004/05/28 16:05:25  warmerda
- * add default ext handling and docs for  GDALReadWorldFile
- *
- * Revision 1.58  2004/05/25 16:58:59  warmerda
- * Try to return an error if we don't find GCPs in TAB file.
- *
- * Revision 1.57  2004/04/21 15:48:47  warmerda
- * Reimplement GDALGetGeoTransformFromGCPs to do best fit - Eric Donges
- *
- * Revision 1.56  2004/04/02 18:42:48  warmerda
- * Added rw/ro flag in --formats list.
- *
- * Revision 1.55  2004/04/02 18:01:35  warmerda
- * Finished docs for commandline processor function.
- *
- * Revision 1.54  2004/04/02 17:58:29  warmerda
- * added --optfile support in general commandline processor
- *
- * Revision 1.53  2004/04/02 17:32:40  warmerda
- * added GDALGeneralCmdLineProcessor()
- *
- * Revision 1.52  2004/02/25 09:03:15  dron
- * Added GDALPackedDMSToDec() and GDALDecToPackedDMS() functions.
- *
- * Revision 1.51  2004/02/18 14:59:55  dron
- * Properly determine pixel offset in last tiles in GDALGetRandomRasterSample().
- *
- * Revision 1.50  2004/01/18 16:43:37  dron
- * Added GDALGetDataTypeByName() function.
- */
+ ****************************************************************************/
 
 #include "gdal_priv.h"
 #include "cpl_string.h"
@@ -126,7 +33,7 @@
 #include <ctype.h>
 #include <string>
 
-CPL_CVSID("$Id: gdal_misc.cpp,v 1.78 2006/03/03 19:43:44 fwarmerdam Exp $");
+CPL_CVSID("$Id: gdal_misc.cpp 11186 2007-04-03 01:07:32Z mloskot $");
 
 #include "ogr_spatialref.h"
 
@@ -1289,10 +1196,10 @@ int CPL_STDCALL GDALReadTabFile( const char * pszBaseFilename,
         {
             GDALInitGCPs( 1, asGCPs + nCoordinateCount );
             
-            asGCPs[nCoordinateCount].dfGCPPixel = atof(papszTok[2]);
-            asGCPs[nCoordinateCount].dfGCPLine = atof(papszTok[3]);
-            asGCPs[nCoordinateCount].dfGCPX = atof(papszTok[0]);
-            asGCPs[nCoordinateCount].dfGCPY = atof(papszTok[1]);
+            asGCPs[nCoordinateCount].dfGCPPixel = CPLAtofM(papszTok[2]);
+            asGCPs[nCoordinateCount].dfGCPLine = CPLAtofM(papszTok[3]);
+            asGCPs[nCoordinateCount].dfGCPX = CPLAtofM(papszTok[0]);
+            asGCPs[nCoordinateCount].dfGCPY = CPLAtofM(papszTok[1]);
             if( papszTok[5] != NULL )
             {
                 CPLFree( asGCPs[nCoordinateCount].pszId );
@@ -1419,8 +1326,10 @@ GDALReadWorldFile( const char * pszBaseFilename, const char *pszExtension,
 {
     const char  *pszTFW;
     char        szExtUpper[32], szExtLower[32];
-    int         i;
-    char        **papszLines;
+    int         i = 0;
+    int         nLinesCount = 0;
+    char        **papszLines = NULL;
+    bool        bValid = false;
 
 /* -------------------------------------------------------------------- */
 /*      If we aren't given an extension, try both the unix and          */
@@ -1498,16 +1407,38 @@ GDALReadWorldFile( const char * pszBaseFilename, const char *pszExtension,
 /* -------------------------------------------------------------------- */
     papszLines = CSLLoad( pszTFW );
 
-    if( CSLCount(papszLines) >= 6 
-        && (atof(papszLines[0]) != 0.0 || atof(papszLines[2]) != 0.0)
-        && (atof(papszLines[3]) != 0.0 || atof(papszLines[1]) != 0.0) )
+    /* Handling of blank lines is not supported. */
+    nLinesCount = CSLCount(papszLines);
+    if( nLinesCount >= 6 )
     {
-        padfGeoTransform[0] = atof(papszLines[4]);
-        padfGeoTransform[1] = atof(papszLines[0]);
-        padfGeoTransform[2] = atof(papszLines[2]);
-        padfGeoTransform[3] = atof(papszLines[5]);
-        padfGeoTransform[4] = atof(papszLines[1]);
-        padfGeoTransform[5] = atof(papszLines[3]);
+        bValid = true;
+
+        /* First six lines of a world file can not be empty. */
+        for( i = 0; i < 6; i++)
+        {
+           CPLString line(papszLines[i]);
+           if( line.Trim().empty() )
+           {
+               bValid = false;
+               break;
+           }
+        }
+    }
+    else
+    {
+        bValid = false;
+    }
+
+    if( bValid
+        && (CPLAtofM(papszLines[0]) != 0.0 || CPLAtofM(papszLines[2]) != 0.0)  
+        && (CPLAtofM(papszLines[3]) != 0.0 || CPLAtofM(papszLines[1]) != 0.0) ) 
+    {
+        padfGeoTransform[0] = CPLAtofM(papszLines[4]);
+        padfGeoTransform[1] = CPLAtofM(papszLines[0]);
+        padfGeoTransform[2] = CPLAtofM(papszLines[2]);
+        padfGeoTransform[3] = CPLAtofM(papszLines[5]);
+        padfGeoTransform[4] = CPLAtofM(papszLines[1]);
+        padfGeoTransform[5] = CPLAtofM(papszLines[3]);
 
         // correct for center of pixel vs. top left of pixel
         padfGeoTransform[0] -= 0.5 * padfGeoTransform[1];
@@ -1894,6 +1825,7 @@ GDALGCPsToGeoTransform( int nGCPCount, const GDAL_GCP *pasGCPs,
  *  --optfile filename: expand an option file into the argument list. 
  *  --config key value: set system configuration option. 
  *  --debug [on/off/value]: set debug level.
+ *  --mempreload dir: preload directory contents into /vsimem
  *  --help-general: report detailed help on general options. 
  *
  * The argument array is replaced "in place" and should be freed with 
@@ -1964,6 +1896,52 @@ GDALGeneralCmdLineProcessor( int nArgc, char ***ppapszArgv, int nOptions )
             iArg += 2;
         }
 
+/* -------------------------------------------------------------------- */
+/*      --mempreload                                                    */
+/* -------------------------------------------------------------------- */
+        else if( EQUAL(papszArgv[iArg],"--mempreload") )
+        {
+            int i;
+
+            if( iArg + 1 >= nArgc )
+            {
+                CPLError( CE_Failure, CPLE_AppDefined, 
+                          "--mempreload option given without directory path.");
+                CSLDestroy( papszReturn );
+                return -1;
+            }
+            
+            char **papszFiles = CPLReadDir( papszArgv[iArg+1] );
+            if( CSLCount(papszFiles) == 0 )
+            {
+                CPLError( CE_Failure, CPLE_AppDefined, 
+                          "--mempreload given invalid or empty directory.");
+                CSLDestroy( papszReturn );
+                return -1;
+            }
+                
+            for( i = 0; papszFiles[i] != NULL; i++ )
+            {
+                CPLString osOldPath, osNewPath;
+                
+                if( EQUAL(papszFiles[i],".") || EQUAL(papszFiles[i],"..") )
+                    continue;
+
+                osOldPath = CPLFormFilename( papszArgv[iArg+1], 
+                                             papszFiles[i], NULL );
+                osNewPath.Printf( "/vsimem/%s", papszFiles[i] );
+
+                CPLDebug( "VSI", "Preloading %s to %s.", 
+                          osOldPath.c_str(), osNewPath.c_str() );
+
+                if( CPLCopyFile( osNewPath, osOldPath ) != 0 )
+                    return -1;
+            }
+            
+            CSLDestroy( papszFiles );
+            iArg += 1;
+        }
+
 /* -------------------------------------------------------------------- */
 /*      --debug                                                         */
 /* -------------------------------------------------------------------- */
@@ -2192,7 +2170,7 @@ static int _FetchDblFromMD( char **papszMD, const char *pszKey,
 
     if( nCount == 1 )
     {
-        *padfTarget = atof( pszValue );
+        *padfTarget = CPLAtofM( pszValue );
         return TRUE;
     }
 
@@ -2206,7 +2184,7 @@ static int _FetchDblFromMD( char **papszMD, const char *pszKey,
     }
 
     for( i = 0; i < nCount; i++ )
-        padfTarget[i] = atof(papszTokens[i]);
+        padfTarget[i] = CPLAtofM(papszTokens[i]);
 
     CSLDestroy( papszTokens );
 
@@ -2269,62 +2247,152 @@ GDALDataset *GDALFindAssociatedAuxFile( const char *pszBasename,
                                         GDALAccess eAccess )
 
 {
-    if( EQUAL(CPLGetExtension(pszBasename),"aux") )
+    const char *pszAuxSuffixLC = "aux";
+    const char *pszAuxSuffixUC = "AUX";
+
+    if( EQUAL(CPLGetExtension(pszBasename), pszAuxSuffixLC) )
+        return NULL;
+
+/* -------------------------------------------------------------------- */
+/*      Don't even try to look for an .aux file if we don't have a      */
+/*      path of any kind.                                               */
+/* -------------------------------------------------------------------- */
+    if( strlen(pszBasename) == 0 )
         return NULL;
 
 /* -------------------------------------------------------------------- */
 /*      We didn't find that, so try and find a corresponding aux        */
 /*      file.  Check that we are the dependent file of the aux          */
-/*      file.                                                           */
+/*      file, or if we aren't verify that the dependent file does       */
+/*      not exist, likely mean it is us but some sort of renaming       */
+/*      has occured.                                                    */
 /* -------------------------------------------------------------------- */
-    CPLString oAuxFilename = CPLResetExtension(pszBasename,"aux");
     CPLString oJustFile = CPLGetFilename(pszBasename); // without dir
+    CPLString oAuxFilename = CPLResetExtension(pszBasename, pszAuxSuffixLC);
     GDALDataset *poODS = NULL;
     GByte abyHeader[32];
     FILE *fp;
 
     fp = VSIFOpenL( oAuxFilename, "rb" );
-    if( fp != NULL )
+
+
+    if ( fp == NULL ) 
     {
-       VSIFReadL( abyHeader, 1, 32, fp );
-       if( EQUALN((char *) abyHeader,"EHFA_HEADER_TAG",15) )
-          poODS =  (GDALDataset *) GDALOpenShared( oAuxFilename, eAccess );
-       VSIFCloseL( fp );
+        // Can't found file with lower case suffix. Try the upper case one.
+        // no point in doing this on Win32 with case insensitive filenames.
+#ifndef WIN32
+        oAuxFilename = CPLResetExtension(pszBasename, pszAuxSuffixUC);
+        fp = VSIFOpenL( oAuxFilename, "rb" );
+#endif
     }
 
+    if( fp != NULL )
+    {
+        VSIFReadL( abyHeader, 1, 32, fp );
+        if( EQUALN((char *) abyHeader,"EHFA_HEADER_TAG",15) )
+            poODS =  (GDALDataset *) GDALOpenShared( oAuxFilename, eAccess );
+        VSIFCloseL( fp );
+    }
+
+/* -------------------------------------------------------------------- */
+/*      Try replacing extension with .aux                               */
+/* -------------------------------------------------------------------- */
     if( poODS != NULL )
     {
         const char *pszDep
             = poODS->GetMetadataItem( "HFA_DEPENDENT_FILE", "HFA" );
-        if( pszDep == NULL || !EQUAL(pszDep,oJustFile) )
+        if( pszDep == NULL  )
         {
+            CPLDebug( "AUX", 
+                      "Found %s but it has no dependent file, ignoring.",
+                      oAuxFilename.c_str() );
             GDALClose( poODS );
             poODS = NULL;
         }
+        else if( !EQUAL(pszDep,oJustFile) )
+        {
+            VSIStatBufL sStatBuf;
+
+            if( VSIStatL( pszDep, &sStatBuf ) == 0 )
+            {
+                CPLDebug( "AUX", "%s is for file %s, not %s, ignoring.",
+                          oAuxFilename.c_str(), 
+                          pszDep, oJustFile.c_str() );
+                GDALClose( poODS );
+                poODS = NULL;
+            }
+            else
+            {
+                CPLDebug( "AUX", "%s is for file %s, not %s, but since\n"
+                          "%s does not exist, we will use .aux file as our own.",
+                          oAuxFilename.c_str(), 
+                          pszDep, oJustFile.c_str(),
+                          pszDep );
+            }
+        }
     }
         
+/* -------------------------------------------------------------------- */
+/*      Try appending .aux to the end of the filename.                  */
+/* -------------------------------------------------------------------- */
     if( poODS == NULL )
     {
         oAuxFilename = pszBasename;
-        oAuxFilename += ".aux";
+        oAuxFilename += ".";
+        oAuxFilename += pszAuxSuffixLC;
         fp = VSIFOpenL( oAuxFilename, "rb" );
+#ifndef WIN32
+        if ( fp == NULL )
+        {
+            // Can't found file with lower case suffix. Try the upper case one.
+            oAuxFilename = pszBasename;
+            oAuxFilename += ".";
+            oAuxFilename += pszAuxSuffixUC;
+            fp = VSIFOpenL( oAuxFilename, "rb" );
+        }
+#endif
+
         if( fp != NULL )
         {
-           VSIFReadL( abyHeader, 1, 32, fp );
-           if( EQUALN((char *) abyHeader,"EHFA_HEADER_TAG",15) )
-              poODS =  (GDALDataset *) GDALOpenShared( oAuxFilename, eAccess );
-           VSIFCloseL( fp );
+            VSIFReadL( abyHeader, 1, 32, fp );
+            if( EQUALN((char *) abyHeader,"EHFA_HEADER_TAG",15) )
+                poODS = (GDALDataset *) GDALOpenShared( oAuxFilename, eAccess );
+            VSIFCloseL( fp );
         }
  
         if( poODS != NULL )
         {
             const char *pszDep
                 = poODS->GetMetadataItem( "HFA_DEPENDENT_FILE", "HFA" );
-            if( pszDep == NULL || !EQUAL(pszDep,oJustFile) )
+            if( pszDep == NULL  )
             {
+                CPLDebug( "AUX", 
+                          "Found %s but it has no dependent file, ignoring.",
+                          oAuxFilename.c_str() );
                 GDALClose( poODS );
                 poODS = NULL;
             }
+            else if( !EQUAL(pszDep,oJustFile) )
+            {
+                VSIStatBufL sStatBuf;
+
+                if( VSIStatL( pszDep, &sStatBuf ) == 0 )
+                {
+                    CPLDebug( "AUX", "%s is for file %s, not %s, ignoring.",
+                              oAuxFilename.c_str(), 
+                              pszDep, oJustFile.c_str() );
+                    GDALClose( poODS );
+                    poODS = NULL;
+                }
+                else
+                {
+                    CPLDebug( "AUX", "%s is for file %s, not %s, but since\n"
+                              "%s does not exist, we will use .aux file as our own.",
+                              oAuxFilename.c_str(), 
+                              pszDep, oJustFile.c_str(),
+                              pszDep );
+                }
+            }
         }
     }
 
