@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdal_pam.h,v 1.8 2006/02/08 06:03:40 fwarmerdam Exp $
+ * $Id: gdal_pam.h 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GDAL Core
  * Purpose:  Declaration for Peristable Auxilary Metadata classes.
@@ -25,34 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: gdal_pam.h,v $
- * Revision 1.8  2006/02/08 06:03:40  fwarmerdam
- * expose some PAM histo stuff for VRT, fixed InitFromXML() hist bug
- *
- * Revision 1.7  2005/10/13 01:19:57  fwarmerdam
- * moved GDALMultiDomainMetadata into GDALMajorObject
- *
- * Revision 1.6  2005/09/24 19:02:15  fwarmerdam
- * added RasterAttributeTable support
- *
- * Revision 1.5  2005/09/11 18:03:34  fwarmerdam
- * added Clear() method on multidomainmetadata
- *
- * Revision 1.4  2005/05/22 08:14:06  fwarmerdam
- * added multidomain metadata support
- *
- * Revision 1.3  2005/05/13 18:19:04  fwarmerdam
- * Added SetDefaultHistogram
- *
- * Revision 1.2  2005/05/11 14:04:21  fwarmerdam
- * added getdefaulthistogram
- *
- * Revision 1.1  2005/04/27 16:27:44  fwarmerdam
- * New
- *
- */
+ ****************************************************************************/
 
 #ifndef GDAL_PAM_H_INCLUDED
 #define GDAL_PAM_H_INCLUDED
@@ -286,8 +259,6 @@ class CPL_DLL GDALPamRasterBand : public GDALRasterBand
 };
 
 // These are mainly helper functions for internal use.
-int CPL_DLL PamApplyMetadata( CPLXMLNode *psTree, GDALMajorObject *poMO );
-CPLXMLNode CPL_DLL *PamSerializeMetadata( GDALMajorObject *poMO );
 int CPL_DLL PamParseHistogram( CPLXMLNode *psHistItem, 
                                double *pdfMin, double *pdfMax, 
                                int *pnBuckets, int **ppanHistogram, 
