@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdal_rat.cpp,v 1.7 2006/02/13 17:22:54 fwarmerdam Exp $
+ * $Id: gdal_rat.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GDAL Core
  * Purpose:  Implementation of GDALRasterAttributeTable and related classes.
@@ -25,37 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: gdal_rat.cpp,v $
- * Revision 1.7  2006/02/13 17:22:54  fwarmerdam
- * Avoid large amounts of linked list walking adding rows when
- * serializing RAT.
- *
- * Revision 1.6  2005/11/01 22:16:36  fwarmerdam
- * fix comments (bug 985)
- *
- * Revision 1.5  2005/09/29 00:50:36  fwarmerdam
- * Added doc note.
- *
- * Revision 1.4  2005/09/28 21:29:30  fwarmerdam
- * added RAT documentation
- *
- * Revision 1.3  2005/09/27 22:12:44  fwarmerdam
- * fixed bug creating string columns
- *
- * Revision 1.2  2005/09/27 14:05:47  fwarmerdam
- * fixed various C wrappers returning void
- *
- * Revision 1.1  2005/09/24 19:00:53  fwarmerdam
- * New
- *
- */
+ ****************************************************************************/
 
 #include "gdal_priv.h"
 #include "gdal_rat.h"
 
-CPL_CVSID("$Id: gdal_rat.cpp,v 1.7 2006/02/13 17:22:54 fwarmerdam Exp $");
+CPL_CVSID("$Id: gdal_rat.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /**
  * \class GDALRasterAttributeTable
@@ -103,6 +78,7 @@ CPL_CVSID("$Id: gdal_rat.cpp,v 1.7 2006/02/13 17:22:54 fwarmerdam Exp $");
 GDALRasterAttributeTable::GDALRasterAttributeTable()
 
 {
+    bColumnsAnalysed = FALSE;
     nMinCol = -1;
     nMaxCol = -1;
     bLinearBinning = FALSE;
@@ -158,6 +134,27 @@ GDALDestroyRasterAttributeTable( GDALRasterAttributeTableH hRAT )
         delete (GDALRasterAttributeTable *) hRAT;
 }
 
+/************************************************************************/
+/*                           AnalyseColumns()                           */
+/*                                                                      */
+/*      Internal method to work out which column to use for various     */
+/*      tasks.                                                          */
+/************************************************************************/
+
+void GDALRasterAttributeTable::AnalyseColumns()
+
+{
+    bColumnsAnalysed = TRUE;
+
+    nMinCol = GetColOfUsage( GFU_Min );
+    if( nMinCol == -1 )
+        nMinCol = GetColOfUsage( GFU_MinMax );
+
+    nMaxCol = GetColOfUsage( GFU_Max );
+    if( nMaxCol == -1 )
+        nMaxCol = GetColOfUsage( GFU_MinMax );
+}
+
 /************************************************************************/
 /*                           GetColumnCount()                           */
 /************************************************************************/
@@ -201,7 +198,7 @@ int CPL_STDCALL GDALRATGetColumnCount( GDALRasterAttributeTableH hRAT )
  * @return the column name or an empty string for invalid column numbers.
  */
 
-CPLString GDALRasterAttributeTable::GetNameOfCol( int iCol ) const
+const char *GDALRasterAttributeTable::GetNameOfCol( int iCol ) const
 
 {
     if( iCol < 0 || iCol >= (int) aoFields.size() )
@@ -394,7 +391,7 @@ GDALRATGetRowCount( GDALRasterAttributeTableH hRAT )
  * @return field value
  */
 
-CPLString
+const char *
 GDALRasterAttributeTable::GetValueAsString( int iRow, int iField ) const
 
 {
@@ -418,16 +415,16 @@ GDALRasterAttributeTable::GetValueAsString( int iRow, int iField ) const
     {
       case GFT_Integer:
       {
-          char szValue[100];
-          sprintf( szValue, "%d", aoFields[iField].anValues[iRow] );
-          return szValue;
+          ((GDALRasterAttributeTable *) this)->
+              osWorkingResult.Printf( "%d", aoFields[iField].anValues[iRow] );
+          return osWorkingResult;
       }
 
       case GFT_Real:
       {
-          char szValue[100];
-          sprintf( szValue, "%.16g", aoFields[iField].adfValues[iRow] );
-          return szValue;
+          ((GDALRasterAttributeTable *) this)->
+              osWorkingResult.Printf( "%.16g", aoFields[iField].adfValues[iRow]);
+          return osWorkingResult;
       }
 
       case GFT_String:
@@ -894,6 +891,9 @@ int GDALRasterAttributeTable::GetRowOfValue( double dfValue ) const
 /* -------------------------------------------------------------------- */
     const GDALRasterAttributeField *poMin, *poMax;
 
+    if( !bColumnsAnalysed )
+        ((GDALRasterAttributeTable *) this)->AnalyseColumns();
+
     if( nMinCol == -1 && nMaxCol == -1 )
         return -1;
 
@@ -946,6 +946,19 @@ int GDALRasterAttributeTable::GetRowOfValue( double dfValue ) const
     return -1;
 }
 
+/************************************************************************/
+/*                           GetRowOfValue()                            */
+/*                                                                      */
+/*      Int arg for now just converted to double.  Perhaps we will      */
+/*      handle this in a special way some day?                          */
+/************************************************************************/
+
+int GDALRasterAttributeTable::GetRowOfValue( int nValue ) const
+
+{
+    return GetRowOfValue( (double) nValue );
+}
+
 /************************************************************************/
 /*                        GDALRATGetRowOfValue()                        */
 /************************************************************************/
@@ -1057,14 +1070,14 @@ GDALRATGetLinearBinning( GDALRasterAttributeTableH hRAT,
  * 
  * This method is the same as the C function GDALRATCreateColumn().
  *
- * @param osFieldName the name of the field to create.
+ * @param pszFieldName the name of the field to create.
  * @param eFieldType the field type (integer, double or string).
  * @param eFieldUsage the field usage, GFU_Generic if not known.
  *
  * @return CE_None on success or CE_Failure if something goes wrong.
  */
 
-CPLErr GDALRasterAttributeTable::CreateColumn( CPLString osFieldName, 
+CPLErr GDALRasterAttributeTable::CreateColumn( const char *pszFieldName, 
                                                GDALRATFieldType eFieldType,
                                                GDALRATFieldUsage eFieldUsage )
 
@@ -1073,7 +1086,7 @@ CPLErr GDALRasterAttributeTable::CreateColumn( CPLString osFieldName,
 
     aoFields.resize( iNewField+1 );
 
-    aoFields[iNewField].sName = osFieldName;
+    aoFields[iNewField].sName = pszFieldName;
     aoFields[iNewField].eType = eFieldType;
     aoFields[iNewField].eUsage = eFieldUsage;
 
@@ -1179,6 +1192,112 @@ GDALRATInitializeFromColorTable( GDALRasterAttributeTableH hRAT,
         InitializeFromColorTable( (GDALColorTable *) hCT );
 }
 
+/************************************************************************/
+/*                       TranslateToColorTable()                        */
+/************************************************************************/
+
+/**
+ * \brief Translate to a color table.
+ *
+ * This method will attempt to create a corresponding GDALColorTable from
+ * this raster attribute table. 
+ * 
+ * This method is the same as the C function GDALRATTranslateToColorTable().
+ *
+ * @param nEntryCount The number of entries to produce (0 to nEntryCount-1), or -1 to auto-determine the number of entries.
+ *
+ * @return the generated color table or NULL on failure.
+ */
+
+GDALColorTable *GDALRasterAttributeTable::TranslateToColorTable( 
+    int nEntryCount )
+
+{
+/* -------------------------------------------------------------------- */
+/*      Establish which fields are red, green, blue and alpha.          */
+/* -------------------------------------------------------------------- */
+    int iRed, iGreen, iBlue, iAlpha;
+
+    iRed = GetColOfUsage( GFU_Red );
+    iGreen = GetColOfUsage( GFU_Green );
+    iBlue = GetColOfUsage( GFU_Blue );
+    iAlpha = GetColOfUsage( GFU_Alpha );
+
+    if( iRed == -1 || iGreen == -1 || iBlue == -1 )
+        return NULL;
+
+/* -------------------------------------------------------------------- */
+/*      If we aren't given an explicit number of values to scan for,    */
+/*      search for the maximum "max" value.                             */
+/* -------------------------------------------------------------------- */
+    if( nEntryCount == -1 )
+    {
+        int  iRow, nRowCount = GetRowCount();
+        int  iMaxCol;
+
+        iMaxCol = GetColOfUsage( GFU_Max );
+        if( iMaxCol == -1 )
+            GetColOfUsage( GFU_MinMax );
+
+        if( iMaxCol == -1 || nRowCount == 0 )
+            return NULL;
+    
+        for( iRow = 0; iRow < nRowCount; iRow++ )
+            nEntryCount = MAX(nEntryCount,GetValueAsInt(iRow,iMaxCol)+1);
+
+        if( nEntryCount < 0 )
+            return NULL;
+
+        // restrict our number of entries to something vaguely sensible
+        nEntryCount = MIN(65535,nEntryCount);
+    }
+
+/* -------------------------------------------------------------------- */
+/*      Assign values to color table.                                   */
+/* -------------------------------------------------------------------- */
+    GDALColorTable *poCT = new GDALColorTable();
+    int iEntry;
+
+    for( iEntry = 0; iEntry < nEntryCount; iEntry++ )
+    {
+        GDALColorEntry sColor;
+        int iRow = GetRowOfValue( iEntry );
+
+        if( iRow == -1 )
+        {
+            sColor.c1 = sColor.c2 = sColor.c3 = sColor.c4 = 0;
+        }
+        else
+        {
+            sColor.c1 = GetValueAsInt( iRow, iRed );
+            sColor.c2 = GetValueAsInt( iRow, iGreen );
+            sColor.c3 = GetValueAsInt( iRow, iBlue );
+            if( iAlpha == -1 )
+                sColor.c4 = 255;
+            else
+                sColor.c4 = GetValueAsInt( iRow, iAlpha );
+        }
+        
+        poCT->SetColorEntry( iEntry, &sColor );
+    }
+
+    return poCT;
+}
+
+/************************************************************************/
+/*                  GDALRATInitializeFromColorTable()                   */
+/************************************************************************/
+
+GDALColorTableH CPL_STDCALL 
+GDALRATTranslateToColorTable( GDALRasterAttributeTableH hRAT,
+                              int nEntryCount )
+                                 
+
+{
+    return ((GDALRasterAttributeTable *) hRAT)->
+        TranslateToColorTable( nEntryCount );
+}
+
 /************************************************************************/
 /*                              XMLInit()                               */
 /************************************************************************/
@@ -1233,7 +1352,10 @@ CPLErr GDALRasterAttributeTable::XMLInit( CPLXMLNode *psTree,
                 if( psF->eType != CXT_Element || !EQUAL(psF->pszValue,"F") )
                     continue;
 
-                SetValue( iRow, iField++, psF->psChild->pszValue );
+                if( psF->psChild != NULL && psF->psChild->eType == CXT_Text )
+                    SetValue( iRow, iField++, psF->psChild->pszValue );
+                else
+                    SetValue( iRow, iField++, "" );
             }
         }
     }
