@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdalcolortable.cpp,v 1.6 2006/03/28 14:49:56 fwarmerdam Exp $
+ * $Id: gdalcolortable.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GDAL Core
  * Purpose:  Color table implementation.
@@ -25,32 +25,11 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- * $Log: gdalcolortable.cpp,v $
- * Revision 1.6  2006/03/28 14:49:56  fwarmerdam
- * updated contact info
- *
- * Revision 1.5  2005/09/05 19:29:29  fwarmerdam
- * minor formatting fix
- *
- * Revision 1.4  2005/07/25 21:24:28  ssoule
- * Changed GDALColorTable's "GDALColorEntry *paoEntries" to
- * "std::vector<GDALColorEntry> aoEntries".
- *
- * Revision 1.3  2005/04/04 15:24:48  fwarmerdam
- * Most C entry points now CPL_STDCALL
- *
- * Revision 1.2  2001/07/18 04:04:30  warmerda
- * added CPL_CVSID
- *
- * Revision 1.1  2000/03/06 02:26:00  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "gdal_priv.h"
 
-CPL_CVSID("$Id: gdalcolortable.cpp,v 1.6 2006/03/28 14:49:56 fwarmerdam Exp $");
+CPL_CVSID("$Id: gdalcolortable.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                           GDALColorTable()                           */
