@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdaldataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: gdaldataset.cpp 11489 2007-05-11 19:27:48Z warmerdam $
  *
  * Project:  GDAL Core
  * Purpose:  Base class for raster file formats.  
@@ -31,7 +31,7 @@
 #include "cpl_string.h"
 #include "cpl_multiproc.h"
 
-CPL_CVSID("$Id: gdaldataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: gdaldataset.cpp 11489 2007-05-11 19:27:48Z warmerdam $");
 
 static volatile int nGDALDatasetCount = 0;
 static GDALDataset ** volatile papoGDALDatasetList = NULL;
@@ -1291,6 +1291,20 @@ CPLErr GDALDataset::RasterIO( GDALRWFlag eRWFlag,
     int bNeedToFreeBandMap = FALSE;
     CPLErr eErr = CE_None;
 
+/* -------------------------------------------------------------------- */
+/*      Some size values are "noop".  Lets just return to avoid         */
+/*      stressing lower level functions.                                */
+/* -------------------------------------------------------------------- */
+    if( nXSize < 1 || nYSize < 1 || nBufXSize < 1 || nBufYSize < 1 )
+    {
+        CPLDebug( "GDAL", 
+                  "RasterIO() skipped for odd window or buffer size.\n"
+                  "  Window = (%d,%d)x%dx%d\n"
+                  "  Buffer = %dx%d\n",
+                  nXOff, nYOff, nXSize, nYSize, 
+                  nBufXSize, nBufYSize );
+    }
+
 /* -------------------------------------------------------------------- */
 /*      If pixel and line spaceing are defaulted assign reasonable      */
 /*      value assuming a packed buffer.                                 */
@@ -1353,25 +1367,11 @@ CPLErr GDALDataset::RasterIO( GDALRWFlag eRWFlag,
         }
     }
 
-/* -------------------------------------------------------------------- */
-/*      Some size values are "noop".  Lets just return to avoid         */
-/*      stressing lower level functions.                                */
-/* -------------------------------------------------------------------- */
-    if( nXSize < 1 || nYSize < 1 || nBufXSize < 1 || nBufYSize < 1 )
-    {
-        CPLDebug( "GDAL", 
-                  "RasterIO() skipped for odd window or buffer size.\n"
-                  "  Window = (%d,%d)x%dx%d\n"
-                  "  Buffer = %dx%d\n",
-                  nXOff, nYOff, nXSize, nYSize, 
-                  nBufXSize, nBufYSize );
-    }
-
 /* -------------------------------------------------------------------- */
 /*      We are being forced to use cached IO instead of a driver        */
 /*      specific implementation.                                        */
 /* -------------------------------------------------------------------- */
-    else if( bForceCachedIO )
+    if( bForceCachedIO )
     {
         eErr = 
             BlockBasedRasterIO( eRWFlag, nXOff, nYOff, nXSize, nYSize,
