@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdaldriver.cpp,v 1.41 2006/03/28 14:49:56 fwarmerdam Exp $
+ * $Id: gdaldriver.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GDAL Core
  * Purpose:  Implementation of GDALDriver class (and C wrappers)
@@ -25,53 +25,11 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: gdaldriver.cpp,v $
- * Revision 1.41  2006/03/28 14:49:56  fwarmerdam
- * updated contact info
- *
- * Revision 1.40  2006/03/03 19:44:45  fwarmerdam
- * force C numeric locale in select locations
- *
- * Revision 1.39  2006/02/07 19:07:07  fwarmerdam
- * applied some strategic improved outofmemory checking
- *
- * Revision 1.38  2006/02/07 18:13:25  fwarmerdam
- * Perform graceful error recovery if line buffer allocation fails.
- *
- * Revision 1.37  2005/10/13 01:38:29  fwarmerdam
- * Ensure "large file" stat is used in GDALDriver::Delete() so it works
- * on in-memory stuff.
- *
- * Revision 1.36  2005/10/13 00:46:19  fwarmerdam
- * Avoid trying to set scale and offset if they are the defaults.
- *
- * Revision 1.35  2005/05/24 18:13:15  dron
- * Added GDALGetDriverCreationOptionList() function.
- *
- * Revision 1.34  2005/05/17 15:13:06  fwarmerdam
- * Added nodata support for bands
- *
- * Revision 1.33  2005/04/04 15:24:48  fwarmerdam
- * Most C entry points now CPL_STDCALL
- *
- * Revision 1.32  2005/03/16 11:01:10  lichun
- * in CreateCopy() the category names are copied as well
- *
- * Revision 1.31  2005/01/15 16:10:10  fwarmerdam
- * added offset, scale and colorinterp to default createcopy
- *
- * Revision 1.30  2003/05/23 20:42:24  sperkins
- * default CreateCopy() now copies metadata
- *
- * Revision 1.29  2003/04/30 17:13:48  warmerda
- * added docs for many C functions
- */
+ ****************************************************************************/
 
 #include "gdal_priv.h"
 
-CPL_CVSID("$Id: gdaldriver.cpp,v 1.41 2006/03/28 14:49:56 fwarmerdam Exp $");
+CPL_CVSID("$Id: gdaldriver.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                             GDALDriver()                             */
@@ -184,78 +142,19 @@ GDALCreate( GDALDriverH hDriver, const char * pszFilename,
 }
 
 /************************************************************************/
-/*                             CreateCopy()                             */
+/*                         DefaultCreateCopy()                          */
 /************************************************************************/
 
-/**
- * Create a copy of a dataset.
- *
- * This method will attempt to create a copy of a raster dataset with the
- * indicated filename, and in this drivers format.  Band number, size, 
- * type, projection, geotransform and so forth are all to be copied from
- * the provided template dataset.  
- *
- * Note that many sequential write once formats (such as JPEG and PNG) don't
- * implement the Create() method but do implement this CreateCopy() method.
- * If the driver doesn't implement CreateCopy(), but does implement Create()
- * then the default CreateCopy() mechanism built on calling Create() will
- * be used.                                                             
- *
- * It is intended that CreateCopy() would often be used with a source dataset
- * which is a virtual dataset allowing configuration of band types, and
- * other information without actually duplicating raster data.  This virtual
- * dataset format hasn't yet been implemented at the time of this documentation
- * being written. 
- *
- * @param pszFilename the name for the new dataset. 
- * @param poSrcDS the dataset being duplicated. 
- * @param bStrict TRUE if the copy must be strictly equivelent, or more
- * normally FALSE indicating that the copy may adapt as needed for the 
- * output format. 
- * @param papszOptions additional format dependent options controlling 
- * creation of the output file. 
- * @param pfnProgress a function to be used to report progress of the copy.
- * @param pProgressData application data passed into progress function.
- *
- * @return a pointer to the newly created dataset (may be read-only access).
- */
-
-GDALDataset *GDALDriver::CreateCopy( const char * pszFilename, 
-                                     GDALDataset * poSrcDS, 
-                                     int bStrict, char ** papszOptions,
-                                     GDALProgressFunc pfnProgress,
-                                     void * pProgressData )
+GDALDataset *GDALDriver::DefaultCreateCopy( const char * pszFilename, 
+                                            GDALDataset * poSrcDS, 
+                                            int bStrict, char ** papszOptions,
+                                            GDALProgressFunc pfnProgress,
+                                            void * pProgressData )
 
 {
-    CPLLocaleC  oLocaleForcer;
-
     if( pfnProgress == NULL )
         pfnProgress = GDALDummyProgress;
 
-/* -------------------------------------------------------------------- */
-/*      If the format provides a CreateCopy() method use that,          */
-/*      otherwise fallback to the internal implementation using the     */
-/*      Create() method.                                                */
-/* -------------------------------------------------------------------- */
-    if( pfnCreateCopy != NULL )
-    {
-        GDALDataset *poDstDS;
-
-        poDstDS = pfnCreateCopy( pszFilename, poSrcDS, bStrict, papszOptions,
-                                 pfnProgress, pProgressData );
-        if( poDstDS != NULL )
-        {
-            if( poDstDS->GetDescription() == NULL 
-                || strlen(poDstDS->GetDescription()) > 0 )
-                poDstDS->SetDescription( pszFilename );
-
-            if( poDstDS->poDriver == NULL )
-                poDstDS->poDriver = this;
-        }
-
-        return poDstDS;
-    }
-    
 /* -------------------------------------------------------------------- */
 /*      Create destination dataset.                                     */
 /* -------------------------------------------------------------------- */
@@ -409,6 +308,83 @@ GDALDataset *GDALDriver::CreateCopy( const char * pszFilename,
     return poDstDS;
 }
 
+/************************************************************************/
+/*                             CreateCopy()                             */
+/************************************************************************/
+
+/**
+ * Create a copy of a dataset.
+ *
+ * This method will attempt to create a copy of a raster dataset with the
+ * indicated filename, and in this drivers format.  Band number, size, 
+ * type, projection, geotransform and so forth are all to be copied from
+ * the provided template dataset.  
+ *
+ * Note that many sequential write once formats (such as JPEG and PNG) don't
+ * implement the Create() method but do implement this CreateCopy() method.
+ * If the driver doesn't implement CreateCopy(), but does implement Create()
+ * then the default CreateCopy() mechanism built on calling Create() will
+ * be used.                                                             
+ *
+ * It is intended that CreateCopy() would often be used with a source dataset
+ * which is a virtual dataset allowing configuration of band types, and
+ * other information without actually duplicating raster data.  This virtual
+ * dataset format hasn't yet been implemented at the time of this documentation
+ * being written. 
+ *
+ * @param pszFilename the name for the new dataset. 
+ * @param poSrcDS the dataset being duplicated. 
+ * @param bStrict TRUE if the copy must be strictly equivelent, or more
+ * normally FALSE indicating that the copy may adapt as needed for the 
+ * output format. 
+ * @param papszOptions additional format dependent options controlling 
+ * creation of the output file. 
+ * @param pfnProgress a function to be used to report progress of the copy.
+ * @param pProgressData application data passed into progress function.
+ *
+ * @return a pointer to the newly created dataset (may be read-only access).
+ */
+
+GDALDataset *GDALDriver::CreateCopy( const char * pszFilename, 
+                                     GDALDataset * poSrcDS, 
+                                     int bStrict, char ** papszOptions,
+                                     GDALProgressFunc pfnProgress,
+                                     void * pProgressData )
+
+{
+    CPLLocaleC  oLocaleForcer;
+
+    if( pfnProgress == NULL )
+        pfnProgress = GDALDummyProgress;
+
+/* -------------------------------------------------------------------- */
+/*      If the format provides a CreateCopy() method use that,          */
+/*      otherwise fallback to the internal implementation using the     */
+/*      Create() method.                                                */
+/* -------------------------------------------------------------------- */
+    if( pfnCreateCopy != NULL )
+    {
+        GDALDataset *poDstDS;
+
+        poDstDS = pfnCreateCopy( pszFilename, poSrcDS, bStrict, papszOptions,
+                                 pfnProgress, pProgressData );
+        if( poDstDS != NULL )
+        {
+            if( poDstDS->GetDescription() == NULL 
+                || strlen(poDstDS->GetDescription()) > 0 )
+                poDstDS->SetDescription( pszFilename );
+
+            if( poDstDS->poDriver == NULL )
+                poDstDS->poDriver = this;
+        }
+
+        return poDstDS;
+    }
+    else
+        return DefaultCreateCopy( pszFilename, poSrcDS, bStrict, 
+                                  papszOptions, pfnProgress, pProgressData );
+}
+
 /************************************************************************/
 /*                           GDALCreateCopy()                           */
 /************************************************************************/
