@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdaljp2box.cpp,v 1.5 2006/01/11 06:30:18 fwarmerdam Exp $
+ * $Id: gdaljp2box.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GDAL 
  * Purpose:  GDALJP2Box Implementation - Low level JP2 box reader.
@@ -25,32 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- *****************************************************************************
- *
- * $Log: gdaljp2box.cpp,v $
- * Revision 1.5  2006/01/11 06:30:18  fwarmerdam
- * Fixed bug in ReadBox() with boxes where LBox is 1 and the length
- * is read from the XLBox (such as GeoJP2 UUID Boxes from Erdas Imagine).
- * http://bugzilla.remotesensing.org/show_bug.cgi?id=1032
- *
- * Revision 1.4  2005/09/14 19:26:50  fwarmerdam
- * added better debug output
- *
- * Revision 1.3  2005/09/14 13:13:17  dron
- * Avoid warnings in DumpReadable().
- *
- * Revision 1.2  2005/05/09 14:42:33  fwarmerdam
- * Fixed to use VSFReadL() instead of VSIFRead().
- *
- * Revision 1.1  2005/05/03 21:10:59  fwarmerdam
- * New
- *
- */
+ ****************************************************************************/
 
 #include "gdaljp2metadata.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: gdaljp2box.cpp,v 1.5 2006/01/11 06:30:18 fwarmerdam Exp $");
+CPL_CVSID("$Id: gdaljp2box.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                             GDALJP2Box()                             */
@@ -64,6 +44,8 @@ GDALJP2Box::GDALJP2Box( FILE *fpIn )
     nBoxOffset = -1;
     nDataOffset = -1;
     nBoxLength = 0;
+    
+    pabyData = NULL;
 }
 
 /************************************************************************/
@@ -73,6 +55,7 @@ GDALJP2Box::GDALJP2Box( FILE *fpIn )
 GDALJP2Box::~GDALJP2Box()
 
 {
+    CPLFree( pabyData );
 }
 
 /************************************************************************/
@@ -173,7 +156,7 @@ int GDALJP2Box::ReadBox()
             return FALSE;
 
         
-        if( sizeof(nBoxLength) == 64 )
+        if( sizeof(nBoxLength) == 8 )
         {
             CPL_MSBPTR64( abyXLBox );
             memcpy( &nBoxLength, abyXLBox, 8 );
@@ -277,3 +260,155 @@ int GDALJP2Box::DumpReadable( FILE *fpOut )
     }
     return 0;
 }
+
+/************************************************************************/
+/*                              SetType()                               */
+/************************************************************************/
+
+void GDALJP2Box::SetType( const char *pszType )
+
+{
+    CPLAssert( strlen(pszType) == 4 );
+
+    szBoxType[0] = pszType[3];
+    szBoxType[1] = pszType[2];
+    szBoxType[2] = pszType[1];
+    szBoxType[3] = pszType[0];
+    szBoxType[4] = '\0';
+}
+
+/************************************************************************/
+/*                          SetWritableData()                           */
+/************************************************************************/
+
+void GDALJP2Box::SetWritableData( int nLength, const GByte *pabyDataIn )
+
+{
+    CPLFree( pabyData );
+    
+    pabyData = (GByte *) CPLMalloc(nLength);
+    memcpy( pabyData, pabyDataIn, nLength );
+
+    nBoxOffset = -9; // virtual offsets for data length computation.
+    nDataOffset = -1;
+    
+    nBoxLength = 8 + nLength;
+}
+
+/************************************************************************/
+/*                           CreateUUIDBox()                            */
+/************************************************************************/
+
+GDALJP2Box *GDALJP2Box::CreateUUIDBox( 
+    const GByte *pabyUUID, int nDataSize, GByte *pabyData )
+
+{
+    GDALJP2Box *poBox;
+
+    poBox = new GDALJP2Box();
+    poBox->SetType( "uuid" );
+    memcpy( poBox->abyUUID, pabyUUID, 16 );
+
+    GByte *pabyMergedData = (GByte *) CPLMalloc(16+nDataSize);
+    memcpy( pabyMergedData, pabyUUID, 16 );
+    memcpy( pabyMergedData+16, pabyData, nDataSize );
+    
+    poBox->SetWritableData( 16 + nDataSize, pabyMergedData );
+    
+    CPLFree( pabyMergedData );
+
+    return poBox;
+}
+
+/************************************************************************/
+/*                           CreateAsocBox()                            */
+/************************************************************************/
+
+GDALJP2Box *GDALJP2Box::CreateAsocBox( int nCount, GDALJP2Box **papoBoxes )
+
+
+{
+    int nDataSize=0, iBox;
+    GByte *pabyCompositeData, *pabyNext;
+
+/* -------------------------------------------------------------------- */
+/*      Compute size of data area of asoc box.                          */
+/* -------------------------------------------------------------------- */
+    for( iBox = 0; iBox < nCount; iBox++ )
+        nDataSize += 8 + papoBoxes[iBox]->GetDataLength();
+
+    pabyNext = pabyCompositeData = (GByte *) CPLMalloc(nDataSize);
+
+/* -------------------------------------------------------------------- */
+/*      Copy subboxes headers and data into buffer.                     */
+/* -------------------------------------------------------------------- */
+    for( iBox = 0; iBox < nCount; iBox++ )
+    {
+        GUInt32   nLBox, nTBox;
+
+        nLBox = CPL_MSBWORD32(papoBoxes[iBox]->nBoxLength);
+        memcpy( pabyNext, &nLBox, 4 );
+        pabyNext += 4;
+
+        memcpy( &nTBox, papoBoxes[iBox]->szBoxType, 4 );
+        nTBox = CPL_MSBWORD32( nTBox );
+        memcpy( pabyNext, &nTBox, 4 );
+        pabyNext += 4;
+
+        memcpy( pabyNext, papoBoxes[iBox]->pabyData, 
+                papoBoxes[iBox]->GetDataLength() );
+        pabyNext += papoBoxes[iBox]->GetDataLength();
+    }
+    
+/* -------------------------------------------------------------------- */
+/*      Create asoc box.                                                */
+/* -------------------------------------------------------------------- */
+    GDALJP2Box *poAsoc = new GDALJP2Box();
+
+    poAsoc->SetType( "asoc" );
+    poAsoc->SetWritableData( nDataSize, pabyCompositeData );
+    
+    CPLFree( pabyCompositeData );
+
+    return poAsoc;
+}
+
+/************************************************************************/
+/*                            CreateLblBox()                            */
+/************************************************************************/
+
+GDALJP2Box *GDALJP2Box::CreateLblBox( const char *pszLabel )
+
+{
+    GDALJP2Box *poBox;
+
+    poBox = new GDALJP2Box();
+    poBox->SetType( "lbl " );
+    poBox->SetWritableData( strlen(pszLabel)+1, (const GByte *) pszLabel );
+
+    return poBox;
+}
+
+/************************************************************************/
+/*                       CreateLabelledXMLAssoc()                       */
+/************************************************************************/
+
+GDALJP2Box *GDALJP2Box::CreateLabelledXMLAssoc( const char *pszLabel,
+                                                const char *pszXML )
+
+{
+    GDALJP2Box oLabel, oXML;
+    GDALJP2Box *aoList[2];
+
+    oLabel.SetType( "lbl " );
+    oLabel.SetWritableData( strlen(pszLabel)+1, (const GByte *) pszLabel );
+
+    oXML.SetType( "xml " );
+    oXML.SetWritableData( strlen(pszXML)+1, (const GByte *) pszXML );
+
+    aoList[0] = &oLabel;
+    aoList[1] = &oXML;
+    
+    return CreateAsocBox( 2, aoList );
+}
+
