@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdaljp2metadata.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: gdaljp2metadata.cpp 12389 2007-10-13 01:47:54Z warmerdam $
  *
  * Project:  GDAL 
  * Purpose:  GDALJP2Metadata - Read GeoTIFF and/or GML georef info.
@@ -34,7 +34,7 @@
 #include "ogr_geometry.h"
 #include "ogr_api.h"
 
-CPL_CVSID("$Id: gdaljp2metadata.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: gdaljp2metadata.cpp 12389 2007-10-13 01:47:54Z warmerdam $");
 
 static const unsigned char msi_uuid2[16] =
 {0xb1,0x4b,0xf8,0xbd,0x08,0x3d,0x4b,0x43,
@@ -627,6 +627,20 @@ int GDALJP2Metadata::ParseGMLCoverageDesc()
     if( poOriginGeometry != NULL )
         delete poOriginGeometry;
 
+/* -------------------------------------------------------------------- */
+/*      If we still don't have an srsName, check for it on the          */
+/*      boundedBy Envelope.  Some products                              */
+/*      (ie. EuropeRasterTile23.jpx) use this as the only srsName       */
+/*      delivery vehicle.                                               */
+/* -------------------------------------------------------------------- */
+    if( pszSRSName == NULL )
+    {
+        pszSRSName = 
+            CPLGetXMLValue( psXML,
+                            "=FeatureCollection.boundedBy.Envelope.srsName",
+                            NULL );
+    }
+
 /* -------------------------------------------------------------------- */
 /*      If we have gotten a geotransform, then try to interprete the    */
 /*      srsName.                                                        */
@@ -634,27 +648,18 @@ int GDALJP2Metadata::ParseGMLCoverageDesc()
     if( bSuccess && pszSRSName != NULL 
         && (pszProjection == NULL || strlen(pszProjection) == 0) )
     {
+        OGRSpatialReference oSRS;
+
         if( EQUALN(pszSRSName,"epsg:",5) )
         {
-            OGRSpatialReference oSRS;
             if( oSRS.SetFromUserInput( pszSRSName ) == OGRERR_NONE )
                 oSRS.exportToWkt( &pszProjection );
         }
-        else if( EQUALN(pszSRSName,"urn:ogc:def:crs:EPSG::",22) )
+        else if( EQUALN(pszSRSName,"urn:",4) 
+                 && strstr(pszSRSName,":def:") != NULL
+                 && oSRS.importFromURN(pszSRSName) == OGRERR_NONE )
         {
-            OGRSpatialReference oSRS;
-            if( oSRS.importFromEPSG( atoi(pszSRSName + 22) ) == OGRERR_NONE )
-                oSRS.exportToWkt( &pszProjection );
-        }
-        else if( EQUALN(pszSRSName,"urn:ogc:def:crs:EPSG:",21) )
-        {
-            const char *pszCode = pszSRSName+21;
-            while( *pszCode != ':' && *pszCode != '\0' )
-                pszCode++;
-
-            OGRSpatialReference oSRS;
-            if( oSRS.importFromEPSG( atoi(pszCode+1) ) == OGRERR_NONE )
-                oSRS.exportToWkt( &pszProjection );
+            oSRS.exportToWkt( &pszProjection );
         }
         else if( !GMLSRSLookup( pszSRSName ) )
         {
