@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdaljp2metadata.h,v 1.4 2006/04/07 05:35:25 fwarmerdam Exp $
+ * $Id: gdaljp2metadata.h 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GDAL 
  * Purpose:  JP2 Box Reader (and GMLJP2 Interpreter)
@@ -25,23 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- *****************************************************************************
- *
- * $Log: gdaljp2metadata.h,v $
- * Revision 1.4  2006/04/07 05:35:25  fwarmerdam
- * Added ReadAndParse() method, which includes worldfile reading.
- * Actually set HaveGeoTransform flag properly.
- *
- * Revision 1.3  2005/07/05 22:09:00  fwarmerdam
- * add preliminary support for MSIG boxes
- *
- * Revision 1.2  2005/05/05 20:17:15  fwarmerdam
- * support dictionary lookups
- *
- * Revision 1.1  2005/05/03 21:10:59  fwarmerdam
- * New
- *
- */
+ ****************************************************************************/
 
 #ifndef _JP2READER_H_INCLUDED 
 #define _JP2READER_H_INCLUDED 
@@ -68,8 +52,10 @@ class CPL_DLL GDALJP2Box
 
     GByte       abyUUID[16];
 
+    GByte      *pabyData;
+
 public:
-                GDALJP2Box( FILE * );
+                GDALJP2Box( FILE * = NULL );
                 ~GDALJP2Box();
 
     int         SetOffset( GIntBig nNewOffset );
@@ -93,6 +79,19 @@ public:
     FILE        *GetFILE() { return fpVSIL; }
 
     const GByte *GetUUID() { return abyUUID; }
+
+    // write support
+    void        SetType( const char * );
+    void        SetWritableData( int nLength, const GByte *pabyData );
+    const GByte*GetWritableData() { return pabyData; }
+
+    // factory methods.
+    static GDALJP2Box *CreateAsocBox( int nCount, GDALJP2Box **papoBoxes );
+    static GDALJP2Box *CreateLblBox( const char *pszLabel );
+    static GDALJP2Box *CreateLabelledXMLAssoc( const char *pszLabel,
+                                               const char *pszXML );
+    static GDALJP2Box *CreateUUIDBox( const GByte *pabyUUID, 
+                                      int nDataSize, GByte *pabyData );
 };
 
 /************************************************************************/
@@ -102,11 +101,19 @@ public:
 class CPL_DLL GDALJP2Metadata
 
 {
-  private:
+private:
     void    CollectGMLData( GDALJP2Box * );
     int     GMLSRSLookup( const char *pszURN );
 
-  public:
+    int    nGeoTIFFSize;
+    GByte  *pabyGeoTIFFData;
+
+    int    nMSIGSize;
+    GByte  *pabyMSIGData;
+
+public:
+    char   **papszGMLMetadata;
+    
     int     bHaveGeoTransform;
     double  adfGeoTransform[6];
 
@@ -115,16 +122,9 @@ class CPL_DLL GDALJP2Metadata
     int         nGCPCount;
     GDAL_GCP    *pasGCPList;
 
-    char   **papszGMLMetadata;
-    
-    int    nGeoTIFFSize;
-    GByte  *pabyGeoTIFFData;
-
-    int    nMSIGSize;
-    GByte  *pabyMSIGData;
-
+public:
             GDALJP2Metadata();
-           ~GDALJP2Metadata();
+            ~GDALJP2Metadata();
 
     int     ReadBoxes( FILE * fpVSIL );
 
@@ -133,8 +133,18 @@ class CPL_DLL GDALJP2Metadata
     int     ParseGMLCoverageDesc();
 
     int     ReadAndParse( const char *pszFilename );
+
+    // Write oriented. 
+    void    SetProjection( const char *pszWKT );
+    void    SetGeoTransform( double * );
+    void    SetGCPs( int, const GDAL_GCP * );
+    
+    GDALJP2Box *CreateJP2GeoTIFF();
+    GDALJP2Box *CreateGMLJP2( int nXSize, int nYSize );
 };
 
+
+
 #endif /* ndef _JP2READER_H_INCLUDED */
 
 
