@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdalpamdataset.cpp,v 1.19 2006/04/13 03:16:01 fwarmerdam Exp $
+ * $Id: gdalpamdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  GDAL Core
  * Purpose:  Implementation of GDALPamDataset, a dataset base class that 
@@ -26,74 +26,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: gdalpamdataset.cpp,v $
- * Revision 1.19  2006/04/13 03:16:01  fwarmerdam
- * keep track if an object is PAM enabled, bug 1135
- *
- * Revision 1.18  2006/04/07 13:12:16  fwarmerdam
- * Fix merging of band metadata.
- *
- * Revision 1.17  2006/03/31 14:25:10  fwarmerdam
- * avoiding cloning from missing source bands
- *
- * Revision 1.16  2005/10/14 21:10:16  fwarmerdam
- * avoid error if .aux.xml file does not exist
- *
- * Revision 1.15  2005/10/13 01:19:57  fwarmerdam
- * moved GDALMultiDomainMetadata into GDALMajorObject
- *
- * Revision 1.14  2005/10/12 15:35:23  fwarmerdam
- * mark pam info clean at end of TryLoadAux
- *
- * Revision 1.13  2005/09/27 22:12:19  fwarmerdam
- * added RAT support when cloning
- *
- * Revision 1.12  2005/09/26 15:52:03  fwarmerdam
- * centralized .aux opening logic
- *
- * Revision 1.11  2005/09/23 20:55:19  fwarmerdam
- * avoid unimplemented errors if PAM disabled
- *
- * Revision 1.10  2005/09/11 18:04:24  fwarmerdam
- * clearup multidomain metadata
- *
- * Revision 1.9  2005/08/31 03:34:23  fwarmerdam
- * use CPLString.Printf instead of CSPrintf()
- *
- * Revision 1.8  2005/07/22 13:50:13  fwarmerdam
- * Default PAM support to off.
- *
- * Revision 1.7  2005/06/09 15:43:02  fwarmerdam
- * Clear dirty flag in TryLoadXML() so we don't end up writing out
- * a pam file for metadata set within the callers Open() method.
- *
- * Revision 1.6  2005/06/08 14:04:38  fwarmerdam
- * use .aux.xml as the default extension instead of .pam
- *
- * Revision 1.5  2005/05/22 08:13:40  fwarmerdam
- * added multidomain metadata support
- *
- * Revision 1.4  2005/05/17 15:13:28  fwarmerdam
- * ensure pam info initialize on any set operation
- *
- * Revision 1.3  2005/05/16 21:36:23  fwarmerdam
- * prototype support for reading aux file
- *
- * Revision 1.2  2005/05/11 14:03:08  fwarmerdam
- * added option to disable pam, and quiet failed .pam opens
- *
- * Revision 1.1  2005/04/27 16:27:44  fwarmerdam
- * New
- *
- */
+ ****************************************************************************/
 
 #include "gdal_pam.h"
 #include "cpl_string.h"
 #include "ogr_spatialref.h"
 
-CPL_CVSID("$Id: gdalpamdataset.cpp,v 1.19 2006/04/13 03:16:01 fwarmerdam Exp $");
+CPL_CVSID("$Id: gdalpamdataset.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                           GDALPamDataset()                           */
@@ -875,74 +814,6 @@ CPLErr GDALPamDataset::SetMetadataItem( const char *pszName,
     return GDALDataset::SetMetadataItem( pszName, pszValue, pszDomain );
 }
 
-/************************************************************************/
-/*                          PAMApplyMetadata()                          */
-/************************************************************************/
-int PamApplyMetadata( CPLXMLNode *psTree, GDALMajorObject *poMO )
-
-{
-    char **papszMD = NULL;
-    CPLXMLNode *psMetadata = CPLGetXMLNode( psTree, "Metadata" );
-    CPLXMLNode *psMDI;
-
-    if( psMetadata == NULL )
-        return FALSE;
-
-    /* Format is <MDI key="...">value_Text</MDI> */
-
-    for( psMDI = psMetadata->psChild; psMDI != NULL; psMDI = psMDI->psNext )
-    {
-        if( !EQUAL(psMDI->pszValue,"MDI") || psMDI->eType != CXT_Element 
-            || psMDI->psChild == NULL || psMDI->psChild->psNext == NULL 
-            || psMDI->psChild->eType != CXT_Attribute
-            || psMDI->psChild->psChild == NULL )
-            continue;
-
-        papszMD = 
-            CSLSetNameValue( papszMD, psMDI->psChild->psChild->pszValue, 
-                             psMDI->psChild->psNext->pszValue );
-    }
-
-    poMO->SetMetadata( papszMD );
-    CSLDestroy( papszMD );
-
-    return papszMD != NULL;
-}
-
-/************************************************************************/
-/*                        PAMSerializeMetadata()                        */
-/************************************************************************/
-
-CPLXMLNode *PamSerializeMetadata( GDALMajorObject *poMO )
-
-{
-    char **papszMD = poMO->GetMetadata();
-
-    if( papszMD == NULL || CSLCount(papszMD) == 0 )
-        return NULL;
-
-    CPLXMLNode *psMD;
-
-    psMD = CPLCreateXMLNode( NULL, CXT_Element, "Metadata" );
-
-    for( int i = 0; papszMD[i] != NULL; i++ )
-    {
-        const char *pszRawValue;
-        char *pszKey;
-        CPLXMLNode *psMDI;
-
-        pszRawValue = CPLParseNameValue( papszMD[i], &pszKey );
-
-        psMDI = CPLCreateXMLNode( psMD, CXT_Element, "MDI" );
-        CPLSetXMLValue( psMDI, "#key", pszKey );
-        CPLCreateXMLNode( psMDI, CXT_Text, pszRawValue );
-
-        CPLFree( pszKey );
-    }
-
-    return psMD;
-}
-
 /************************************************************************/
 /*                             TryLoadAux()                             */
 /************************************************************************/
