@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: gdalrasterblock.cpp 10798 2007-02-07 23:27:06Z warmerdam $
+ * $Id: gdalrasterblock.cpp 12426 2007-10-15 03:29:04Z warmerdam $
  *
  * Project:  GDAL Core
  * Purpose:  Implementation of GDALRasterBlock class and related global 
@@ -31,7 +31,7 @@
 #include "gdal_priv.h"
 #include "cpl_multiproc.h"
 
-CPL_CVSID("$Id: gdalrasterblock.cpp 10798 2007-02-07 23:27:06Z warmerdam $");
+CPL_CVSID("$Id: gdalrasterblock.cpp 12426 2007-10-15 03:29:04Z warmerdam $");
 
 static int bCacheMaxInitialized = FALSE;
 static int nCacheMax = 40 * 1024*1024;
@@ -363,7 +363,8 @@ CPLErr GDALRasterBlock::Internalize()
     if( pNewData == NULL )
     {
         CPLError( CE_Failure, CPLE_OutOfMemory, 
-                  "Internalize failed" );
+                  "Out of memory allocating %d byte raster cache block.",
+                  nSizeInBytes );
         return( CE_Failure );
     }
 
