@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogr2ogr.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: ogr2ogr.cpp 11646 2007-06-11 04:50:13Z mloskot $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Simple client for translating between formats.
@@ -33,7 +33,7 @@
 #include "cpl_string.h"
 #include "ogr_api.h"
 
-CPL_CVSID("$Id: ogr2ogr.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: ogr2ogr.cpp 11646 2007-06-11 04:50:13Z mloskot $");
 
 static void Usage();
 
@@ -564,6 +564,9 @@ static int TranslateLayer( OGRDataSource *poSrcDS,
             exit( 1 );
         }
 
+        CPLAssert( NULL != poSourceSRS );
+        CPLAssert( NULL != poOutputSRS );
+
         poCT = OGRCreateCoordinateTransformation( poSourceSRS, poOutputSRS );
         if( poCT == NULL )
         {
@@ -574,7 +577,7 @@ static int TranslateLayer( OGRDataSource *poSrcDS,
                    "are not transformable, or because projection services\n"
                    "(PROJ.4 DLL/.so) could not be loaded.\n" );
             
-            poSrcLayer->GetSpatialRef()->exportToPrettyWkt( &pszWKT, FALSE );
+            poSourceSRS->exportToPrettyWkt( &pszWKT, FALSE );
             printf( "Source:\n%s\n", pszWKT );
             
             poOutputSRS->exportToPrettyWkt( &pszWKT, FALSE );
