@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogr_api.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: ogr_api.cpp 12043 2007-09-03 17:58:51Z mloskot $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  C API Functions that don't correspond one-to-one with C++ 
@@ -634,22 +634,36 @@ OGRErr OGR_G_RemoveGeometry( OGRGeometryH hGeom, int iGeom, int bDelete )
 double OGR_G_GetArea( OGRGeometryH hGeom )
 
 {
+    double fArea = 0.0;
+
     switch( wkbFlatten(((OGRGeometry *) hGeom)->getGeometryType()) )
     {
       case wkbPolygon:
-        return ((OGRPolygon *) hGeom)->get_Area();
+        fArea = ((OGRPolygon *) hGeom)->get_Area();
         break;
 
       case wkbMultiPolygon:
-        return ((OGRMultiPolygon *) hGeom)->get_Area();
+        fArea = ((OGRMultiPolygon *) hGeom)->get_Area();
         break;
 
       case wkbLinearRing:
-        return ((OGRLinearRing *) hGeom)->get_Area();
+      case wkbLineString:
+        /* This test below is required to filter out wkbLineString geometries
+         * not being of type of wkbLinearRing.
+         */
+        if( EQUAL( ((OGRGeometry*) hGeom)->getGeometryName(), "LINEARRING" ) )
+        {
+            fArea = ((OGRLinearRing *) hGeom)->get_Area();
+        }
         break;
-        
+
       default:
-        return 0.0;
+        CPLError( CE_Warning, CPLE_AppDefined,
+                  "OGR_G_GetArea() called against non-surface geometry type." );
+
+        fArea = 0.0;
     }
+
+    return fArea;
 }
 
