@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogr_srs_esri.cpp 11161 2007-04-02 03:14:32Z warmerdam $
+ * $Id: ogr_srs_esri.cpp 11828 2007-08-01 23:15:47Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  OGRSpatialReference translation to/from ESRI .prj definitions.
@@ -31,11 +31,12 @@
 #include "ogr_p.h"
 #include "cpl_csv.h"
 
-CPL_CVSID("$Id: ogr_srs_esri.cpp 11161 2007-04-02 03:14:32Z warmerdam $");
+CPL_CVSID("$Id: ogr_srs_esri.cpp 11828 2007-08-01 23:15:47Z warmerdam $");
 
 static char *apszProjMapping[] = {
     "Albers", SRS_PT_ALBERS_CONIC_EQUAL_AREA,
     "Cassini", SRS_PT_CASSINI_SOLDNER,
+    "Plate_Carree", SRS_PT_EQUIRECTANGULAR,
     "Hotine_Oblique_Mercator_Azimuth_Natural_Origin", 
                                         SRS_PT_HOTINE_OBLIQUE_MERCATOR,
     "Hotine_Oblique_Mercator_Azimuth_Center", 
@@ -730,8 +731,8 @@ OGRErr OGRSpatialReference::importFromESRI( char **papszPrj )
 
     else if( EQUAL(pszProj,"TRANSVERSE") )
     {
-        SetTM( OSR_GDV( papszPrj, "PARAM_2", 0.0 ), 
-               OSR_GDV( papszPrj, "PARAM_3", 0.0 ), 
+        SetTM( OSR_GDV( papszPrj, "PARAM_3", 0.0 ), 
+               OSR_GDV( papszPrj, "PARAM_2", 0.0 ), 
                OSR_GDV( papszPrj, "PARAM_1", 0.0 ), 
                OSR_GDV( papszPrj, "PARAM_4", 0.0 ), 
                OSR_GDV( papszPrj, "PARAM_5", 0.0 ) );
@@ -766,10 +767,15 @@ OGRErr OGRSpatialReference::importFromESRI( char **papszPrj )
         {
             SetWellKnownGeogCS( pszDatum );
         }
-        else if( EQUAL( pszDatum, "EUR" ) )
+        else if( EQUAL( pszDatum, "EUR" )
+                 || EQUAL( pszDatum, "ED50" ) )
         {
             SetWellKnownGeogCS( "EPSG:4230" );
         }
+        else if( EQUAL( pszDatum, "GDA94" ) )
+        {
+            SetWellKnownGeogCS( "EPSG:4283" );
+        }
         else
         {
             const char *pszSpheroid;
@@ -822,6 +828,7 @@ OGRErr OGRSpatialReference::importFromESRI( char **papszPrj )
     if( IsLocal() || IsProjected() )
     {
         const char *pszValue;
+        double dfOldUnits = GetLinearUnits();
 
         pszValue = OSR_GDS( papszPrj, "Units", NULL );
         if( pszValue == NULL )
@@ -833,6 +840,18 @@ OGRErr OGRSpatialReference::importFromESRI( char **papszPrj )
                                                1.0 / atof(pszValue) );
         else
             SetLinearUnitsAndUpdateParameters( pszValue, 1.0 );
+
+        // If we have reset the linear units we should clear any authority
+        // nodes on the PROJCS.  This especially applies to state plane
+        // per bug 1697
+        double dfNewUnits = GetLinearUnits();
+        if( dfOldUnits != 0.0 
+            && (dfNewUnits / dfOldUnits < 0.9999999
+                || dfNewUnits / dfOldUnits > 1.0000001) )
+        {
+            if( GetRoot()->FindChild( "AUTHORITY" ) != -1 )
+                GetRoot()->DestroyChild(GetRoot()->FindChild( "AUTHORITY" ));
+        }
     }
     
     return OGRERR_NONE;
