@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogr_srs_panorama.cpp,v 1.3 2006/03/09 10:46:48 dron Exp $
+ * $Id: ogr_srs_panorama.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  OGRSpatialReference translation to/from "Panorama" GIS
@@ -26,25 +26,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogr_srs_panorama.cpp,v $
- * Revision 1.3  2006/03/09 10:46:48  dron
- * Typo fixed.
- *
- * Revision 1.2  2005/10/19 16:32:20  dron
- * Export projection info in newly created datasets.
- *
- * Revision 1.1  2005/10/10 14:43:22  dron
- * New.
- *
- */
+ ****************************************************************************/
 
 #include "ogr_spatialref.h"
 #include "cpl_conv.h"
 #include "cpl_csv.h"
 
-CPL_CVSID("$Id: ogr_srs_panorama.cpp,v 1.3 2006/03/09 10:46:48 dron Exp $");
+CPL_CVSID("$Id: ogr_srs_panorama.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 #define TO_DEGREES (180.0 / 3.14159265358979323846)
 #define TO_RADIANS (3.14159265358979323846 / 180.0)
