@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogr_srs_pci.cpp,v 1.9 2006/03/03 18:35:40 fwarmerdam Exp $
+ * $Id: ogr_srs_pci.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  OGRSpatialReference translation to/from PCI georeferencing
@@ -26,45 +26,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogr_srs_pci.cpp,v $
- * Revision 1.9  2006/03/03 18:35:40  fwarmerdam
- * Added comment.
- *
- * Revision 1.8  2006/03/03 18:34:17  fwarmerdam
- * Don't require pszUnits to be passed in, and don't assume METER if it isn't.
- *
- * Revision 1.7  2006/03/03 18:30:37  fwarmerdam
- * Added ellipsoid definition to ellipsoid tables so we can support
- * those without EPSG equivs (ie. E019).
- * Support "Geosys" values without the earth model pre-formatted properly
- * such as "SIN E019" instead of "SIN         E019".
- *
- * Revision 1.6  2004/01/31 09:51:40  dron
- * Fixed projection parameters number mismatch; more datums added.
- *
- * Revision 1.5  2004/01/29 15:21:46  dron
- * More datums added.
- *
- * Revision 1.4  2003/10/08 07:59:39  dron
- * More datums and ellipsoids added.
- *
- * Revision 1.3  2003/09/11 19:47:48  warmerda
- * it seems Visual C++ doesnt like having a const int field in PCIDatums
- *
- * Revision 1.2  2003/09/09 07:49:18  dron
- * Added exportToPCI() method.
- *
- * Revision 1.1  2003/08/31 14:49:37  dron
- * New.
- */
+ ****************************************************************************/
 
 #include "ogr_spatialref.h"
 #include "cpl_conv.h"
 #include "cpl_csv.h"
 
-CPL_CVSID("$Id: ogr_srs_pci.cpp,v 1.9 2006/03/03 18:35:40 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogr_srs_pci.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 typedef struct 
 {
@@ -409,6 +377,20 @@ OGRErr OGRSpatialReference::importFromPCI( const char *pszProj,
     {
     }
     
+    else if( EQUALN( pszProj, "METER", 5 ) 
+             || EQUALN( pszProj, "METRE", 5 ) )
+    {
+        SetLocalCS( "METER" );
+        SetLinearUnits( "METER", 1.0 );
+    }
+
+    else if( EQUALN( pszProj, "FEET", 4 ) 
+             || EQUALN( pszProj, "FOOT", 4 ) )
+    {
+        SetLocalCS( "FEET" );
+        SetLinearUnits( "FEET", atof(SRS_UL_FOOT_CONV) );
+    }
+
     else if( EQUALN( pszProj, "ACEA", 4 ) )
     {
         SetACEA( padfPrjParams[4], padfPrjParams[5],
@@ -589,7 +571,8 @@ OGRErr OGRSpatialReference::importFromPCI( const char *pszProj,
 /* -------------------------------------------------------------------- */
 /*      We have an earthmodel string, look it up in the datum list.     */
 /* -------------------------------------------------------------------- */
-    if( strlen(szEarthModel) > 0 && (IsProjected() || IsGeographic()) )
+    if( strlen(szEarthModel) > 0 
+        && (poRoot == NULL || IsProjected() || IsGeographic()) )
     {
         PCIDatums   *paoDatum = aoDatums;
 
@@ -813,8 +796,10 @@ OGRErr OGRSpatialReference::exportToPCI( char **ppszProj, char **ppszUnits,
 
     if( IsLocal() )
     {
-        CPLPrintStringFill( szProj, "PIXEL", 17 );
-        return OGRERR_NONE;
+        if( GetLinearUnits() > 0.30479999 && GetLinearUnits() < 0.3048010 )
+            CPLPrintStringFill( szProj, "FEET", 17 );
+        else
+            CPLPrintStringFill( szProj, "METER", 17 );
     }
 
     else if( pszProjection == NULL )
@@ -1037,7 +1022,9 @@ OGRErr OGRSpatialReference::exportToPCI( char **ppszProj, char **ppszUnits,
 /* -------------------------------------------------------------------- */
     const char  *pszDatum = GetAttrValue( "DATUM" );
 
-    if( EQUAL( pszDatum, SRS_DN_NAD27 ) )
+    if( pszDatum == NULL || strlen(pszDatum) == 0 )
+        /* do nothing */;
+    else if( EQUAL( pszDatum, SRS_DN_NAD27 ) )
         CPLPrintStringFill( szProj + 12, "D-01", 4 );
 
     else if( EQUAL( pszDatum, SRS_DN_NAD83 ) )
