@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogr_srsnode.cpp,v 1.26 2003/05/28 19:16:42 warmerda Exp $
+ * $Id: ogr_srsnode.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  The OGR_SRSNode class.
@@ -25,95 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogr_srsnode.cpp,v $
- * Revision 1.26  2003/05/28 19:16:42  warmerda
- * fixed up argument names and stuff for docs
- *
- * Revision 1.25  2003/03/12 14:25:31  warmerda
- * Fixed bug 294 re: quoting of axis directions
- *
- * Revision 1.24  2003/01/08 18:14:28  warmerda
- * added FixupOrdering()
- *
- * Revision 1.23  2002/12/10 04:06:57  warmerda
- * Added support for a parent pointer in OGR_SRSNode.
- * Ensure that authority codes are quoted (bugzilla 201)
- *
- * Revision 1.22  2002/07/25 13:13:36  warmerda
- * fixed const correctness of some docs
- *
- * Revision 1.21  2002/04/18 14:22:45  warmerda
- * made OGRSpatialReference and co 'const correct'
- *
- * Revision 1.20  2002/03/05 14:25:14  warmerda
- * expand tabs
- *
- * Revision 1.19  2002/02/21 20:09:04  warmerda
- * Drop white space outside of quotes when ingesting WKT.  This makes the
- * ingest of 'pretty' WKT possible.
- *
- * Revision 1.18  2002/01/24 16:21:29  warmerda
- * added StripNodes method, removed simplify flag from pretty wkt
- *
- * Revision 1.17  2002/01/18 15:30:04  warmerda
- * fixed serious bug in DeleteChild()
- *
- * Revision 1.16  2001/12/01 17:01:50  warmerda
- * don't omit empty child nodes when exporting pretty wkt
- *
- * Revision 1.15  2001/10/11 19:29:57  warmerda
- * fixed redeclaration of i
- *
- * Revision 1.14  2001/10/11 19:26:16  warmerda
- * added applyRemapping
- *
- * Revision 1.13  2001/07/18 05:03:05  warmerda
- * added CPL_CVSID
- *
- * Revision 1.12  2001/01/19 21:10:46  warmerda
- * replaced tabs
- *
- * Revision 1.11  2000/07/09 20:48:02  warmerda
- * added exportToPrettyWkt
- *
- * Revision 1.10  2000/03/31 14:40:49  warmerda
- * Fixed multiple declaration of i in GetNode().
- *
- * Revision 1.9  2000/03/16 19:03:20  warmerda
- * added DestroyChild(), FindChild()
- *
- * Revision 1.8  2000/02/25 13:23:25  warmerda
- * removed include of ogr_geometry.h
- *
- * Revision 1.7  2000/01/26 21:22:18  warmerda
- * added tentative MakeValueSafe implementation
- *
- * Revision 1.6  2000/01/12 04:12:55  warmerda
- * Fixed bug in InsertChild().
- *
- * Revision 1.5  2000/01/11 22:12:13  warmerda
- * added InsertChild
- *
- * Revision 1.4  1999/11/18 19:02:19  warmerda
- * expanded tabs
- *
- * Revision 1.3  1999/07/29 18:09:20  warmerda
- * Avoid use of isdigit()
- *
- * Revision 1.2  1999/07/29 18:00:44  warmerda
- * modified quoting rules for WKT to more closely match standard examples
- *
- * Revision 1.1  1999/06/25 20:20:53  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_spatialref.h"
 #include "ogr_p.h"
 
-CPL_CVSID("$Id: ogr_srsnode.cpp,v 1.26 2003/05/28 19:16:42 warmerda Exp $");
+CPL_CVSID("$Id: ogr_srsnode.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                            OGR_SRSNode()                             */
@@ -717,7 +634,10 @@ OGRErr OGR_SRSNode::importFromWkt( char ** ppszInput )
 
             eErr = poNewChild->importFromWkt( (char **) &pszInput );
             if( eErr != OGRERR_NONE )
+            {
+                delete poNewChild;
                 return eErr;
+            }
 
             AddChild( poNewChild );
             
