@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrct.cpp,v 1.33 2006/04/04 14:38:47 fwarmerdam Exp $
+ * $Id: ogrct.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  The OGRSCoordinateTransformation class.
@@ -25,111 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrct.cpp,v $
- * Revision 1.33  2006/04/04 14:38:47  fwarmerdam
- * Use CPLGetConfigOption() instead of getenv() for PROJSO.
- *
- * Revision 1.32  2006/02/19 21:00:04  mloskot
- * [WCE]
- * + Add main makefile.evc for Windows CE target build
- * * Minor changes in ogrct.cpp and swq.c for Windows CE target
- *
- * Revision 1.31  2006/01/21 19:16:37  fwarmerdam
- * Added LIBNAME case for cygwin.
- *
- * Revision 1.30  2005/09/05 20:45:16  fwarmerdam
- * fail in intialize() if exportToProj4 result is empty
- *
- * Revision 1.29  2005/07/13 18:06:03  mbrudka
- * Just for a case moved proj4 lock above static bTriedToLoad
- *
- * Revision 1.28  2005/06/08 19:38:14  fwarmerdam
- * protect PROJ.4 use with a mutex
- *
- * Revision 1.27  2005/04/06 00:02:05  fwarmerdam
- * various osr and oct functions now stdcall
- *
- * Revision 1.26  2004/12/16 16:58:29  fwarmerdam
- * Use libproj.dylib on Apple
- *
- * Revision 1.25  2004/09/23 15:05:27  fwarmerdam
- * cast pj_get_errno_ref in hopes of fixing Bug 614
- *
- * Revision 1.24  2004/09/21 00:15:29  fwarmerdam
- * Fixed PJ_VERSION checking syntax (secondary issue in bug 614).
- *
- * Revision 1.23  2004/01/24 09:35:00  warmerda
- * added TransformEx support to capture per point reprojection failure
- *
- * Revision 1.22  2003/11/10 17:08:31  warmerda
- * dont delete OGRSpatialReferences if they are still referenced
- *
- * Revision 1.21  2003/06/27 19:02:50  warmerda
- * changed to use pj_init_plus instead of CSLTokenizeString
- *
- * Revision 1.20  2003/01/21 22:04:34  warmerda
- * don't report errors for pj_get_def or pj_dalloc missing
- *
- * Revision 1.19  2002/12/09 17:24:33  warmerda
- * fixed PROJ_STATIC settings for pj_strerrno
- *
- * Revision 1.18  2002/12/09 16:49:55  warmerda
- * implemented support for alternate GEOGCS units
- *
- * Revision 1.17  2002/11/27 14:48:22  warmerda
- * added PROJSO environment variable
- *
- * Revision 1.16  2002/11/19 20:47:04  warmerda
- * fixed to call pj_free, not pj_dalloc for projPJ
- *
- * Revision 1.15  2002/06/11 18:02:03  warmerda
- * add PROJ.4 normalization and EPSG support
- *
- * Revision 1.14  2002/03/05 14:25:14  warmerda
- * expand tabs
- *
- * Revision 1.13  2002/01/18 04:49:17  warmerda
- * report CPL errors if transform() fails
- *
- * Revision 1.12  2001/12/11 17:37:24  warmerda
- * improved PROJ.4 error reporting.
- *
- * Revision 1.11  2001/11/18 00:57:53  warmerda
- * change printf to CPLDebug
- *
- * Revision 1.10  2001/11/07 22:14:17  warmerda
- * add a way of statically linking in PROJ.4
- *
- * Revision 1.9  2001/07/18 05:03:05  warmerda
- * added CPL_CVSID
- *
- * Revision 1.8  2001/05/24 21:02:42  warmerda
- * moved OGRCoordinateTransform destructor defn
- *
- * Revision 1.7  2001/01/19 21:10:47  warmerda
- * replaced tabs
- *
- * Revision 1.6  2000/07/12 18:19:09  warmerda
- * Removed debug statements.
- *
- * Revision 1.5  2000/07/09 20:48:28  warmerda
- * rewrote to use PROJ.4 datum shifting
- *
- * Revision 1.4  2000/03/24 14:49:31  warmerda
- * fetch TOWGS84 coefficients
- *
- * Revision 1.3  2000/03/20 23:08:18  warmerda
- * Added docs.
- *
- * Revision 1.2  2000/03/20 22:40:23  warmerda
- * Added C API.
- *
- * Revision 1.1  2000/03/20 15:00:11  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_spatialref.h"
 #include "cpl_port.h"
@@ -142,7 +38,7 @@
 #include "proj_api.h"
 #endif
 
-CPL_CVSID("$Id: ogrct.cpp,v 1.33 2006/04/04 14:38:47 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrct.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /* ==================================================================== */
 /*      PROJ.4 interface stuff.                                         */
@@ -192,6 +88,8 @@ class OGRProj4CT : public OGRCoordinateTransformation
     int         bSourceLatLong;
     double      dfSourceToRadians;
     double      dfSourceFromRadians;
+    int         bSourceWrap;
+    double      dfSourceWrapLong;
     
 
     OGRSpatialReference *poSRSTarget;
@@ -199,6 +97,8 @@ class OGRProj4CT : public OGRCoordinateTransformation
     int         bTargetLatLong;
     double      dfTargetToRadians;
     double      dfTargetFromRadians;
+    int         bTargetWrap;
+    double      dfTargetWrapLong;
 
     int         nErrorCount;
 
@@ -358,6 +258,9 @@ OCTDestroyCoordinateTransformation( OGRCoordinateTransformationH hCT )
  *
  * This is the same as the C function OCTNewCoordinateTransformation().
  *
+ * Input spatial reference system objects are assigned 
+ * by copy (calling clone() method) and no ownership transfer occurs.
+ *
  * The delete operator, or OCTDestroyCoordinateTransformation() should
  * be used to destroy transformation objects. 
  *
@@ -421,7 +324,7 @@ OGRProj4CT::OGRProj4CT()
     poSRSTarget = NULL;
     psPJSource = NULL;
     psPJTarget = NULL;
-
+    
     nErrorCount = 0;
 }
 
@@ -478,6 +381,8 @@ int OGRProj4CT::Initialize( OGRSpatialReference * poSourceIn,
 /* -------------------------------------------------------------------- */
     dfSourceToRadians = DEG_TO_RAD;
     dfSourceFromRadians = RAD_TO_DEG;
+    bSourceWrap = FALSE;
+    dfSourceWrapLong = 0.0;
 
     if( bSourceLatLong )
     {
@@ -494,6 +399,8 @@ int OGRProj4CT::Initialize( OGRSpatialReference * poSourceIn,
 
     dfTargetToRadians = DEG_TO_RAD;
     dfTargetFromRadians = RAD_TO_DEG;
+    bTargetWrap = FALSE;
+    dfTargetWrapLong = 0.0;
 
     if( bTargetLatLong )
     {
@@ -508,6 +415,34 @@ int OGRProj4CT::Initialize( OGRSpatialReference * poSourceIn,
         }
     }
 
+/* -------------------------------------------------------------------- */
+/*      Preliminary logic to setup wrapping.                            */
+/* -------------------------------------------------------------------- */
+    const char *pszCENTER_LONG;
+
+    if( CPLGetConfigOption( "CENTER_LONG", NULL ) != NULL )
+    {
+        bSourceWrap = bTargetWrap = TRUE;
+        dfSourceWrapLong = dfTargetWrapLong = 
+            atof(CPLGetConfigOption( "CENTER_LONG", "" ));
+        CPLDebug( "OGRCT", "Wrap at %g.", dfSourceWrapLong );
+    }
+
+    pszCENTER_LONG = poSRSSource->GetExtension( "GEOGCS", "CENTER_LONG" );
+    if( pszCENTER_LONG != NULL )
+    {
+        dfSourceWrapLong = atof(pszCENTER_LONG);
+        bSourceWrap = TRUE;
+        CPLDebug( "OGRCT", "Wrap source at %g.", dfSourceWrapLong );
+    }
+
+    pszCENTER_LONG = poSRSTarget->GetExtension( "GEOGCS", "CENTER_LONG" );
+    if( pszCENTER_LONG != NULL )
+    {
+        dfTargetWrapLong = atof(pszCENTER_LONG);
+        bTargetWrap = TRUE;
+        CPLDebug( "OGRCT", "Wrap target at %g.", dfTargetWrapLong );
+    }
 
 /* -------------------------------------------------------------------- */
 /*      Establish PROJ.4 handle for source if projection.               */
@@ -655,10 +590,27 @@ int OGRProj4CT::TransformEx( int nCount, double *x, double *y, double *z,
 /* -------------------------------------------------------------------- */
     if( bSourceLatLong )
     {
+        if( bSourceWrap )
+        {
+            for( i = 0; i < nCount; i++ )
+            {
+                if( x[i] != HUGE_VAL && y[i] != HUGE_VAL )
+                {
+                    if( x[i] < dfSourceWrapLong - 180.0 )
+                        x[i] += 360.0;
+                    else if( x[i] > dfSourceWrapLong + 180 )
+                        x[i] -= 360.0;
+                }
+            }
+        }
+
         for( i = 0; i < nCount; i++ )
         {
-            x[i] *= dfSourceToRadians;
-            y[i] *= dfSourceToRadians;
+            if( x[i] != HUGE_VAL )
+            {
+                x[i] *= dfSourceToRadians;
+                y[i] *= dfSourceToRadians;
+            }
         }
     }
 
@@ -715,6 +667,20 @@ int OGRProj4CT::TransformEx( int nCount, double *x, double *y, double *z,
                 y[i] *= dfTargetFromRadians;
             }
         }
+
+        if( bTargetWrap )
+        {
+            for( i = 0; i < nCount; i++ )
+            {
+                if( x[i] != HUGE_VAL && y[i] != HUGE_VAL )
+                {
+                    if( x[i] < dfTargetWrapLong - 180.0 )
+                        x[i] += 360.0;
+                    else if( x[i] > dfTargetWrapLong + 180 )
+                        x[i] -= 360.0;
+                }
+            }
+        }
     }
 
 /* -------------------------------------------------------------------- */
