@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrcurve.cpp,v 1.11 2005/04/06 20:43:00 fwarmerdam Exp $
+ * $Id: ogrcurve.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  The OGRCurve geometry class. 
@@ -25,52 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrcurve.cpp,v $
- * Revision 1.11  2005/04/06 20:43:00  fwarmerdam
- * fixed a variety of method signatures for documentation
- *
- * Revision 1.10  2004/02/21 15:36:14  warmerda
- * const correctness updates for geometry: bug 289
- *
- * Revision 1.9  2003/09/11 22:47:53  aamici
- * add class constructors and destructors where needed in order to
- * let the mingw/cygwin binutils produce sensible partially linked objet files
- * with 'ld -r'.
- *
- * Revision 1.8  2001/07/18 05:03:05  warmerda
- * added CPL_CVSID
- *
- * Revision 1.7  1999/11/18 19:02:19  warmerda
- * expanded tabs
- *
- * Revision 1.6  1999/05/31 15:01:59  warmerda
- * OGRCurve now an abstract base class with essentially no implementation.
- * Everything moved down to OGRLineString where it belongs.  Also documented
- * classes.
- *
- * Revision 1.5  1999/05/31 11:05:08  warmerda
- * added some documentation
- *
- * Revision 1.4  1999/05/20 14:35:44  warmerda
- * added support for well known text format
- *
- * Revision 1.3  1999/05/17 14:39:46  warmerda
- * Added various new methods for ICurve compatibility.
- *
- * Revision 1.2  1999/03/30 21:21:43  warmerda
- * added linearring/polygon support
- *
- * Revision 1.1  1999/03/29 21:21:10  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_geometry.h"
 #include "ogr_p.h"
 
-CPL_CVSID("$Id: ogrcurve.cpp,v 1.11 2005/04/06 20:43:00 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrcurve.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 OGRCurve::OGRCurve()
 {
