@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrfeature.cpp,v 1.36 2006/04/02 18:25:59 fwarmerdam Exp $
+ * $Id: ogrfeature.cpp 11087 2007-03-27 03:55:12Z warmerdam $
  * 
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  The OGRFeature class implementation. 
@@ -25,64 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrfeature.cpp,v $
- * Revision 1.36  2006/04/02 18:25:59  fwarmerdam
- * added OFTDateTime, and OFTTime support
- *
- * Revision 1.35  2006/02/28 05:04:18  fwarmerdam
- * Reduced default GetFieldAsString() format to %.15g to avoid introducing
- * partially fake digits.
- *
- * Revision 1.34  2006/02/15 20:30:51  fwarmerdam
- * added date support
- *
- * Revision 1.33  2005/09/21 00:50:26  fwarmerdam
- * release OGRFeatureDefn on feature destruction
- *
- * Revision 1.32  2005/08/30 23:52:35  fwarmerdam
- * implement preliminary OFTBinary support
- *
- * Revision 1.31  2005/02/22 12:38:19  fwarmerdam
- * rename Equal/Intersect to Equals/Intersects
- *
- * Revision 1.30  2004/10/12 19:26:33  fwarmerdam
- * fixed up documentation on passing NULL to DumpReadable()
- *
- * Revision 1.29  2003/05/28 19:16:42  warmerda
- * fixed up argument names and stuff for docs
- *
- * Revision 1.28  2003/04/08 20:57:28  warmerda
- * added RemapFields on OGRFeature
- *
- * Revision 1.27  2003/04/03 23:39:11  danmo
- * Small updates to C API docs (Normand S.)
- *
- * Revision 1.26  2003/03/31 15:55:42  danmo
- * Added C API function docs
- *
- * Revision 1.25  2003/01/08 22:03:44  warmerda
- * added StealGeometry() method on OGRFeature
- *
- * Revision 1.24  2002/11/12 19:42:41  warmerda
- * copy style string in SetFrom()
- *
- * Revision 1.23  2002/09/26 18:12:38  warmerda
- * added C support
- *
- * Revision 1.22  2002/04/25 16:06:26  warmerda
- * don't copy style string if not set during clone
- *
- * Revision 1.21  2002/04/24 20:00:30  warmerda
- * fix clone to copy fid as well
- */
+ ****************************************************************************/
 
 #include "ogr_feature.h"
 #include "ogr_api.h"
 #include "ogr_p.h"
 
-CPL_CVSID("$Id: ogrfeature.cpp,v 1.36 2006/04/02 18:25:59 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrfeature.cpp 11087 2007-03-27 03:55:12Z warmerdam $");
 
 /************************************************************************/
 /*                             OGRFeature()                             */
@@ -107,6 +56,7 @@ OGRFeature::OGRFeature( OGRFeatureDefn * poDefnIn )
 {
     m_pszStyleString = NULL;
     m_poStyleTable = NULL;
+    m_pszTmpFieldValue = NULL;
     poDefnIn->Reference();
     poDefn = poDefnIn;
 
@@ -200,6 +150,7 @@ OGRFeature::~OGRFeature()
 
     CPLFree( pauFields );
     CPLFree(m_pszStyleString);
+    CPLFree(m_pszTmpFieldValue);
 }
 
 /************************************************************************/
@@ -320,7 +271,9 @@ OGRFeatureDefnH OGR_F_GetDefnRef( OGRFeatureH hFeat )
  *
  * This method is the same as the C function OGR_F_SetGeometryDirectly().
  *
- * @param poGeomIn new geometry to apply to feature.
+ * @param poGeomIn new geometry to apply to feature. Passing NULL value here
+ * is correct and it will result in deallocation of currently assigned geometry
+ * without assigning new one.
  *
  * @return OGRERR_NONE if successful, or OGR_UNSUPPORTED_GEOMETRY_TYPE if
  * the geometry type is illegal for the OGRFeatureDefn (checking not yet
@@ -330,9 +283,7 @@ OGRFeatureDefnH OGR_F_GetDefnRef( OGRFeatureH hFeat )
 OGRErr OGRFeature::SetGeometryDirectly( OGRGeometry * poGeomIn )
 
 {
-    if( poGeometry != NULL )
-        delete poGeometry;
-
+    delete poGeometry;
     poGeometry = poGeomIn;
 
     // I should be verifying that the geometry matches the defn's type.
@@ -381,7 +332,9 @@ OGRErr OGR_F_SetGeometryDirectly( OGRFeatureH hFeat, OGRGeometryH hGeom )
  *
  * This method is the same as the C function OGR_F_SetGeometry().
  *
- * @param poGeomIn new geometry to apply to feature.
+ * @param poGeomIn new geometry to apply to feature. Passing NULL value here
+ * is correct and it will result in deallocation of currently assigned geometry
+ * without assigning new one.
  *
  * @return OGRERR_NONE if successful, or OGR_UNSUPPORTED_GEOMETRY_TYPE if
  * the geometry type is illegal for the OGRFeatureDefn (checking not yet
@@ -391,8 +344,7 @@ OGRErr OGR_F_SetGeometryDirectly( OGRFeatureH hFeat, OGRGeometryH hGeom )
 OGRErr OGRFeature::SetGeometry( OGRGeometry * poGeomIn )
 
 {
-    if( poGeometry != NULL )
-        delete poGeometry;
+    delete poGeometry;
 
     if( poGeomIn != NULL )
         poGeometry = poGeomIn->clone();
@@ -827,6 +779,19 @@ OGRField *OGR_F_GetRawFieldRef( OGRFeatureH hFeat, int iField )
 int OGRFeature::GetFieldAsInteger( int iField )
 
 {
+    int iSpecialField = iField - poDefn->GetFieldCount();
+    if (iSpecialField >= 0)
+    {
+    // special field value accessors
+        switch (iSpecialField)
+        {
+        case SPF_FID:
+            return GetFID();
+        default:
+            return 0;
+        }
+    }
+    
     OGRFieldDefn        *poFDefn = poDefn->GetFieldDefn( iField );
     
     CPLAssert( poFDefn != NULL || iField == -1 );
@@ -897,6 +862,19 @@ int OGR_F_GetFieldAsInteger( OGRFeatureH hFeat, int iField )
 double OGRFeature::GetFieldAsDouble( int iField )
 
 {
+    int iSpecialField = iField - poDefn->GetFieldCount();
+    if (iSpecialField >= 0)
+    {
+    // special field value accessors
+        switch (iSpecialField)
+        {
+        case SPF_FID:
+            return GetFID();
+        default:
+            return 0.0;
+        }
+    }
+    
     OGRFieldDefn        *poFDefn = poDefn->GetFieldDefn( iField );
     
     CPLAssert( poFDefn != NULL || iField == -1 );
@@ -968,9 +946,52 @@ double OGR_F_GetFieldAsDouble( OGRFeatureH hFeat, int iField )
 const char *OGRFeature::GetFieldAsString( int iField )
 
 {
-    OGRFieldDefn        *poFDefn = poDefn->GetFieldDefn( iField );
-    static char         szTempBuffer[80];
+#define TEMP_BUFFER_SIZE 80
+    char         szTempBuffer[TEMP_BUFFER_SIZE];
 
+    CPLFree(m_pszTmpFieldValue);
+    m_pszTmpFieldValue = NULL;            
+
+    int iSpecialField = iField - poDefn->GetFieldCount();
+    if (iSpecialField >= 0)
+    {
+        // special field value accessors
+        switch (iSpecialField)
+        {
+          case SPF_FID:
+            snprintf( szTempBuffer, TEMP_BUFFER_SIZE, "%ld", GetFID() );
+            return m_pszTmpFieldValue = CPLStrdup( szTempBuffer );
+
+          case SPF_OGR_GEOMETRY:
+            if( poGeometry )
+                return poGeometry->getGeometryName();
+            else
+                return "";
+
+          case SPF_OGR_STYLE:
+            if( GetStyleString() == NULL )
+                return "";
+            else
+                return GetStyleString();
+
+          case SPF_OGR_GEOM_WKT:
+          {
+              if( poGeometry == NULL )
+                  return "";
+
+              if (poGeometry->exportToWkt( &m_pszTmpFieldValue ) == OGRERR_NONE )
+                  return m_pszTmpFieldValue;
+              else
+                  return "";
+          }
+
+          default:
+            return "";
+        }
+    }
+    
+    OGRFieldDefn        *poFDefn = poDefn->GetFieldDefn( iField );
+    
     CPLAssert( poFDefn != NULL || iField == -1 );
     if( poFDefn == NULL )
         return "";
@@ -987,8 +1008,9 @@ const char *OGRFeature::GetFieldAsString( int iField )
     }
     else if( poFDefn->GetType() == OFTInteger )
     {
-        sprintf( szTempBuffer, "%d", pauFields[iField].Integer );
-        return szTempBuffer;
+        snprintf( szTempBuffer, TEMP_BUFFER_SIZE,
+                  "%d", pauFields[iField].Integer );
+        return m_pszTmpFieldValue = CPLStrdup( szTempBuffer );
     }
     else if( poFDefn->GetType() == OFTReal )
     {
@@ -996,25 +1018,27 @@ const char *OGRFeature::GetFieldAsString( int iField )
 
         if( poFDefn->GetWidth() != 0 )
         {
-            sprintf( szFormat, "%%%d.%df",
-                     poFDefn->GetWidth(), poFDefn->GetPrecision() );
+            snprintf( szFormat, TEMP_BUFFER_SIZE, "%%%d.%df",
+                      poFDefn->GetWidth(), poFDefn->GetPrecision() );
         }
         else
             strcpy( szFormat, "%.15g" );
         
-        sprintf( szTempBuffer, szFormat, pauFields[iField].Real );
+        snprintf( szTempBuffer, TEMP_BUFFER_SIZE,
+                  szFormat, pauFields[iField].Real );
         
-        return szTempBuffer;
+        return m_pszTmpFieldValue = CPLStrdup( szTempBuffer );
     }
     else if( poFDefn->GetType() == OFTDateTime )
     {
-        sprintf( szTempBuffer, "%4d/%02d/%02d %2d:%02d:%02d", 
-                 pauFields[iField].Date.Year,
-                 pauFields[iField].Date.Month,
-                 pauFields[iField].Date.Day,
-                 pauFields[iField].Date.Hour,
-                 pauFields[iField].Date.Minute,
-                 pauFields[iField].Date.Second );
+        snprintf( szTempBuffer, TEMP_BUFFER_SIZE,
+                  "%04d/%02d/%02d %2d:%02d:%02d", 
+                  pauFields[iField].Date.Year,
+                  pauFields[iField].Date.Month,
+                  pauFields[iField].Date.Day,
+                  pauFields[iField].Date.Hour,
+                  pauFields[iField].Date.Minute,
+                  pauFields[iField].Date.Second );
         
         if( pauFields[iField].Date.TZFlag > 1 )
         {
@@ -1031,42 +1055,43 @@ const char *OGRFeature::GetFieldAsString( int iField )
                 strcat( szTempBuffer, "+" );
 
             if( nMinutes == 0 )
-                sprintf( szTempBuffer+strlen(szTempBuffer), 
-                         "%02d", nHours );
+                snprintf( szTempBuffer+strlen(szTempBuffer), 
+                          TEMP_BUFFER_SIZE, "%02d", nHours );
             else
-                sprintf( szTempBuffer+strlen(szTempBuffer), 
-                         "%02d%02d", nHours, nMinutes );
+                snprintf( szTempBuffer+strlen(szTempBuffer), 
+                          TEMP_BUFFER_SIZE, "%02d%02d", nHours, nMinutes );
         }
 
-        return szTempBuffer;
+        return m_pszTmpFieldValue = CPLStrdup( szTempBuffer );
     }
     else if( poFDefn->GetType() == OFTDate )
     {
-        sprintf( szTempBuffer, "%4d/%02d/%02d", 
-                 pauFields[iField].Date.Year,
-                 pauFields[iField].Date.Month,
-                 pauFields[iField].Date.Day );
+        snprintf( szTempBuffer, TEMP_BUFFER_SIZE, "%04d/%02d/%02d",
+                  pauFields[iField].Date.Year,
+                  pauFields[iField].Date.Month,
+                  pauFields[iField].Date.Day );
 
-        return szTempBuffer;
+        return m_pszTmpFieldValue = CPLStrdup( szTempBuffer );
     }
     else if( poFDefn->GetType() == OFTTime )
     {
-        sprintf( szTempBuffer, "%2d:%02d:%02d", 
-                 pauFields[iField].Date.Hour,
-                 pauFields[iField].Date.Minute,
-                 pauFields[iField].Date.Second );
+        snprintf( szTempBuffer, TEMP_BUFFER_SIZE, "%2d:%02d:%02d", 
+                  pauFields[iField].Date.Hour,
+                  pauFields[iField].Date.Minute,
+                  pauFields[iField].Date.Second );
         
-        return szTempBuffer;
+        return m_pszTmpFieldValue = CPLStrdup( szTempBuffer );
     }
     else if( poFDefn->GetType() == OFTIntegerList )
     {
         char    szItem[32];
         int     i, nCount = pauFields[iField].IntegerList.nCount;
 
-        sprintf( szTempBuffer, "(%d:", nCount );
+        snprintf( szTempBuffer, TEMP_BUFFER_SIZE, "(%d:", nCount );
         for( i = 0; i < nCount; i++ )
         {
-            sprintf( szItem, "%d", pauFields[iField].IntegerList.paList[i] );
+            snprintf( szItem, TEMP_BUFFER_SIZE, "%d",
+                      pauFields[iField].IntegerList.paList[i] );
             if( strlen(szTempBuffer) + strlen(szItem) + 6
                 > sizeof(szTempBuffer) )
             {
@@ -1084,7 +1109,7 @@ const char *OGRFeature::GetFieldAsString( int iField )
         else
             strcat( szTempBuffer, ")" );
         
-        return szTempBuffer;
+        return m_pszTmpFieldValue = CPLStrdup( szTempBuffer );
     }
     else if( poFDefn->GetType() == OFTRealList )
     {
@@ -1094,16 +1119,17 @@ const char *OGRFeature::GetFieldAsString( int iField )
 
         if( poFDefn->GetWidth() != 0 )
         {
-            sprintf( szFormat, "%%%d.%df",
-                     poFDefn->GetWidth(), poFDefn->GetPrecision() );
+            snprintf( szFormat, TEMP_BUFFER_SIZE, "%%%d.%df",
+                      poFDefn->GetWidth(), poFDefn->GetPrecision() );
         }
         else
             strcpy( szFormat, "%.16g" );
         
-        sprintf( szTempBuffer, "(%d:", nCount );
+        snprintf( szTempBuffer, TEMP_BUFFER_SIZE, "(%d:", nCount );
         for( i = 0; i < nCount; i++ )
         {
-            sprintf( szItem, szFormat, pauFields[iField].RealList.paList[i] );
+            snprintf( szItem, TEMP_BUFFER_SIZE, szFormat,
+                      pauFields[iField].RealList.paList[i] );
             if( strlen(szTempBuffer) + strlen(szItem) + 6
                 > sizeof(szTempBuffer) )
             {
@@ -1121,13 +1147,13 @@ const char *OGRFeature::GetFieldAsString( int iField )
         else
             strcat( szTempBuffer, ")" );
         
-        return szTempBuffer;
+        return m_pszTmpFieldValue = CPLStrdup( szTempBuffer );
     }
     else if( poFDefn->GetType() == OFTStringList )
     {
         int     i, nCount = pauFields[iField].StringList.nCount;
 
-        sprintf( szTempBuffer, "(%d:", nCount );
+        snprintf( szTempBuffer, TEMP_BUFFER_SIZE, "(%d:", nCount );
         for( i = 0; i < nCount; i++ )
         {
             const char  *pszItem = pauFields[iField].StringList.paList[i];
@@ -1149,7 +1175,7 @@ const char *OGRFeature::GetFieldAsString( int iField )
         else
             strcat( szTempBuffer, ")" );
         
-        return szTempBuffer;
+        return m_pszTmpFieldValue = CPLStrdup( szTempBuffer );
     }
     else if( poFDefn->GetType() == OFTBinary )
     {
@@ -1168,10 +1194,11 @@ const char *OGRFeature::GetFieldAsString( int iField )
 
         CPLFree( pszHex );
 
-        return szTempBuffer;
+        return m_pszTmpFieldValue = CPLStrdup( szTempBuffer );
     }
     else
         return "";
+#undef TEMP_BUFFER_SIZE
 }
 
 /************************************************************************/
@@ -1367,7 +1394,7 @@ const double *OGR_F_GetFieldAsDoubleList( OGRFeatureH hFeat, int iField,
  * modified, or freed.  It's lifetime may be very brief.
  */
 
-char **OGRFeature::GetFieldAsStringList( int iField )
+char **OGRFeature::GetFieldAsStringList( int iField ) const
 
 {
     OGRFieldDefn        *poFDefn = poDefn->GetFieldDefn( iField );
@@ -2565,8 +2592,7 @@ OGRErr OGRFeature::SetFrom( OGRFeature * poSrcFeature, int bForgiving )
 /* -------------------------------------------------------------------- */
 /*      Copy feature style string.                                      */
 /* -------------------------------------------------------------------- */
-    if( poSrcFeature->GetStyleString() != NULL )
-        SetStyleString( poSrcFeature->GetStyleString() );
+    SetStyleString( poSrcFeature->GetStyleString() );
 
 /* -------------------------------------------------------------------- */
 /*      Set the fields by name.                                         */
@@ -2673,10 +2699,7 @@ OGRErr OGR_F_SetFrom( OGRFeatureH hFeat, OGRFeatureH hOtherFeat,
 
 const char *OGRFeature::GetStyleString()
 {
-    if (m_pszStyleString)
-      return m_pszStyleString;
-    else
-      return NULL;
+    return m_pszStyleString;
 }
 
 /************************************************************************/
@@ -2706,7 +2729,9 @@ const char *OGR_F_GetStyleString( OGRFeatureH hFeat )
 /************************************************************************/
 
 /**
- * Set feature style string.
+ * Set feature style string. This method operate exactly as
+ * OGRFeature::SetStyleStringDirectly() except that it does not assume
+ * ownership of the passed string, but instead makes a copy of it.
  *
  * This method is the same as the C function OGR_F_SetStyleString().
  *
@@ -2716,10 +2741,13 @@ const char *OGR_F_GetStyleString( OGRFeatureH hFeat )
 void OGRFeature::SetStyleString(const char *pszString)
 {
     if (m_pszStyleString)
-      CPLFree(m_pszStyleString);
-    
-    m_pszStyleString = CPLStrdup(pszString);
+    {
+        CPLFree(m_pszStyleString);
+        m_pszStyleString = NULL;
+    }
     
+    if( pszString )
+        m_pszStyleString = CPLStrdup(pszString);
 }
 
 /************************************************************************/
@@ -2727,7 +2755,9 @@ void OGRFeature::SetStyleString(const char *pszString)
 /************************************************************************/
 
 /**
- * Set feature style string.
+ * Set feature style string. This method operate exactly as
+ * OGR_F_SetStyleStringDirectly() except that it does not assume ownership
+ * of the passed string, but instead makes a copy of it.
  *
  * This function is the same as the C++ method OGRFeature::SetStyleString().
  *
@@ -2742,11 +2772,56 @@ void OGR_F_SetStyleString( OGRFeatureH hFeat, const char *pszStyle )
 }
 
 /************************************************************************/
+/*                       SetStyleStringDirectly()                       */
+/************************************************************************/
+
+/**
+ * Set feature style string. This method operate exactly as
+ * OGRFeature::SetStyleString() except that it assumes ownership of the passed
+ * string.
+ *
+ * This method is the same as the C function OGR_F_SetStyleStringDirectly().
+ *
+ * @param pszString the style string to apply to this feature, cannot be NULL.
+ */
+
+void OGRFeature::SetStyleStringDirectly(char *pszString)
+{
+    if (m_pszStyleString)
+        CPLFree(m_pszStyleString);
+    m_pszStyleString = pszString;
+}
+
+/************************************************************************/
+/*                     OGR_F_SetStyleStringDirectly()                   */
+/************************************************************************/
+
+/**
+ * Set feature style string. This method operate exactly as
+ * OGR_F_SetStyleString() except that it assumes ownership of the passed
+ * string.
+ *
+ * This function is the same as the C++ method
+ * OGRFeature::SetStyleStringDirectly().
+ *
+ * @param hFeat handle to the feature to set style to.
+ * @param pszStyle the style string to apply to this feature, cannot be NULL.
+ */
+
+void OGR_F_SetStyleStringDirectly( OGRFeatureH hFeat, char *pszStyle )
+
+{
+    ((OGRFeature *)hFeat)->SetStyleStringDirectly( pszStyle );
+}
+
+//************************************************************************/
 /*                           SetStyleTable()                            */
 /************************************************************************/
 void OGRFeature::SetStyleTable(OGRStyleTable *poStyleTable)
 {
-    m_poStyleTable = poStyleTable;
+    if ( m_poStyleTable )
+        delete m_poStyleTable;
+    m_poStyleTable = ( poStyleTable ) ? poStyleTable->Clone() : NULL;
 }
 
 /************************************************************************/
