@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrfeaturestyle.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: ogrfeaturestyle.cpp 11399 2007-05-02 20:10:00Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Feature Representation string API
@@ -32,7 +32,7 @@
 #include "ogr_feature.h"
 #include "ogr_featurestyle.h"
 
-CPL_CVSID("$Id: ogrfeaturestyle.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: ogrfeaturestyle.cpp 11399 2007-05-02 20:10:00Z warmerdam $");
 
 CPL_C_START
 void OGRFeatureStylePuller() {}
@@ -848,13 +848,14 @@ GBool OGRStyleTool::GetRGBFromString(const char *pszColor, int &nRed,
                                      int &nGreen ,int & nBlue, 
                                      int &nTransparance)
 {
-   int nCount;
+   int nCount = 0;
    
    nTransparance = 255;
 
    // FIXME: should we really use sscanf here?
-   nCount  = sscanf(pszColor,"#%2x%2x%2x%2x",&nRed,&nGreen,&nBlue, 
-                    &nTransparance);
+   if( pszColor )
+       nCount  = sscanf(pszColor,"#%2x%2x%2x%2x",&nRed,&nGreen,&nBlue, 
+                        &nTransparance);
    
    if (nCount >=3)
      return TRUE;
