@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrgeometry.cpp,v 1.35 2006/03/31 17:57:32 fwarmerdam Exp $
+ * $Id: ogrgeometry.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements a few base methods on OGRGeometry.
@@ -25,119 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrgeometry.cpp,v $
- * Revision 1.35  2006/03/31 17:57:32  fwarmerdam
- * header updates
- *
- * Revision 1.34  2005/10/21 15:58:33  fwarmerdam
- * use c++ casting for GEOSGeom
- *
- * Revision 1.33  2005/10/20 19:55:29  fwarmerdam
- * added GEOS C API support
- *
- * Revision 1.32  2005/09/21 00:50:53  fwarmerdam
- * Release SRS on geometry destruction
- *
- * Revision 1.31  2005/07/20 01:43:51  fwarmerdam
- * upgraded OGR geometry dimension handling
- *
- * Revision 1.30  2005/04/18 15:42:17  fwarmerdam
- * fix geos exception catching
- *
- * Revision 1.29  2005/04/06 20:43:00  fwarmerdam
- * fixed a variety of method signatures for documentation
- *
- * Revision 1.28  2005/02/22 12:39:32  fwarmerdam
- * Rename Equal to Equals, and Intersect to Intersects.
- * Intersects() now always uses GEOS if available.  Also, Intersects()
- * returns TRUE if the other geometry is NULL.
- *
- * Revision 1.27  2004/09/16 18:29:21  fwarmerdam
- * Disable GEOS Insersect().  Is is very expensive for the common case of a
- * bounding rectangle intersection.  We need something better eventually.
- *
- * Revision 1.26  2004/08/20 21:21:28  warmerda
- * added support for managing a persistent geos::GeometryFactory
- *
- * Revision 1.25  2004/07/10 06:57:53  warmerda
- * Added C entry points and docs for GEOS geometry functions
- *
- * Revision 1.24  2004/07/10 04:52:24  warmerda
- * Added lots of GEOS methods.
- * Added closeRings().
- *
- * Revision 1.23  2004/02/21 15:36:14  warmerda
- * const correctness updates for geometry: bug 289
- *
- * Revision 1.22  2004/01/06 19:07:45  warmerda
- * Added braces within case with variable declarations.
- *
- * Revision 1.21  2003/09/04 14:01:44  warmerda
- * added OGRGetGenerate_DB2_V72_BYTE_ORDER
- *
- * Revision 1.20  2003/08/27 15:40:37  warmerda
- * added support for generating DB2 V7.2 compatible WKB
- *
- * Revision 1.19  2003/06/10 14:51:07  warmerda
- * Allow Intersects() test against NULL geometry
- *
- * Revision 1.18  2003/04/03 23:39:11  danmo
- * Small updates to C API docs (Normand S.)
- *
- * Revision 1.17  2003/03/31 15:55:42  danmo
- * Added C API function docs
- *
- * Revision 1.16  2003/03/06 20:59:41  warmerda
- * Added exportToGML() implementation.
- *
- * Revision 1.15  2003/02/08 00:37:15  warmerda
- * try to improve documentation
- *
- * Revision 1.14  2002/10/24 16:46:33  warmerda
- * added docs and C implementation for Equal and FlattenTo2D
- *
- * Revision 1.13  2002/09/26 18:12:38  warmerda
- * added C support
- *
- * Revision 1.12  2002/05/03 14:16:23  warmerda
- * improve 3D geometry names
- *
- * Revision 1.11  2001/11/01 17:20:33  warmerda
- * added DISABLE_OGRGEOM_TRANSFORM macro
- *
- * Revision 1.10  2001/09/21 16:24:20  warmerda
- * added transform() and transformTo() methods
- *
- * Revision 1.9  2001/07/18 05:03:05  warmerda
- * added CPL_CVSID
- *
- * Revision 1.8  2001/02/06 14:14:09  warmerda
- * fixed up documentation
- *
- * Revision 1.7  2000/03/14 21:38:17  warmerda
- * added method to translate geometrytype to name
- *
- * Revision 1.6  1999/11/18 19:02:19  warmerda
- * expanded tabs
- *
- * Revision 1.5  1999/07/06 21:36:47  warmerda
- * tenatively added getEnvelope() and Intersect()
- *
- * Revision 1.4  1999/06/25 20:44:43  warmerda
- * implemented assignSpatialReference, carry properly
- *
- * Revision 1.3  1999/05/31 20:42:28  warmerda
- * added empty method
- *
- * Revision 1.2  1999/05/31 11:05:08  warmerda
- * added some documentation
- *
- * Revision 1.1  1999/05/20 14:35:00  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_geometry.h"
 #include "ogr_api.h"
@@ -145,16 +33,30 @@
 #include "ogr_geos.h"
 #include <assert.h>
 
-#if defined(HAVE_GEOS) && !defined(GEOS_C_API)
-#  include "geos/opDistance.h"
-#  include "geos/opBuffer.h"
-#  include "geos/geosAlgorithm.h"
-#endif
-
-CPL_CVSID("$Id: ogrgeometry.cpp,v 1.35 2006/03/31 17:57:32 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrgeometry.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 int OGRGeometry::bGenerate_DB2_V72_BYTE_ORDER = FALSE;
 
+#ifdef HAVE_GEOS
+static void _GEOSErrorHandler(const char *fmt, ...)
+{
+    va_list args;
+
+    va_start(args, fmt);
+    CPLErrorV( CE_Failure, CPLE_AppDefined, fmt, args );
+    va_end(args);
+}
+
+static void _GEOSWarningHandler(const char *fmt, ...)
+{
+    va_list args;
+
+    va_start(args, fmt);
+    CPLErrorV( CE_Warning, CPLE_AppDefined, fmt, args );
+    va_end(args);
+}
+#endif
+
 /************************************************************************/
 /*                            OGRGeometry()                             */
 /************************************************************************/
@@ -191,7 +93,7 @@ OGRGeometry::~OGRGeometry()
  * @param pszPrefix the prefix to put on each line of output.
  */
 
-void OGRGeometry::dumpReadable( FILE * fp, const char * pszPrefix )
+void OGRGeometry::dumpReadable( FILE * fp, const char * pszPrefix ) const
 
 {
     char        *pszWkt = NULL;
@@ -327,11 +229,15 @@ OGRBoolean OGRGeometry::Intersects( OGRGeometry *poOtherGeom ) const
         return FALSE;
 
 #ifndef HAVE_GEOS
+
     // Without GEOS we assume that envelope overlap is equivelent to
     // actual intersection.
     return TRUE;
-#elif GEOS_C_API
-    GEOSGeom hThisGeosGeom, hOtherGeosGeom;
+
+#else
+
+    GEOSGeom hThisGeosGeom = NULL;
+    GEOSGeom hOtherGeosGeom = NULL;
 
     hThisGeosGeom = exportToGEOS();
     hOtherGeosGeom = poOtherGeom->exportToGEOS();
@@ -354,31 +260,6 @@ OGRBoolean OGRGeometry::Intersects( OGRGeometry *poOtherGeom ) const
     {
         return TRUE;
     }
-#else // C++ API
-    
-    geos::Geometry *poThisGeosGeom, *poOtherGeosGeom;
-
-    poThisGeosGeom = (geos::Geometry *) exportToGEOS();
-    poOtherGeosGeom = (geos::Geometry *) poOtherGeom->exportToGEOS();
-
-    if( poThisGeosGeom != NULL && poOtherGeosGeom != NULL )
-    {
-        OGRBoolean bResult;
-        
-        if( poThisGeosGeom->intersects( poOtherGeosGeom ) )
-            bResult = TRUE;
-        else
-            bResult = FALSE;
-        
-        delete poThisGeosGeom;
-        delete poOtherGeosGeom;
-
-        return bResult;
-    }
-    else
-    {
-        return TRUE;
-    }
 #endif /* HAVE_GEOS */
 }
 
@@ -1359,13 +1240,14 @@ GEOSGeom OGRGeometry::exportToGEOS() const
               "GEOS support not enabled." );
     return NULL;
 
-#elif GEOS_C_API
+#else
+
     static int bGEOSInitialized = FALSE;
 
     if( !bGEOSInitialized )
     {
         bGEOSInitialized = TRUE;
-        initGEOS( NULL, NULL );
+        initGEOS( _GEOSWarningHandler, _GEOSErrorHandler );
     }
 
     GEOSGeom hGeom = NULL;
@@ -1380,33 +1262,6 @@ GEOSGeom OGRGeometry::exportToGEOS() const
     CPLFree( pabyData );
 
     return hGeom;
-#else
-
-    char *pszWKT = NULL;
-    geos::WKTReader   geosWktReader( (geos::GeometryFactory *) 
-        OGRGeometryFactory::getGEOSGeometryFactory() );
-
-    if( exportToWkt( &pszWKT ) != OGRERR_NONE )
-        return NULL;
-
-    string oWKT = pszWKT;
-    CPLFree( pszWKT );
-
-    try 
-    { 
-        geos::Geometry *geosGeometry = NULL;
-        geosGeometry = geosWktReader.read( oWKT );
-        return (GEOSGeom) geosGeometry;
-    }
-    catch( geos::GEOSException *e )
-    {
-        CPLError( CE_Failure, CPLE_AppDefined,
-                  "GEOSException: %s", 
-                  e->toString().c_str() );
-
-        delete e;
-        return NULL;
-    }
 
 #endif /* HAVE_GEOS */
 }
@@ -1436,40 +1291,45 @@ GEOSGeom OGRGeometry::exportToGEOS() const
 double OGRGeometry::Distance( const OGRGeometry *poOtherGeom ) const
 
 {
+    if( NULL == poOtherGeom )
+    {
+        CPLDebug( "OGR", "OGRGeometry::Distance called with NULL geometry pointer" );
+        return -1.0;
+    }
+
 #ifndef HAVE_GEOS
 
     CPLError( CE_Failure, CPLE_NotSupported, 
               "GEOS support not enabled." );
     return -1.0;
 
-#elif GEOS_C_API 
-
-    CPLError( CE_Failure, CPLE_NotSupported, 
-              "GEOS C API does not include DistanceOp." );
-    return -1.0;
-
 #else
-    geos::Geometry *poThis, *poOther;
 
-    poThis = (geos::Geometry *) exportToGEOS();
-    poOther = (geos::Geometry *) poOtherGeom->exportToGEOS();
+    // GEOSGeom is a pointer
+    GEOSGeom hThis = NULL;
+    GEOSGeom hOther = NULL;
 
-    if( poThis != NULL && poOther != NULL )
+    hOther = poOtherGeom->exportToGEOS();
+    hThis = exportToGEOS();
+   
+    int bIsErr = 0;
+    double dfDistance = 0.0;
+
+    if( hThis != NULL && hOther != NULL )
     {
-        geos::DistanceOp oDistOp( poThis, poOther );
-        double dfDistance;
+        bIsErr = GEOSDistance( hThis, hOther, &dfDistance );
+    }
 
-        dfDistance = oDistOp.distance();
-        
-        delete poThis;
-        delete poOther;
+    GEOSGeom_destroy( hThis );
+    GEOSGeom_destroy( hOther );
 
+    if ( bIsErr > 0 ) 
+    {
         return dfDistance;
     }
-    else
-    {
-        return -1.0;
-    }
+
+    /* Calculations error */
+    return -1.0;
 
 #endif /* HAVE_GEOS */
 }
@@ -1513,8 +1373,10 @@ OGRGeometry *OGRGeometry::ConvexHull() const
               "GEOS support not enabled." );
     return NULL;
 
-#elif GEOS_C_API
-    GEOSGeom hGeosGeom, hGeosHull = NULL;
+#else
+
+    GEOSGeom hGeosGeom = NULL;
+    GEOSGeom hGeosHull = NULL;
     OGRGeometry *poHullOGRGeom = NULL;
 
     hGeosGeom = exportToGEOS();
@@ -1532,31 +1394,6 @@ OGRGeometry *OGRGeometry::ConvexHull() const
 
     return poHullOGRGeom;
 
-#else
-    geos::Geometry *poGeosGeom;
-    OGRGeometry *poHullOGRGeom = NULL;
-
-    poGeosGeom = (geos::Geometry *) exportToGEOS();
-
-    if( poGeosGeom != NULL )
-    {
-        geos::ConvexHull oCHull( poGeosGeom );
-        geos::Geometry *poHullGeosGeom;
-
-        poHullGeosGeom = oCHull.getConvexHull();
-
-        if( poHullGeosGeom != NULL )
-        {
-            poHullOGRGeom = 
-                OGRGeometryFactory::createFromGEOS((GEOSGeom)poHullGeosGeom);
-            delete poHullGeosGeom;
-        }
-
-        delete poGeosGeom;
-    }
-
-    return poHullOGRGeom;
-
 #endif /* HAVE_GEOS */
 }
 
@@ -1599,8 +1436,10 @@ OGRGeometry *OGRGeometry::getBoundary() const
               "GEOS support not enabled." );
     return NULL;
 
-#elif GEOS_C_API
-    GEOSGeom hGeosGeom, hGeosProduct = NULL;
+#else
+    
+    GEOSGeom hGeosGeom = NULL;
+    GEOSGeom hGeosProduct = NULL;
     OGRGeometry *poOGRProduct = NULL;
 
     hGeosGeom = exportToGEOS();
@@ -1618,29 +1457,6 @@ OGRGeometry *OGRGeometry::getBoundary() const
 
     return poOGRProduct;
 
-#else
-    geos::Geometry *poSrcGeosGeom;
-    OGRGeometry *poResultOGRGeom = NULL;
-
-    poSrcGeosGeom = (geos::Geometry *) exportToGEOS();
-
-    if( poSrcGeosGeom != NULL )
-    {
-        geos::Geometry *poResultGeosGeom = 
-            poSrcGeosGeom->getBoundary();
-
-        if( poResultGeosGeom != NULL )
-        {
-            poResultOGRGeom = 
-                OGRGeometryFactory::createFromGEOS((GEOSGeom)poResultGeosGeom);
-            delete poResultGeosGeom;
-        }
-
-        delete poSrcGeosGeom;
-    }
-
-    return poResultOGRGeom;
-
 #endif /* HAVE_GEOS */
 }
 
@@ -1697,8 +1513,10 @@ OGRGeometry *OGRGeometry::Buffer( double dfDist, int nQuadSegs ) const
               "GEOS support not enabled." );
     return NULL;
 
-#elif GEOS_C_API
-    GEOSGeom hGeosGeom, hGeosProduct = NULL;
+#else
+
+    GEOSGeom hGeosGeom = NULL;
+    GEOSGeom hGeosProduct = NULL;
     OGRGeometry *poOGRProduct = NULL;
 
     hGeosGeom = exportToGEOS();
@@ -1716,31 +1534,6 @@ OGRGeometry *OGRGeometry::Buffer( double dfDist, int nQuadSegs ) const
 
     return poOGRProduct;
 
-#else
-    geos::Geometry *poGeosGeom;
-    OGRGeometry *poBufferOGRGeom = NULL;
-
-    poGeosGeom = (geos::Geometry *) exportToGEOS();
-
-    if( poGeosGeom != NULL )
-    {
-        geos::BufferOp oBuffer( poGeosGeom );
-        geos::Geometry *poBufferGeosGeom;
-
-        poBufferGeosGeom = oBuffer.getResultGeometry( dfDist, nQuadSegs );
-
-        if( poBufferGeosGeom != NULL )
-        {
-            poBufferOGRGeom = 
-                OGRGeometryFactory::createFromGEOS((GEOSGeom)poBufferGeosGeom);
-            delete poBufferGeosGeom;
-        }
-
-        delete poGeosGeom;
-    }
-
-    return poBufferOGRGeom;
-
 #endif /* HAVE_GEOS */
 }
 
@@ -1787,8 +1580,11 @@ OGRGeometry *OGRGeometry::Intersection( const OGRGeometry *poOtherGeom ) const
               "GEOS support not enabled." );
     return NULL;
 
-#elif GEOS_C_API
-    GEOSGeom hThisGeosGeom, hOtherGeosGeom, hGeosProduct = NULL;
+#else
+
+    GEOSGeom hThisGeosGeom = NULL;
+    GEOSGeom hOtherGeosGeom = NULL;
+    GEOSGeom hGeosProduct = NULL;
     OGRGeometry *poOGRProduct = NULL;
 
     hThisGeosGeom = exportToGEOS();
@@ -1808,31 +1604,6 @@ OGRGeometry *OGRGeometry::Intersection( const OGRGeometry *poOtherGeom ) const
 
     return poOGRProduct;
 
-#else
-    geos::Geometry *poThisGeosGeom, *poOtherGeosGeom;
-
-    poThisGeosGeom = (geos::Geometry *) exportToGEOS();
-    poOtherGeosGeom = (geos::Geometry *) poOtherGeom->exportToGEOS();
-
-    if( poThisGeosGeom != NULL && poOtherGeosGeom != NULL )
-    {
-        geos::Geometry *poResultGeosGeom = 
-            poThisGeosGeom->intersection( poOtherGeosGeom );
-        
-        delete poThisGeosGeom;
-        delete poOtherGeosGeom;
-
-        OGRGeometry *poResultOGRGeom = 
-            OGRGeometryFactory::createFromGEOS( (GEOSGeom)poResultGeosGeom );
-        delete poResultGeosGeom;
-
-        return poResultOGRGeom;
-    }
-    else
-    {
-        return NULL;
-    }
-
 #endif /* HAVE_GEOS */
 }
 
@@ -1878,8 +1649,11 @@ OGRGeometry *OGRGeometry::Union( const OGRGeometry *poOtherGeom ) const
               "GEOS support not enabled." );
     return NULL;
 
-#elif GEOS_C_API
-    GEOSGeom hThisGeosGeom, hOtherGeosGeom, hGeosProduct = NULL;
+#else
+
+    GEOSGeom hThisGeosGeom = NULL;
+    GEOSGeom hOtherGeosGeom = NULL;
+    GEOSGeom hGeosProduct = NULL;
     OGRGeometry *poOGRProduct = NULL;
 
     hThisGeosGeom = exportToGEOS();
@@ -1899,31 +1673,6 @@ OGRGeometry *OGRGeometry::Union( const OGRGeometry *poOtherGeom ) const
 
     return poOGRProduct;
 
-#else
-    geos::Geometry *poThisGeosGeom, *poOtherGeosGeom;
-
-    poThisGeosGeom = (geos::Geometry *) exportToGEOS();
-    poOtherGeosGeom = (geos::Geometry *) poOtherGeom->exportToGEOS();
-
-    if( poThisGeosGeom != NULL && poOtherGeosGeom != NULL )
-    {
-        geos::Geometry *poResultGeosGeom = 
-            poThisGeosGeom->Union( poOtherGeosGeom );
-        
-        delete poThisGeosGeom;
-        delete poOtherGeosGeom;
-
-        OGRGeometry *poResultOGRGeom = 
-            OGRGeometryFactory::createFromGEOS( (GEOSGeom) poResultGeosGeom );
-        delete poResultGeosGeom;
-
-        return poResultOGRGeom;
-    }
-    else
-    {
-        return NULL;
-    }
-
 #endif /* HAVE_GEOS */
 }
 
@@ -1970,8 +1719,11 @@ OGRGeometry *OGRGeometry::Difference( const OGRGeometry *poOtherGeom ) const
               "GEOS support not enabled." );
     return NULL;
 
-#elif GEOS_C_API
-    GEOSGeom hThisGeosGeom, hOtherGeosGeom, hGeosProduct = NULL;
+#else
+    
+    GEOSGeom hThisGeosGeom = NULL;
+    GEOSGeom hOtherGeosGeom = NULL;
+    GEOSGeom hGeosProduct = NULL;
     OGRGeometry *poOGRProduct = NULL;
 
     hThisGeosGeom = exportToGEOS();
@@ -1991,31 +1743,6 @@ OGRGeometry *OGRGeometry::Difference( const OGRGeometry *poOtherGeom ) const
 
     return poOGRProduct;
 
-#else
-    geos::Geometry *poThisGeosGeom, *poOtherGeosGeom;
-
-    poThisGeosGeom = (geos::Geometry *) exportToGEOS();
-    poOtherGeosGeom = (geos::Geometry *) poOtherGeom->exportToGEOS();
-
-    if( poThisGeosGeom != NULL && poOtherGeosGeom != NULL )
-    {
-        geos::Geometry *poResultGeosGeom = 
-            poThisGeosGeom->difference( poOtherGeosGeom );
-        
-        delete poThisGeosGeom;
-        delete poOtherGeosGeom;
-
-        OGRGeometry *poResultOGRGeom = 
-            OGRGeometryFactory::createFromGEOS( (GEOSGeom)poResultGeosGeom );
-        delete poResultGeosGeom;
-
-        return poResultOGRGeom;
-    }
-    else
-    {
-        return NULL;
-    }
-
 #endif /* HAVE_GEOS */
 }
 
@@ -2063,8 +1790,11 @@ OGRGeometry::SymmetricDifference( const OGRGeometry *poOtherGeom ) const
               "GEOS support not enabled." );
     return NULL;
 
-#elif GEOS_C_API
-    GEOSGeom hThisGeosGeom, hOtherGeosGeom, hGeosProduct = NULL;
+#else
+
+    GEOSGeom hThisGeosGeom = NULL;
+    GEOSGeom hOtherGeosGeom = NULL;
+    GEOSGeom hGeosProduct = NULL;
     OGRGeometry *poOGRProduct = NULL;
 
     hThisGeosGeom = exportToGEOS();
@@ -2084,31 +1814,6 @@ OGRGeometry::SymmetricDifference( const OGRGeometry *poOtherGeom ) const
 
     return poOGRProduct;
 
-#else
-    geos::Geometry *poThisGeosGeom, *poOtherGeosGeom;
-
-    poThisGeosGeom = (geos::Geometry *) exportToGEOS();
-    poOtherGeosGeom = (geos::Geometry *) poOtherGeom->exportToGEOS();
-
-    if( poThisGeosGeom != NULL && poOtherGeosGeom != NULL )
-    {
-        geos::Geometry *poResultGeosGeom = 
-            poThisGeosGeom->symDifference( poOtherGeosGeom );
-        
-        delete poThisGeosGeom;
-        delete poOtherGeosGeom;
-
-        OGRGeometry *poResultOGRGeom = 
-            OGRGeometryFactory::createFromGEOS( (GEOSGeom)poResultGeosGeom );
-        delete poResultGeosGeom;
-
-        return poResultOGRGeom;
-    }
-    else
-    {
-        return NULL;
-    }
-
 #endif /* HAVE_GEOS */
 }
 
@@ -2154,8 +1859,10 @@ OGRGeometry::Disjoint( const OGRGeometry *poOtherGeom ) const
               "GEOS support not enabled." );
     return FALSE;
 
-#elif GEOS_C_API
-    GEOSGeom hThisGeosGeom, hOtherGeosGeom;
+#else
+
+    GEOSGeom hThisGeosGeom = NULL;
+    GEOSGeom hOtherGeosGeom = NULL;
     OGRBoolean bResult = FALSE;
 
     hThisGeosGeom = exportToGEOS();
@@ -2169,31 +1876,6 @@ OGRGeometry::Disjoint( const OGRGeometry *poOtherGeom ) const
 
     return bResult;
 
-#else
-    geos::Geometry *poThisGeosGeom, *poOtherGeosGeom;
-
-    poThisGeosGeom = (geos::Geometry *) exportToGEOS();
-    poOtherGeosGeom = (geos::Geometry *) poOtherGeom->exportToGEOS();
-
-    if( poThisGeosGeom != NULL && poOtherGeosGeom != NULL )
-    {
-        OGRBoolean bResult;
-        
-        if( poThisGeosGeom->disjoint( poOtherGeosGeom ) )
-            bResult = TRUE;
-        else
-            bResult = FALSE;
-        
-        delete poThisGeosGeom;
-        delete poOtherGeosGeom;
-
-        return bResult;
-    }
-    else
-    {
-        return FALSE;
-    }
-
 #endif /* HAVE_GEOS */
 }
 
@@ -2238,12 +1920,15 @@ OGRGeometry::Touches( const OGRGeometry *poOtherGeom ) const
               "GEOS support not enabled." );
     return FALSE;
 
-#elif GEOS_C_API
-    GEOSGeom hThisGeosGeom, hOtherGeosGeom;
+#else
+
+    GEOSGeom hThisGeosGeom = NULL;
+    GEOSGeom hOtherGeosGeom = NULL;
     OGRBoolean bResult = FALSE;
 
     hThisGeosGeom = exportToGEOS();
     hOtherGeosGeom = poOtherGeom->exportToGEOS();
+
     if( hThisGeosGeom != NULL && hOtherGeosGeom != NULL )
     {
         bResult = GEOSTouches( hThisGeosGeom, hOtherGeosGeom );
@@ -2253,31 +1938,6 @@ OGRGeometry::Touches( const OGRGeometry *poOtherGeom ) const
 
     return bResult;
 
-#else
-    geos::Geometry *poThisGeosGeom, *poOtherGeosGeom;
-
-    poThisGeosGeom = (geos::Geometry *) exportToGEOS();
-    poOtherGeosGeom = (geos::Geometry *) poOtherGeom->exportToGEOS();
-
-    if( poThisGeosGeom != NULL && poOtherGeosGeom != NULL )
-    {
-        OGRBoolean bResult;
-        
-        if( poThisGeosGeom->touches( poOtherGeosGeom ) )
-            bResult = TRUE;
-        else
-            bResult = FALSE;
-        
-        delete poThisGeosGeom;
-        delete poOtherGeosGeom;
-
-        return bResult;
-    }
-    else
-    {
-        return FALSE;
-    }
-
 #endif /* HAVE_GEOS */
 }
 
@@ -2322,12 +1982,15 @@ OGRGeometry::Crosses( const OGRGeometry *poOtherGeom ) const
               "GEOS support not enabled." );
     return FALSE;
 
-#elif GEOS_C_API
-    GEOSGeom hThisGeosGeom, hOtherGeosGeom;
+#else
+
+    GEOSGeom hThisGeosGeom = NULL;
+    GEOSGeom hOtherGeosGeom = NULL;
     OGRBoolean bResult = FALSE;
 
     hThisGeosGeom = exportToGEOS();
     hOtherGeosGeom = poOtherGeom->exportToGEOS();
+
     if( hThisGeosGeom != NULL && hOtherGeosGeom != NULL )
     {
         bResult = GEOSCrosses( hThisGeosGeom, hOtherGeosGeom );
@@ -2337,31 +2000,6 @@ OGRGeometry::Crosses( const OGRGeometry *poOtherGeom ) const
 
     return bResult;
 
-#else
-    geos::Geometry *poThisGeosGeom, *poOtherGeosGeom;
-
-    poThisGeosGeom = (geos::Geometry *) exportToGEOS();
-    poOtherGeosGeom = (geos::Geometry *) poOtherGeom->exportToGEOS();
-
-    if( poThisGeosGeom != NULL && poOtherGeosGeom != NULL )
-    {
-        OGRBoolean bResult;
-        
-        if( poThisGeosGeom->crosses( poOtherGeosGeom ) )
-            bResult = TRUE;
-        else
-            bResult = FALSE;
-        
-        delete poThisGeosGeom;
-        delete poOtherGeosGeom;
-
-        return bResult;
-    }
-    else
-    {
-        return FALSE;
-    }
-
 #endif /* HAVE_GEOS */
 }
 
@@ -2406,8 +2044,10 @@ OGRGeometry::Within( const OGRGeometry *poOtherGeom ) const
               "GEOS support not enabled." );
     return FALSE;
 
-#elif GEOS_C_API
-    GEOSGeom hThisGeosGeom, hOtherGeosGeom;
+#else
+
+    GEOSGeom hThisGeosGeom = NULL;
+    GEOSGeom hOtherGeosGeom = NULL;
     OGRBoolean bResult = FALSE;
 
     hThisGeosGeom = exportToGEOS();
@@ -2421,31 +2061,6 @@ OGRGeometry::Within( const OGRGeometry *poOtherGeom ) const
 
     return bResult;
 
-#else
-    geos::Geometry *poThisGeosGeom, *poOtherGeosGeom;
-
-    poThisGeosGeom = (geos::Geometry *) exportToGEOS();
-    poOtherGeosGeom = (geos::Geometry *) poOtherGeom->exportToGEOS();
-
-    if( poThisGeosGeom != NULL && poOtherGeosGeom != NULL )
-    {
-        OGRBoolean bResult;
-        
-        if( poThisGeosGeom->within( poOtherGeosGeom ) )
-            bResult = TRUE;
-        else
-            bResult = FALSE;
-        
-        delete poThisGeosGeom;
-        delete poOtherGeosGeom;
-
-        return bResult;
-    }
-    else
-    {
-        return FALSE;
-    }
-
 #endif /* HAVE_GEOS */
 }
 
@@ -2490,8 +2105,10 @@ OGRGeometry::Contains( const OGRGeometry *poOtherGeom ) const
               "GEOS support not enabled." );
     return FALSE;
 
-#elif GEOS_C_API
-    GEOSGeom hThisGeosGeom, hOtherGeosGeom;
+#else
+
+    GEOSGeom hThisGeosGeom = NULL;
+    GEOSGeom hOtherGeosGeom = NULL;
     OGRBoolean bResult = FALSE;
 
     hThisGeosGeom = exportToGEOS();
@@ -2505,31 +2122,6 @@ OGRGeometry::Contains( const OGRGeometry *poOtherGeom ) const
 
     return bResult;
 
-#else
-    geos::Geometry *poThisGeosGeom, *poOtherGeosGeom;
-
-    poThisGeosGeom = (geos::Geometry *) exportToGEOS();
-    poOtherGeosGeom = (geos::Geometry *) poOtherGeom->exportToGEOS();
-
-    if( poThisGeosGeom != NULL && poOtherGeosGeom != NULL )
-    {
-        OGRBoolean bResult;
-        
-        if( poThisGeosGeom->contains( poOtherGeosGeom ) )
-            bResult = TRUE;
-        else
-            bResult = FALSE;
-        
-        delete poThisGeosGeom;
-        delete poOtherGeosGeom;
-
-        return bResult;
-    }
-    else
-    {
-        return FALSE;
-    }
-
 #endif /* HAVE_GEOS */
 }
 
@@ -2575,8 +2167,10 @@ OGRGeometry::Overlaps( const OGRGeometry *poOtherGeom ) const
               "GEOS support not enabled." );
     return FALSE;
 
-#elif GEOS_C_API
-    GEOSGeom hThisGeosGeom, hOtherGeosGeom;
+#else
+
+    GEOSGeom hThisGeosGeom = NULL;
+    GEOSGeom hOtherGeosGeom = NULL;
     OGRBoolean bResult = FALSE;
 
     hThisGeosGeom = exportToGEOS();
@@ -2590,31 +2184,6 @@ OGRGeometry::Overlaps( const OGRGeometry *poOtherGeom ) const
 
     return bResult;
 
-#else
-    geos::Geometry *poThisGeosGeom, *poOtherGeosGeom;
-
-    poThisGeosGeom = (geos::Geometry *) exportToGEOS();
-    poOtherGeosGeom = (geos::Geometry *) poOtherGeom->exportToGEOS();
-
-    if( poThisGeosGeom != NULL && poOtherGeosGeom != NULL )
-    {
-        OGRBoolean bResult;
-        
-        if( poThisGeosGeom->overlaps( poOtherGeosGeom ) )
-            bResult = TRUE;
-        else
-            bResult = FALSE;
-        
-        delete poThisGeosGeom;
-        delete poOtherGeosGeom;
-
-        return bResult;
-    }
-    else
-    {
-        return FALSE;
-    }
-
 #endif /* HAVE_GEOS */
 }
 
