@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrgeometrycollection.cpp,v 1.32 2006/03/31 17:44:20 fwarmerdam Exp $
+ * $Id: ogrgeometrycollection.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  The OGRGeometryCollection class.
@@ -25,111 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrgeometrycollection.cpp,v $
- * Revision 1.32  2006/03/31 17:44:20  fwarmerdam
- * header updates
- *
- * Revision 1.31  2005/07/20 01:43:51  fwarmerdam
- * upgraded OGR geometry dimension handling
- *
- * Revision 1.30  2005/07/12 17:34:00  fwarmerdam
- * updated to produce proper empty syntax and consume either
- *
- * Revision 1.29  2005/02/22 12:38:01  fwarmerdam
- * rename Equal/Intersect to Equals/Intersects
- *
- * Revision 1.28  2004/07/10 04:51:22  warmerda
- * added closeRings
- *
- * Revision 1.27  2004/02/22 09:52:04  dron
- * Fix compirison casting problems in OGRGeometryCollection::Equal().
- *
- * Revision 1.26  2004/02/21 15:36:14  warmerda
- * const correctness updates for geometry: bug 289
- *
- * Revision 1.25  2004/01/16 21:57:16  warmerda
- * fixed up EMPTY support
- *
- * Revision 1.24  2004/01/16 21:20:00  warmerda
- * Added EMPTY support
- *
- * Revision 1.23  2003/08/27 15:40:37  warmerda
- * added support for generating DB2 V7.2 compatible WKB
- *
- * Revision 1.22  2003/06/09 13:48:54  warmerda
- * added DB2 V7.2 byte order hack
- *
- * Revision 1.21  2003/05/28 19:16:42  warmerda
- * fixed up argument names and stuff for docs
- *
- * Revision 1.20  2003/03/31 15:55:42  danmo
- * Added C API function docs
- *
- * Revision 1.19  2003/03/07 21:32:52  warmerda
- * fixed bug with coordinate dimension reading from WKB
- *
- * Revision 1.18  2003/01/07 16:44:27  warmerda
- * added removeGeometry
- *
- * Revision 1.17  2002/09/11 13:47:17  warmerda
- * preliminary set of fixes for 3D WKB enum
- *
- * Revision 1.16  2002/05/02 19:45:36  warmerda
- * added flattenTo2D() method
- *
- * Revision 1.15  2002/03/05 14:25:14  warmerda
- * expand tabs
- *
- * Revision 1.14  2001/11/01 17:20:33  warmerda
- * added DISABLE_OGRGEOM_TRANSFORM macro
- *
- * Revision 1.13  2001/09/21 16:24:20  warmerda
- * added transform() and transformTo() methods
- *
- * Revision 1.12  2001/08/30 02:06:19  warmerda
- * fixed array overrun error in exportToWkt()
- *
- * Revision 1.11  2001/07/18 05:03:05  warmerda
- * added CPL_CVSID
- *
- * Revision 1.10  2001/05/24 18:06:30  warmerda
- * use addGeometryDirectly when parsing WKT
- *
- * Revision 1.9  1999/11/18 19:02:19  warmerda
- * expanded tabs
- *
- * Revision 1.8  1999/11/04 16:26:29  warmerda
- * Implemented addGeometryDirectly().
- *
- * Revision 1.7  1999/09/01 11:50:40  warmerda
- * Fixed CPLAssert on legal geometry types.
- *
- * Revision 1.6  1999/07/27 00:48:11  warmerda
- * Added Equal() support
- *
- * Revision 1.5  1999/07/06 21:36:47  warmerda
- * tenatively added getEnvelope() and Intersect()
- *
- * Revision 1.4  1999/06/25 20:44:43  warmerda
- * implemented assignSpatialReference, carry properly
- *
- * Revision 1.3  1999/05/31 20:43:04  warmerda
- * added empty method, implement createFromWkt(), added mline/mpoint
- *
- * Revision 1.2  1999/05/31 14:59:06  warmerda
- * added documentation
- *
- * Revision 1.1  1999/05/23 05:34:36  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_geometry.h"
 #include "ogr_p.h"
 
-CPL_CVSID("$Id: ogrgeometrycollection.cpp,v 1.32 2006/03/31 17:44:20 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrgeometrycollection.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                       OGRGeometryCollection()                        */
