@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrinfo.cpp,v 1.32 2006/03/31 17:44:20 fwarmerdam Exp $
+ * $Id: ogrinfo.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Simple client for viewing OGR driver data.
@@ -25,106 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrinfo.cpp,v $
- * Revision 1.32  2006/03/31 17:44:20  fwarmerdam
- * header updates
- *
- * Revision 1.31  2006/03/02 15:42:52  fwarmerdam
- * Accept -so or -summary.
- *
- * Revision 1.30  2006/02/02 01:19:34  fwarmerdam
- * Use EQUAL, not EQUALN for -so and -al as per bug 1052.
- *
- * Revision 1.29  2006/01/27 00:08:36  fwarmerdam
- * added Get{FID,Geometry}Column() support
- *
- * Revision 1.28  2005/11/25 02:16:53  fwarmerdam
- * Added --help-general.
- *
- * Revision 1.27  2005/11/19 00:41:31  fwarmerdam
- * added general commandline processor
- *
- * Revision 1.26  2005/10/20 19:54:18  fwarmerdam
- * added better cleanup logic
- *
- * Revision 1.25  2005/09/05 19:30:06  fwarmerdam
- * fix usage message
- *
- * Revision 1.24  2004/10/12 19:27:17  fwarmerdam
- * avoid passing local stdout into GDAL library
- *
- * Revision 1.23  2004/07/10 04:45:20  warmerda
- * added dialect option
- *
- * Revision 1.22  2004/02/19 17:17:42  warmerda
- * clean finder for easier memory leak testing
- *
- * Revision 1.21  2003/11/19 20:41:17  warmerda
- * avoid memory leak
- *
- * Revision 1.20  2003/03/19 20:28:30  warmerda
- * destroy registrar on exit to help find memory leaks
- *
- * Revision 1.19  2003/03/05 15:36:22  warmerda
- * Added -summary to Usage().
- *
- * Revision 1.18  2003/02/25 14:56:25  warmerda
- * Added the -so (summary only) switch.
- *
- * Revision 1.17  2002/11/17 17:41:39  warmerda
- * added --formats option
- *
- * Revision 1.16  2002/08/08 13:02:01  warmerda
- * added the -al commandline switch
- *
- * Revision 1.15  2002/04/25 03:40:41  warmerda
- * fixed to pass spatial query
- *
- * Revision 1.14  2002/04/24 20:00:43  warmerda
- * added the -sql command line switch
- *
- * Revision 1.13  2002/03/27 22:50:16  warmerda
- * improve quiet support, and make WKT output be pretty
- *
- * Revision 1.12  2001/11/19 21:59:33  warmerda
- * added repeat count for memory leak testing
- *
- * Revision 1.11  2001/07/18 05:03:05  warmerda
- * added CPL_CVSID
- *
- * Revision 1.10  2001/07/17 15:00:21  danmo
- * Report layer extent in ReportOnLayer().
- *
- * Revision 1.9  2001/06/26 20:58:45  warmerda
- * added spatial query option
- *
- * Revision 1.8  2001/06/19 15:48:36  warmerda
- * added feature attribute query support
- *
- * Revision 1.7  2000/03/14 21:37:49  warmerda
- * report layer geometry type
- *
- * Revision 1.6  1999/11/18 19:02:19  warmerda
- * expanded tabs
- *
- * Revision 1.5  1999/11/04 21:07:22  warmerda
- * Changed to OGRRegisterAll().
- *
- * Revision 1.4  1999/09/29 16:36:41  warmerda
- * added srs reporting
- *
- * Revision 1.3  1999/09/22 13:31:48  warmerda
- * added sdts
- *
- * Revision 1.2  1999/09/13 14:34:20  warmerda
- * added feature reporting
- *
- * Revision 1.1  1999/09/09 20:40:19  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogrsf_frmts.h"
 #include "ogr_p.h"
@@ -132,7 +33,7 @@
 #include "cpl_string.h"
 #include "cpl_multiproc.h"
 
-CPL_CVSID("$Id: ogrinfo.cpp,v 1.32 2006/03/31 17:44:20 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrinfo.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 int     bReadOnly = FALSE;
 int     bVerbose = TRUE;
@@ -223,25 +124,6 @@ int main( int nArgc, char ** papszArgv )
         {
             bSummaryOnly = TRUE;
         }
-        else if( EQUAL(papszArgv[iArg],"--formats") )
-        {
-            OGRSFDriverRegistrar *poR = OGRSFDriverRegistrar::GetRegistrar();
-        
-            printf( "Loaded OGR Format Drivers:\n" );
-
-            for( int iDriver = 0; iDriver < poR->GetDriverCount(); iDriver++ )
-            {
-                OGRSFDriver *poDriver = poR->GetDriver(iDriver);
-
-                if( poDriver->TestCapability( ODrCCreateDataSource ) )
-                    printf( "  -> \"%s\" (read/write)\n", 
-                            poDriver->GetName() );
-                else
-                    printf( "  -> \"%s\" (readonly)\n", 
-                            poDriver->GetName() );
-            }
-            exit( 0 );
-        }
         else if( papszArgv[iArg][0] == '-' )
         {
             Usage();
@@ -261,8 +143,8 @@ int main( int nArgc, char ** papszArgv )
 /* -------------------------------------------------------------------- */
 /*      Open data source.                                               */
 /* -------------------------------------------------------------------- */
-    OGRDataSource       *poDS;
-    OGRSFDriver         *poDriver;
+    OGRDataSource       *poDS = NULL;
+    OGRSFDriver         *poDriver = NULL;
 
     poDS = OGRSFDriverRegistrar::Open( pszDataSource, !bReadOnly, &poDriver );
     if( poDS == NULL && !bReadOnly )
@@ -294,12 +176,14 @@ int main( int nArgc, char ** papszArgv )
         exit( 1 );
     }
 
+    CPLAssert( poDriver != NULL);
+
 /* -------------------------------------------------------------------- */
 /*      Some information messages.                                      */
 /* -------------------------------------------------------------------- */
     if( bVerbose )
         printf( "INFO: Open of `%s'\n"
-                "using driver `%s' successful.\n",
+                "      using driver `%s' successful.\n",
                 pszDataSource, poDriver->GetName() );
 
     if( bVerbose && !EQUAL(pszDataSource,poDS->GetName()) )
@@ -314,12 +198,10 @@ int main( int nArgc, char ** papszArgv )
 /* -------------------------------------------------------------------- */
     if( pszSQLStatement != NULL )
     {
-        OGRLayer *poResultSet;
+        OGRLayer *poResultSet = NULL;
 
         nRepeatCount = 0;  // skip layer reporting.
 
-        if( pszWHERE != NULL )
-            printf( "-where clause ignored in combination with -sql.\n" );
         if( CSLCount(papszLayers) > 0 )
             printf( "layer names ignored in combination with -sql.\n" );
         
@@ -328,6 +210,9 @@ int main( int nArgc, char ** papszArgv )
 
         if( poResultSet != NULL )
         {
+            if( pszWHERE != NULL )
+                poResultSet->SetAttributeFilter( pszWHERE );
+
             ReportOnLayer( poResultSet, NULL, NULL );
             poDS->ReleaseResultSet( poResultSet );
         }
@@ -336,6 +221,8 @@ int main( int nArgc, char ** papszArgv )
 /* -------------------------------------------------------------------- */
 /*      Process each data source layer.                                 */
 /* -------------------------------------------------------------------- */
+    CPLDebug( "OGR", "GetLayerCount() = %d\n", poDS->GetLayerCount() );
+
     for( int iRepeat = 0; iRepeat < nRepeatCount; iRepeat++ )
     {
         for( int iLayer = 0; iLayer < poDS->GetLayerCount(); iLayer++ )
@@ -427,6 +314,8 @@ static void ReportOnLayer( OGRLayer * poLayer, const char *pszWHERE,
 /* -------------------------------------------------------------------- */
 /*      Report various overall information.                             */
 /* -------------------------------------------------------------------- */
+    CPLDebug("INFO", "---------- General Layer Report ----------"); 
+
     printf( "\n" );
     
     printf( "Layer name: %s\n", poDefn->GetName() );
@@ -457,6 +346,9 @@ static void ReportOnLayer( OGRLayer * poLayer, const char *pszWHERE,
         printf( "Layer SRS WKT:\n%s\n", pszWKT );
         CPLFree( pszWKT );
 
+    
+        CPLDebug("\nINFO", "---------- Geometry Column Report ----------\n"); 
+
         if( strlen(poLayer->GetFIDColumn()) > 0 )
             printf( "FID Column = %s\n", 
                     poLayer->GetFIDColumn() );
@@ -464,7 +356,7 @@ static void ReportOnLayer( OGRLayer * poLayer, const char *pszWHERE,
         if( strlen(poLayer->GetGeometryColumn()) > 0 )
             printf( "Geometry Column = %s\n", 
                     poLayer->GetGeometryColumn() );
-    
+
         for( int iAttr = 0; iAttr < poDefn->GetFieldCount(); iAttr++ )
         {
             OGRFieldDefn    *poField = poDefn->GetFieldDefn( iAttr );
@@ -480,7 +372,9 @@ static void ReportOnLayer( OGRLayer * poLayer, const char *pszWHERE,
 /* -------------------------------------------------------------------- */
 /*      Read, and dump features.                                        */
 /* -------------------------------------------------------------------- */
-    OGRFeature  *poFeature;
+    CPLDebug("\nINFO", "---------- Features Dump ----------\n"); 
+
+    OGRFeature  *poFeature = NULL;
 
     if( nFetchFID == OGRNullFID && !bSummaryOnly )
     {
