@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrlinearring.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: ogrlinearring.cpp 12921 2007-11-21 19:37:49Z mloskot $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  The OGRLinearRing geometry class.
@@ -30,7 +30,7 @@
 #include "ogr_geometry.h"
 #include "ogr_p.h"
 
-CPL_CVSID("$Id: ogrlinearring.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: ogrlinearring.cpp 12921 2007-11-21 19:37:49Z mloskot $");
 
 /************************************************************************/
 /*                           OGRLinearRing()                            */
@@ -371,7 +371,14 @@ void OGRLinearRing::closeRings()
         || getY(0) != getY(nPointCount-1)
         || getZ(0) != getZ(nPointCount-1) )
     {
-        addPoint( getX(0), getY(0), getZ(0) );
+        /* Avoid implicit change of coordinate dimensionality
+         * if z=0.0 and dim=2
+         */
+        if( getCoordinateDimension() == 2 )
+            addPoint( getX(0), getY(0) );
+        else
+            addPoint( getX(0), getY(0), getZ(0) );
+            
     }
 }
 
