@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogr_avc.h,v 1.5 2005/09/21 01:00:55 fwarmerdam Exp $
+ * $Id: ogr_avc.h 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Arc/Info Coverage (E00 & Binary) Reader
  * Purpose:  Declarations for OGR wrapper classes for coverage access.
@@ -25,25 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogr_avc.h,v $
- * Revision 1.5  2005/09/21 01:00:55  fwarmerdam
- * fixup OGRFeatureDefn and OGRSpatialReference refcount handling
- *
- * Revision 1.4  2005/02/22 12:55:03  fwarmerdam
- * use OGRLayer base spatial filter support
- *
- * Revision 1.3  2002/02/18 20:36:27  warmerda
- * added spatial query, nNextFID, nTableAttrIndex
- *
- * Revision 1.2  2002/02/14 23:01:04  warmerda
- * added region and attribute support
- *
- * Revision 1.1  2002/02/13 20:48:18  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #ifndef _OGR_AVC_H_INCLUDED
 #define _OGR_AVC_H_INCLUDED
@@ -103,7 +85,7 @@ class OGRAVCDataSource : public OGRDataSource
 		        OGRAVCDataSource();
     			~OGRAVCDataSource();
 
-    OGRSpatialReference *GetSpatialRef();
+    virtual OGRSpatialReference *GetSpatialRef();
 
     const char          *GetCoverageName();
 };
@@ -202,12 +184,24 @@ class OGRAVCBinDriver : public OGRSFDriver
 /************************************************************************/
 /*                            OGRAVCE00Layer                            */
 /************************************************************************/
-#ifdef notdef
 class OGRAVCE00Layer : public OGRAVCLayer
 {
     AVCE00Section       *psSection;
-    AVCBinFile          *hFile;
+    AVCE00ReadE00Ptr    psRead;
+    OGRAVCE00Layer      *poArcLayer;
+    int                 nFeatureCount;
+    int                 bNeedReset;
+    int                 nNextFID;
 
+    AVCE00Section       *psTableSection;
+    AVCE00ReadE00Ptr    psTableRead;
+    char                *pszTableFilename;
+    int                 nTablePos;
+    int                 nTableBaseField;
+    int                 nTableAttrIndex;
+
+    int                 FormPolygonGeometry( OGRFeature *poFeature,
+                                             AVCPal *psPAL );
   public:
                         OGRAVCE00Layer( OGRAVCDataSource *poDS,
                                         AVCE00Section *psSectionIn );
@@ -216,7 +210,39 @@ class OGRAVCE00Layer : public OGRAVCLayer
 
     void		ResetReading();
     OGRFeature *	GetNextFeature();
+    OGRFeature *GetFeature( long nFID );
+    int GetFeatureCount(int bForce);
+    int CheckSetupTable(AVCE00Section *psTblSectionIn);
+    int AppendTableFields( OGRFeature *poFeature );
+};
+
+/************************************************************************/
+/*                         OGRAVCE00DataSource                          */
+/************************************************************************/
+
+class OGRAVCE00DataSource : public OGRAVCDataSource
+{
+    int nLayers;
+    char *pszName;
+    AVCE00ReadE00Ptr psE00;
+    OGRAVCE00Layer **papoLayers;
+
+  protected:
+    int CheckAddTable(AVCE00Section *psTblSection);
+
+  public:
+    OGRAVCE00DataSource();
+    ~OGRAVCE00DataSource();
+
+    int Open(const char *, int bTestOpen);
+
+    AVCE00ReadE00Ptr GetInfo() { return psE00; }
+    const char *GetName() { return pszName; }
+    int GetLayerCount() { return nLayers; }
+
+    OGRLayer *GetLayer( int );
+    int TestCapability( const char * );
+    virtual OGRSpatialReference *GetSpatialRef();
 };
-#endif
 
 #endif /* _OGR_AVC_H_INCLUDED */
