@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogravcbindatasource.cpp,v 1.5 2005/09/21 01:00:55 fwarmerdam Exp $
+ * $Id: ogravcbindatasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OGR
  * Purpose:  Implements OGRAVCBinDataSource class.
@@ -25,31 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogravcbindatasource.cpp,v $
- * Revision 1.5  2005/09/21 01:00:55  fwarmerdam
- * fixup OGRFeatureDefn and OGRSpatialReference refcount handling
- *
- * Revision 1.4  2002/03/18 19:56:13  warmerda
- * added an error reset
- *
- * Revision 1.3  2002/02/18 20:38:42  warmerda
- * added TXT and TX6 support
- *
- * Revision 1.2  2002/02/14 23:01:04  warmerda
- * added region and attribute support
- *
- * Revision 1.1  2002/02/13 20:48:18  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_avc.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogravcbindatasource.cpp,v 1.5 2005/09/21 01:00:55 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogravcbindatasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                        OGRAVCBinDataSource()                         */
