@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogravclayer.cpp,v 1.9 2005/09/21 01:00:55 fwarmerdam Exp $
+ * $Id: ogravclayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OGR
  * Purpose:  Implements OGRAVCLayer class.  This is the base class for E00
@@ -28,43 +28,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogravclayer.cpp,v $
- * Revision 1.9  2005/09/21 01:00:55  fwarmerdam
- * fixup OGRFeatureDefn and OGRSpatialReference refcount handling
- *
- * Revision 1.8  2005/02/22 12:55:03  fwarmerdam
- * use OGRLayer base spatial filter support
- *
- * Revision 1.7  2005/02/02 21:09:44  fwarmerdam
- * track m_nFeaturesRead
- *
- * Revision 1.6  2004/10/19 22:05:03  dmorissette
- * Remove trailing spaces in string attribute fields (MapServer bug 184)
- *
- * Revision 1.5  2002/12/21 19:48:05  warmerda
- * rearrange code a bit to workaround VStudio.NET bug
- *
- * Revision 1.4  2002/02/18 20:36:50  warmerda
- * added attribute query
- *
- * Revision 1.3  2002/02/15 02:35:16  warmerda
- * added preliminary text support
- *
- * Revision 1.2  2002/02/14 23:01:04  warmerda
- * added region and attribute support
- *
- * Revision 1.1  2002/02/13 20:48:18  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_avc.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogravclayer.cpp,v 1.9 2005/09/21 01:00:55 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogravclayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                           OGRAVCLayer()                           */
@@ -134,10 +104,10 @@ int OGRAVCLayer::SetupFeatureDefinition( const char *pszName )
             poFeatureDefn->SetGeomType( wkbLineString );
 
             OGRFieldDefn	oUserId( "UserId", OFTInteger );
-            OGRFieldDefn	oFNode( "FNODE#", OFTInteger );
-            OGRFieldDefn	oTNode( "TNODE#", OFTInteger );
-            OGRFieldDefn	oLPoly( "LPOLY#", OFTInteger );
-            OGRFieldDefn	oRPoly( "RPOLY#", OFTInteger );
+            OGRFieldDefn	oFNode( "FNODE_", OFTInteger );
+            OGRFieldDefn	oTNode( "TNODE_", OFTInteger );
+            OGRFieldDefn	oLPoly( "LPOLY_", OFTInteger );
+            OGRFieldDefn	oRPoly( "RPOLY_", OFTInteger );
 
             poFeatureDefn->AddFieldDefn( &oUserId );
             poFeatureDefn->AddFieldDefn( &oFNode );
