@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: dgnwrite.cpp,v 1.21 2005/06/22 16:18:38 fwarmerdam Exp $
+ * $Id: dgnwrite.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Microstation DGN Access Library
  * Purpose:  DGN Access functions related to writing DGN elements.
@@ -25,80 +25,11 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: dgnwrite.cpp,v $
- * Revision 1.21  2005/06/22 16:18:38  fwarmerdam
- * Fixed from JeffGIS for cloning DGNST_TAG_SET properly.
- *
- * Revision 1.20  2004/03/23 16:17:12  warmerda
- * Corrected level setting of cell header groups, and also fixed total length
- * of cell groups.
- *
- * Revision 1.19  2004/03/23 16:06:27  warmerda
- * Fixed up complex header attribute handling as complained about by EDG.
- *
- * Revision 1.18  2003/11/25 15:47:56  warmerda
- * Added surface type for complex headers: Marius
- *
- * Revision 1.17  2003/11/21 16:17:33  warmerda
- * fix missing handling of min/max Z in DGNCreateMultiPointElem()
- *
- * Revision 1.16  2003/11/21 14:43:59  warmerda
- * removed extra bounds transformation in DGNCreateCellHeaderFromGroup()
- *
- * Revision 1.15  2003/11/19 17:37:00  warmerda
- * Fixes from Marius: use ElemTypeHasDispHdr, and cosmetic
- *
- * Revision 1.14  2003/11/05 17:17:38  warmerda
- * use DGNLoadTCB() to ensure scaling setup
- *
- * Revision 1.13  2003/08/19 20:17:15  warmerda
- * Implemented DGNCreateConeElem(). Extended DGNCreateComplex*() to
- * support 3D surface and 3D solid elements.
- * Marius Kintel
- *
- * Revision 1.12  2003/06/27 14:50:53  warmerda
- * avoid warnings
- *
- * Revision 1.11  2003/06/12 17:33:17  warmerda
- * improved DNGO_CAPTURE_RAW_DATA flag documnentation
- *
- * Revision 1.10  2003/05/21 03:42:01  warmerda
- * Expanded tabs
- *
- * Revision 1.9  2003/05/15 14:47:24  warmerda
- * implement quaternion support on write
- *
- * Revision 1.8  2003/05/12 18:48:57  warmerda
- * added preliminary 3D write support
- *
- * Revision 1.7  2003/02/06 16:53:48  warmerda
- * Improved text bounding box calcuation from Mart Kelder.
- *
- * Revision 1.6  2003/01/20 20:06:55  warmerda
- * added cell header creation
- *
- * Revision 1.5  2002/11/13 21:26:32  warmerda
- * added more documentation
- *
- * Revision 1.4  2002/11/12 19:45:54  warmerda
- * added support to update TCB in DGNCreate
- *
- * Revision 1.3  2002/11/11 20:38:43  warmerda
- * implemented write api
- *
- * Revision 1.2  2002/10/20 01:50:20  warmerda
- * added new write prototypes
- *
- * Revision 1.1  2002/03/14 21:40:43  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "dgnlibp.h"
 
-CPL_CVSID("$Id: dgnwrite.cpp,v 1.21 2005/06/22 16:18:38 fwarmerdam Exp $");
+CPL_CVSID("$Id: dgnwrite.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 static void DGNPointToInt( DGNInfo *psDGN, DGNPoint *psPoint, 
                            unsigned char *pabyTarget );
@@ -426,12 +357,12 @@ DGNHandle
         memcpy( pabyRawTCB+1120, pszMasterUnits, 2 );
         memcpy( pabyRawTCB+1122, pszSubUnits, 2 );
 
-        DGN_WRITE_INT32( (unsigned char) nUORPerSubUnit, pabyRawTCB+1116 );
-        DGN_WRITE_INT32((unsigned char)nSubUnitsPerMasterUnit,pabyRawTCB+1112);
+        DGN_WRITE_INT32( nUORPerSubUnit, pabyRawTCB+1116 );
+        DGN_WRITE_INT32( nSubUnitsPerMasterUnit,pabyRawTCB+1112);
     }
     else
     {
-        nUORPerSubUnit = DGN_INT32( pabyRawTCB+1120 );
+        nUORPerSubUnit = DGN_INT32( pabyRawTCB+1116 );
         nSubUnitsPerMasterUnit = DGN_INT32( pabyRawTCB+1112 );
     }
 
@@ -572,6 +503,16 @@ DGNElemCore *DGNCloneElement( DGNHandle hDGNSrc, DGNHandle hDGNDst,
 
         psClone = (DGNElemCore *) psText;
     }
+    else if( psSrcElement->stype == DGNST_TEXT_NODE )
+    {
+        DGNElemTextNode *psNode;
+
+        psNode = (DGNElemTextNode *) 
+            CPLMalloc(sizeof(DGNElemTextNode));
+        memcpy( psNode, psSrcElement, sizeof(DGNElemTextNode) );
+
+        psClone = (DGNElemCore *) psNode;
+    }
     else if( psSrcElement->stype == DGNST_COMPLEX_HEADER )
     {
         DGNElemComplexHeader *psCH;
@@ -658,6 +599,77 @@ DGNElemCore *DGNCloneElement( DGNHandle hDGNSrc, DGNHandle hDGNDst,
         psTS->tagList = pasTagList;
         psClone = (DGNElemCore *) psTS;
     }
+    else if( psSrcElement->stype == DGNST_CONE )
+    {
+        DGNElemCone *psCone;
+
+        psCone = (DGNElemCone *) CPLMalloc(sizeof(DGNElemCone));
+        memcpy( psCone, psSrcElement, sizeof(DGNElemCone) );
+
+        psClone = (DGNElemCore *) psCone;
+    }
+    else if( psSrcElement->stype == DGNST_BSPLINE_SURFACE_HEADER )
+    {
+        DGNElemBSplineSurfaceHeader *psSurface;
+
+        psSurface = (DGNElemBSplineSurfaceHeader *) 
+          CPLMalloc(sizeof(DGNElemBSplineSurfaceHeader));
+        memcpy( psSurface, psSrcElement, sizeof(DGNElemBSplineSurfaceHeader) );
+
+        psClone = (DGNElemCore *) psSurface;
+    }
+    else if( psSrcElement->stype == DGNST_BSPLINE_CURVE_HEADER )
+    {
+        DGNElemBSplineCurveHeader *psCurve;
+
+        psCurve = (DGNElemBSplineCurveHeader *) 
+          CPLMalloc(sizeof(DGNElemBSplineCurveHeader));
+        memcpy( psCurve, psSrcElement, sizeof(DGNElemBSplineCurveHeader) );
+
+        psClone = (DGNElemCore *) psCurve;
+    }
+    else if( psSrcElement->stype == DGNST_BSPLINE_SURFACE_BOUNDARY )
+    {
+        DGNElemBSplineSurfaceBoundary *psBSB, *psSrcBSB;
+        int               nSize;
+
+        psSrcBSB = (DGNElemBSplineSurfaceBoundary *) psSrcElement;
+
+        nSize = sizeof(DGNElemBSplineSurfaceBoundary) 
+            + sizeof(DGNPoint) * (psSrcBSB->numverts-1);
+
+        psBSB = (DGNElemBSplineSurfaceBoundary *) CPLMalloc( nSize );
+        memcpy( psBSB, psSrcElement, nSize );
+
+        psClone = (DGNElemCore *) psBSB;
+    }
+    else if( psSrcElement->stype == DGNST_KNOT_WEIGHT )
+    {
+        DGNElemKnotWeight *psArray, *psSrcArray;
+        int               nSize, numelems;
+
+        // FIXME: Is it OK to assume that the # of elements corresponds
+        // directly to the element size? kintel 20051218.
+        numelems = (psSrcElement->size - 36 - psSrcElement->attr_bytes)/4;
+
+        psSrcArray = (DGNElemKnotWeight *) psSrcElement;
+
+        nSize = sizeof(DGNElemKnotWeight) + sizeof(long) * (numelems-1);
+
+        psArray = (DGNElemKnotWeight *) CPLMalloc( nSize );
+        memcpy( psArray, psSrcElement, nSize );
+
+        psClone = (DGNElemCore *) psArray;
+    }
+    else if( psSrcElement->stype == DGNST_SHARED_CELL_DEFN )
+    {
+        DGNElemSharedCellDefn *psCH;
+
+        psCH = (DGNElemSharedCellDefn *)CPLMalloc(sizeof(DGNElemSharedCellDefn));
+        memcpy( psCH, psSrcElement, sizeof(DGNElemSharedCellDefn) );
+
+        psClone = (DGNElemCore *) psCH;
+    }
     else
     {
         CPLAssert( FALSE );
@@ -802,7 +814,7 @@ int DGNUpdateElemCoreExtended( DGNHandle hDGN, DGNElemCore *psElement )
 }
 
 /************************************************************************/
-/*                         DGNInitializeCore()                          */
+/*                         DGNInitializeElemCore()                      */
 /************************************************************************/
 
 static void DGNInitializeElemCore( DGNHandle hDGN, DGNElemCore *psElement )
@@ -856,7 +868,7 @@ static void DGNWriteBounds( DGNInfo *psInfo, DGNElemCore *psElement,
  *
  * @param hDGN the file on which the element will eventually be written.
  * @param nType the type of the element to be created.  It must be one of
- * DGNT_LINE, DGNT_LINE_STRING, DGNT_SHAPE, DGNT_CURVE or DGNT_BSPLINE. 
+ * DGNT_LINE, DGNT_LINE_STRING, DGNT_SHAPE, DGNT_CURVE or DGNT_BSPLINE_POLE. 
  * @param nPointCount the number of points in the pasVertices list.
  * @param pasVertices the list of points to be written. 
  *
@@ -877,15 +889,14 @@ DGNElemCore *DGNCreateMultiPointElem( DGNHandle hDGN, int nType,
                || nType == DGNT_LINE_STRING
                || nType == DGNT_SHAPE
                || nType == DGNT_CURVE
-               || nType == DGNT_BSPLINE );
+               || nType == DGNT_BSPLINE_POLE );
 
     DGNLoadTCB( hDGN );
 
 /* -------------------------------------------------------------------- */
 /*      Is this too many vertices to write to a single element?         */
 /* -------------------------------------------------------------------- */
-    if( (psDGN->dimension == 2 && 38 + 8 * nPointCount >= 512)
-        || (psDGN->dimension == 3 && 38 + 12 * nPointCount >= 512) )
+    if( nPointCount > 101 )
     {
         CPLError( CE_Failure, CPLE_ElementTooBig, 
                   "Attempt to create %s element with %d points failed.\n"
@@ -1443,10 +1454,10 @@ DGNCreateTextElem( DGNHandle hDGN, const char *pszText,
     psCore->raw_data[36] = (unsigned char) nFontId;
     psCore->raw_data[37] = (unsigned char) nJustification;
 
-    nIntValue = (int) (dfLengthMult * 1000.0 / (psDGN->scale * 6.0));
+    nIntValue = (int) (dfLengthMult * 1000.0 / (psDGN->scale * 6.0) + 0.5);
     DGN_WRITE_INT32( nIntValue, psCore->raw_data + 38 );
     
-    nIntValue = (int) (dfHeightMult * 1000.0 / (psDGN->scale * 6.0));
+    nIntValue = (int) (dfHeightMult * 1000.0 / (psDGN->scale * 6.0) + 0.5);
     DGN_WRITE_INT32( nIntValue, psCore->raw_data + 42 );
 
     if( psDGN->dimension == 2 )
@@ -1615,12 +1626,9 @@ DGNCreateColorTableElem( DGNHandle hDGN, int nScreenFlag,
  * a complex element from the members more conveniently.  
  *
  * @param hDGN the file on which the element will be written.
- * @param nType DGNT_COMPLEX_CHAIN_HEADER, DGNT_COMPLEX_SHAPE_HEADER, 
- * DGNT_3DSURFACE_HEADER or DGNT_3DSOLID_HEADER.
+ * @param nType DGNT_COMPLEX_CHAIN_HEADER or DGNT_COMPLEX_SHAPE_HEADER.
  * depending on whether the list is open or closed (last point equal to last)
  * or if the object represents a surface or a solid.
- * @param nSurfType the surface/solid type, one of DGNSUT_* or DGNSOT_*. 
- * Ignored if nType is DGNT_COMPLEX_CHAIN_HEADER or DGNT_COMPLEX_SHAPE_HEADER.
  * @param nTotLength the value of the totlength field in the element.
  * @param nNumElems the number of elements in the complex group not including
  * the header element. 
@@ -1628,7 +1636,7 @@ DGNCreateColorTableElem( DGNHandle hDGN, int nScreenFlag,
  * @return the new element (DGNElemComplexHeader) or NULL on failure. 
  */
 DGNElemCore *
-DGNCreateComplexHeaderElem( DGNHandle hDGN, int nType, int nSurfType,
+DGNCreateComplexHeaderElem( DGNHandle hDGN, int nType, 
                             int nTotLength, int nNumElems )
 {
     DGNElemComplexHeader *psCH;
@@ -1636,9 +1644,7 @@ DGNCreateComplexHeaderElem( DGNHandle hDGN, int nType, int nSurfType,
     unsigned char abyRawZeroLinkage[8] = {0,0,0,0,0,0,0,0};
 
     CPLAssert( nType == DGNT_COMPLEX_CHAIN_HEADER 
-               || nType == DGNT_COMPLEX_SHAPE_HEADER
-               || nType == DGNT_3DSURFACE_HEADER 
-               || nType == DGNT_3DSOLID_HEADER );
+               || nType == DGNT_COMPLEX_SHAPE_HEADER );
 
     DGNLoadTCB( hDGN );
 
@@ -1650,6 +1656,7 @@ DGNCreateComplexHeaderElem( DGNHandle hDGN, int nType, int nSurfType,
     psCore = &(psCH->core);
 
     DGNInitializeElemCore( hDGN, psCore );
+    psCore->complex = TRUE;
     psCore->stype = DGNST_COMPLEX_HEADER;
     psCore->type = nType;
 
@@ -1658,27 +1665,19 @@ DGNCreateComplexHeaderElem( DGNHandle hDGN, int nType, int nSurfType,
 /* -------------------------------------------------------------------- */
     psCH->totlength = nTotLength - 4;
     psCH->numelems = nNumElems;
-    psCH->surftype = nSurfType;
+    psCH->surftype = 0;
+    psCH->boundelms = 0;
 
 /* -------------------------------------------------------------------- */
 /*      Setup Raw data for the complex specific portion.                */
 /* -------------------------------------------------------------------- */
-    if ( nType == DGNT_COMPLEX_CHAIN_HEADER 
-         || nType == DGNT_COMPLEX_SHAPE_HEADER ) 
-      psCore->raw_bytes = 40;
-    else 
-      psCore->raw_bytes = 42;
-
+    psCore->raw_bytes = 40;
     psCore->raw_data = (unsigned char*) CPLCalloc(psCore->raw_bytes,1);
 
     psCore->raw_data[36] = (unsigned char) ((nTotLength-4) % 256);
     psCore->raw_data[37] = (unsigned char) ((nTotLength-4) / 256);
     psCore->raw_data[38] = (unsigned char) (nNumElems % 256);
     psCore->raw_data[39] = (unsigned char) (nNumElems / 256);
-    if ( nType == DGNT_3DSURFACE_HEADER || nType == DGNT_3DSOLID_HEADER ) {
-      psCore->raw_data[40] = (unsigned char) (psCH->surftype % 256);
-      psCore->raw_data[41] = (unsigned char) (psCH->surftype / 256);
-    }
 
 /* -------------------------------------------------------------------- */
 /*      Set the core raw data.                                          */
@@ -1708,12 +1707,9 @@ DGNCreateComplexHeaderElem( DGNHandle hDGN, int nType, int nSurfType,
  * setting the level based on the level of the member elements. 
  * 
  * @param hDGN the file on which the element will be written.
- * @param nType DGNT_COMPLEX_CHAIN_HEADER, DGNT_COMPLEX_SHAPE_HEADER, 
- * DGNT_3DSURFACE_HEADER or DGNT_3DSOLID_HEADER.
+ * @param nType DGNT_COMPLEX_CHAIN_HEADER or DGNT_COMPLEX_SHAPE_HEADER.
  * depending on whether the list is open or closed (last point equal to last)
  * or if the object represents a surface or a solid.
- * @param nSurfType the surface/solid type, one of DGNSUT_* or DGNSOT_*. 
- * Ignored if nType is DGNT_COMPLEX_CHAIN_HEADER or DGNT_COMPLEX_SHAPE_HEADER.
  * @param nNumElems the number of elements in the complex group not including
  * the header element. 
  * @param papsElems array of pointers to nNumElems elements in the complex
@@ -1723,7 +1719,7 @@ DGNCreateComplexHeaderElem( DGNHandle hDGN, int nType, int nSurfType,
  */
 
 DGNElemCore *
-DGNCreateComplexHeaderFromGroup( DGNHandle hDGN, int nType, int nSurfType,
+DGNCreateComplexHeaderFromGroup( DGNHandle hDGN, int nType, 
                                  int nNumElems, DGNElemCore **papsElems )
 
 {
@@ -1781,8 +1777,188 @@ DGNCreateComplexHeaderFromGroup( DGNHandle hDGN, int nType, int nSurfType,
 /* -------------------------------------------------------------------- */
 /*      Create the corresponding complex header.                        */
 /* -------------------------------------------------------------------- */
-    psCH = DGNCreateComplexHeaderElem( hDGN, nType, nSurfType, 
-                                       nTotalLength, nNumElems );
+    psCH = DGNCreateComplexHeaderElem( hDGN, nType, nTotalLength, nNumElems );
+    DGNUpdateElemCore( hDGN, psCH, papsElems[0]->level, psCH->graphic_group,
+                       psCH->color, psCH->weight, psCH->style );
+
+    DGNWriteBounds( (DGNInfo *) hDGN, psCH, &sMin, &sMax );
+    
+    return psCH;
+}
+
+/************************************************************************/
+/*                     DGNCreateSolidHeaderElem()                       */
+/************************************************************************/
+
+/**
+ * Create 3D solid/surface.
+ *
+ * The newly created element will still need to be written to file using
+ * DGNWriteElement(). Also the level and other core values will be defaulted.
+ * Use DGNUpdateElemCore() on the element before writing to set these values.
+ *
+ * The nTotLength is the sum of the size of all elements in the solid
+ * group plus 6.  The DGNCreateSolidHeaderFromGroup() can be used to build
+ * a solid element from the members more conveniently.  
+ *
+ * @param hDGN the file on which the element will be written.
+ * @param nType DGNT_3DSURFACE_HEADER or DGNT_3DSOLID_HEADER.
+ * @param nSurfType the surface/solid type, one of DGNSUT_* or DGNSOT_*. 
+ * @param nBoundElems the number of elements in each boundary. 
+ * @param nTotLength the value of the totlength field in the element.
+ * @param nNumElems the number of elements in the solid not including
+ * the header element. 
+ *
+ * @return the new element (DGNElemComplexHeader) or NULL on failure. 
+ */
+DGNElemCore *
+DGNCreateSolidHeaderElem( DGNHandle hDGN, int nType, int nSurfType,
+                          int nBoundElems, int nTotLength, int nNumElems )
+{
+    DGNElemComplexHeader *psCH;
+    DGNElemCore *psCore;
+    unsigned char abyRawZeroLinkage[8] = {0,0,0,0,0,0,0,0};
+
+    CPLAssert( nType == DGNT_3DSURFACE_HEADER 
+               || nType == DGNT_3DSOLID_HEADER );
+
+    DGNLoadTCB( hDGN );
+
+/* -------------------------------------------------------------------- */
+/*      Allocate element.                                               */
+/* -------------------------------------------------------------------- */
+    psCH = (DGNElemComplexHeader *) 
+        CPLCalloc( sizeof(DGNElemComplexHeader), 1 );
+    psCore = &(psCH->core);
+
+    DGNInitializeElemCore( hDGN, psCore );
+    psCore->complex = TRUE;
+    psCore->stype = DGNST_COMPLEX_HEADER;
+    psCore->type = nType;
+
+/* -------------------------------------------------------------------- */
+/*      Set solid header specific information in the structure.         */
+/* -------------------------------------------------------------------- */
+    psCH->totlength = nTotLength - 4;
+    psCH->numelems = nNumElems;
+    psCH->surftype = nSurfType;
+    psCH->boundelms = nBoundElems;
+
+/* -------------------------------------------------------------------- */
+/*      Setup Raw data for the solid specific portion.                  */
+/* -------------------------------------------------------------------- */
+    psCore->raw_bytes = 42;
+
+    psCore->raw_data = (unsigned char*) CPLCalloc(psCore->raw_bytes,1);
+
+    psCore->raw_data[36] = (unsigned char) ((nTotLength-4) % 256);
+    psCore->raw_data[37] = (unsigned char) ((nTotLength-4) / 256);
+    psCore->raw_data[38] = (unsigned char) (nNumElems % 256);
+    psCore->raw_data[39] = (unsigned char) (nNumElems / 256);
+    psCore->raw_data[40] = (unsigned char) psCH->surftype;
+    psCore->raw_data[41] = (unsigned char) psCH->boundelms - 1;
+
+/* -------------------------------------------------------------------- */
+/*      Set the core raw data.                                          */
+/* -------------------------------------------------------------------- */
+    DGNUpdateElemCoreExtended( hDGN, psCore );
+
+/* -------------------------------------------------------------------- */
+/*      Elements have to be at least 48 bytes long, so we have to       */
+/*      add a dummy bit of attribute data to fill out the length.       */
+/* -------------------------------------------------------------------- */
+    DGNAddRawAttrLink( hDGN, psCore, 8, abyRawZeroLinkage );
+    
+    return psCore;
+}
+
+/************************************************************************/
+/*                  DGNCreateSolidHeaderFromGroup()                     */
+/************************************************************************/
+
+/**
+ * Create 3D solid/surface header.
+ *
+ * This function is similar to DGNCreateSolidHeaderElem(), but it takes
+ * care of computing the total size of the set of elements being written, 
+ * and collecting the bounding extents.  It also takes care of some other
+ * convenience issues, like marking all the member elements as complex, and 
+ * setting the level based on the level of the member elements. 
+ * 
+ * @param hDGN the file on which the element will be written.
+ * @param nType DGNT_3DSURFACE_HEADER or DGNT_3DSOLID_HEADER.
+ * @param nSurfType the surface/solid type, one of DGNSUT_* or DGNSOT_*. 
+ * @param nBoundElems the number of boundary elements. 
+ * @param nNumElems the number of elements in the solid not including
+ * the header element. 
+ * @param papsElems array of pointers to nNumElems elements in the solid.
+ * Some updates may be made to these elements. 
+ *
+ * @return the new element (DGNElemComplexHeader) or NULL on failure. 
+ */
+
+DGNElemCore *
+DGNCreateSolidHeaderFromGroup( DGNHandle hDGN, int nType, int nSurfType,
+                               int nBoundElems, int nNumElems, 
+                               DGNElemCore **papsElems )
+
+{
+    int         nTotalLength = 6;
+    int         i, nLevel;
+    DGNElemCore *psCH;
+    DGNPoint    sMin = {0.0,0.0,0.0}, sMax = {0.0,0.0,0.0};
+
+    DGNLoadTCB( hDGN );
+
+    if( nNumElems < 1 || papsElems == NULL )
+    {
+        CPLError( CE_Failure, CPLE_AppDefined, 
+                  "Need at least one element to form a solid." );
+        return NULL;
+    }
+
+/* -------------------------------------------------------------------- */
+/*      Collect the total size, and bounds.                             */
+/* -------------------------------------------------------------------- */
+    nLevel = papsElems[0]->level;
+
+    for( i = 0; i < nNumElems; i++ )
+    {
+        DGNPoint sThisMin, sThisMax;
+
+        nTotalLength += papsElems[i]->raw_bytes / 2;
+
+        papsElems[i]->complex = TRUE;
+        papsElems[i]->raw_data[0] |= 0x80;
+
+        if( papsElems[i]->level != nLevel )
+        {
+            CPLError( CE_Warning, CPLE_AppDefined, 
+                      "Not all level values matching in a complex set group!");
+        }
+
+        DGNGetElementExtents( hDGN, papsElems[i], &sThisMin, &sThisMax );
+        if( i == 0 )
+        {
+            sMin = sThisMin;
+            sMax = sThisMax;
+        }
+        else
+        {
+            sMin.x = MIN(sMin.x,sThisMin.x);
+            sMin.y = MIN(sMin.y,sThisMin.y);
+            sMin.z = MIN(sMin.z,sThisMin.z);
+            sMax.x = MAX(sMax.x,sThisMax.x);
+            sMax.y = MAX(sMax.y,sThisMax.y);
+            sMax.z = MAX(sMax.z,sThisMax.z);
+        }
+    }
+
+/* -------------------------------------------------------------------- */
+/*      Create the corresponding solid header.                          */
+/* -------------------------------------------------------------------- */
+    psCH = DGNCreateSolidHeaderElem( hDGN, nType, nSurfType, nBoundElems, 
+                                     nTotalLength, nNumElems );
     DGNUpdateElemCore( hDGN, psCH, papsElems[0]->level, psCH->graphic_group,
                        psCH->color, psCH->weight, psCH->style );
 
@@ -2246,7 +2422,8 @@ int DGNAddRawAttrLink( DGNHandle hDGN, DGNElemCore *psElement,
 /*      If the element is a shape or chain complex header, then we      */
 /*      need to increase the total complex group size appropriately.    */
 /* -------------------------------------------------------------------- */
-    if( psElement->stype == DGNST_COMPLEX_HEADER )
+    if( psElement->stype == DGNST_COMPLEX_HEADER ||
+        psElement->stype == DGNST_TEXT_NODE )  // compatible structures
     {
         DGNElemComplexHeader *psCT = (DGNElemComplexHeader *) psElement;
 
