@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrdgndatasource.cpp,v 1.11 2004/08/17 21:00:21 warmerda Exp $
+ * $Id: ogrdgndatasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRPGDataSource class.
@@ -25,49 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrdgndatasource.cpp,v $
- * Revision 1.11  2004/08/17 21:00:21  warmerda
- * Fixed last fix so that short files aren't even passed to DGNTestOpen().
- *
- * Revision 1.10  2004/08/17 20:56:48  warmerda
- * Keep track of how many bytes we get when reading info for testopen.
- *
- * Revision 1.9  2003/05/21 03:42:01  warmerda
- * Expanded tabs
- *
- * Revision 1.8  2003/05/12 18:48:57  warmerda
- * added preliminary 3D write support
- *
- * Revision 1.7  2002/11/12 19:46:12  warmerda
- * use default seed file if none given
- *
- * Revision 1.6  2002/11/11 20:34:22  warmerda
- * added create support
- *
- * Revision 1.5  2002/03/14 21:40:19  warmerda
- * pass update flag to DGNOpen
- *
- * Revision 1.4  2001/07/18 04:55:16  warmerda
- * added CPL_CSVID
- *
- * Revision 1.3  2001/03/18 16:54:39  warmerda
- * added use of DGNTestOpen, remove extention test
- *
- * Revision 1.2  2000/12/28 21:27:11  warmerda
- * updated email address
- *
- * Revision 1.1  2000/11/28 19:03:47  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_dgn.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogrdgndatasource.cpp,v 1.11 2004/08/17 21:00:21 warmerda Exp $");
+CPL_CVSID("$Id: ogrdgndatasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                         OGRDGNDataSource()                           */
@@ -226,7 +190,7 @@ OGRLayer *OGRDGNDataSource::CreateLayer( const char *pszLayerName,
 {
     const char *pszSeed, *pszMasterUnit = "m", *pszSubUnit = "cm";
     const char *pszValue;
-    int nUORPerSU=100, nSUPerMU=1;
+    int nUORPerSU=1, nSUPerMU=100;
     int nCreationFlags = 0, b3DRequested;
     double dfOriginX = -21474836.0,  /* default origin centered on zero */
            dfOriginY = -21474836.0,  /* with two decimals of precision */
