@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrdodsfielddefn.cpp,v 1.3 2004/03/12 22:13:07 warmerda Exp $
+ * $Id: ogrdodsfielddefn.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OGR/DODS Interface
  * Purpose:  Implements OGRDODSFieldDefn class.  This is a small class used
@@ -26,24 +26,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrdodsfielddefn.cpp,v $
- * Revision 1.3  2004/03/12 22:13:07  warmerda
- * major upgrade with normalized sequen nested sequence support
- *
- * Revision 1.2  2004/01/29 21:01:03  warmerda
- * added sequences within sequences support
- *
- * Revision 1.1  2004/01/21 20:08:29  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_dods.h"
 #include "cpl_conv.h"
 
-CPL_CVSID("$Id: ogrdodsfielddefn.cpp,v 1.3 2004/03/12 22:13:07 warmerda Exp $");
+CPL_CVSID("$Id: ogrdodsfielddefn.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                          OGRDODSFieldDefn()                          */
