@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrdodsgrid.cpp,v 1.8 2006/05/01 16:27:33 fwarmerdam Exp $
+ * $Id: ogrdodsgrid.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OGR/DODS Interface
  * Purpose:  Implements OGRDODSGridLayer class, which implements the
@@ -26,40 +26,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrdodsgrid.cpp,v $
- * Revision 1.8  2006/05/01 16:27:33  fwarmerdam
- * updated to work with libdap 1.6.2
- *
- * Revision 1.7  2005/09/21 01:00:28  fwarmerdam
- * fixup OGRFeatureDefn and OGRSpatialReference refcount handling
- *
- * Revision 1.6  2005/02/22 12:57:39  fwarmerdam
- * use OGRLayer base spatial filter support
- *
- * Revision 1.5  2005/02/02 20:54:26  fwarmerdam
- * track m_nFeaturesRead
- *
- * Revision 1.4  2004/03/23 18:08:17  warmerda
- * Fixed row/column major orientedness of data for multi-dimensional arrays.
- *
- * Revision 1.3  2004/02/19 13:57:21  warmerda
- * complete support for extra_containers
- *
- * Revision 1.2  2004/02/17 18:47:05  warmerda
- * added geometry support
- *
- * Revision 1.1  2004/02/17 16:22:19  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "cpl_conv.h"
 #include "ogr_dods.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogrdodsgrid.cpp,v 1.8 2006/05/01 16:27:33 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrdodsgrid.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                          OGRDODSGridLayer()                          */
