@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrfmecacheindex.cpp,v 1.3 2003/02/06 05:02:42 warmerda Exp $
+ * $Id: ogrfmecacheindex.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  FMEObjects Translator
  * Purpose:  Implement the OGRFMECacheIndex class, a mechanism to manage a
@@ -21,25 +21,7 @@
  * accuracy or completeness of the Software. In no event will Safe Software 
  * Incorporated be liable for damages, including loss of profits or 
  * consequential damages, arising out of the use of the Software.
- ******************************************************************************
- *
- * $Log: ogrfmecacheindex.cpp,v $
- * Revision 1.3  2003/02/06 05:02:42  warmerda
- * added rec to clean list
- *
- * Revision 1.2  2002/07/11 16:07:27  warmerda
- * added CreationTime support, test against FMECACHE_MAX_RETENTION
- *
- * Revision 1.1  2002/05/24 06:23:57  warmerda
- * New
- *
- * Revision 1.2  2002/05/24 05:14:05  warmerda
- * removed stuff moved to minixml in cpl
- *
- * Revision 1.1  2002/05/24 03:59:00  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "fme2ogr.h"
 #include "cpl_multiproc.h"
@@ -48,7 +30,7 @@
 #include "cpl_string.h"
 #include <time.h>
 
-CPL_CVSID("$Id: ogrfmecacheindex.cpp,v 1.3 2003/02/06 05:02:42 warmerda Exp $");
+CPL_CVSID("$Id: ogrfmecacheindex.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                          OGRFMECacheIndex()                          */
