@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogr_miattrind.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: ogr_miattrind.cpp 12519 2007-10-23 15:28:53Z mloskot $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements interface to MapInfo .ID files used as attribute
@@ -32,7 +32,7 @@
 #include "mitab/mitab_priv.h"
 #include "cpl_minixml.h"
 
-CPL_CVSID("$Id: ogr_miattrind.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: ogr_miattrind.cpp 12519 2007-10-23 15:28:53Z mloskot $");
 
 /************************************************************************/
 /*                            OGRMIAttrIndex                            */
@@ -224,7 +224,12 @@ OGRErr OGRMILayerAttrIndex::LoadConfigFromXML()
 /*      Open the index file.                                            */
 /* -------------------------------------------------------------------- */
     poINDFile = new TABINDFile();
-    if( poINDFile->Open( pszMetadataFilename, "r+" ) != 0 )
+
+    /* NOTE: Replaced r+ with r according to explanation in Ticket #1620.
+     * This change has to be observed if it doesn't cause any
+     * problems in future. (mloskot)
+     */
+    if( poINDFile->Open( pszMetadataFilename, "r" ) != 0 )
     {
         CPLDestroyXMLNode( psRoot );
         CPLError( CE_Failure, CPLE_OpenFailed,
