@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrsfdriverregistrar.cpp,v 1.23 2005/10/28 16:47:02 fwarmerdam Exp $
+ * $Id: ogrsfdriverregistrar.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  The OGRSFDriverRegistrar class implementation.
@@ -25,86 +25,14 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrsfdriverregistrar.cpp,v $
- * Revision 1.23  2005/10/28 16:47:02  fwarmerdam
- * Added OGRCleanupAll()
- *
- * Revision 1.22  2005/10/25 19:59:15  fwarmerdam
- * added driver tracking on datasource
- *
- * Revision 1.21  2005/08/10 13:49:43  fwarmerdam
- * fix logic for dll entry point.
- *
- * Revision 1.20  2005/06/10 15:38:10  fwarmerdam
- * avoid use of MAX_PATH
- *
- * Revision 1.19  2005/06/10 14:58:46  fwarmerdam
- * Added option to search under executable directory for plugins.
- *
- * Revision 1.18  2005/06/08 21:11:24  fwarmerdam
- * bug 865: fixed "ogr_" name test.
- *
- * Revision 1.17  2005/01/19 20:28:18  fwarmerdam
- * added untested autoloaddrivers.
- *
- * Revision 1.16  2004/10/17 04:04:05  fwarmerdam
- * fixed bug with cleanup order in ReleaseDataSource, issue with vrt
- *
- * Revision 1.15  2003/10/10 19:12:06  warmerda
- * Ensure registrar is created before trying to use it.
- *
- * Revision 1.14  2003/05/28 19:18:04  warmerda
- * fixup argument names for docs
- *
- * Revision 1.13  2003/05/20 19:07:03  warmerda
- * added GDAL_DATA support, use CPLGetConfigOption
- *
- * Revision 1.12  2003/04/08 21:23:33  warmerda
- * added OGRGetDriverByName
- *
- * Revision 1.11  2003/03/20 19:12:15  warmerda
- * added debug messages
- *
- * Revision 1.10  2003/03/19 20:37:09  warmerda
- * added OpenShared() mechanism
- *
- * Revision 1.9  2003/03/14 02:28:07  danmo
- * Prevent crash if poRegistrar==NULL in OGRGetDriverCount() and OGROpen()
- *
- * Revision 1.8  2002/09/26 18:16:19  warmerda
- * added C entry points
- *
- * Revision 1.7  2002/05/14 21:38:00  warmerda
- * make INST_DATA overidable with binary patch
- *
- * Revision 1.6  2001/07/18 04:55:16  warmerda
- * added CPL_CSVID
- *
- * Revision 1.5  2001/01/22 22:36:05  warmerda
- * expanded tabs
- *
- * Revision 1.4  2000/12/05 23:07:43  warmerda
- * Check for CE_Failure, not just an error being set.
- *
- * Revision 1.3  2000/08/30 09:13:34  warmerda
- * Set INST_DATA as FinderLocation
- *
- * Revision 1.2  1999/07/27 00:51:08  warmerda
- * added arg to get driver out of Open()
- *
- * Revision 1.1  1999/07/05 18:58:32  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogrsf_frmts.h"
 #include "ogr_api.h"
 #include "ogr_p.h"
 #include "cpl_multiproc.h"
 
-CPL_CVSID("$Id: ogrsfdriverregistrar.cpp,v 1.23 2005/10/28 16:47:02 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrsfdriverregistrar.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 static OGRSFDriverRegistrar *poRegistrar = NULL;
 
@@ -658,8 +586,12 @@ void OGRSFDriverRegistrar::AutoLoadDrivers()
     else
     {
 #ifdef GDAL_PREFIX
-        papszSearchPath = CSLAddString( papszSearchPath, 
+        papszSearchPath = CSLAddString( papszSearchPath,
+    #ifdef MACOSX_FRAMEWORK
+                                        GDAL_PREFIX "/PlugIns");
+    #else
                                         GDAL_PREFIX "/lib/gdalplugins" );
+    #endif
 #else
         char szExecPath[1024];
 
@@ -675,15 +607,13 @@ void OGRSFDriverRegistrar::AutoLoadDrivers()
             papszSearchPath = CSLAddString( papszSearchPath, 
                                             "/usr/local/lib/gdalplugins" );
         }
+#endif 
+
+#ifdef MACOSX_FRAMEWORK
+        papszSearchPath = CSLAddString( papszSearchPath, 
+                                        "/Library/Application Support/GDAL/PlugIns" );
 #endif
 
-#ifdef notdef
-        if( strlen(GetHome()) > 0 )
-        {
-            papszSearchPath = CSLAddString( papszSearchPath, 
-                                  CPLFormFilename( GetHome(), "lib", NULL ) );
-        }
-#endif
     }
 
 /* -------------------------------------------------------------------- */
