@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: gmlpropertydefn.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: gmlpropertydefn.cpp 12782 2007-11-15 15:24:07Z mloskot $
  *
  * Project:  GML Reader
  * Purpose:  Implementation of GMLPropertyDefn
@@ -82,20 +82,6 @@ void GMLPropertyDefn::SetSrcElement( const char *pszSrcElement )
 void GMLPropertyDefn::AnalysePropertyValue( const char *pszValue )
 
 {
-/* -------------------------------------------------------------------- */
-/*      We can't get more general than string, so at this point just    */
-/*      give up on changing.                                            */
-/* -------------------------------------------------------------------- */
-    if( m_eType == GMLPT_String )
-    {
-        /* grow the Width to the length of the string passed in */
-        int nWidth;
-        nWidth = strlen(pszValue);
-        if ( m_nWidth < nWidth ) 
-            SetWidth( nWidth );
-        return;
-    }
-
 /* -------------------------------------------------------------------- */
 /*      If it is a zero length string, just return.  We can't deduce    */
 /*      much from this.                                                 */
@@ -108,6 +94,8 @@ void GMLPropertyDefn::AnalysePropertyValue( const char *pszValue )
 /* -------------------------------------------------------------------- */
     int bIsReal = FALSE;
     
+    /* Saved to calculate length of string property value. */
+    const char* pszTmp = pszValue;
 
     for(; *pszValue != '\0'; pszValue++ )
     {
@@ -120,11 +108,21 @@ void GMLPropertyDefn::AnalysePropertyValue( const char *pszValue )
         else 
         {
             m_eType = GMLPT_String;
-            return;
+
+            /* Skip forward to calculate property width. */
+            break;
         }
     }
 
-    if( m_eType == GMLPT_Untyped || m_eType == GMLPT_Integer )
+    if( m_eType == GMLPT_String )
+    {
+        /* grow the Width to the length of the string passed in */
+        int nWidth;
+        nWidth = strlen(pszTmp);
+        if ( m_nWidth < nWidth ) 
+            SetWidth( nWidth );
+    }
+    else if( m_eType == GMLPT_Untyped || m_eType == GMLPT_Integer )
     {
         if( bIsReal )
             m_eType = GMLPT_Real;
