@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrgmldatasource.cpp,v 1.23 2005/12/12 21:33:07 fwarmerdam Exp $
+ * $Id: ogrgmldatasource.cpp 11193 2007-04-03 22:29:41Z mloskot $
  *
  * Project:  OGR
  * Purpose:  Implements OGRGMLDataSource class.
@@ -25,87 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrgmldatasource.cpp,v $
- * Revision 1.23  2005/12/12 21:33:07  fwarmerdam
- * remove ogr: prefix from field names: bug 1016
- *
- * Revision 1.22  2005/07/05 19:18:58  fwarmerdam
- * Use www.w3.org not www.w3c.org.
- *
- * Revision 1.21  2005/06/30 02:16:41  fwarmerdam
- * more efforts to produce valid GML
- *
- * Revision 1.20  2005/06/29 16:08:57  fwarmerdam
- * Fixed gml:geometryPropertyType to be gml:GeometryPropertyType as per
- * suggestion from Tom Kralidis.
- *
- * Revision 1.19  2005/05/04 19:34:07  fwarmerdam
- * delete reader in datasource destructor, not layer
- *
- * Revision 1.18  2005/04/06 13:38:33  fwarmerdam
- * Initialize nSchemaStart.
- *
- * Revision 1.17  2005/01/27 16:34:56  fwarmerdam
- * Fixed gml test.  Don't try to read any old XML file!
- *
- * Revision 1.16  2005/01/27 04:06:32  fwarmerdam
- * added 3L0 XSD support
- *
- * Revision 1.15  2004/01/29 15:30:40  warmerda
- * cleanup layer and field names
- *
- * Revision 1.14  2004/01/15 20:53:16  warmerda
- * Ensure that ogr namespace is defined.
- *
- * Revision 1.13  2003/05/21 03:48:35  warmerda
- * Expand tabs
- *
- * Revision 1.12  2003/04/03 16:23:49  warmerda
- * Added support for XSISCHEMA creation option which may be INTERNAL, EXTERNAL
- * or OFF.  EXTERNAL (write an associated .xsd file) is the default.
- *
- * Revision 1.11  2003/03/13 14:40:00  warmerda
- * added missing xs:sequence
- *
- * Revision 1.10  2003/03/11 01:26:35  warmerda
- * Fixed redeclared variable.
- *
- * Revision 1.9  2003/03/07 14:53:21  warmerda
- * implement preliminary BXFS write support
- *
- * Revision 1.8  2003/01/22 17:20:24  warmerda
- * fixed xsi:schemaLocation output
- *
- * Revision 1.7  2003/01/17 20:40:06  warmerda
- * added bounding rectangle support and XSISCHEMAURI option
- *
- * Revision 1.6  2003/01/07 22:30:18  warmerda
- * Added special support for output filename "stdout".
- *
- * Revision 1.5  2002/08/15 15:26:12  warmerda
- * Properly close file if test open fails.
- *
- * Revision 1.4  2002/03/06 20:08:47  warmerda
- * save/use .gfs file by default
- *
- * Revision 1.3  2002/01/25 20:54:23  warmerda
- * fixed last fix
- *
- * Revision 1.2  2002/01/25 20:46:26  warmerda
- * recover if CreateGMLReader() fails
- *
- * Revision 1.1  2002/01/25 20:37:02  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_gml.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogrgmldatasource.cpp,v 1.23 2005/12/12 21:33:07 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrgmldatasource.cpp 11193 2007-04-03 22:29:41Z mloskot $");
 
 /************************************************************************/
 /*                         OGRGMLDataSource()                         */
@@ -206,8 +132,28 @@ int OGRGMLDataSource::Open( const char * pszNewName, int bTestOpen )
         VSIFRead( szHeader, 1, sizeof(szHeader), fp );
         szHeader[sizeof(szHeader)-1] = '\0';
 
-        if( szHeader[0] != '<' 
-            || strstr(szHeader,"opengis.net/gml") == NULL )
+/* -------------------------------------------------------------------- */
+/*      Check for a UTF-8 BOM and skip if found                         */
+/*                                                                      */
+/*      TODO: BOM is variable-lenght parameter and depends on encoding. */
+/*            Add BOM detection for other encodings.                    */
+/* -------------------------------------------------------------------- */
+
+        // Used to skip to actual beginning of XML data
+        char* szPtr = szHeader;
+
+        if( ( (unsigned char)szHeader[0] == 0xEF )
+            && ( (unsigned char)szHeader[1] == 0xBB )
+            && ( (unsigned char)szHeader[2] == 0xBF) )
+        {
+            szPtr += 3;
+        }
+
+/* -------------------------------------------------------------------- */
+/*      Here, we expect the opening chevrons of GML tree root element   */
+/* -------------------------------------------------------------------- */
+        if( szPtr[0] != '<' 
+            || strstr(szPtr,"opengis.net/gml") == NULL )
         {
             VSIFClose( fp );
             return FALSE;
@@ -366,6 +312,9 @@ OGRGMLLayer *OGRGMLDataSource::TranslateGMLSchema( GMLFeatureClass *poClass )
         OGRFieldDefn oField( poProperty->GetName(), eFType );
         if ( EQUALN(oField.GetNameRef(), "ogr:", 4) )
           oField.SetName(poProperty->GetName()+4);
+        if( poProperty->GetWidth() > 0 )
+            oField.SetWidth( poProperty->GetWidth() );
+
         poLayer->GetLayerDefn()->AddFieldDefn( &oField );
     }
 
@@ -433,7 +382,7 @@ int OGRGMLDataSource::Create( const char *pszFilename,
 
         VSIFPrintf( fpOutput, 
               "     xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"\n"
-              "     xsi:schemaLocation=\"http://ogr.maptools.org/ %s\"\n", 
+              "     xsi:schemaLocation=\"http://ogr.maptools.org/%s\"\n", 
                     CPLResetExtension( pszBasename, "xsd" ) );
         CPLFree( pszBasename );
     }
