@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrgrasslayer.cpp,v 1.2 2005/09/21 00:59:36 fwarmerdam Exp $
+ * $Id: ogrgrasslayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRGRASSLayer class.
@@ -25,23 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrgrasslayer.cpp,v $
- * Revision 1.2  2005/09/21 00:59:36  fwarmerdam
- * fixup OGRFeatureDefn and OGRSpatialReference refcount handling
- *
- * Revision 1.1  2005/08/05 15:32:43  fwarmerdam
- * New
- *
- *
- */
+ ****************************************************************************/
 
 #include <signal.h>
 #include "ogrgrass.h"
 #include "cpl_conv.h"
 
-CPL_CVSID("$Id: ogrgrasslayer.cpp,v 1.2 2005/09/21 00:59:36 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrgrasslayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                           OGRGRASSLayer()                            */
@@ -157,7 +147,7 @@ OGRGRASSLayer::OGRGRASSLayer( int layerIndex,  struct Map_info * map )
 			    ogrFtype = OFTString;
 			    break; 
 			 case DB_C_TYPE_DATETIME:
-			    ogrFtype = OFTString;
+			    ogrFtype = OFTDateTime;
 			    break; 
 		    }
 
@@ -299,6 +289,9 @@ bool OGRGRASSLayer::StopDbDriver()
     // we have to use kill
     CPLDebug ( "GRASS", "driver PID = %d", poDriver->pid ); 
 
+#if defined(_WIN32) || defined(__WIN32__)
+    db_close_database_shutdown_driver ( poDriver );
+#else
     if ( kill (poDriver->pid, SIGINT) != 0 ) 
     {
 	if ( kill (poDriver->pid, SIGKILL) != 0 ) 
@@ -307,7 +300,7 @@ bool OGRGRASSLayer::StopDbDriver()
 		      "driver pid = %d", poDriver->pid );
 	}
     }
-    //db_close_database_shutdown_driver ( poDriver );
+#endif
 	    
     bCursorOpened = false;
     
