@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ili2readerp.h 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: ili2readerp.h 11557 2007-05-18 18:11:25Z pka $
  *
  * Project:  Interlis 2 Reader
  * Purpose:  Private Declarations for Reader code.
@@ -50,6 +50,10 @@
 #include <dom/DOM.hpp>
 #include <util/XMLString.hpp>
 
+#if _XERCES_VERSION >= 30000
+# include <sax2/Attributes.hpp>
+#endif
+
 #ifdef XERCES_CPP_NAMESPACE_USE
 XERCES_CPP_NAMESPACE_USE
 #endif
