@@ -33,14 +33,16 @@
 #include <vector>
 #include <stack>
 #include <map>
-#include <xercesc/util/XMLString.hpp>
-#include <xercesc/framework/XMLBuffer.hpp>
-#include <xercesc/util/StringPool.hpp>
-#include <xercesc/framework/XMLPScanToken.hpp>
+#include <xercesc/sax/Locator.hpp>
+#include <xercesc/sax2/Attributes.hpp>
 #include <xercesc/sax2/SAX2XMLReader.hpp>
 #include <xercesc/sax2/DefaultHandler.hpp>
+#include <xercesc/framework/XMLBuffer.hpp>
 #include <xercesc/framework/XMLFormatter.hpp>
+#include <xercesc/framework/XMLPScanToken.hpp>
 #include <xercesc/framework/LocalFileFormatTarget.hpp>
+#include <xercesc/util/XMLString.hpp>
+#include <xercesc/util/StringPool.hpp>
 #include <xercesc/util/TransService.hpp>
 #include <iom/iom.h>
 #ifdef _MSC_VER
