@@ -23,11 +23,13 @@
  * @{
  */
 
-#include <assert.h>
-#include <string.h>
+#include <cassert>
+#include <cstring>
 
 #include <xercesc/util/XMLString.hpp>
+#include <xercesc/sax/Locator.hpp>
 #include <xercesc/sax2/XMLReaderFactory.hpp>
+#include <xercesc/sax2/Attributes.hpp>
 
 #include <iom/iom_p.h>
 
