@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrili1layer.cpp 11178 2007-04-02 20:44:35Z warmerdam $
+ * $Id: ogrili1layer.cpp 11557 2007-05-18 18:11:25Z pka $
  *
  * Project:  Interlis 1 Translator
  * Purpose:  Implements OGRILI1Layer class.
@@ -31,7 +31,7 @@
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogrili1layer.cpp 11178 2007-04-02 20:44:35Z warmerdam $");
+CPL_CVSID("$Id: ogrili1layer.cpp 11557 2007-05-18 18:11:25Z pka $");
 
 /************************************************************************/
 /*                           OGRILI1Layer()                              */
@@ -119,13 +119,44 @@ void OGRILI1Layer::ResetReading(){
 /************************************************************************/
 
 OGRFeature *OGRILI1Layer::GetNextFeature() {
+    OGRFeature *poFeature = GetNextFeatureRef();
+    return poFeature ? poFeature->Clone() : NULL;
+}
+
+OGRFeature *OGRILI1Layer::GetNextFeatureRef() {
+    OGRFeature *poFeature = NULL;
     if (nFeatureIdx < nFeatures)
     {
-      return papoFeatures[nFeatureIdx++]->Clone();
+      poFeature = papoFeatures[nFeatureIdx++];
+      //apply filters
+      if( (m_poFilterGeom == NULL
+           || FilterGeometry( poFeature->GetGeometryRef() ) )
+          && (m_poAttrQuery == NULL
+              || m_poAttrQuery->Evaluate( poFeature )) )
+          return poFeature;
     }
     return NULL;
 }
 
+/************************************************************************/
+/*                             GetFeatureRef()                          */
+/************************************************************************/
+
+OGRFeature *OGRILI1Layer::GetFeatureRef( long nFID )
+
+{
+    OGRFeature *poFeature;
+
+    ResetReading();
+    while( (poFeature = GetNextFeatureRef()) != NULL )
+    {
+        if( poFeature->GetFID() == nFID )
+            return poFeature;
+    }
+
+    return NULL;
+}
+
 /************************************************************************/
 /*                          GetFeatureCount()                           */
 /************************************************************************/
@@ -139,7 +170,7 @@ int OGRILI1Layer::GetFeatureCount( int bForce ) {
 /************************************************************************/
 
 OGRErr OGRILI1Layer::GetExtent(OGREnvelope *psExtent, int bForce ) {
-  return OGRERR_NONE;
+  return OGRLayer::GetExtent( psExtent, bForce );
 }
 
 static char* d2str(double val)
