@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrili2datasource.cpp,v 1.7 2006/04/27 16:37:19 pka Exp $
+ * $Id: ogrili2datasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Interlis 2 Translator
  * Purpose:  Implements OGRILI2DataSource class.
@@ -25,35 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrili2datasource.cpp,v $
- * Revision 1.7  2006/04/27 16:37:19  pka
- * Ili2 model reader fix
- * Support for multiple Ili2 models
- *
- * Revision 1.6  2006/04/24 16:49:48  pka
- * Fixed polyline feature with coordinate attribute
- * Float support for ARC_DEGREES
- *
- * Revision 1.5  2006/03/28 16:07:14  pka
- * Optional model file for Interlis 2 reader
- *
- * Revision 1.4  2005/12/20 16:47:04  pka
- * Interlis 1 output without model
- *
- * Revision 1.3  2005/12/19 17:33:21  pka
- * Interlis 1: Support for 100 columns (unlimited, if model given)
- * Interlis 1: Fixes for output
- * Interlis: Examples in driver documentation
- *
- * Revision 1.2  2005/08/06 22:21:53  pka
- * Area polygonizer added
- *
- * Revision 1.1  2005/07/08 22:10:57  pka
- * Initial import of OGR Interlis driver
- *
- */
+ ****************************************************************************/
 
 #include "ogr_ili2.h"
 #include "cpl_conv.h"
@@ -65,7 +37,7 @@
 using namespace std;
 
 
-CPL_CVSID("$Id: ogrili2datasource.cpp,v 1.7 2006/04/27 16:37:19 pka Exp $");
+CPL_CVSID("$Id: ogrili2datasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                         OGRILI2DataSource()                         */
@@ -120,6 +92,8 @@ int OGRILI2DataSource::Open( const char * pszNewName, int bTestOpen )
     if( CSLCount(filenames) > 1 )
         modelFilenames = &filenames[1];
 
+    CSLDestroy( filenames );
+
 /* -------------------------------------------------------------------- */
 /*      Open the source file.                                           */
 /* -------------------------------------------------------------------- */
@@ -171,8 +145,6 @@ int OGRILI2DataSource::Open( const char * pszNewName, int bTestOpen )
     if (modelFilenames)
         poReader->ReadModel( modelFilenames );
 
-    CSLDestroy( filenames );
-
     if( getenv( "ARC_DEGREES" ) != NULL ) {
       //No better way to pass arguments to the reader (it could even be an -lco arg)
       poReader->SetArcDegrees( atof( getenv("ARC_DEGREES") ) );
