@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrmemdatasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: ogrmemdatasource.cpp 11667 2007-06-18 17:39:49Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRMemDataSource class.
@@ -31,7 +31,7 @@
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogrmemdatasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: ogrmemdatasource.cpp 11667 2007-06-18 17:39:49Z warmerdam $");
 
 /************************************************************************/
 /*                          OGRMemDataSource()                          */
@@ -41,7 +41,7 @@ OGRMemDataSource::OGRMemDataSource( const char *pszFilename,
                                     char **papszOptions)
 
 {
-    pszName = NULL;
+    pszName = CPLStrdup(pszFilename);
     papoLayers = NULL;
     nLayers = 0;
 }
