@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrmemlayer.cpp,v 1.6 2005/09/21 00:59:36 fwarmerdam Exp $
+ * $Id: ogrmemlayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRMemLayer class.
@@ -25,33 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrmemlayer.cpp,v $
- * Revision 1.6  2005/09/21 00:59:36  fwarmerdam
- * fixup OGRFeatureDefn and OGRSpatialReference refcount handling
- *
- * Revision 1.5  2005/02/22 12:54:34  fwarmerdam
- * use OGRLayer base spatial filter support
- *
- * Revision 1.4  2005/02/02 20:12:41  fwarmerdam
- * added SetNextByIndex support
- *
- * Revision 1.3  2003/10/09 15:30:23  warmerda
- * added OGRLayer::DeleteFeature() support
- *
- * Revision 1.2  2003/04/08 20:58:16  warmerda
- * added support for adding fields when existing features exist
- *
- * Revision 1.1  2003/04/08 19:32:47  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_mem.h"
 #include "cpl_conv.h"
 
-CPL_CVSID("$Id: ogrmemlayer.cpp,v 1.6 2005/09/21 00:59:36 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrmemlayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                            OGRMemLayer()                             */
