@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: mitab_feature_mif.cpp,v 1.26 2005/07/14 16:15:05 jlacroix Exp $
+ * $Id: mitab_feature_mif.cpp,v 1.31 2006/01/27 13:44:44 fwarmerdam Exp $
  *
  * Name:     mitab_feature.cpp
  * Project:  MapInfo TAB Read/Write library
@@ -31,6 +31,24 @@
  **********************************************************************
  *
  * $Log: mitab_feature_mif.cpp,v $
+ * Revision 1.31  2006/01/27 13:44:44  fwarmerdam
+ * fixed Mills.mif reading, crash at file end
+ *
+ * Revision 1.30  2006/01/26 21:26:36  fwarmerdam
+ * fixed bug with multi character delimeters in .mid file
+ *
+ * Revision 1.29  2005/10/04 19:36:10  dmorissette
+ * Added support for reading collections from MIF files (bug 1126)
+ *
+ * Revision 1.28  2005/10/04 15:44:31  dmorissette
+ * First round of support for Collection objects. Currently supports reading
+ * from .TAB/.MAP and writing to .MIF. Still lacks symbol support and write
+ * support. (Based in part on patch and docs from Jim Hope, bug 1126)
+ *
+ * Revision 1.27  2005/10/04 15:35:52  dmorissette
+ * Fixed an instance of hardcoded delimiter (",") in WriteRecordToMIDFile()
+ * (patch by KB Kieron, bug 1126)
+ *
  * Revision 1.26  2005/07/14 16:15:05  jlacroix
  * \n and \ are now unescaped internally.
  *
@@ -130,6 +148,55 @@
  *                      class TABFeature
  *====================================================================*/
 
+/************************************************************************/
+/*                            MIDTokenize()                             */
+/*                                                                      */
+/*      We implement a special tokenize function so we can handle       */
+/*      multibyte delimeters (ie. MITAB bug 1266).                      */
+/*                                                                      */
+/*      http://bugzilla.maptools.org/show_bug.cgi?id=1266               */
+/************************************************************************/
+static char **MIDTokenize( const char *pszLine, const char *pszDelim )
+
+{
+    char **papszResult = NULL;
+    int iChar, iTokenChar = 0, bInQuotes = FALSE;
+    char *pszToken = (char *) CPLMalloc(strlen(pszLine)+1);
+    int nDelimLen = strlen(pszDelim);
+
+    for( iChar = 0; pszLine[iChar] != '\0'; iChar++ )
+    {
+        if( bInQuotes && pszLine[iChar] == '\\' && pszLine[iChar+1] == '"' )
+        {
+            pszToken[iTokenChar++] = '"';
+            iChar++;
+        }
+        else if( pszLine[iChar] == '"' )
+        {
+            bInQuotes = !bInQuotes;
+        }
+        else if( !bInQuotes && strncmp(pszLine+iChar,pszDelim,nDelimLen) == 0 )
+        {
+            pszToken[iTokenChar++] = '\0';
+            papszResult = CSLAddString( papszResult, pszToken );
+            
+            iChar += strlen(pszDelim) - 1;
+            iTokenChar = 0;
+        }
+        else
+        {
+            pszToken[iTokenChar++] = pszLine[iChar];
+        }
+    }
+
+    pszToken[iTokenChar++] = '\0';
+    papszResult = CSLAddString( papszResult, pszToken );
+
+    CPLFree( pszToken );
+
+    return papszResult;
+}
+
 /**********************************************************************
  *                   TABFeature::ReadRecordFromMIDFile()
  *
@@ -149,8 +216,14 @@ int TABFeature::ReadRecordFromMIDFile(MIDDATAFile *fp)
     
     pszLine = fp->GetLastLine();
 
-    papszToken = CSLTokenizeStringComplex(pszLine,
-                                          fp->GetDelimiter(),TRUE,TRUE); 
+    if (pszLine == NULL)
+    {
+        CPLError(CE_Failure, CPLE_FileIO,
+               "Unexpected EOF while reading attribute record from MID file.");
+        return -1;
+    }
+
+    papszToken = MIDTokenize( pszLine, fp->GetDelimiter() );
 
     // Ensure that a blank line in a mid file is treated as one field 
     // containing an empty string.
@@ -194,12 +267,14 @@ int TABFeature::WriteRecordToMIDFile(MIDDATAFile *fp)
 
     CPLAssert(fp);
     
+    const char *delimiter = fp->GetDelimiter();
+
     numFields = GetFieldCount();
 
     for(iField=0; iField<numFields; iField++)
     {
         if (iField != 0)
-          fp->WriteLine(",");
+          fp->WriteLine(delimiter);
         poFDefn = GetFieldDefnRef( iField );
 
         switch(poFDefn->GetType())
@@ -296,8 +371,9 @@ int TABPoint::ReadGeometryFromMIFFile(MIDDATAFile *fp)
 
     // Read optional SYMBOL line...
     pszLine = fp->GetLastLine();
-    papszToken = CSLTokenizeStringComplex(pszLine," ,()\t",
-                                          TRUE,FALSE);
+    if( pszLine != NULL )
+        papszToken = CSLTokenizeStringComplex(pszLine," ,()\t",
+                                              TRUE,FALSE);
     if (CSLCount(papszToken) == 4 && EQUAL(papszToken[0], "SYMBOL") )
     {
         SetSymbolNo(atoi(papszToken[1]));
@@ -1973,6 +2049,164 @@ int TABMultiPoint::WriteGeometryToMIFFile(MIDDATAFile *fp)
 }
 
 
+/**********************************************************************
+ *
+ **********************************************************************/
+int TABCollection::ReadGeometryFromMIFFile(MIDDATAFile *fp)
+{
+    char                **papszToken;
+    const char          *pszLine;
+    int                 numParts, i;
+    OGREnvelope         sEnvelope;
+
+    /*-----------------------------------------------------------------
+     * Fetch number of parts in "COLLECTION %d" line
+     *----------------------------------------------------------------*/
+    papszToken = CSLTokenizeString2(fp->GetLastLine(), 
+                                    " \t", CSLT_HONOURSTRINGS);
+     
+    if (CSLCount(papszToken) !=2)
+    {
+        CSLDestroy(papszToken);
+        return -1;
+    }
+    
+    numParts = atoi(papszToken[1]);
+    CSLDestroy(papszToken);
+    papszToken = NULL;
+
+    // Make sure collection is empty
+    EmptyCollection();
+
+    pszLine = fp->GetLine();
+
+    /*-----------------------------------------------------------------
+     * Read each part and add them to the feature
+     *----------------------------------------------------------------*/
+    for (i=0; i < numParts; i++)
+    {
+        if (pszLine == NULL)
+        {
+            CPLError(CE_Failure, CPLE_FileIO,
+                  "Unexpected EOF while reading TABCollection from MIF file.");
+            return -1;
+         }
+
+        while(*pszLine == ' ' || *pszLine == '\t')
+            pszLine++;  // skip leading spaces
+
+        if (*pszLine == '\0')
+            continue;  // Skip blank lines
+
+        if (EQUALN(pszLine,"REGION",6))
+        {
+            m_poRegion = new TABRegion(GetDefnRef());
+            if (m_poRegion->ReadGeometryFromMIFFile(fp) != 0)
+            {
+                CPLError(CE_Failure, CPLE_NotSupported,
+                         "TABCollection: Error reading REGION part.");
+                delete m_poRegion;
+                m_poRegion = NULL;
+                return -1;
+            }
+        }  
+        else if (EQUALN(pszLine,"LINE",4) ||
+                 EQUALN(pszLine,"PLINE",5))
+        {
+            m_poPline = new TABPolyline(GetDefnRef());
+            if (m_poPline->ReadGeometryFromMIFFile(fp) != 0)
+            {
+                CPLError(CE_Failure, CPLE_NotSupported,
+                         "TABCollection: Error reading PLINE part.");
+                delete m_poPline;
+                m_poPline = NULL;
+                return -1;
+            }
+        }
+        else if (EQUALN(pszLine,"MULTIPOINT",10))
+        {
+            m_poMpoint = new TABMultiPoint(GetDefnRef());
+            if (m_poMpoint->ReadGeometryFromMIFFile(fp) != 0)
+            {
+                CPLError(CE_Failure, CPLE_NotSupported,
+                         "TABCollection: Error reading MULTIPOINT part.");
+                delete m_poMpoint;
+                m_poMpoint = NULL;
+                return -1;
+            }
+        }
+        else
+        {
+            CPLError(CE_Failure, CPLE_FileIO,
+                     "Reading TABCollection from MIF failed, expecting one "
+                     "of REGION, PLINE or MULTIPOINT, got: '%s'",
+                     pszLine);
+            return -1;
+        }
+
+        pszLine = fp->GetLastLine();
+    }
+
+    /*-----------------------------------------------------------------
+     * Set the main OGRFeature Geometry 
+     * (this is actually duplicating geometries from each member)
+     *----------------------------------------------------------------*/
+    // use addGeometry() rather than addGeometryDirectly() as this clones
+    // the added geometry so won't leave dangling ptrs when the above features
+    // are deleted
+
+    OGRGeometryCollection *poGeomColl = new OGRGeometryCollection();
+    if(m_poRegion && m_poRegion->GetGeometryRef() != NULL)
+        poGeomColl->addGeometry(m_poRegion->GetGeometryRef());
+    
+    if(m_poPline && m_poPline->GetGeometryRef() != NULL)
+        poGeomColl->addGeometry(m_poPline->GetGeometryRef());
+
+    if(m_poMpoint && m_poMpoint->GetGeometryRef() != NULL)
+        poGeomColl->addGeometry(m_poMpoint->GetGeometryRef());
+
+    this->SetGeometryDirectly(poGeomColl);
+
+    poGeomColl->getEnvelope(&sEnvelope);
+    SetMBR(sEnvelope.MinX, sEnvelope.MinY,
+           sEnvelope.MaxX, sEnvelope.MaxY);
+
+    return 0;
+}
+
+/**********************************************************************
+ *
+ **********************************************************************/
+int TABCollection::WriteGeometryToMIFFile(MIDDATAFile *fp)
+{
+    int numParts = 0;
+    if (m_poRegion)     numParts++;
+    if (m_poPline)      numParts++;
+    if (m_poMpoint)     numParts++;
+
+    fp->WriteLine("COLLECTION %d\n", numParts);
+
+    if (m_poRegion)
+    {
+        if (m_poRegion->WriteGeometryToMIFFile(fp) != 0)
+            return -1;
+    }
+
+    if (m_poPline)
+    {
+        if (m_poPline->WriteGeometryToMIFFile(fp) != 0)
+            return -1;
+    }
+
+    if (m_poMpoint)
+    {
+        if (m_poMpoint->WriteGeometryToMIFFile(fp) != 0)
+            return -1;
+    }
+
+    return 0;
+}
+
 /**********************************************************************
  *
  **********************************************************************/
