@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogr_mysql.h,v 1.20 2006/02/13 04:15:04 hobu Exp $
+ * $Id: ogr_mysql.h 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Declarations for MySQL OGR Driver Classes.
@@ -26,75 +26,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogr_mysql.h,v $
- * Revision 1.20  2006/02/13 04:15:04  hobu
- * major formatting cleanup
- * Added myself as an author
- *
- * Revision 1.19  2006/02/13 01:44:25  hobu
- * Define an Initialize() method for TableLayer and
- * make sure to use it when we after we construct
- * a new one.  This is to prevent ResetReading from
- * causing segfault in the case where we were given
- * an invalid table name
- *
- * Revision 1.17  2006/02/12 06:17:25  hobu
- * Implement DeleteFeature
- *
- * Revision 1.16  2006/02/12 00:40:56  hobu
- * Implement a somewhat working CreateFeature
- *
- * Revision 1.15  2006/02/11 18:07:26  hobu
- * Moved FetchSRS to happen via the Datasource like PG
- * rather than in the TableLayer and ResultLayer as before
- * Implemented CreateField and CreateLayer
- *
- * Revision 1.14  2006/02/10 04:58:37  hobu
- * InitializeMetadataTables implementation
- *
- * Revision 1.13  2006/02/09 05:54:52  hobu
- * start on CreateLayer
- *
- * Revision 1.12  2006/02/06 23:06:45  fwarmerdam
- * undef mysql's bool
- *
- * Revision 1.11  2006/02/01 01:40:09  hobu
- * separate fetching of SRID
- *
- * Revision 1.10  2006/01/31 06:16:57  hobu
- * move SRS fetching to mysqllayer.cpp
- *
- * Revision 1.9  2006/01/31 05:35:09  hobu
- * move SRS fetching to mysqllayer.cpp
- *
- * Revision 1.8  2006/01/30 03:51:18  hobu
- * some god-awful hackery, but we can do a good job of reading 
- * field definitions from a select query as well as get a spatial reference.
- *
- * Revision 1.7  2006/01/27 01:27:48  fwarmerdam
- * added GetFIDColumn and GetGeometryColumn support
- *
- * Revision 1.6  2006/01/16 16:06:48  hobu
- * Handle geometry column
- *
- * Revision 1.5  2005/08/30 23:53:16  fwarmerdam
- * implement binary field support
- *
- * Revision 1.4  2005/02/22 12:54:27  fwarmerdam
- * use OGRLayer base spatial filter support
- *
- * Revision 1.3  2004/10/12 16:59:31  fwarmerdam
- * rearrange include files for win32
- *
- * Revision 1.2  2004/10/08 20:49:01  fwarmerdam
- * enable ExecuteSQL
- *
- * Revision 1.1  2004/10/07 20:57:50  fwarmerdam
- * New
- *
- */
+ ****************************************************************************/
 
 #ifndef _OGR_MYSQL_H_INCLUDED
 #define _OGR_MYSQL_H_INLLUDED
@@ -325,10 +257,8 @@ class OGRMySQLDriver : public OGRSFDriver
                 
     const char *GetName();
     OGRDataSource *Open( const char *, int );
-#ifdef notdef
     virtual OGRDataSource *CreateDataSource( const char *pszName,
                                              char ** = NULL );
-#endif    
     int                 TestCapability( const char * );
 };
 
