@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrmysqlresultlayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: ogrmysqlresultlayer.cpp 11523 2007-05-15 14:38:49Z mloskot $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRMySQLResultLayer class.
@@ -31,7 +31,7 @@
 #include "cpl_conv.h"
 #include "ogr_mysql.h"
 
-CPL_CVSID("$Id: ogrmysqlresultlayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: ogrmysqlresultlayer.cpp 11523 2007-05-15 14:38:49Z mloskot $");
 
 /************************************************************************/
 /*                        OGRMySQLResultLayer()                         */
@@ -158,9 +158,12 @@ OGRFeatureDefn *OGRMySQLResultLayer::ReadResultDefinition()
             oField.SetWidth((int)psMSField->length);
             poDefn->AddFieldDefn( &oField );
             break;
-            
+
+          case FIELD_TYPE_TINY_BLOB:
+          case FIELD_TYPE_MEDIUM_BLOB:
+          case FIELD_TYPE_LONG_BLOB:
           case FIELD_TYPE_BLOB:
-            oField.SetType( OFTString );
+            oField.SetType( OFTBinary );
             oField.SetWidth((int)psMSField->max_length);
             poDefn->AddFieldDefn( &oField );
             break;
