@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrmysqltablelayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: ogrmysqltablelayer.cpp 12200 2007-09-19 13:27:52Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRMySQLTableLayer class.
@@ -32,7 +32,7 @@
 #include "cpl_string.h"
 #include "ogr_mysql.h"
 
-CPL_CVSID("$Id: ogrmysqltablelayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: ogrmysqltablelayer.cpp 12200 2007-09-19 13:27:52Z warmerdam $");
 
 /************************************************************************/
 /*                         OGRMySQLTableLayer()                         */
@@ -631,6 +631,7 @@ OGRErr OGRMySQLTableLayer::DeleteFeature( long nFID )
 /* -------------------------------------------------------------------- */
 /*      Execute the delete.                                             */
 /* -------------------------------------------------------------------- */
+    poDS->InterruptLongResult();
     if( mysql_query(poDS->GetConn(), osCommand.c_str() ) ){   
         poDS->ReportError(  osCommand.c_str() );
         return OGRERR_FAILURE;   
@@ -704,6 +705,7 @@ OGRErr OGRMySQLTableLayer::CreateFeature( OGRFeature *poFeature )
             OGRGeometry *poGeom = (OGRGeometry *) poFeature->GetGeometryRef();
             
             poGeom->closeRings();
+            poGeom->flattenTo2D();
             poGeom->exportToWkt( &pszWKT );
         }
 
@@ -732,9 +734,6 @@ OGRErr OGRMySQLTableLayer::CreateFeature( OGRFeature *poFeature )
 
     for( i = 0; i < poFeatureDefn->GetFieldCount(); i++ )
     {
-        const char *pszStrValue = poFeature->GetFieldAsString(i);
-        char *pszNeedToFree = NULL;
-
         if( !poFeature->IsFieldSet( i ) )
             continue;
 
@@ -743,8 +742,11 @@ OGRErr OGRMySQLTableLayer::CreateFeature( OGRFeature *poFeature )
         else
             bNeedComma = TRUE;
 
+        const char *pszStrValue = poFeature->GetFieldAsString(i);
+
         if( poFeatureDefn->GetFieldDefn(i)->GetType() != OFTInteger
-                 && poFeatureDefn->GetFieldDefn(i)->GetType() != OFTReal )
+                 && poFeatureDefn->GetFieldDefn(i)->GetType() != OFTReal
+                 && poFeatureDefn->GetFieldDefn(i)->GetType() != OFTBinary )
         {
             int         iChar;
 
@@ -776,13 +778,23 @@ OGRErr OGRMySQLTableLayer::CreateFeature( OGRFeature *poFeature )
 
             osCommand += "'";
         }
+        else if( poFeatureDefn->GetFieldDefn(i)->GetType() == OFTBinary )
+        {
+            int binaryCount = 0;
+            GByte* binaryData = poFeature->GetFieldAsBinary(i, &binaryCount);
+            char* pszHexValue = CPLBinaryToHex( binaryCount, binaryData );
+
+            osCommand += "x'";
+            osCommand += pszHexValue;
+            osCommand += "'";
+
+            CPLFree( pszHexValue );
+        }
         else
         {
             osCommand += pszStrValue;
         }
 
-        if( pszNeedToFree )
-            CPLFree( pszNeedToFree );
     }
 
     osCommand += ")";
@@ -884,6 +896,11 @@ OGRErr OGRMySQLTableLayer::CreateField( OGRFieldDefn *poFieldIn, int bApproxOK )
         sprintf( szFieldType, "TIME" );
     }
 
+    else if( oField.GetType() == OFTBinary )
+    {
+        sprintf( szFieldType, "LONGBLOB" );
+    }
+
     else if( oField.GetType() == OFTString )
     {
         if( oField.GetWidth() == 0 || !bPreservePrecision )
