@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ntf_estlayers.cpp,v 1.21 2006/03/28 22:59:55 fwarmerdam Exp $
+ * $Id: ntf_estlayers.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  NTF Translator
  * Purpose:  NTFFileReader methods related to establishing the schemas
@@ -27,85 +27,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ntf_estlayers.cpp,v $
- * Revision 1.21  2006/03/28 22:59:55  fwarmerdam
- * updated contact info
- *
- * Revision 1.20  2005/09/21 00:59:55  fwarmerdam
- * fixup OGRFeatureDefn and OGRSpatialReference refcount handling
- *
- * Revision 1.19  2003/12/15 16:07:41  warmerda
- * Added CHG_TYPE for landline plus product
- *
- * Revision 1.18  2003/01/10 22:27:35  warmerda
- * Corrected width of CENSUS_CODE ... should be 7 according to
- * GREATER_LONDON_AUTHORITY.NTF.
- *
- * Revision 1.17  2003/01/07 16:46:28  warmerda
- * Added support for forming polygons by caching line geometries
- *
- * Revision 1.16  2002/11/17 05:16:49  warmerda
- * added meridian 2 support
- *
- * Revision 1.15  2002/02/06 15:19:36  warmerda
- * TEXT_CODE is 4 long, not 3
- *
- * Revision 1.14  2001/08/23 14:47:31  warmerda
- * Added support for adding an _LIST attribute to the OGRFeatures in
- * cases of GENERIC features for which an attribute appears more than
- * once per features.  This has occured with the SAMPE1250.NTF Irish
- * dataset which has multiple feature codes for some line features.
- *
- * Revision 1.13  2001/07/18 04:55:16  warmerda
- * added CPL_CSVID
- *
- * Revision 1.12  2001/01/19 20:31:12  warmerda
- * expand tabs
- *
- * Revision 1.11  2001/01/17 19:08:37  warmerda
- * added CODELIST support
- *
- * Revision 1.10  2000/12/23 05:10:35  warmerda
- * Segregate referenced collections in BL2000 collections into the COLL_ID_REFS field.
- * Improve error handling if MAX_LINKS exceeded.  Raise MAX_LINKS to 5000.
- *
- * Revision 1.9  2000/12/06 19:31:16  warmerda
- * added BL2000 support
- *
- * Revision 1.8  1999/10/03 03:01:21  warmerda
- * Up width of real fields derived from "Rn,m" formats by one to account for
- * the implicit decimal in NTF that is explicit in the length in OGR.
- *
- * Revision 1.7  1999/10/01 14:47:51  warmerda
- * major upgrade: generic, string feature codes, etc
- *
- * Revision 1.6  1999/09/14 01:34:36  warmerda
- * added scale support, and generation of TEXT_HT_GROUND
- *
- * Revision 1.5  1999/09/13 14:36:45  warmerda
- * Mark PROFILE_POINT and PROFILE_LINE as 3D features.
- *
- * Revision 1.4  1999/09/13 14:09:10  warmerda
- * added oscar comment, profile and landline chg_date
- *
- * Revision 1.3  1999/09/12 17:18:52  warmerda
- * Reorganized attributes for address point layers.  Fixed landline point
- * orient precision.
- *
- * Revision 1.2  1999/08/30 16:48:25  warmerda
- * Added several product types
- *
- * Revision 1.1  1999/08/28 03:13:35  warmerda
- * New
- */
+ ****************************************************************************/
 
 #include <stdarg.h>
 #include "ntf.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ntf_estlayers.cpp,v 1.21 2006/03/28 22:59:55 fwarmerdam Exp $");
+CPL_CVSID("$Id: ntf_estlayers.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 #define MAX_LINK        5000
 
