@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ntffilereader.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: ntffilereader.cpp 11590 2007-06-03 15:03:34Z warmerdam $
  *
  * Project:  NTF Translator
  * Purpose:  NTFFileReader class implementation.
@@ -33,7 +33,7 @@
 #include "cpl_string.h"
 #include "ogr_api.h"
 
-CPL_CVSID("$Id: ntffilereader.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: ntffilereader.cpp 11590 2007-06-03 15:03:34Z warmerdam $");
 
 static int DefaultNTFRecordGrouper( NTFFileReader *, NTFRecord **,
                                     NTFRecord * );
@@ -449,7 +449,7 @@ int NTFFileReader::Open( const char * pszFilenameIn )
         nProduct = NPC_LANDRANGER_DTM;
     else if( EQUALN(pszProduct,"L-F_PROFILE_DTM",15) )
         nProduct = NPC_LANDFORM_PROFILE_DTM;
-    else if( EQUALN(pszProduct,"NEXTMap Britian DTM",19) )
+    else if( EQUALN(pszProduct,"NEXTMap Britain DTM",19) )
         nProduct = NPC_LANDFORM_PROFILE_DTM; // Treat as landform
 
     if( poDS->GetOption("FORCE_GENERIC") != NULL
