@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ntfstroke.cpp,v 1.4 2004/11/17 19:30:15 fwarmerdam Exp $
+ * $Id: ntfstroke.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  NTF Translator
  * Purpose:  NTF Arc to polyline stroking code.  This code is really generic,
@@ -27,30 +27,14 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ntfstroke.cpp,v $
- * Revision 1.4  2004/11/17 19:30:15  fwarmerdam
- * further fixes to stroking 3pt arcs
- *
- * Revision 1.3  2004/09/13 20:20:03  fwarmerdam
- * Fixed bug in NTFStrokeArcToOGRGeometry_Angles which resulted in
- * wrong quadrant for angles (in some? cases) - Safe bug 11672.
- *
- * Revision 1.2  2001/08/28 20:50:03  warmerda
- * expand tabs
- *
- * Revision 1.1  2001/08/28 20:40:44  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include <stdarg.h>
 #include "ntf.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ntfstroke.cpp,v 1.4 2004/11/17 19:30:15 fwarmerdam Exp $");
+CPL_CVSID("$Id: ntfstroke.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 #ifndef PI
 #define PI  3.14159265358979323846
