@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrocidatasource.cpp,v 1.33 2006/01/30 19:25:09 fwarmerdam Exp $
+ * $Id: ogrocidatasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Oracle Spatial Driver
  * Purpose:  Implementation of the OGROCIDataSource class.
@@ -25,122 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrocidatasource.cpp,v $
- * Revision 1.33  2006/01/30 19:25:09  fwarmerdam
- * Fixed GetGeometryColumn() calls.
- *
- * Revision 1.32  2006/01/27 15:55:56  fwarmerdam
- * few fixes for GetGeom/FIDColumn support
- *
- * Revision 1.31  2006/01/27 15:47:36  fwarmerdam
- * preliminary Get{FID/Geometry}Column support
- *
- * Revision 1.30  2005/10/11 19:23:11  fwarmerdam
- * fixed bugin DeleteLayer
- *
- * Revision 1.29  2005/09/21 00:56:55  fwarmerdam
- * fixup OGRFeatureDefn and OGRSpatialReference refcount handling
- *
- * Revision 1.28  2005/08/18 14:45:22  fwarmerdam
- * Cleanup session on exit.
- *
- * Revision 1.27  2005/08/09 20:54:43  hobu
- * Allow CreateLayer to use the OCI_FID environment
- * variable if it set.  Also, throw a CPLDebug statement
- * out there if the layer wasn't found in the layer list
- * when deleting.
- *
- * Revision 1.26  2005/02/10 15:46:02  fwarmerdam
- * added GEOMETRY_NAME layer creation option
- *
- * Revision 1.25  2004/11/22 19:24:15  fwarmerdam
- * added support for a list of tables in the datasource name
- *
- * Revision 1.24  2004/11/09 02:49:12  fwarmerdam
- * Don't add user_sdo_geom_metadata record till finalize (layer load complete)
- * time as that is when we have all the diminfo details.  Inserts of metadata
- * records with NULL diminfos fails in Oracle 10 due to new constraints.
- *
- * Revision 1.23  2004/07/09 07:07:39  warmerda
- * Added OGRSQL dialect support.
- *
- * Revision 1.22  2003/09/18 14:45:47  warmerda
- * return -1 from FetchSRSId() for SRS if not GEOGCS or PROJCS
- *
- * Revision 1.21  2003/09/13 04:52:38  warmerda
- * Added logic to mapping some EPSG codes to and from Oracle codes by table.
- * Added logic to recognise an Oracle authority in WKT as a direct mapping
- * request.  Return authority information from MDSYS.CS_SRS where available.
- *
- * Revision 1.20  2003/05/21 03:54:01  warmerda
- * expand tabs
- *
- * Revision 1.19  2003/04/22 19:37:50  warmerda
- * Added sync to disk
- *
- * Revision 1.18  2003/04/04 06:18:08  warmerda
- * first pass implementation of loader support
- *
- * Revision 1.17  2003/03/18 18:34:17  warmerda
- * added reason code 13349
- *
- * Revision 1.16  2003/02/06 21:14:43  warmerda
- * cleanup some memory leaks
- *
- * Revision 1.15  2003/01/15 06:10:04  warmerda
- * Added logic to hack angular unit name to "Decimal Degree".
- *
- * Revision 1.14  2003/01/15 05:35:32  warmerda
- * allow override of SRID, pass to table constructor
- *
- * Revision 1.13  2003/01/14 22:15:13  warmerda
- * added pseudo-sql commands DELLAYER and VALLAYER
- *
- * Revision 1.12  2003/01/14 15:09:44  warmerda
- * set layer creation options on OGROCITableLayer
- *
- * Revision 1.11  2003/01/13 13:49:43  warmerda
- * add multi-user table support (ALL_SDO_GEOM_METADATA)
- *
- * Revision 1.10  2003/01/10 22:31:06  warmerda
- * use OGROCISession::CleanName() to fixup names
- *
- * Revision 1.9  2003/01/10 19:30:14  warmerda
- * Another related initialization fix.
- *
- * Revision 1.8  2003/01/10 16:40:33  warmerda
- * initialize SRS table
- *
- * Revision 1.7  2003/01/07 22:24:35  warmerda
- * added SRS support
- *
- * Revision 1.6  2003/01/06 17:58:20  warmerda
- * Fix FID support, add DIM creation keyword
- *
- * Revision 1.5  2003/01/02 21:48:52  warmerda
- * uppercaseify layer names when creating tables
- *
- * Revision 1.4  2002/12/29 19:43:59  warmerda
- * avoid some warnings
- *
- * Revision 1.3  2002/12/29 03:19:48  warmerda
- * fixed extraction of database name
- *
- * Revision 1.2  2002/12/28 04:38:36  warmerda
- * converted to unix file conventions
- *
- * Revision 1.1  2002/12/28 04:07:27  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_oci.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogrocidatasource.cpp,v 1.33 2006/01/30 19:25:09 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrocidatasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 static int anEPSGOracleMapping[] = 
 {
