@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrocilayer.cpp,v 1.14 2006/01/27 15:47:36 fwarmerdam Exp $
+ * $Id: ogrocilayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Oracle Spatial Driver
  * Purpose:  Implementation of the OGROCILayer class.  This is layer semantics
@@ -27,57 +27,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrocilayer.cpp,v $
- * Revision 1.14  2006/01/27 15:47:36  fwarmerdam
- * preliminary Get{FID/Geometry}Column support
- *
- * Revision 1.13  2005/09/21 00:59:36  fwarmerdam
- * fixup OGRFeatureDefn and OGRSpatialReference refcount handling
- *
- * Revision 1.12  2005/02/22 12:57:51  fwarmerdam
- * use OGRLayer base spatial filter support
- *
- * Revision 1.11  2005/02/02 20:54:27  fwarmerdam
- * track m_nFeaturesRead
- *
- * Revision 1.10  2004/11/22 19:24:15  fwarmerdam
- * added support for a list of tables in the datasource name
- *
- * Revision 1.9  2004/11/22 17:19:14  fwarmerdam
- * fixed missing case for 3d multipolygons: bug 618
- *
- * Revision 1.8  2004/11/10 20:17:14  fwarmerdam
- * fixed memory leak of geometry objects
- *
- * Revision 1.7  2003/05/21 03:54:01  warmerda
- * expand tabs
- *
- * Revision 1.6  2003/01/07 21:13:35  warmerda
- * executequery() now takes query as input, getfeature moved
- *
- * Revision 1.5  2003/01/07 18:16:26  warmerda
- * fixed some egrarious errors in geometry support
- *
- * Revision 1.4  2003/01/06 17:58:50  warmerda
- * restructure geometry translation, add FID support
- *
- * Revision 1.3  2002/12/29 19:43:59  warmerda
- * avoid some warnings
- *
- * Revision 1.2  2002/12/28 04:38:36  warmerda
- * converted to unix file conventions
- *
- * Revision 1.1  2002/12/28 04:07:27  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_oci.h"
 #include "cpl_conv.h"
 
-CPL_CVSID("$Id: ogrocilayer.cpp,v 1.14 2006/01/27 15:47:36 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrocilayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                           OGROCILayer()                               */
@@ -193,6 +148,13 @@ OGRFeature *OGROCILayer::GetNextRawFeature()
             return NULL;
     }
 
+/* -------------------------------------------------------------------- */
+/*      Have we run out of query results, such that we have no          */
+/*      statement left?                                                 */
+/* -------------------------------------------------------------------- */
+    if( poStatement == NULL )
+        return NULL;
+
 /* -------------------------------------------------------------------- */
 /*      Are we in some sort of error condition?                         */
 /* -------------------------------------------------------------------- */
