@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrociloaderlayer.cpp,v 1.5 2005/08/09 21:01:00 hobu Exp $
+ * $Id: ogrociloaderlayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Oracle Spatial Driver
  * Purpose:  Implementation of the OGROCILoaderLayer class.  This implements
@@ -26,33 +26,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrociloaderlayer.cpp,v $
- * Revision 1.5  2005/08/09 21:01:00  hobu
- * Allow OGROCILoaderLayer to grab the OCI_FID from the
- * environment if it is available and substitute it into the loader
- * file.
- *
- * Revision 1.4  2005/02/10 15:46:02  fwarmerdam
- * added GEOMETRY_NAME layer creation option
- *
- * Revision 1.3  2003/04/11 18:20:57  warmerda
- * added external dat file in VARIABLE mode
- *
- * Revision 1.2  2003/04/04 22:04:28  warmerda
- * added incomplete support for variable mode
- *
- * Revision 1.1  2003/04/04 06:17:47  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_oci.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogrociloaderlayer.cpp,v 1.5 2005/08/09 21:01:00 hobu Exp $");
+CPL_CVSID("$Id: ogrociloaderlayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                         OGROCILoaderLayer()                          */
