@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrociselectlayer.cpp,v 1.5 2005/08/09 21:02:06 hobu Exp $
+ * $Id: ogrociselectlayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Oracle Spatial Driver
  * Purpose:  Implementation of the OGROCISelectLayer class.  This class 
@@ -26,32 +26,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrociselectlayer.cpp,v $
- * Revision 1.5  2005/08/09 21:02:06  hobu
- * Updated ReadTableDefinition to use the OCI_FID
- * variable from the environment if it is available
- *
- * Revision 1.4  2003/05/21 03:54:01  warmerda
- * expand tabs
- *
- * Revision 1.3  2003/01/06 17:59:07  warmerda
- * initialize FID field
- *
- * Revision 1.2  2002/12/28 04:38:36  warmerda
- * converted to unix file conventions
- *
- * Revision 1.1  2002/12/28 04:07:27  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_oci.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogrociselectlayer.cpp,v 1.5 2005/08/09 21:02:06 hobu Exp $");
+CPL_CVSID("$Id: ogrociselectlayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                          OGROCISelectLayer()                         */
