@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogr_odbc.h,v 1.7 2005/11/02 21:58:26 fwarmerdam Exp $
+ * $Id: ogr_odbc.h 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Private definitions for OGR/ODBC driver.
@@ -25,31 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogr_odbc.h,v $
- * Revision 1.7  2005/11/02 21:58:26  fwarmerdam
- * preliminary support for ODBC spatial querying
- *
- * Revision 1.6  2005/09/09 05:02:12  fwarmerdam
- * added wkb support
- *
- * Revision 1.5  2005/02/22 12:53:56  fwarmerdam
- * use OGRLayer base spatial filter support
- *
- * Revision 1.4  2004/01/05 22:38:17  warmerda
- * stripped out some junk
- *
- * Revision 1.3  2004/01/05 22:23:40  warmerda
- * added ExecuteSQL implementation via OGRODBCSelectLayer
- *
- * Revision 1.2  2003/10/29 17:47:38  warmerda
- * Added FIDcolumn (based on primary key) support
- *
- * Revision 1.1  2003/09/25 17:08:37  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #ifndef _OGR_ODBC_H_INCLUDED
 #define _OGR_ODBC_H_INLLUDED
@@ -59,7 +35,7 @@
 #include "cpl_error.h"
 
 /************************************************************************/
-/*                            OGRODBCLayer                                */
+/*                            OGRODBCLayer                              */
 /************************************************************************/
 
 class OGRODBCDataSource;
@@ -108,7 +84,7 @@ class OGRODBCLayer : public OGRLayer
 };
 
 /************************************************************************/
-/*                           OGRODBCTableLayer                            */
+/*                           OGRODBCTableLayer                          */
 /************************************************************************/
 
 class OGRODBCTableLayer : public OGRODBCLayer
@@ -178,7 +154,6 @@ class OGRODBCSelectLayer : public OGRODBCLayer
     virtual void        ResetReading();
     virtual int         GetFeatureCount( int );
 
-    virtual OGRErr      SetAttributeFilter( const char * );
     virtual OGRFeature *GetFeature( long nFeatureId );
     
     virtual OGRErr      GetExtent(OGREnvelope *psExtent, int bForce = TRUE);
@@ -187,7 +162,7 @@ class OGRODBCSelectLayer : public OGRODBCLayer
 };
 
 /************************************************************************/
-/*                           OGRODBCDataSource                            */
+/*                           OGRODBCDataSource                          */
 /************************************************************************/
 
 class OGRODBCDataSource : public OGRDataSource
