@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrodbcdatasource.cpp,v 1.10 2005/10/24 04:36:38 fwarmerdam Exp $
+ * $Id: ogrodbcdatasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRODBCDataSource class.
@@ -25,47 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrodbcdatasource.cpp,v $
- * Revision 1.10  2005/10/24 04:36:38  fwarmerdam
- * support passing geometry column with table name in datasource name
- *
- * Revision 1.9  2005/09/21 00:56:55  fwarmerdam
- * fixup OGRFeatureDefn and OGRSpatialReference refcount handling
- *
- * Revision 1.8  2004/10/17 04:22:19  fwarmerdam
- * Slightly improve error message.
- *
- * Revision 1.7  2004/08/17 21:08:27  warmerda
- * Avoid calling OpenTable() while still processing a transaction to get
- * a list of tables.  As suggested by John Erik Ekberg (cowi.dk).
- *
- * Revision 1.6  2004/07/09 07:06:43  warmerda
- * Added OGRSQL support in ExecuteSQL().
- *
- * Revision 1.5  2004/01/05 22:38:17  warmerda
- * stripped out some junk
- *
- * Revision 1.4  2004/01/05 22:23:40  warmerda
- * added ExecuteSQL implementation via OGRODBCSelectLayer
- *
- * Revision 1.3  2003/11/10 20:08:50  warmerda
- * support explicit tables list, or GetTables() fallback
- *
- * Revision 1.2  2003/10/06 19:18:30  warmerda
- * Added userid/password support
- *
- * Revision 1.1  2003/09/25 17:08:37  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_odbc.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogrodbcdatasource.cpp,v 1.10 2005/10/24 04:36:38 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrodbcdatasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 /************************************************************************/
 /*                         OGRODBCDataSource()                          */
 /************************************************************************/
@@ -112,27 +78,59 @@ OGRODBCDataSource::~OGRODBCDataSource()
 /************************************************************************/
 
 int OGRODBCDataSource::Open( const char * pszNewName, int bUpdate,
-                              int bTestOpen )
+                             int bTestOpen )
 
 {
     CPLAssert( nLayers == 0 );
 
+/* -------------------------------------------------------------------- */
+/*      Start parsing dataset name from the end of string, fetching     */
+/*      the name of spatial reference table and names for SRID and      */
+/*      SRTEXT columns first.                                           */
+/* -------------------------------------------------------------------- */
+    char *pszWrkName = CPLStrdup( pszNewName + 5 ); // Skip the 'ODBC:' part
+    char **papszTables = NULL;
+    char **papszGeomCol = NULL;
+    char *pszSRSTableName = NULL;
+    char *pszSRIDCol = NULL, *pszSRTextCol = NULL;
+    char *pszDelimiter;
+
+    if ( (pszDelimiter = strrchr( pszWrkName, ':' )) != NULL )
+    {
+        char *pszOBracket = strchr( pszDelimiter + 1, '(' );
+        if( pszOBracket == NULL )
+            pszSRSTableName = CPLStrdup( pszDelimiter + 1 );
+        else
+        {
+            char *pszCBracket = strchr( pszOBracket, ')' );
+            if( pszCBracket != NULL )
+                *pszCBracket = '\0';
+
+            char *pszComma = strchr( pszOBracket, ',' );
+            if( pszComma != NULL )
+            {
+                *pszComma = '\0';
+                pszSRIDCol = CPLStrdup( pszComma + 1 );
+            }
+            
+            *pszOBracket = '\0';
+            pszSRSTableName = CPLStrdup( pszDelimiter + 1 );
+            pszSRTextCol = CPLStrdup( pszOBracket + 1 );
+        }
+        *pszDelimiter = '\0';
+    }
+
 /* -------------------------------------------------------------------- */
 /*      Strip off any comma delimeted set of tables names to access     */
 /*      from the end of the string first.  Also allow an optional       */
 /*      bracketed geometry column name after the table name.            */
 /* -------------------------------------------------------------------- */
-    char *pszWrkName = CPLStrdup( pszNewName );
-    char **papszTables = NULL;
-    char **papszGeomCol = NULL;
-    char *pszComma;
-
-    while( (pszComma = strrchr( pszWrkName, ',' )) != NULL )
+    while( (pszDelimiter = strrchr( pszWrkName, ',' )) != NULL )
     {
-        char *pszOBracket = strstr(pszComma+1,"(");
+        char *pszOBracket = strstr( pszDelimiter + 1, "(" );
         if( pszOBracket == NULL )
         {
-            papszTables = CSLAddString( papszTables, pszComma + 1 );
+            papszTables = CSLAddString( papszTables, pszDelimiter + 1 );
             papszGeomCol = CSLAddString( papszGeomCol, "" );
         }
         else
@@ -143,10 +141,10 @@ int OGRODBCDataSource::Open( const char * pszNewName, int bUpdate,
                 *pszCBracket = '\0';
             
             *pszOBracket = '\0';
-            papszTables = CSLAddString( papszTables, pszComma + 1 );
+            papszTables = CSLAddString( papszTables, pszDelimiter + 1 );
             papszGeomCol = CSLAddString( papszGeomCol, pszOBracket+1 );
         }
-        *pszComma = '\0';
+        *pszDelimiter = '\0';
     }
 
 /* -------------------------------------------------------------------- */
@@ -158,24 +156,24 @@ int OGRODBCDataSource::Open( const char * pszNewName, int bUpdate,
     char *pszPassword = NULL;
     char *pszDSN = NULL;
 
-    if( strstr(pszWrkName+5,"@") == NULL )
+    if( strstr(pszWrkName,"@") == NULL )
     {
-        pszDSN = CPLStrdup(pszWrkName+5);
+        pszDSN = CPLStrdup( pszWrkName );
     }
     else
     {
         char *pszTarget;
 
-        pszDSN = CPLStrdup(strstr(pszWrkName+5,"@")+1);
-        if( pszWrkName[5] == '/' )
+        pszDSN = CPLStrdup(strstr(pszWrkName, "@") + 1);
+        if( *pszWrkName == '/' )
         {
-            pszPassword = CPLStrdup(pszWrkName + 6);
+            pszPassword = CPLStrdup(pszWrkName + 1);
             pszTarget = strstr(pszPassword,"@");
             *pszTarget = '\0';
         }
         else
         {
-            pszUserid = CPLStrdup(pszWrkName+5);
+            pszUserid = CPLStrdup(pszWrkName);
             pszTarget = strstr(pszUserid,"@");
             *pszTarget = '\0';
 
@@ -193,8 +191,10 @@ int OGRODBCDataSource::Open( const char * pszNewName, int bUpdate,
 /* -------------------------------------------------------------------- */
 /*      Initialize based on the DSN.                                    */
 /* -------------------------------------------------------------------- */
-    CPLDebug( "ODBC", "EstablishSession(%s,%s,%s)", 
-              pszDSN, pszUserid, pszPassword );
+    CPLDebug( "OGR_ODBC",
+              "EstablishSession(DSN:\"%s\", userid:\"%s\", password:\"%s\")", 
+              pszDSN, pszUserid ? pszUserid : "",
+              pszPassword ? pszPassword : "" );
 
     if( !oSession.EstablishSession( pszDSN, pszUserid, pszPassword ) )
     {
@@ -202,6 +202,8 @@ int OGRODBCDataSource::Open( const char * pszNewName, int bUpdate,
                   "Unable to initialize ODBC connection to DSN for %s,\n"
                   "%s", 
                   pszNewName+5, oSession.GetLastError() );
+        CSLDestroy( papszTables );
+        CSLDestroy( papszGeomCol );
         CPLFree( pszDSN );
         CPLFree( pszUserid );
         CPLFree( pszPassword );
@@ -270,7 +272,79 @@ int OGRODBCDataSource::Open( const char * pszNewName, int bUpdate,
         else
             OpenTable( papszTables[iTable], NULL, bUpdate );
     }
-    
+
+    CSLDestroy( papszTables );
+    CSLDestroy( papszGeomCol );
+
+/* -------------------------------------------------------------------- */
+/*      If no explicit list of tables was given, check for a list in    */
+/*      a geometry_columns table.                                       */
+/* -------------------------------------------------------------------- */
+    if ( pszSRSTableName )
+    {
+        CPLODBCStatement oSRSList( &oSession );
+
+        if ( !pszSRTextCol )
+            pszSRTextCol = CPLStrdup( "srtext" );
+        if ( !pszSRIDCol )
+            pszSRIDCol = CPLStrdup( "srid" );
+
+        oSRSList.Append( "SELECT " );
+        oSRSList.Append( pszSRIDCol );
+        oSRSList.Append( "," );
+        oSRSList.Append( pszSRTextCol );
+        oSRSList.Append( " FROM " );
+        oSRSList.Append( pszSRSTableName );
+
+        CPLDebug( "OGR_ODBC", "ExecuteSQL(%s) to read SRS table",
+                  oSRSList.GetCommand() );
+        if ( oSRSList.ExecuteSQL() )
+        {
+            int nRows = 256;     // A reasonable number of SRIDs to start from
+            panSRID = (int *)CPLMalloc( nRows * sizeof(int) );
+            papoSRS = (OGRSpatialReference **)
+                CPLMalloc( nRows * sizeof(OGRSpatialReference*) );
+
+            while ( oSRSList.Fetch() )
+            {
+                char *pszSRID = (char *) oSRSList.GetColData( pszSRIDCol );
+                if ( !pszSRID )
+                    continue;
+
+                char *pszSRText = (char *) oSRSList.GetColData( pszSRTextCol );
+
+                if ( pszSRText )
+                {
+                    if ( nKnownSRID > nRows )
+                    {
+                        nRows *= 2;
+                        panSRID = (int *)CPLRealloc( panSRID,
+                                                     nRows * sizeof(int) );
+                        papoSRS = (OGRSpatialReference **)
+                            CPLRealloc( papoSRS,
+                            nRows * sizeof(OGRSpatialReference*) );
+                    }
+                    panSRID[nKnownSRID] = atoi( pszSRID );
+                    papoSRS[nKnownSRID] = new OGRSpatialReference();
+                    if ( papoSRS[nKnownSRID]->importFromWkt( &pszSRText )
+                         != OGRERR_NONE )
+                    {
+                        delete papoSRS[nKnownSRID];
+                        continue;
+                    }
+                    nKnownSRID++;
+                }
+            }
+        }
+    }
+
+    if ( pszSRIDCol )
+        CPLFree( pszSRIDCol );
+    if ( pszSRTextCol )
+        CPLFree( pszSRTextCol );
+    if ( pszSRSTableName )
+        CPLFree( pszSRSTableName );
+
     return TRUE;
 }
 
