@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrodbcselectlayer.cpp,v 1.3 2006/03/21 18:50:56 fwarmerdam Exp $
+ * $Id: ogrodbcselectlayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRODBCSelectLayer class, layer access to the results
@@ -26,24 +26,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrodbcselectlayer.cpp,v $
- * Revision 1.3  2006/03/21 18:50:56  fwarmerdam
- * dont report SetAttributeFilter error if clearing
- *
- * Revision 1.2  2005/02/22 12:53:56  fwarmerdam
- * use OGRLayer base spatial filter support
- *
- * Revision 1.1  2004/01/05 22:23:32  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "cpl_conv.h"
 #include "ogr_odbc.h"
 
-CPL_CVSID("$Id: ogrodbcselectlayer.cpp,v 1.3 2006/03/21 18:50:56 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrodbcselectlayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 /************************************************************************/
 /*                          OGRODBCSelectLayer()                         */
 /************************************************************************/
@@ -112,7 +100,7 @@ OGRErr OGRODBCSelectLayer::ResetStatement()
 
     iNextShapeId = 0;
 
-    CPLDebug( "ODBC", "Recreating statement." );
+    CPLDebug( "OGR_ODBC", "Recreating statement." );
     poStmt = new CPLODBCStatement( poDS->GetSession() );
     poStmt->Append( pszBaseStatement );
 
@@ -149,26 +137,6 @@ OGRFeature *OGRODBCSelectLayer::GetFeature( long nFeatureId )
     return OGRODBCLayer::GetFeature( nFeatureId );
 }
 
-/************************************************************************/
-/*                         SetAttributeFilter()                         */
-/************************************************************************/
-
-OGRErr OGRODBCSelectLayer::SetAttributeFilter( const char *pszQuery )
-
-{
-    if( pszQuery != NULL && strlen(pszQuery) > 0 )
-    {
-        CPLError( CE_Failure, CPLE_AppDefined, 
-                  "SetAttributeFilter() not supported on ExecuteSQL() results." );
-        
-        return OGRERR_UNSUPPORTED_OPERATION;
-    }
-    else
-    {
-        return OGRERR_NONE;
-    }
-}
-
 /************************************************************************/
 /*                           TestCapability()                           */
 /************************************************************************/
