@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrodbctablelayer.cpp,v 1.11 2005/11/18 16:50:46 fwarmerdam Exp $
+ * $Id: ogrodbctablelayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRODBCTableLayer class, access to an existing table.
@@ -25,48 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrodbctablelayer.cpp,v $
- * Revision 1.11  2005/11/18 16:50:46  fwarmerdam
- * added ODBC_OGR_FID config variable
- *
- * Revision 1.10  2005/11/18 14:40:10  fwarmerdam
- * More debug info.
- *
- * Revision 1.9  2005/11/18 14:36:11  fwarmerdam
- * More debug info on FID.
- *
- * Revision 1.8  2005/11/18 14:32:20  fwarmerdam
- * added debug message about fid.
- *
- * Revision 1.7  2005/11/02 21:58:26  fwarmerdam
- * preliminary support for ODBC spatial querying
- *
- * Revision 1.6  2005/09/09 05:02:12  fwarmerdam
- * added wkb support
- *
- * Revision 1.5  2005/02/22 12:53:56  fwarmerdam
- * use OGRLayer base spatial filter support
- *
- * Revision 1.4  2003/12/29 22:48:45  warmerda
- * added error check on whether any columns found
- *
- * Revision 1.3  2003/10/29 17:47:38  warmerda
- * Added FIDcolumn (based on primary key) support
- *
- * Revision 1.2  2003/09/26 18:22:41  warmerda
- * Fixed SetAttributeFilter().
- *
- * Revision 1.1  2003/09/25 17:08:37  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "cpl_conv.h"
 #include "ogr_odbc.h"
 
-CPL_CVSID("$Id: ogrodbctablelayer.cpp,v 1.11 2005/11/18 16:50:46 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrodbctablelayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 /************************************************************************/
 /*                          OGRODBCTableLayer()                         */
 /************************************************************************/
@@ -126,8 +90,8 @@ CPLErr OGRODBCTableLayer::Initialize( const char *pszTableName,
             CPLFree( pszFIDColumn );
             pszFIDColumn = NULL;
 
-            CPLDebug( "OGR_ODBC", "Table %s has multiple primary key fields, ignoring them all.", 
-                      pszTableName );
+            CPLDebug( "OGR_ODBC", "Table %s has multiple primary key fields, "
+                      "ignoring them all.", pszTableName );
         }
     }
 
@@ -190,9 +154,8 @@ CPLErr OGRODBCTableLayer::Initialize( const char *pszTableName,
         }
         else
         {
-            if( oGetCol.GetColType( iColumn ) == SQL_BINARY
-                || oGetCol.GetColType( iColumn ) == SQL_VARBINARY
-                || oGetCol.GetColType( iColumn ) == SQL_LONGVARBINARY )
+            if( CPLODBCStatement::GetTypeMapping(
+                    oGetCol.GetColType( iColumn )) == SQL_C_BINARY )
                 bGeomColumnWKB = TRUE;
         }
     }
@@ -407,3 +370,4 @@ OGRSpatialReference *OGRODBCTableLayer::GetSpatialRef()
 
     return OGRODBCLayer::GetSpatialRef();
 }
+
