@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrogdidatasource.cpp,v 1.8 2005/09/21 00:55:43 fwarmerdam Exp $
+ * $Id: ogrogdidatasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OGDI Bridge
  * Purpose:  Implements OGROGDIDataSource class.
@@ -26,43 +26,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrogdidatasource.cpp,v $
- * Revision 1.8  2005/09/21 00:55:43  fwarmerdam
- * fixup OGRFeatureDefn and OGRSpatialReference refcount handling
- *
- * Revision 1.7  2004/02/19 06:59:36  warmerda
- * Fixed a couple memory leaks.
- *
- * Revision 1.6  2003/05/21 03:58:49  warmerda
- * expand tabs
- *
- * Revision 1.5  2002/01/13 01:46:31  warmerda
- * fix handling of dataset names with drive colon
- *
- * Revision 1.4  2001/07/18 04:55:16  warmerda
- * added CPL_CSVID
- *
- * Revision 1.3  2001/04/17 21:41:02  warmerda
- * Added use of cln_GetLayerCapabilities() to query list of available layers.
- * Restructured OGROGDIDataSource and OGROGDILayer classes somewhat to
- * avoid passing so much information in the layer creation call.  Added support
- * for preserving text on OGDI text features.
- *
- * Revision 1.2  2000/08/30 01:36:57  danmo
- * Added GetSpatialRef() support
- *
- * Revision 1.1  2000/08/24 04:16:19  danmo
- * Initial revision
- *
- */
+ ****************************************************************************/
 
 #include "ogrogdi.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogrogdidatasource.cpp,v 1.8 2005/09/21 00:55:43 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrogdidatasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                         OGROGDIDataSource()                          */
