@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrpgdatasource.cpp,v 1.48 2006/04/13 03:36:59 fwarmerdam Exp $
+ * $Id: ogrpgdatasource.cpp 11225 2007-04-08 14:51:34Z mloskot $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRPGDataSource class.
@@ -25,167 +25,14 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrpgdatasource.cpp,v $
- * Revision 1.48  2006/04/13 03:36:59  fwarmerdam
- * When adding records to spatial_ref_sys, ensure that proj4text is
- * also added!  http://bugzilla.remotesensing.org/show_bug.cgi?id=1146
- *
- * Revision 1.47  2006/03/28 23:06:57  fwarmerdam
- * fixed contact info
- *
- * Revision 1.46  2006/03/02 00:16:06  fwarmerdam
- * Applied change to GEOMETRY_NAME creation option.
- *
- * Revision 1.45  2006/02/09 05:04:03  fwarmerdam
- * proper overriding of DeleteLayer() method
- *
- * Revision 1.44  2005/12/19 15:06:59  dron
- * Remove erroneous linebreak in "CREATE TABLE" query.
- *
- * Revision 1.43  2005/12/18 16:57:22  fwarmerdam
- * added primary key constraint on ogc_fid, c/o Craig Miller
- *
- * Revision 1.42  2005/10/25 21:59:43  fwarmerdam
- * disable setencoding for now
- *
- * Revision 1.41  2005/10/24 23:50:50  fwarmerdam
- * moved bUseCopy test into layer on creation of first feature
- *
- * Revision 1.40  2005/10/16 03:39:25  fwarmerdam
- * cleanup COPY support somewhat
- *
- * Revision 1.39  2005/10/16 01:38:34  cfis
- * Updates that add support for using COPY for inserting data to Postgresql.  COPY is less robust than INSERT, but signficantly faster.
- *
- * Revision 1.38  2005/09/23 14:09:27  fwarmerdam
- * Fixed last fix to cast rename to text for postgres 7.x support.
- *
- * Revision 1.37  2005/09/22 19:29:14  fwarmerdam
- * Fixed to do exact table name test, instead of a wildcarded test when
- * scanning for spatial tables.
- *
- * Revision 1.36  2005/09/21 00:55:42  fwarmerdam
- * fixup OGRFeatureDefn and OGRSpatialReference refcount handling
- *
- * Revision 1.35  2005/08/06 14:49:27  osemykin
- * Added BINARY CURSOR support
- * Use it with 'PGB:dbname=...' instead 'PG:dbname=...'
- *
- * Revision 1.34  2005/08/04 19:01:29  fwarmerdam
- * avoid use of non-standard datatypes like uint
- *
- * Revision 1.33  2005/08/04 07:28:28  osemykin
- * Fixes for support postgis version < 0.9.0
- * geom as EWKT for PostGIS >= 1.0
- * geom as Text for PostGIS < 1.0
- *
- * Revision 1.32  2005/08/03 21:22:29  osemykin
- * Changed PostGIS version representation
- * For PostGIS database layers loads from geometry_columns table
- *
- * Revision 1.31  2005/07/20 01:45:56  fwarmerdam
- * fetch PostGIS version
- *
- * Revision 1.30  2005/03/04 21:04:06  fwarmerdam
- * Added setting of dimension based on geometry type, or DIM override.
- *
- * Revision 1.29  2004/07/10 04:45:52  warmerda
- * more rigerous soft transaction handling
- *
- * Revision 1.28  2004/07/09 07:05:37  warmerda
- * Added OGRSQL dialect support.
- *
- * Revision 1.27  2004/04/30 18:30:05  warmerda
- * Fixed pszLayerName typo.
- *
- * Revision 1.26  2004/04/30 17:52:42  warmerda
- * added layer name laundering
- *
- * Revision 1.25  2004/04/30 15:17:38  warmerda
- * Added DELLAYER:layername ExecuteSQL() pseudo-directive.
- * Clean stale entries in geometry_columns table when creating a layer.
- *
- * Revision 1.24  2004/04/30 00:45:45  warmerda
- * default to launder being on
- *
- * Revision 1.23  2004/04/28 12:45:46  warmerda
- * Fixed screwup in table selection query.
- *
- * Revision 1.22  2004/04/23 15:10:10  warmerda
- * Added support for enumerating views.
- *
- * Revision 1.21  2004/04/02 17:44:55  warmerda
- * SELECT in caps for readability
- *
- * Revision 1.20  2004/01/19 18:48:11  warmerda
- * added commit after DROP TABLE and before dropping sequence
- *
- * Revision 1.19  2003/09/11 20:03:03  warmerda
- * initialize poSRS ariable in FetchSRS
- *
- * Revision 1.18  2003/05/21 03:59:42  warmerda
- * expand tabs
- *
- * Revision 1.17  2002/12/12 14:28:35  warmerda
- * fixed bug in DeleteLayer
- *
- * Revision 1.16  2002/10/20 03:45:27  warmerda
- * added debug on table create command
- *
- * Revision 1.15  2002/10/09 18:30:10  warmerda
- * substantial upgrade to type handling, and preservations of width/precision
- *
- * Revision 1.14  2002/10/04 14:03:09  warmerda
- * added column name laundering support
- *
- * Revision 1.13  2002/05/09 16:48:08  warmerda
- * upgrade to quote table and field names
- *
- * Revision 1.12  2002/05/09 16:03:19  warmerda
- * major upgrade to support SRS better and add ExecuteSQL
- *
- * Revision 1.11  2002/03/01 20:42:00  warmerda
- * fixed parsing of connect string, see bug 107
- *
- * Revision 1.10  2002/01/13 21:48:32  warmerda
- * fixed addgeometrycolumn call to include pszDBname
- *
- * Revision 1.9  2002/01/13 16:23:16  warmerda
- * capture dbname= parameter for use in AddGeometryColumn() call
- *
- * Revision 1.8  2001/11/15 21:19:58  warmerda
- * added soft transaction semantics
- *
- * Revision 1.7  2001/09/28 04:03:52  warmerda
- * partially upraded to PostGIS 0.6
- *
- * Revision 1.6  2001/07/18 04:55:16  warmerda
- * added CPL_CSVID
- *
- * Revision 1.5  2001/06/26 20:59:13  warmerda
- * implement efficient spatial and attribute query support
- *
- * Revision 1.4  2001/06/20 16:10:24  warmerda
- * fixed PostGIS autodetect
- *
- * Revision 1.3  2001/06/19 22:29:12  warmerda
- * upgraded to include PostGIS support
- *
- * Revision 1.2  2000/11/23 06:03:35  warmerda
- * added Oid support
- *
- * Revision 1.1  2000/10/17 17:46:51  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_pg.h"
+#include "ogrpgutility.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogrpgdatasource.cpp,v 1.48 2006/04/13 03:36:59 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrpgdatasource.cpp 11225 2007-04-08 14:51:34Z mloskot $");
 
 static void OGRPGNoticeProcessor( void *arg, const char * pszMessage );
 
@@ -232,7 +79,13 @@ OGRPGDataSource::~OGRPGDataSource()
     CPLFree( papoLayers );
 
     if( hPGConn != NULL )
+    {
+        /* XXX - mloskot: After the connection is closed, valgrind still
+         * reports 36 bytes definitely lost, somewhere in the libpq.
+         */
         PQfinish( hPGConn );
+        hPGConn = NULL;
+    }
 
     for( i = 0; i < nKnownSRID; i++ )
     {
@@ -243,6 +96,7 @@ OGRPGDataSource::~OGRPGDataSource()
     CPLFree( papoSRS );
 }
 
+
 /************************************************************************/
 /*                                Open()                                */
 /************************************************************************/
@@ -278,7 +132,7 @@ int OGRPGDataSource::Open( const char * pszNewName, int bUpdate,
     if( hPGConn == NULL || PQstatus(hPGConn) == CONNECTION_BAD )
     {
         CPLError( CE_Failure, CPLE_AppDefined,
-                  "PGconnectcb failed.\n%s",
+                  "PQconnectdb failed.\n%s",
                   PQerrorMessage(hPGConn) );
         PQfinish(hPGConn);
         hPGConn = NULL;
@@ -313,11 +167,9 @@ int OGRPGDataSource::Open( const char * pszNewName, int bUpdate,
 /* -------------------------------------------------------------------- */
     if( strstr(pszNewName, "dbname=") != NULL )
     {
-        int     i;
-
         pszDBName = CPLStrdup( strstr(pszNewName, "dbname=") + 7 );
 
-        for( i = 0; pszDBName[i] != '\0'; i++ )
+        for( int i = 0; pszDBName[i] != '\0'; i++ )
         {
             if( pszDBName[i] == ' ' )
             {
@@ -338,13 +190,14 @@ int OGRPGDataSource::Open( const char * pszNewName, int bUpdate,
 /*      PostGIS Geometry type.  If so, disable sequential scanning      */
 /*      so we will get the value of the gist indexes.                   */
 /* -------------------------------------------------------------------- */
-    PGresult            *hResult;
+    PGresult    *hResult = NULL;
 
     hResult = PQexec(hPGConn, "BEGIN");
 
     if( hResult && PQresultStatus(hResult) == PGRES_COMMAND_OK )
     {
-        PQclear( hResult );
+        OGRPGClearResult( hResult );
+        CPLAssert(NULL == hResult);
 
         hResult = PQexec(hPGConn,
                          "SELECT oid FROM pg_type WHERE typname = 'geometry'" );
@@ -357,13 +210,12 @@ int OGRPGDataSource::Open( const char * pszNewName, int bUpdate,
         nGeometryOID = atoi(PQgetvalue(hResult,0,0));
     }
     else
+    {
         nGeometryOID = (Oid) 0;
+    }
 
-    if( hResult )
-        PQclear( hResult );
-
-    hResult = PQexec(hPGConn, "SET ENABLE_SEQSCAN = OFF");
-    PQclear( hResult );
+    OGRPGClearResult( hResult );
+    CPLAssert(NULL == hResult); /* Test if safe PQclear has not been broken */
 
     // find out postgis version.
     sPostGISVersion.nMajor = -1;
@@ -426,13 +278,29 @@ int OGRPGDataSource::Open( const char * pszNewName, int bUpdate,
             }
 
             CPLDebug( "OGR_PG", "POSTGIS_VERSION=%s",
-                      PQgetvalue(hResult,0,0));
+                    PQgetvalue(hResult,0,0) );
         }
-        PQclear(hResult);
+        OGRPGClearResult(hResult);
+
+
+        if (sPostGISVersion.nMajor == 0 && sPostGISVersion.nMinor < 8)
+        {
+            // Turning off sequential scans for PostGIS < 0.8
+            hResult = PQexec(hPGConn, "SET ENABLE_SEQSCAN = OFF");
+            
+            CPLDebug( "OGR_PG", "SET ENABLE_SEQSCAN=OFF" );
+        }
+        else
+        {
+            // PostGIS >=0.8 is correctly integrated with query planner,
+            // thus PostgreSQL will use indexes whenever appropriate.
+            hResult = PQexec(hPGConn, "SET ENABLE_SEQSCAN = ON");
+        }
+        OGRPGClearResult( hResult );
     }
 
     hResult = PQexec(hPGConn, "COMMIT");
-    PQclear( hResult );
+    OGRPGClearResult( hResult );
 
 /* -------------------------------------------------------------------- */
 /*      Get a list of available tables.                                 */
@@ -441,29 +309,31 @@ int OGRPGDataSource::Open( const char * pszNewName, int bUpdate,
 
     if( hResult && PQresultStatus(hResult) == PGRES_COMMAND_OK )
     {
-        PQclear( hResult );
+        OGRPGClearResult( hResult );
 
         if ( bHavePostGIS )
             hResult = PQexec(hPGConn,
                              "DECLARE mycursor CURSOR for "
-                             "SELECT c.relname FROM pg_class c, geometry_columns g "
-                             "WHERE (c.relkind in ('r','v') AND c.relname !~ '^pg' "
-                             "AND c.relname::TEXT = g.f_table_name::TEXT)" );
+                             "SELECT c.relname, n.nspname FROM pg_class c, pg_namespace n, geometry_columns g "
+                             "WHERE (c.relkind in ('r','v') AND c.relname !~ '^pg' AND c.relnamespace=n.oid "
+                             "AND c.relname::TEXT = g.f_table_name::TEXT AND n.nspname = g.f_table_schema)" );
         else
             hResult = PQexec(hPGConn,
                              "DECLARE mycursor CURSOR for "
-                             "SELECT relname FROM pg_class "
-                             "WHERE (relkind in ('r','v') AND relname !~ '^pg')" );
+                             "SELECT c.relname, n.nspname FROM pg_class c, pg_namespace n "
+                             "WHERE (c.relkind in ('r','v') AND c.relname !~ '^pg' AND c.relnamespace=n.oid)" );
     }
 
     if( hResult && PQresultStatus(hResult) == PGRES_COMMAND_OK )
     {
-        PQclear( hResult );
+        OGRPGClearResult( hResult );
         hResult = PQexec(hPGConn, "FETCH ALL in mycursor" );
     }
 
     if( !hResult || PQresultStatus(hResult) != PGRES_TUPLES_OK )
     {
+        OGRPGClearResult( hResult );
+
         CPLError( CE_Failure, CPLE_AppDefined,
                   "%s", PQerrorMessage(hPGConn) );
         return FALSE;
@@ -473,6 +343,7 @@ int OGRPGDataSource::Open( const char * pszNewName, int bUpdate,
 /*      Parse the returned table list                                   */
 /* -------------------------------------------------------------------- */
     char        **papszTableNames=NULL;
+    char        **papszSchemaNames=NULL;
     int           iRecord;
 
     for( iRecord = 0; iRecord < PQntuples(hResult); iRecord++ )
@@ -485,31 +356,36 @@ int OGRPGDataSource::Open( const char * pszNewName, int bUpdate,
 
         papszTableNames = CSLAddString(papszTableNames,
                                        PQgetvalue(hResult, iRecord, 0));
+        papszSchemaNames = CSLAddString(papszSchemaNames,
+                                       PQgetvalue(hResult, iRecord, 1));
+
     }
 
 /* -------------------------------------------------------------------- */
 /*      Cleanup                                                         */
 /* -------------------------------------------------------------------- */
-    PQclear( hResult );
+    OGRPGClearResult( hResult );
 
     hResult = PQexec(hPGConn, "CLOSE mycursor");
-    PQclear( hResult );
+    OGRPGClearResult( hResult );
 
     hResult = PQexec(hPGConn, "COMMIT");
-    PQclear( hResult );
+    OGRPGClearResult( hResult );
 
 /* -------------------------------------------------------------------- */
-/*      Get the schema of the available tables.                         */
+/*      Register the available tables.                                  */
 /* -------------------------------------------------------------------- */
     for( iRecord = 0;
          papszTableNames != NULL && papszTableNames[iRecord] != NULL;
          iRecord++ )
     {
-        OpenTable( papszTableNames[iRecord], bUpdate, FALSE );
+        OpenTable( papszTableNames[iRecord], papszSchemaNames[iRecord], bUpdate, FALSE );
     }
 
+    CSLDestroy( papszSchemaNames );
     CSLDestroy( papszTableNames );
 
+/* -------------------------------------------------------------------- */
     return nLayers > 0 || bUpdate;
 }
 
@@ -517,22 +393,27 @@ int OGRPGDataSource::Open( const char * pszNewName, int bUpdate,
 /*                             OpenTable()                              */
 /************************************************************************/
 
-int OGRPGDataSource::OpenTable( const char *pszNewName, int bUpdate,
+int OGRPGDataSource::OpenTable( const char *pszNewName, const char *pszSchemaName, int bUpdate,
                                 int bTestOpen )
 
 {
 /* -------------------------------------------------------------------- */
 /*      Create the layer object.                                        */
 /* -------------------------------------------------------------------- */
-    OGRPGLayer  *poLayer;
+    OGRPGTableLayer  *poLayer;
 
-    poLayer = new OGRPGTableLayer( this, pszNewName, bUpdate );
+    poLayer = new OGRPGTableLayer( this, pszNewName, pszSchemaName, bUpdate );
+    if( poLayer->GetLayerDefn() == NULL )
+    {
+        delete poLayer;
+        return FALSE;
+    }
 
 /* -------------------------------------------------------------------- */
 /*      Add layer to data source layer list.                            */
 /* -------------------------------------------------------------------- */
-    papoLayers = (OGRPGLayer **)
-        CPLRealloc( papoLayers,  sizeof(OGRPGLayer *) * (nLayers+1) );
+    papoLayers = (OGRPGTableLayer **)
+        CPLRealloc( papoLayers,  sizeof(OGRPGTableLayer *) * (nLayers+1) );
     papoLayers[nLayers++] = poLayer;
 
     return TRUE;
@@ -553,6 +434,8 @@ int OGRPGDataSource::DeleteLayer( int iLayer )
 /*      pretty dangerous if anything has a reference to this layer!     */
 /* -------------------------------------------------------------------- */
     CPLString osLayerName = papoLayers[iLayer]->GetLayerDefn()->GetName();
+    CPLString osTableName = papoLayers[iLayer]->GetTableName();
+    CPLString osSchemaName = papoLayers[iLayer]->GetSchemaName();
 
     CPLDebug( "OGR_PG", "DeleteLayer(%s)", osLayerName.c_str() );
 
@@ -568,38 +451,27 @@ int OGRPGDataSource::DeleteLayer( int iLayer )
     char                szCommand[1024];
 
     hResult = PQexec(hPGConn, "BEGIN");
-    PQclear( hResult );
+    OGRPGClearResult( hResult );
 
     if( bHavePostGIS )
     {
         sprintf( szCommand,
-                 "SELECT DropGeometryColumn('%s','%s',(SELECT f_geometry_column from geometry_columns where f_table_name='%s' order by f_geometry_column limit 1))",
-                 pszDBName, osLayerName.c_str(), osLayerName.c_str() );
+                 "SELECT DropGeometryColumn('%s','%s',(SELECT f_geometry_column from geometry_columns where f_table_name='%s' and f_table_schema='%s' order by f_geometry_column limit 1))",
+                 osSchemaName.c_str(), osTableName.c_str(), osTableName.c_str(), osSchemaName.c_str() );
 
         CPLDebug( "OGR_PG", "PGexec(%s)", szCommand );
 
         hResult = PQexec( hPGConn, szCommand );
-        PQclear( hResult );
+        OGRPGClearResult( hResult );
     }
 
-    sprintf( szCommand, "DROP TABLE %s", osLayerName.c_str() );
+    sprintf( szCommand, "DROP TABLE %s.\"%s\" CASCADE", osSchemaName.c_str(), osTableName.c_str() );
     CPLDebug( "OGR_PG", "PGexec(%s)", szCommand );
     hResult = PQexec( hPGConn, szCommand );
-    PQclear( hResult );
+    OGRPGClearResult( hResult );
 
     hResult = PQexec(hPGConn, "COMMIT");
-    PQclear( hResult );
-
-    hResult = PQexec(hPGConn, "BEGIN");
-    PQclear( hResult );
-
-    sprintf( szCommand, "DROP SEQUENCE %s_ogc_fid_seq", osLayerName.c_str() );
-    CPLDebug( "OGR_PG", "PGexec(%s)", szCommand );
-    hResult = PQexec( hPGConn, szCommand );
-    PQclear( hResult );
-
-    hResult = PQexec(hPGConn, "COMMIT");
-    PQclear( hResult );
+    OGRPGClearResult( hResult );
 
     return OGRERR_NONE;
 }
@@ -619,6 +491,8 @@ OGRPGDataSource::CreateLayer( const char * pszLayerNameIn,
     char                szCommand[1024];
     const char          *pszGeomType;
     char                *pszLayerName;
+    const char          *pszTableName;
+    char                *pszSchemaName;
     int                 nDimension = 3;
 
     if( CSLFetchBoolean(papszOptions,"LAUNDER",TRUE) )
@@ -629,6 +503,45 @@ OGRPGDataSource::CreateLayer( const char * pszLayerNameIn,
     if( wkbFlatten(eType) == eType )
         nDimension = 2;
 
+    /* Postgres Schema handling:
+       Extract schema name from input layer name or passed with -lco SCHEMA.
+       Set layer name to "schema.table" or to "table" if schema == current_schema()
+       Usage without schema name is backwards compatible
+    */
+    pszTableName = strstr(pszLayerNameIn,".");
+    if ( pszTableName != NULL )
+    {
+      int length = pszTableName-pszLayerNameIn;
+      pszSchemaName = (char*)CPLMalloc(length);
+      strncpy(pszSchemaName, pszLayerNameIn, length);
+      pszSchemaName[length] = '\0';
+      ++pszTableName; //skip "."
+    }
+    else
+    {
+      pszSchemaName = NULL;
+      pszTableName = pszLayerNameIn;
+    }
+
+/* -------------------------------------------------------------------- */
+/*      Set the default schema for the layers.                          */
+/* -------------------------------------------------------------------- */
+    if( CSLFetchNameValue( papszOptions, "SCHEMA" ) != NULL )
+    {
+        pszSchemaName = CPLStrdup(CSLFetchNameValue( papszOptions, "SCHEMA" ));
+    }
+
+    if ( pszSchemaName == NULL )
+    {
+      //pszSchemaName = current_schema()
+      hResult = PQexec(hPGConn,"SELECT current_schema()");
+      if ( hResult && PQntuples(hResult) == 1 && !PQgetisnull(hResult,0,0) )
+      {
+          pszSchemaName = CPLStrdup(PQgetvalue(hResult,0,0));
+      }
+      OGRPGClearResult( hResult );
+    }
+
 /* -------------------------------------------------------------------- */
 /*      Do we already have this layer?  If so, should we blow it        */
 /*      away?                                                           */
@@ -646,12 +559,13 @@ OGRPGDataSource::CreateLayer( const char * pszLayerNameIn,
             }
             else
             {
-                CPLFree( pszLayerName );
                 CPLError( CE_Failure, CPLE_AppDefined,
                           "Layer %s already exists, CreateLayer failed.\n"
                           "Use the layer creation option OVERWRITE=YES to "
                           "replace it.",
                           pszLayerName );
+                CPLFree( pszLayerName );
+                CPLFree( pszSchemaName );
                 return NULL;
             }
         }
@@ -676,6 +590,7 @@ OGRPGDataSource::CreateLayer( const char * pszLayerNameIn,
                   "Creation of layer %s with GEOM_TYPE %s has failed.",
                   pszLayerName, pszGeomType );
         CPLFree( pszLayerName );
+        CPLFree( pszSchemaName );
         return NULL;
     }
 
@@ -693,22 +608,22 @@ OGRPGDataSource::CreateLayer( const char * pszLayerNameIn,
 /*      geometry if this is not a PostGIS enabled table.                */
 /* -------------------------------------------------------------------- */
     hResult = PQexec(hPGConn, "BEGIN");
-    PQclear( hResult );
+    OGRPGClearResult( hResult );
 
     if( !bHavePostGIS )
     {
         sprintf( szCommand,
-                 "CREATE TABLE \"%s\" ( "
+                 "CREATE TABLE %s.\"%s\" ( "
                  "   OGC_FID SERIAL, "
                  "   WKB_GEOMETRY %s, "
                  "   CONSTRAINT \"%s_pk\" PRIMARY KEY (OGC_FID) )",
-                 pszLayerName, pszGeomType, pszLayerName );
+                 pszSchemaName, pszTableName, pszGeomType, pszTableName );
     }
     else
     {
         sprintf( szCommand,
-                 "CREATE TABLE \"%s\" ( OGC_FID SERIAL, CONSTRAINT \"%s_pk\" PRIMARY KEY (OGC_FID) )",
-                 pszLayerName, pszLayerName );
+                 "CREATE TABLE %s.\"%s\" ( OGC_FID SERIAL, CONSTRAINT \"%s_pk\" PRIMARY KEY (OGC_FID) )",
+                 pszSchemaName, pszTableName, pszTableName );
     }
 
     CPLDebug( "OGR_PG", "PQexec(%s)", szCommand );
@@ -717,17 +632,16 @@ OGRPGDataSource::CreateLayer( const char * pszLayerNameIn,
     {
         CPLError( CE_Failure, CPLE_AppDefined,
                   "%s\n%s", szCommand, PQerrorMessage(hPGConn) );
-
         CPLFree( pszLayerName );
+        CPLFree( pszSchemaName );
 
-        PQclear( hResult );
+        OGRPGClearResult( hResult );
         hResult = PQexec( hPGConn, "ROLLBACK" );
-        PQclear( hResult );
-
+        OGRPGClearResult( hResult );
         return NULL;
     }
 
-    PQclear( hResult );
+    OGRPGClearResult( hResult );
 
 /* -------------------------------------------------------------------- */
 /*      Eventually we should be adding this table to a table of         */
@@ -742,7 +656,6 @@ OGRPGDataSource::CreateLayer( const char * pszLayerNameIn,
         if( CSLFetchNameValue( papszOptions, "DIM") != NULL )
             nDimension = atoi(CSLFetchNameValue( papszOptions, "DIM"));
 
-	/** rgp added this **/
         if( CSLFetchNameValue( papszOptions, "GEOMETRY_NAME") != NULL )
             pszGFldName = CSLFetchNameValue( papszOptions, "GEOMETRY_NAME");
 	else
@@ -753,12 +666,12 @@ OGRPGDataSource::CreateLayer( const char * pszLayerNameIn,
          * an effort to clean out such cruft.
          */
         sprintf( szCommand,
-                 "DELETE FROM geometry_columns WHERE f_table_name = '%s'",
-                 pszLayerName );
+                 "DELETE FROM geometry_columns WHERE f_table_name = '%s' AND f_table_schema = '%s'",
+                 pszTableName, pszSchemaName );
 
         CPLDebug( "OGR_PG", "PQexec(%s)", szCommand );
         hResult = PQexec(hPGConn, szCommand);
-        PQclear( hResult );
+        OGRPGClearResult( hResult );
 
         switch( wkbFlatten(eType) )
         {
@@ -798,7 +711,7 @@ OGRPGDataSource::CreateLayer( const char * pszLayerNameIn,
 
         sprintf( szCommand,
                  "select AddGeometryColumn('%s','%s','%s',%d,'%s',%d)",
-                 pszDBName, pszLayerName, pszGFldName, nSRSId, pszGeometryType,
+                 pszSchemaName, pszTableName, pszGFldName, nSRSId, pszGeometryType,
                  nDimension );
 
         CPLDebug( "OGR_PG", "PQexec(%s)", szCommand );
@@ -812,28 +725,31 @@ OGRPGDataSource::CreateLayer( const char * pszLayerNameIn,
                       pszLayerName );
 
             CPLFree( pszLayerName );
+            CPLFree( pszSchemaName );
 
-            PQclear( hResult );
+            OGRPGClearResult( hResult );
 
             hResult = PQexec(hPGConn, "ROLLBACK");
-            PQclear( hResult );
+            OGRPGClearResult( hResult );
 
             return NULL;
         }
+
+        OGRPGClearResult( hResult );
     }
 
 /* -------------------------------------------------------------------- */
 /*      Complete, and commit the transaction.                           */
 /* -------------------------------------------------------------------- */
     hResult = PQexec(hPGConn, "COMMIT");
-    PQclear( hResult );
+    OGRPGClearResult( hResult );
 
 /* -------------------------------------------------------------------- */
 /*      Create the layer object.                                        */
 /* -------------------------------------------------------------------- */
     OGRPGTableLayer     *poLayer;
 
-    poLayer = new OGRPGTableLayer( this, pszLayerName, TRUE, nSRSId );
+    poLayer = new OGRPGTableLayer( this, pszTableName, pszSchemaName, TRUE, nSRSId );
 
     poLayer->SetLaunderFlag( CSLFetchBoolean(papszOptions,"LAUNDER",TRUE) );
     poLayer->SetPrecisionFlag( CSLFetchBoolean(papszOptions,"PRECISION",TRUE));
@@ -841,12 +757,13 @@ OGRPGDataSource::CreateLayer( const char * pszLayerNameIn,
 /* -------------------------------------------------------------------- */
 /*      Add layer to data source layer list.                            */
 /* -------------------------------------------------------------------- */
-    papoLayers = (OGRPGLayer **)
-        CPLRealloc( papoLayers,  sizeof(OGRPGLayer *) * (nLayers+1) );
+    papoLayers = (OGRPGTableLayer **)
+        CPLRealloc( papoLayers,  sizeof(OGRPGTableLayer *) * (nLayers+1) );
 
     papoLayers[nLayers++] = poLayer;
 
     CPLFree( pszLayerName );
+    CPLFree( pszSchemaName );
 
     return poLayer;
 }
@@ -878,6 +795,44 @@ OGRLayer *OGRPGDataSource::GetLayer( int iLayer )
         return papoLayers[iLayer];
 }
 
+/************************************************************************/
+/*                           GetLayerByName()                           */
+/************************************************************************/
+
+OGRLayer *OGRPGDataSource::GetLayerByName( const char *pszName )
+
+{
+    if ( ! pszName )
+        return NULL;
+
+    int  i;
+    
+    int count = GetLayerCount();
+    /* first a case sensitive check */
+    for( i = 0; i < count; i++ )
+    {
+        OGRPGTableLayer *poLayer = papoLayers[i];
+
+        if( strcmp( pszName, poLayer->GetLayerDefn()->GetName() ) == 0 )
+            return poLayer;
+    }
+        
+    /* then case insensitive */
+    for( i = 0; i < count; i++ )
+    {
+        OGRPGTableLayer *poLayer = papoLayers[i];
+
+        if( EQUAL( pszName, poLayer->GetLayerDefn()->GetName() ) )
+            return poLayer;
+    }
+    
+    if( OpenTable( pszName, NULL, TRUE, FALSE ) )
+        return GetLayer(count);
+    else
+        return NULL;
+}
+
+
 /************************************************************************/
 /*                        OGRPGNoticeProcessor()                        */
 /************************************************************************/
@@ -930,7 +885,7 @@ OGRSpatialReference *OGRPGDataSource::FetchSRS( int nId )
 /* -------------------------------------------------------------------- */
 /*      Try looking up in spatial_ref_sys table.                        */
 /* -------------------------------------------------------------------- */
-    PGresult        *hResult;
+    PGresult        *hResult = NULL;
     char            szCommand[1024];
     OGRSpatialReference *poSRS = NULL;
 
@@ -957,7 +912,7 @@ OGRSpatialReference *OGRPGDataSource::FetchSRS( int nId )
         }
     }
 
-    PQclear( hResult );
+    OGRPGClearResult( hResult );
     SoftCommit();
 
 /* -------------------------------------------------------------------- */
@@ -968,6 +923,7 @@ OGRSpatialReference *OGRPGDataSource::FetchSRS( int nId )
         CPLRealloc(papoSRS, sizeof(void*) * (nKnownSRID + 1) );
     panSRID[nKnownSRID] = nId;
     papoSRS[nKnownSRID] = poSRS;
+    nKnownSRID++;
 
     return poSRS;
 }
@@ -982,10 +938,10 @@ OGRSpatialReference *OGRPGDataSource::FetchSRS( int nId )
 int OGRPGDataSource::FetchSRSId( OGRSpatialReference * poSRS )
 
 {
-    PGresult            *hResult;
+    PGresult            *hResult = NULL;
     char                szCommand[10000];
     char                *pszWKT = NULL;
-    int                 nSRSId;
+    int                 nSRSId = -1;
 
     if( poSRS == NULL )
         return -1;
@@ -1003,6 +959,7 @@ int OGRPGDataSource::FetchSRSId( OGRSpatialReference * poSRS )
 /*      Try to find in the existing table.                              */
 /* -------------------------------------------------------------------- */
     hResult = PQexec(hPGConn, "BEGIN");
+    OGRPGClearResult( hResult );
 
     sprintf( szCommand,
              "SELECT srid FROM spatial_ref_sys WHERE srtext = '%s'",
@@ -1017,12 +974,16 @@ int OGRPGDataSource::FetchSRSId( OGRSpatialReference * poSRS )
     if( hResult && PQresultStatus(hResult) == PGRES_TUPLES_OK
         && PQntuples(hResult) > 0 )
     {
+        // TODO: mloskot - replace with strtol() function.
+        // atoi does not provide any level of diagnostics.
+        // What about adding CPLAtoi() ? 
+
         nSRSId = atoi(PQgetvalue( hResult, 0, 0 ));
 
-        PQclear( hResult );
+        OGRPGClearResult( hResult );
 
         hResult = PQexec(hPGConn, "COMMIT");
-        PQclear( hResult );
+        OGRPGClearResult( hResult );
 
         return nSRSId;
     }
@@ -1037,7 +998,7 @@ int OGRPGDataSource::FetchSRSId( OGRSpatialReference * poSRS )
         hResult == NULL || PQresultStatus(hResult) == PGRES_NONFATAL_ERROR;
 
     hResult = PQexec(hPGConn, "COMMIT");
-    PQclear( hResult );
+    OGRPGClearResult( hResult );
 
     if( bTableMissing )
     {
@@ -1049,17 +1010,19 @@ int OGRPGDataSource::FetchSRSId( OGRSpatialReference * poSRS )
 /*      Get the current maximum srid in the srs table.                  */
 /* -------------------------------------------------------------------- */
     hResult = PQexec(hPGConn, "BEGIN");
-    PQclear( hResult );
+    OGRPGClearResult( hResult );
 
     hResult = PQexec(hPGConn, "SELECT MAX(srid) FROM spatial_ref_sys" );
 
     if( hResult && PQresultStatus(hResult) == PGRES_TUPLES_OK )
     {
         nSRSId = atoi(PQgetvalue(hResult,0,0)) + 1;
-        PQclear( hResult );
+        OGRPGClearResult( hResult );
     }
     else
+    {
         nSRSId = 1;
+    }
 
 /* -------------------------------------------------------------------- */
 /*      Try adding the SRS to the SRS table.                            */
@@ -1089,10 +1052,10 @@ int OGRPGDataSource::FetchSRSId( OGRSpatialReference * poSRS )
     CPLFree( pszWKT);
 
     hResult = PQexec(hPGConn, szCommand );
-    PQclear( hResult );
+    OGRPGClearResult( hResult );
 
     hResult = PQexec(hPGConn, "COMMIT");
-    PQclear( hResult );
+    OGRPGClearResult( hResult );
 
     return nSRSId;
 }
@@ -1112,20 +1075,22 @@ OGRErr OGRPGDataSource::SoftStartTransaction()
 
     if( nSoftTransactionLevel == 1 )
     {
-        PGresult            *hResult;
-        PGconn          *hPGConn = GetPGConn();
+        PGresult    *hResult = NULL;
+        PGconn      *hPGConn = GetPGConn();
 
         //CPLDebug( "OGR_PG", "BEGIN Transaction" );
         hResult = PQexec(hPGConn, "BEGIN");
 
         if( !hResult || PQresultStatus(hResult) != PGRES_COMMAND_OK )
         {
+            OGRPGClearResult( hResult );
+
             CPLDebug( "OGR_PG", "BEGIN Transaction failed:\n%s",
                       PQerrorMessage( hPGConn ) );
             return OGRERR_FAILURE;
         }
 
-        PQclear( hResult );
+        OGRPGClearResult( hResult );
     }
 
     return OGRERR_NONE;
@@ -1153,20 +1118,22 @@ OGRErr OGRPGDataSource::SoftCommit()
 
     if( nSoftTransactionLevel == 0 )
     {
-        PGresult            *hResult;
-        PGconn          *hPGConn = GetPGConn();
+        PGresult    *hResult = NULL;
+        PGconn      *hPGConn = GetPGConn();
 
         //CPLDebug( "OGR_PG", "COMMIT Transaction" );
         hResult = PQexec(hPGConn, "COMMIT");
 
         if( !hResult || PQresultStatus(hResult) != PGRES_COMMAND_OK )
         {
+            OGRPGClearResult( hResult );
+
             CPLDebug( "OGR_PG", "COMMIT Transaction failed:\n%s",
                       PQerrorMessage( hPGConn ) );
             return OGRERR_FAILURE;
         }
-
-        PQclear( hResult );
+        
+        OGRPGClearResult( hResult );
     }
 
     return OGRERR_NONE;
@@ -1190,15 +1157,19 @@ OGRErr OGRPGDataSource::SoftRollback()
 
     nSoftTransactionLevel = 0;
 
-    PGresult            *hResult;
-    PGconn              *hPGConn = GetPGConn();
+    PGresult    *hResult = NULL;
+    PGconn      *hPGConn = GetPGConn();
 
     hResult = PQexec(hPGConn, "ROLLBACK");
 
     if( !hResult || PQresultStatus(hResult) != PGRES_COMMAND_OK )
-        return OGRERR_FAILURE;
+    {
+        OGRPGClearResult( hResult );
 
-    PQclear( hResult );
+        return OGRERR_FAILURE;
+    }
+
+    OGRPGClearResult( hResult );
 
     return OGRERR_NONE;
 }
@@ -1257,12 +1228,11 @@ OGRLayer * OGRPGDataSource::ExecuteSQL( const char *pszSQLCommand,
     if( EQUALN(pszSQLCommand,"DELLAYER:",9) )
     {
         const char *pszLayerName = pszSQLCommand + 9;
-        int iLayer;
 
         while( *pszLayerName == ' ' )
             pszLayerName++;
         
-        for( iLayer = 0; iLayer < nLayers; iLayer++ )
+        for( int iLayer = 0; iLayer < nLayers; iLayer++ )
         {
             if( EQUAL(papoLayers[iLayer]->GetLayerDefn()->GetName(), 
                       pszLayerName ))
@@ -1277,7 +1247,7 @@ OGRLayer * OGRPGDataSource::ExecuteSQL( const char *pszSQLCommand,
 /* -------------------------------------------------------------------- */
 /*      Execute the statement.                                          */
 /* -------------------------------------------------------------------- */
-    PGresult            *hResult = NULL;
+    PGresult    *hResult = NULL;
 
     FlushSoftTransaction();
 
@@ -1314,8 +1284,7 @@ OGRLayer * OGRPGDataSource::ExecuteSQL( const char *pszSQLCommand,
                   "%s", PQresultErrorMessage( hResult ) );
     }
 
-    if( hResult )
-        PQclear( hResult );
+    OGRPGClearResult( hResult );
 
     FlushSoftTransaction();
 
@@ -1340,9 +1309,8 @@ char *OGRPGDataSource::LaunderName( const char *pszSrcName )
 
 {
     char    *pszSafeName = CPLStrdup( pszSrcName );
-    int     i;
 
-    for( i = 0; pszSafeName[i] != '\0'; i++ )
+    for( int i = 0; pszSafeName[i] != '\0'; i++ )
     {
         pszSafeName[i] = (char) tolower( pszSafeName[i] );
         if( pszSafeName[i] == '-' || pszSafeName[i] == '#' )
