@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrpgdriver.cpp,v 1.5 2006/03/28 23:06:57 fwarmerdam Exp $
+ * $Id: ogrpgdriver.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRPGDriver class.
@@ -25,30 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrpgdriver.cpp,v $
- * Revision 1.5  2006/03/28 23:06:57  fwarmerdam
- * fixed contact info
- *
- * Revision 1.4  2003/05/21 03:59:42  warmerda
- * expand tabs
- *
- * Revision 1.3  2002/05/09 16:03:19  warmerda
- * major upgrade to support SRS better and add ExecuteSQL
- *
- * Revision 1.2  2001/07/18 04:55:16  warmerda
- * added CPL_CSVID
- *
- * Revision 1.1  2000/10/17 17:46:51  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_pg.h"
 #include "cpl_conv.h"
 
-CPL_CVSID("$Id: ogrpgdriver.cpp,v 1.5 2006/03/28 23:06:57 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrpgdriver.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                            ~OGRPGDriver()                            */
