@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrpgresultlayer.cpp,v 1.6 2005/11/10 09:19:20 osemykin Exp $
+ * $Id: ogrpgresultlayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRPGResultLayer class, access the resultset from
@@ -26,33 +26,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrpgresultlayer.cpp,v $
- * Revision 1.6  2005/11/10 09:19:20  osemykin
- * fixed ReadResultDefinition() for text/wkt geometry column detecting
- *
- * Revision 1.5  2005/09/21 00:55:42  fwarmerdam
- * fixup OGRFeatureDefn and OGRSpatialReference refcount handling
- *
- * Revision 1.4  2004/05/08 02:14:49  warmerda
- * added GetFeature() on table, generalize FID support a bit
- *
- * Revision 1.3  2003/05/21 03:59:42  warmerda
- * expand tabs
- *
- * Revision 1.2  2003/02/01 07:55:48  warmerda
- * avoid dependence on libpq-fs.h
- *
- * Revision 1.1  2002/05/09 16:03:46  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "cpl_conv.h"
 #include "ogr_pg.h"
 
-CPL_CVSID("$Id: ogrpgresultlayer.cpp,v 1.6 2005/11/10 09:19:20 osemykin Exp $");
+CPL_CVSID("$Id: ogrpgresultlayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /* These are the OIDs for some builtin types, as returned by PQftype(). */
 /* They were copied from pg_type.h in src/include/catalog/pg_type.h */
