@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrpgtablelayer.cpp 11225 2007-04-08 14:51:34Z mloskot $
+ * $Id: ogrpgtablelayer.cpp 12932 2007-11-22 03:00:53Z mloskot $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRPGTableLayer class, access to an existing table.
@@ -33,7 +33,7 @@
 #include "cpl_string.h"
 #include "cpl_error.h"
 
-CPL_CVSID("$Id: ogrpgtablelayer.cpp 11225 2007-04-08 14:51:34Z mloskot $");
+CPL_CVSID("$Id: ogrpgtablelayer.cpp 12932 2007-11-22 03:00:53Z mloskot $");
 
 #define USE_COPY_UNSET  -10
 
@@ -134,30 +134,74 @@ OGRFeatureDefn *OGRPGTableLayer::ReadTableDefinition( const char * pszTableIn,
         OGRPGClearResult( hResult );
     }
 
-    /* TODO make changes corresponded to Frank issues
-       
-    sprintf ( szCommand,
-              "SELECT a.attname "
-              "FROM pg_attribute a, pg_constraint c, pg_class cl "
-              "WHERE c.contype='p' AND c.conrelid=cl.oid "
-              "AND a.attnum = c.conkey[1] AND a.attrelid=cl.oid "
-              "AND cl.relname = '%s'",
-              pszTableIn );
+    CPLString osSchemaClause;
+    if( pszSchemaNameIn )
+        osSchemaClause.Printf("AND n.nspname='%s'", pszSchemaNameIn);
 
-    hResult = PQexec(hPGConn, szCommand );
+    /* XXX - mloskot: This version works well but it uses features available in PostgresQL 8.1+
+     *                like ANY() for type of int2vector. Ticket #1889
+     */
+    /*
+    osCommand.Printf("SELECT a.attname, a.attnum, t.typname, "
+              "t.typname = ANY(ARRAY['int2','int4','serial']) AS isfid "
+              "FROM pg_class c, pg_attribute a, pg_type t, pg_namespace n, pg_index i "
+              "WHERE a.attnum > 0 AND a.attrelid = c.oid "
+              "AND a.atttypid = t.oid AND c.relnamespace = n.oid "
+              "AND c.oid = i.indrelid AND i.indisprimary = 't' "
+              "AND t.typname !~ '^geom' AND c.relname = '%s' "
+              "AND a.attnum = ANY (i.indkey) "
+              "%s"
+              "ORDER BY a.attnum",
+              pszTableIn, osSchemaClause.c_str() );
+    */
 
-    if ( hResult && PQntuples( hResult ) == 1 && PQgetisnull( hResult,0,0 ) == false )
+    osCommand.Printf("SELECT a.attname, a.attnum, t.typname, "
+              "t.typname = ANY(ARRAY['int2','int4','serial']) AS isfid "
+              "FROM pg_class c, pg_attribute a, pg_type t, pg_namespace n, pg_index i "
+              "WHERE a.attnum > 0 AND a.attrelid = c.oid "
+              "AND a.atttypid = t.oid AND c.relnamespace = n.oid "
+              "AND c.oid = i.indrelid AND i.indisprimary = 't' "
+              "AND t.typname !~ '^geom' AND c.relname = '%s' "
+              "AND (i.indkey[0]=a.attnum OR i.indkey[1]=a.attnum OR i.indkey[2]=a.attnum "
+              "OR i.indkey[3]=a.attnum OR i.indkey[4]=a.attnum OR i.indkey[5]=a.attnum "
+              "OR i.indkey[6]=a.attnum OR i.indkey[7]=a.attnum OR i.indkey[8]=a.attnum "
+              "OR i.indkey[9]=a.attnum) %s ORDER BY a.attnum",
+              pszTableIn, osSchemaClause.c_str() );
+     
+    hResult = PQexec(hPGConn, osCommand.c_str() );
+
+    if ( hResult && PGRES_TUPLES_OK == PQresultStatus( hResult) )
     {
-        sprintf( szPrimaryKey, "%s", PQgetvalue(hResult,0,0) );
-        CPLDebug( "OGR_PG", "Primary key name (FID): %s", szPrimaryKey );
+        if ( PQntuples( hResult ) == 1 && PQgetisnull( hResult,0,0 ) == false )
+        {
+            /* Check if single-field PK can be represented as 32-bit integer. */
+            CPLString osValue(PQgetvalue(hResult, 0, 3));
+            if( osValue == "t" )
+            {
+                osPrimaryKey.Printf( "%s", PQgetvalue(hResult,0,0) );
+                CPLDebug( "OGR_PG", "Primary key name (FID): %s", osPrimaryKey.c_str() );
+            }
+        }
+        else
+        {
+            CPLError( CE_Warning, CPLE_AppDefined,
+                      "Multi-column primary key in \'%s\' detected but not supported.",
+                      pszTableIn );
+        }
     }
     else
     {
         CPLError( CE_Failure, CPLE_AppDefined,
                   "%s", PQerrorMessage(hPGConn) );
+    }
+
+    /* TODO - mloskot: Remove this warning after multi-column PK is supported. */
+    if( osPrimaryKey.empty() || osPrimaryKey == "ogc_fid" )
+    {
         CPLError( CE_Warning, CPLE_AppDefined,
-                  "Unable to detect table primary key. Use default 'ogc_fid'");
-    }*/
+                  "Unable to detect single-column primary key for '%s'. Use default 'ogc_fid'",
+                  pszTableIn);
+    }
 
 /* -------------------------------------------------------------------- */
 /*      Fire off commands to get back the columns of the table.          */
@@ -169,8 +213,8 @@ OGRFeatureDefn *OGRPGTableLayer::ReadTableDefinition( const char * pszTableIn,
         OGRPGClearResult( hResult );
 
         CPLString osSchemaClause;
-        if (pszSchemaNameIn)
-          osSchemaClause.Printf("AND n.nspname='%s'", pszSchemaNameIn);
+        if( pszSchemaNameIn )
+            osSchemaClause.Printf("AND n.nspname='%s'", pszSchemaNameIn);
 
         osCommand.Printf(
                  "DECLARE mycursor CURSOR for "
@@ -225,7 +269,7 @@ OGRFeatureDefn *OGRPGTableLayer::ReadTableDefinition( const char * pszTableIn,
     if ( pszSchemaNameIn && osCurrentSchema != pszSchemaNameIn )
     {
         sprintf( szLayerName, "%s.%s", pszSchemaNameIn, pszTableIn );
-        sprintf( pszSqlTableName, "%s.\"%s\"", pszSchemaNameIn, pszTableIn );
+        sprintf( pszSqlTableName, "\"%s\".\"%s\"", pszSchemaNameIn, pszTableIn );
     }
     else
     {
