@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogr_pgeo.h,v 1.2 2005/12/16 01:32:26 fwarmerdam Exp $
+ * $Id: ogr_pgeo.h 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Private definitions for Personal Geodatabase driver.
@@ -25,16 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogr_pgeo.h,v $
- * Revision 1.2  2005/12/16 01:32:26  fwarmerdam
- * removed custom GetExtent on select layer
- *
- * Revision 1.1  2005/09/05 19:34:17  fwarmerdam
- * New
- *
- */
+ ****************************************************************************/
 
 #ifndef _OGR_ODBC_H_INCLUDED
 #define _OGR_ODBC_H_INLLUDED
@@ -174,7 +165,6 @@ class OGRPGeoSelectLayer : public OGRPGeoLayer
     virtual void        ResetReading();
     virtual int         GetFeatureCount( int );
 
-    virtual OGRErr      SetAttributeFilter( const char * );
     virtual OGRFeature *GetFeature( long nFeatureId );
     
     virtual int         TestCapability( const char * );
@@ -224,6 +214,13 @@ class OGRPGeoDataSource : public OGRDataSource
 
 class OGRPGeoDriver : public OGRSFDriver
 {
+    CPLString   osDriverFile;
+
+    bool        InstallMdbDriver();
+    bool        LibraryExists( const char* pszLibPath );
+    bool        FindDriverLib();
+    CPLString   FindDefaultLib(const char* pszLibName);
+
   public:
                 ~OGRPGeoDriver();
                 
