@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrpgeolayer.cpp,v 1.4 2005/09/29 19:49:48 fwarmerdam Exp $
+ * $Id: ogrpgeolayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRPGeoLayer class, code shared between 
@@ -26,28 +26,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrpgeolayer.cpp,v $
- * Revision 1.4  2005/09/29 19:49:48  fwarmerdam
- * dont try to translate GUID SRTEXT entries
- *
- * Revision 1.3  2005/09/21 00:55:42  fwarmerdam
- * fixup OGRFeatureDefn and OGRSpatialReference refcount handling
- *
- * Revision 1.2  2005/09/05 20:30:06  fwarmerdam
- * removed unused variable
- *
- * Revision 1.1  2005/09/05 19:34:17  fwarmerdam
- * New
- *
- */
+ ****************************************************************************/
 
 #include "cpl_conv.h"
 #include "ogr_pgeo.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogrpgeolayer.cpp,v 1.4 2005/09/29 19:49:48 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrpgeolayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                            OGRPGeoLayer()                            */
@@ -89,15 +74,16 @@ OGRPGeoLayer::~OGRPGeoLayer()
         poStmt = NULL;
     }
 
-    if( pszGeomColumn != NULL )
-        CPLFree( pszGeomColumn );
-
     if( poFeatureDefn != NULL )
     {
         poFeatureDefn->Release();
         poFeatureDefn = NULL;
     }
 
+    CPLFree( pszGeomColumn );
+    CPLFree( panFieldOrdinals ); 
+    CPLFree( pszFIDColumn );
+
     if( poSRS != NULL )
     {
         poSRS->Release();
@@ -520,7 +506,7 @@ OGRErr OGRPGeoLayer::createFromShapeBin( GByte *pabyShape,
                 OGRLineString *poLine = new OGRLineString();
                 *ppoGeom = poLine;
 
-                poLine->setPoints( nPoints, padfX, padfY, padfX );
+                poLine->setPoints( nPoints, padfX, padfY, padfZ );
             }
 
 /* -------------------------------------------------------------------- */
@@ -711,7 +697,7 @@ OGRErr OGRPGeoLayer::createFromShapeBin( GByte *pabyShape,
         if( nSHPType == SHPT_POINTZ )
         {
             memcpy( &dfZ, pabyShape + 4 + 16, 8 );
-            CPL_LSBPTR64( &dfY );
+            CPL_LSBPTR64( &dfZ );
         }
 
         *ppoGeom = new OGRPoint( dfX, dfY, dfZ );
