@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrpgeoselectlayer.cpp,v 1.3 2006/03/21 18:50:56 fwarmerdam Exp $
+ * $Id: ogrpgeoselectlayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRPGeoSelectLayer class, layer access to the results
@@ -26,24 +26,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrpgeoselectlayer.cpp,v $
- * Revision 1.3  2006/03/21 18:50:56  fwarmerdam
- * dont report SetAttributeFilter error if clearing
- *
- * Revision 1.2  2005/12/16 01:32:26  fwarmerdam
- * removed custom GetExtent on select layer
- *
- * Revision 1.1  2005/09/05 19:34:17  fwarmerdam
- * New
- *
- */
+ ****************************************************************************/
 
 #include "cpl_conv.h"
 #include "ogr_pgeo.h"
 
-CPL_CVSID("$Id: ogrpgeoselectlayer.cpp,v 1.3 2006/03/21 18:50:56 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrpgeoselectlayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                          OGRPGeoSelectLayer()                        */
@@ -150,26 +138,6 @@ OGRFeature *OGRPGeoSelectLayer::GetFeature( long nFeatureId )
     return OGRPGeoLayer::GetFeature( nFeatureId );
 }
 
-/************************************************************************/
-/*                         SetAttributeFilter()                         */
-/************************************************************************/
-
-OGRErr OGRPGeoSelectLayer::SetAttributeFilter( const char *pszQuery )
-
-{
-    if( pszQuery != NULL && strlen(pszQuery) > 0 )
-    {
-        CPLError( CE_Failure, CPLE_AppDefined, 
-                  "SetAttributeFilter() not supported on ExecuteSQL() results." );
-        
-        return OGRERR_UNSUPPORTED_OPERATION;
-    }
-    else
-    {
-        return OGRERR_NONE;
-    }
-}
-
 /************************************************************************/
 /*                           TestCapability()                           */
 /************************************************************************/
