@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrpgeotablelayer.cpp,v 1.3 2006/01/17 13:57:58 fwarmerdam Exp $
+ * $Id: ogrpgeotablelayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRPGeoTableLayer class, access to an existing table.
@@ -25,24 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrpgeotablelayer.cpp,v $
- * Revision 1.3  2006/01/17 13:57:58  fwarmerdam
- * Fixed extent recording.  Y values were reversed.
- *
- * Revision 1.2  2005/12/01 17:40:37  fwarmerdam
- * dont try to set geometry type for layer
- *
- * Revision 1.1  2005/09/05 19:34:17  fwarmerdam
- * New
- *
- */
+ ****************************************************************************/
 
 #include "cpl_conv.h"
 #include "ogr_pgeo.h"
 
-CPL_CVSID("$Id: ogrpgeotablelayer.cpp,v 1.3 2006/01/17 13:57:58 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrpgeotablelayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                          OGRPGeoTableLayer()                         */
