@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ll_recio.cpp,v 1.2 2006/04/10 02:13:02 fwarmerdam Exp $
+ * $Id: ll_recio.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  EPIInfo .REC Reader
  * Purpose:  Implements low level REC reading API.
@@ -25,22 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ll_recio.cpp,v $
- * Revision 1.2  2006/04/10 02:13:02  fwarmerdam
- * Changed type translations per email from Mario.
- *
- * Revision 1.1  2003/07/11 13:27:50  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_rec.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ll_recio.cpp,v 1.2 2006/04/10 02:13:02 fwarmerdam Exp $");
+CPL_CVSID("$Id: ll_recio.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 static int nNextRecLine = 0;
 
