@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: s57classregistrar.cpp,v 1.18 2006/04/02 18:48:26 fwarmerdam Exp $
+ * $Id: s57classregistrar.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  S-57 Translator
  * Purpose:  Implements S57ClassRegistrar class for keeping track of
@@ -26,90 +26,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: s57classregistrar.cpp,v $
- * Revision 1.18  2006/04/02 18:48:26  fwarmerdam
- * contact info updated
- *
- * Revision 1.17  2006/03/07 07:00:21  fwarmerdam
- * fixed quirk with attribute file lookup for profiles
- *
- * Revision 1.16  2005/08/30 17:57:34  fwarmerdam
- * allow directly set profile names too
- *
- * Revision 1.15  2005/08/30 17:55:50  fwarmerdam
- * Changed profile names
- *
- * Revision 1.14  2005/07/30 18:26:59  fwarmerdam
- * dont freak out about duplicate attributes
- *
- * Revision 1.13  2005/07/30 17:24:27  fwarmerdam
- * Use CPLGetConfigOption for S57_CSV value.
- *
- * Revision 1.12  2005/07/30 17:22:11  fwarmerdam
- * added preliminary "profile" support, and make class selection case
- * sensitive.
- *
- * Revision 16.1  2005/06/21 18:29:33  hsaggu
- * =S57 : Updates to the reader and first check-in of writer code from Frank.(PR#5223).<hss><geh>
- *
- * Revision 1.11  2005/05/03 16:11:53  fwarmerdam
- * Fixed initialization of attr tables.
- *
- * Revision 1.10  2005/04/27 13:34:14  fwarmerdam
- * Fixed a few memory leaks, including the ones from bug 840.
- *
- * Revision 16.0  2005/04/14 19:27:58  geh
- * FME 2006 Beta baseline start. <geh>
- *
- * Revision 1.9  2004/08/30 20:11:14  warmerda
- * various optimizations made
- *
- * Revision 15.0  2004/04/26 20:09:44  geh
- * FME 2005 Baseline just after making branch FME_2004_ICE_Branch. <geh>
- *
- * Revision 14.0  2003/11/07 23:21:02  cvs
- * FME 2004 Baseline before branch/FME 2004ICE start point
- *
- * Revision 1.8  2003/09/12 21:18:54  warmerda
- * open csv files in binary mode, not text mode
- *
- * Revision 5.0  2003/04/05 02:03:15  geh
- * 2003X2 Baseline before branch/ FME 2004 Start Point
- *
- * Revision 4.1  2003/02/19 22:40:29  ryan
- * S57 - Latest version from Frank that does not fail to build with the newest OGR <rjp><dal>
- *
- * Revision 1.7  2001/12/17 22:38:42  warmerda
- * restructure LoadInfo() to support in-code tables
- *
- * Revision 1.6  2001/07/18 04:55:16  warmerda
- * added CPL_CSVID
- *
- * Revision 1.5  2000/12/21 21:58:10  warmerda
- * Append class numbers to list rather than inserting at beginning, to
- * preserve original order.
- *
- * Revision 1.4  2000/08/30 09:14:08  warmerda
- * added use of CPLFindFile
- *
- * Revision 1.3  2000/06/07 20:50:58  warmerda
- * make CSV location configurable with env variable
- *
- * Revision 1.2  1999/11/18 19:01:25  warmerda
- * expanded tabs
- *
- * Revision 1.1  1999/11/08 22:22:55  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "s57.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: s57classregistrar.cpp,v 1.18 2006/04/02 18:48:26 fwarmerdam Exp $");
+CPL_CVSID("$Id: s57classregistrar.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 
 #ifdef S57_BUILTIN_CLASSES
