@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrsdtsdatasource.cpp,v 1.11 2006/03/28 23:17:06 fwarmerdam Exp $
+ * $Id: ogrsdtsdatasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  SDTS Translator
  * Purpose:  Implements OGRSDTSDataSource class
@@ -25,50 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrsdtsdatasource.cpp,v $
- * Revision 1.11  2006/03/28 23:17:06  fwarmerdam
- * updated contact info
- *
- * Revision 1.10  2005/09/21 00:54:43  fwarmerdam
- * fixup OGRFeatureDefn and OGRSpatialReference refcount handling
- *
- * Revision 1.9  2003/12/11 21:10:25  warmerda
- * avoid SRS leak
- *
- * Revision 1.8  2003/02/06 03:21:59  warmerda
- * Added OGRSpatialReference.Fixup() call to set linear units
- * as per http://bugzilla.remotesensing.org/show_bug.cgi?id=279.
- *
- * Revision 1.7  2002/04/17 15:17:49  warmerda
- * Initialize poTransfer to NULL.
- *
- * Revision 1.6  2002/04/15 13:18:39  warmerda
- * Free transfer in destructor!
- *
- * Revision 1.5  2001/07/18 04:55:16  warmerda
- * added CPL_CSVID
- *
- * Revision 1.4  2001/01/19 21:14:22  warmerda
- * expanded tabs
- *
- * Revision 1.3  2000/02/20 21:17:56  warmerda
- * added projection support
- *
- * Revision 1.2  1999/11/04 21:12:31  warmerda
- * added TestCapability() support
- *
- * Revision 1.1  1999/09/22 13:32:16  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_sdts.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogrsdtsdatasource.cpp,v 1.11 2006/03/28 23:17:06 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrsdtsdatasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                          OGRSDTSDataSource()                          */
