@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrsdtsdriver.cpp,v 1.5 2006/03/28 23:17:06 fwarmerdam Exp $
+ * $Id: ogrsdtsdriver.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  SDTS Translator
  * Purpose:  Implements OGRSDTSDriver
@@ -25,30 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrsdtsdriver.cpp,v $
- * Revision 1.5  2006/03/28 23:17:06  fwarmerdam
- * updated contact info
- *
- * Revision 1.4  2001/07/18 04:55:16  warmerda
- * added CPL_CSVID
- *
- * Revision 1.3  2001/01/19 21:14:22  warmerda
- * expanded tabs
- *
- * Revision 1.2  1999/11/04 21:12:31  warmerda
- * added TestCapability() support
- *
- * Revision 1.1  1999/09/22 13:32:16  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_sdts.h"
 #include "cpl_conv.h"
 
-CPL_CVSID("$Id: ogrsdtsdriver.cpp,v 1.5 2006/03/28 23:17:06 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrsdtsdriver.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                           ~OGRSDTSDriver()                           */
