@@ -2,7 +2,7 @@
 #define _SHAPEFILE_H_INCLUDED
 
 /******************************************************************************
- * $Id: shapefil.h 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: shapefil.h 12544 2007-10-26 18:49:10Z mloskot $
  *
  * Project:  Shapelib
  * Purpose:  Primary include file for Shapelib.
@@ -262,6 +262,9 @@ const char SHPAPI_CALL1(*)
 /* this can be two or four for binary or quad tree */
 #define MAX_SUBNODE	4
 
+/* upper limit of tree levels for automatic estimation */
+#define MAX_DEFAULT_TREE_DEPTH 12
+
 typedef struct shape_tree_node
 {
     /* region covered by this node */
