@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrsqlitetablelayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: ogrsqlitetablelayer.cpp 11486 2007-05-11 17:07:22Z mloskot $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRSQLiteTableLayer class, access to an existing table.
@@ -32,7 +32,7 @@
 #include "ogr_sqlite.h"
 #include <string>
 
-CPL_CVSID("$Id: ogrsqlitetablelayer.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: ogrsqlitetablelayer.cpp 11486 2007-05-11 17:07:22Z mloskot $");
 
 /************************************************************************/
 /*                        OGRSQLiteTableLayer()                         */
@@ -411,7 +411,7 @@ OGRErr OGRSQLiteTableLayer::CreateField( OGRFieldDefn *poFieldIn,
     ResetReading();
 
 /* -------------------------------------------------------------------- */
-/*      Do we want to "launder" the column names into Postgres          */
+/*      Do we want to "launder" the column names into SQLite            */
 /*      friendly format?                                                */
 /* -------------------------------------------------------------------- */
     if( bLaunderColumnNames )
@@ -423,7 +423,7 @@ OGRErr OGRSQLiteTableLayer::CreateField( OGRFieldDefn *poFieldIn,
     }
     
 /* -------------------------------------------------------------------- */
-/*      Work out the PostgreSQL type.                                   */
+/*      Work out the SQLite type.                                       */
 /* -------------------------------------------------------------------- */
     if( oField.GetType() == OFTInteger )
     {
@@ -433,6 +433,10 @@ OGRErr OGRSQLiteTableLayer::CreateField( OGRFieldDefn *poFieldIn,
     {
         strcpy( szFieldType, "FLOAT" );
     }
+    else if( oField.GetType() == OFTBinary )
+    {
+        strcpy( szFieldType, "BLOB" );
+    }
     else
     {
         strcpy( szFieldType, "VARCHAR" );
@@ -483,6 +487,8 @@ OGRErr OGRSQLiteTableLayer::CreateField( OGRFieldDefn *poFieldIn,
             pszType = "INTEGER";
         else if( poFldDefn->GetType() == OFTReal )
             pszType = "FLOAT";
+        else if( poFldDefn->GetType() == OFTBinary )
+            pszType = "BLOB";
         else
             pszType = "VARCHAR";
         
@@ -502,6 +508,8 @@ OGRErr OGRSQLiteTableLayer::CreateField( OGRFieldDefn *poFieldIn,
         pszType = "INTEGER";
     else if( oField.GetType() == OFTReal )
         pszType = "FLOAT";
+    else if( oField.GetType() == OFTBinary )
+        pszType = "BLOB";
     else
         pszType = "VARCHAR";
     
@@ -739,24 +747,38 @@ OGRErr OGRSQLiteTableLayer::CreateFeature( OGRFeature *poFeature )
         oCommand +=poFeatureDefn->GetFieldDefn(iField)->GetNameRef();
         oCommand += "'";
 
-        pszRawValue = poFeature->GetFieldAsString( iField );
-        if( strchr( pszRawValue, '\'' ) != NULL )
+        if( poFeatureDefn->GetFieldDefn(iField)->GetType() == OFTBinary  )
         {
-            char *pszEscapedValue = 
-                CPLEscapeString( pszRawValue, -1, CPLES_SQL );
+            int binaryCount = 0;
+            GByte* binaryData = poFeature->GetFieldAsBinary( iField, &binaryCount );
+            char* pszHexValue = CPLBinaryToHex( binaryCount, binaryData );
+            oValues += "X'";
+            oValues += pszHexValue;
             oValues += "'";
-            oValues += pszEscapedValue;
-            oValues += "'";
-
-            CPLFree( pszEscapedValue );
+            CPLFree( pszHexValue );
         }
         else
         {
-            oValues += "'";
-            oValues += pszRawValue;
-            oValues += "'";
+            pszRawValue = poFeature->GetFieldAsString( iField );
+
+            if( strchr( pszRawValue, '\'' ) != NULL )
+            {
+                char *pszEscapedValue = 
+                    CPLEscapeString( pszRawValue, -1, CPLES_SQL );
+                oValues += "'";
+                oValues += pszEscapedValue;
+                oValues += "'";
+
+                CPLFree( pszEscapedValue );
+            }
+            else
+            {
+                oValues += "'";
+                oValues += pszRawValue;
+                oValues += "'";
+            }
         }
-            
+
         bNeedComma = TRUE;
     }
 
@@ -796,3 +818,4 @@ OGRErr OGRSQLiteTableLayer::CreateFeature( OGRFeature *poFeature )
     return OGRERR_NONE;
 }
 
+
