@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrtigerdatasource.cpp,v 1.35 2006/03/29 00:46:07 fwarmerdam Exp $
+ * $Id: ogrtigerdatasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  TIGER/Line Translator
  * Purpose:  Implements OGRTigerDataSource class
@@ -25,142 +25,14 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrtigerdatasource.cpp,v $
- * Revision 1.35  2006/03/29 00:46:07  fwarmerdam
- * avoid CPLString for now for use in FME
- *
- * Revision 1.34  2006/03/08 04:17:24  fwarmerdam
- * added logic to check RTC records when classifying version
- *
- * Revision 1.33  2005/04/06 16:05:29  fwarmerdam
- * added spatialmetadata (RTM) support
- *
- * Revision 1.32  2005/04/06 15:04:23  fwarmerdam
- * added TIGER2004 support
- *
- * Revision 1.31  2004/09/22 16:17:06  fwarmerdam
- * Make GDT support work even if version number seems weird.
- *
- * Revision 1.30  2004/08/17 20:54:00  warmerda
- * Avoid out-of-buffer read for very short filenames.
- *
- * Revision 1.29  2004/02/12 16:00:41  warmerda
- * weaken test for candidate files so all Dynamap files found
- *
- * Revision 1.28  2004/02/12 06:39:16  warmerda
- * added preliminary support for some GDT quirks
- *
- * Revision 1.27  2003/11/05 20:57:19  warmerda
- * Added special hack mapping versioncodde 9999 to UA2000 for FME
- * bug 7625.
- *
- * Revision 1.26  2003/11/05 18:41:07  warmerda
- * added TIGER_VERSION setting to override file type on read
- *
- * Revision 1.25  2003/10/15 19:04:44  warmerda
- * fix a couple memory leaks
- *
- * Revision 1.24  2003/08/27 02:26:56  warmerda
- * fixed overlap in 2002/2003 version classification
- *
- * Revision 1.23  2003/08/18 14:47:53  warmerda
- * upgraded with *untested* TIGER 2003 support
- *
- * Revision 1.22  2003/03/20 19:10:37  warmerda
- * fixed memory leak
- *
- * Revision 1.21  2003/02/27 16:02:46  warmerda
- * Handle case with filename without path properly in BuildFilename().
- *
- * Revision 1.20  2003/01/13 17:06:10  warmerda
- * added support for a single county as a dataset
- *
- * Revision 1.19  2003/01/11 15:29:55  warmerda
- * expanded tabs
- *
- * Revision 1.18  2003/01/04 23:21:56  mbp
- * Minor bug fixes and field definition changes.  Cleaned
- * up and commented code written for TIGER 2002 support.
- *
- * Revision 1.17  2002/12/28 05:18:59  warmerda
- * Loosen candidate file constraints in Open() to include TST* files.
- *
- * Revision 1.16  2002/12/26 00:20:19  mbp
- * re-organized code to hold TIGER-version details in TigerRecordInfo structs;
- * first round implementation of TIGER_2002 support
- *
- * Revision 1.15  2001/12/12 17:25:07  warmerda
- * Use CPLStat instead of VSIStat.
- *
- * Revision 1.14  2001/07/19 16:58:39  warmerda
- * ensure version initialized, even if not testopen
- *
- * Revision 1.13  2001/07/19 16:05:49  warmerda
- * clear out tabs
- *
- * Revision 1.12  2001/07/19 16:03:11  warmerda
- * allow VERSION override on write
- *
- * Revision 1.11  2001/07/19 13:26:32  warmerda
- * enable override of existing modules
- *
- * Revision 1.10  2001/07/18 04:55:16  warmerda
- * added CPL_CSVID
- *
- * Revision 1.9  2001/07/04 23:25:32  warmerda
- * first round implementation of writer
- *
- * Revision 1.8  2001/07/04 05:40:35  warmerda
- * upgraded to support FILE, and Tiger2000 schema
- *
- * Revision 1.7  2001/01/19 21:15:20  warmerda
- * expanded tabs
- *
- * Revision 1.6  2000/01/13 16:39:17  warmerda
- * Use CPLGetBasename() to compare to limitedFileList.
- *
- * Revision 1.5  2000/01/13 05:18:11  warmerda
- * added support for multiple versions
- *
- * Revision 1.4  1999/12/22 15:38:15  warmerda
- * major update
- *
- * Revision 1.3  1999/12/15 19:59:52  warmerda
- * added new file types
- *
- * Revision 1.2  1999/11/04 21:14:31  warmerda
- * various improvements, and TestCapability()
- *
- * Revision 1.1  1999/10/07 18:19:21  warmerda
- * New
- *
- * Revision 1.6  1999/10/04 03:08:52  warmerda
- * added raster support
- *
- * Revision 1.5  1999/10/01 14:47:51  warmerda
- * major upgrade: generic, string feature codes, etc
- *
- * Revision 1.4  1999/09/29 16:43:43  warmerda
- * added spatial ref, improved test open for non-os files
- *
- * Revision 1.3  1999/09/08 00:58:40  warmerda
- * Added limiting list of files for FME.
- *
- * Revision 1.2  1999/08/30 16:49:26  warmerda
- * added feature class layer support
- *
- * Revision 1.1  1999/08/28 03:13:35  warmerda
- * New
- */
+ ****************************************************************************/
 
 #include "ogr_tiger.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 #include <ctype.h>
 
-CPL_CVSID("$Id: ogrtigerdatasource.cpp,v 1.35 2006/03/29 00:46:07 fwarmerdam Exp $");
+CPL_CVSID("$Id: ogrtigerdatasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                        TigerClassifyVersion()                        */
