@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: tigercompletechain.cpp,v 1.22 2006/03/29 00:46:20 fwarmerdam Exp $
+ * $Id: tigercompletechain.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  TIGER/Line Translator
  * Purpose:  Implements TigerCompleteChain, providing access to RT1 and
@@ -26,84 +26,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: tigercompletechain.cpp,v $
- * Revision 1.22  2006/03/29 00:46:20  fwarmerdam
- * update contact info
- *
- * Revision 1.21  2005/09/21 00:53:19  fwarmerdam
- * fixup OGRFeatureDefn and OGRSpatialReference refcount handling
- *
- * Revision 1.20  2004/10/05 19:30:44  fwarmerdam
- * Added bug fix for a "full" shape record at the end of the .RT2 file.
- * http://bugzilla.remotesensing.org/show_bug.cgi?id=628
- *
- * Revision 1.19  2004/02/12 16:00:03  warmerda
- * failure to open shapefile is no longer an error, just a warning
- *
- * Revision 1.18  2004/02/12 06:39:16  warmerda
- * added preliminary support for some GDT quirks
- *
- * Revision 1.17  2004/02/03 05:46:00  warmerda
- * fixed problem with chains at EOF without shape points being dropped
- *
- * Revision 1.16  2004/01/13 17:23:49  warmerda
- * recover more gracefully from RT2 open errors
- *
- * Revision 1.15  2003/10/15 19:09:46  warmerda
- * fixed memory leak of panShapeRecordId array
- *
- * Revision 1.14  2003/01/11 15:29:55  warmerda
- * expanded tabs
- *
- * Revision 1.13  2003/01/04 23:21:56  mbp
- * Minor bug fixes and field definition changes.  Cleaned
- * up and commented code written for TIGER 2002 support.
- *
- * Revision 1.12  2002/12/28 21:45:05  warmerda
- * oncall uses spaces instead of zero for null vertices in .RT2 file
- *
- * Revision 1.11  2002/12/26 00:20:19  mbp
- * re-organized code to hold TIGER-version details in TigerRecordInfo structs;
- * first round implementation of TIGER_2002 support
- *
- * Revision 1.10  2001/07/19 16:05:49  warmerda
- * clear out tabs
- *
- * Revision 1.9  2001/07/18 04:55:16  warmerda
- * added CPL_CSVID
- *
- * Revision 1.8  2001/07/04 23:25:32  warmerda
- * first round implementation of writer
- *
- * Revision 1.7  2001/07/04 05:40:35  warmerda
- * upgraded to support FILE, and Tiger2000 schema
- *
- * Revision 1.6  2001/07/04 03:08:21  warmerda
- * fixed FRADDL width
- *
- * Revision 1.5  2001/01/19 21:15:20  warmerda
- * expanded tabs
- *
- * Revision 1.4  2000/01/13 05:18:11  warmerda
- * added support for multiple versions
- *
- * Revision 1.3  1999/12/22 15:38:15  warmerda
- * major update
- *
- * Revision 1.2  1999/11/04 21:14:31  warmerda
- * various improvements, and TestCapability()
- *
- * Revision 1.1  1999/10/07 18:19:21  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogr_tiger.h"
 #include "cpl_conv.h"
 
-CPL_CVSID("$Id: tigercompletechain.cpp,v 1.22 2006/03/29 00:46:20 fwarmerdam Exp $");
+CPL_CVSID("$Id: tigercompletechain.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 static TigerFieldInfo rt1_2002_fields[] = {
   // fieldname    fmt  type OFTType      beg  end  len  bDefine bSet bWrite
