@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: tigerzerocellid.cpp,v 1.3 2005/09/21 00:53:19 fwarmerdam Exp $
+ * $Id: tigerzerocellid.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  TIGER/Line Translator
  * Purpose:  Implements TigerZeroCellID, providing access to .RTT files.
@@ -25,26 +25,12 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: tigerzerocellid.cpp,v $
- * Revision 1.3  2005/09/21 00:53:19  fwarmerdam
- * fixup OGRFeatureDefn and OGRSpatialReference refcount handling
- *
- * Revision 1.2  2003/01/04 23:21:56  mbp
- * Minor bug fixes and field definition changes.  Cleaned
- * up and commented code written for TIGER 2002 support.
- *
- * Revision 1.1  2002/12/26 00:20:19  mbp
- * re-organized code to hold TIGER-version details in TigerRecordInfo structs;
- * first round implementation of TIGER_2002 support
- *
- */
+ ****************************************************************************/
 
 #include "ogr_tiger.h"
 #include "cpl_conv.h"
 
-CPL_CVSID("$Id: tigerzerocellid.cpp,v 1.3 2005/09/21 00:53:19 fwarmerdam Exp $");
+CPL_CVSID("$Id: tigerzerocellid.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 #define FILE_CODE       "T"
 
