@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogrtindex.cpp,v 1.3 2005/07/15 15:06:52 fwarmerdam Exp $
+ * $Id: ogrtindex.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Program to generate a UMN MapServer compatible tile index for a
@@ -26,25 +26,15 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: ogrtindex.cpp,v $
- * Revision 1.3  2005/07/15 15:06:52  fwarmerdam
- * Set default location field width to 200.
- *
- * Revision 1.2  2002/04/25 20:56:29  warmerda
- * expanded tabs
- *
- * Revision 1.1  2002/03/27 18:34:43  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogrsf_frmts.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogrtindex.cpp,v 1.3 2005/07/15 15:06:52 fwarmerdam Exp $");
+#include <cassert>
+
+CPL_CVSID("$Id: ogrtindex.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 static void Usage();
 
@@ -188,7 +178,9 @@ int main( int nArgc, char ** papszArgv )
 /* ==================================================================== */
 /*      Process each input datasource in turn.                          */
 /* ==================================================================== */
-    for(; nFirstSourceDataset < nArgc; nFirstSourceDataset++ )
+	OGRFeatureDefn* poFeatureDefn = NULL;
+
+	for(; nFirstSourceDataset < nArgc; nFirstSourceDataset++ )
     {
         OGRDataSource       *poDS;
 
@@ -232,6 +224,49 @@ int main( int nArgc, char ** papszArgv )
             if( !bRequested )
                 continue;
 
+/* -------------------------------------------------------------------- */
+/*		Check if all layers in dataset have the same attributes	schema. */
+/* -------------------------------------------------------------------- */
+			if( poFeatureDefn == NULL )
+			{
+				poFeatureDefn = poLayer->GetLayerDefn()->Clone();
+			}
+			else
+			{
+				OGRFeatureDefn* poFeatureDefnCur = poLayer->GetLayerDefn();
+				assert(NULL != poFeatureDefnCur);
+
+				int fieldCount = poFeatureDefnCur->GetFieldCount();
+
+				if( fieldCount != poFeatureDefn->GetFieldCount())
+				{
+					printf( "Number of attributes of subsequent layers does not match ... terminating.\n" );
+					delete poDstDS;
+					exit( 1 );
+				}
+				
+				for( int fn = 0; fn < poFeatureDefnCur->GetFieldCount(); fn++ )
+				{
+ 					OGRFieldDefn* poField = poFeatureDefn->GetFieldDefn(fn);
+ 					OGRFieldDefn* poFieldCur = poFeatureDefnCur->GetFieldDefn(fn);
+
+					/* XXX - Should those pointers be checked against NULL? */ 
+					assert(NULL != poField);
+					assert(NULL != poFieldCur);
+
+					if( poField->GetType() != poFieldCur->GetType() 
+						|| poField->GetWidth() != poFieldCur->GetWidth() 
+						|| poField->GetPrecision() != poFieldCur->GetPrecision() 
+						|| !EQUAL( poField->GetNameRef(), poFieldCur->GetNameRef() ) )
+					{
+						printf( "Schema of attributes of subsequent layers does not match ... terminating.\n" );
+						delete poDstDS;
+						exit( 1 );
+					}
+				}
+			}
+
+
 /* -------------------------------------------------------------------- */
 /*      Get layer extents, and create a corresponding polygon           */
 /*      geometry.                                                       */
@@ -282,9 +317,10 @@ int main( int nArgc, char ** papszArgv )
     }
 
 /* -------------------------------------------------------------------- */
-/*      Close tile index.                                               */
+/*      Close tile index and clear buffers.                             */
 /* -------------------------------------------------------------------- */
     delete poDstDS;
+	delete poFeatureDefn;
 
     return 0;
 }
