@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: sdts2mi.cpp,v 1.4 2006/03/31 17:44:20 fwarmerdam Exp $
+ * $Id: sdts2mi.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  SDTS To Mapinfo Translator
@@ -25,28 +25,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: sdts2mi.cpp,v $
- * Revision 1.4  2006/03/31 17:44:20  fwarmerdam
- * header updates
- *
- * Revision 1.3  2001/07/18 05:03:05  warmerda
- * added CPL_CVSID
- *
- * Revision 1.2  2001/01/19 21:10:47  warmerda
- * replaced tabs
- *
- * Revision 1.1  2000/01/26 22:13:48  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "ogrsf_frmts.h"
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: sdts2mi.cpp,v 1.4 2006/03/31 17:44:20 fwarmerdam Exp $");
+CPL_CVSID("$Id: sdts2mi.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 static void Usage();
 
