@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: sfcdatasource.cpp,v 1.10 2006/03/31 17:44:20 fwarmerdam Exp $
+ * $Id: sfcdatasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project: OpenGIS Simple Features Reference Implementation
  * Purpose: SFCDataSource implementation.
@@ -25,40 +25,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: sfcdatasource.cpp,v $
- * Revision 1.10  2006/03/31 17:44:20  fwarmerdam
- * header updates
- *
- * Revision 1.9  2001/11/01 17:07:30  warmerda
- * lots of changes, including support for executing commands
- *
- * Revision 1.8  2001/07/18 05:03:05  warmerda
- * added CPL_CVSID
- *
- * Revision 1.7  1999/09/07 12:06:13  warmerda
- * type casting warning fixed
- *
- * Revision 1.6  1999/06/26 05:26:49  warmerda
- * Separate out GetWKTFromSRSId static method for use of SFCTable
- *
- * Revision 1.5  1999/06/10 19:18:22  warmerda
- * added support for the spatial ref schema rowset
- *
- * Revision 1.4  1999/06/10 14:39:25  warmerda
- * Added use of OGIS Features Tables schema rowset
- *
- * Revision 1.3  1999/06/09 21:09:36  warmerda
- * updated docs
- *
- * Revision 1.2  1999/06/09 21:00:10  warmerda
- * added support for spatial table identification
- *
- * Revision 1.1  1999/06/08 03:50:25  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include "sfcdatasource.h"
 #include "sfctable.h"
@@ -67,7 +34,7 @@
 #include "cpl_string.h"
 #include "oledb_sup.h"
 
-CPL_CVSID("$Id: sfcdatasource.cpp,v 1.10 2006/03/31 17:44:20 fwarmerdam Exp $");
+CPL_CVSID("$Id: sfcdatasource.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                           SFCDataSource()                            */
