@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: wctsclient.cpp,v 1.3 2003/03/27 21:40:20 warmerda Exp $
+ * $Id: wctsclient.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Project:  Web Coordinate Transformation Service
  * Purpose:  cgi-bin client form processor.  Turns client form request into
@@ -26,19 +26,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- ******************************************************************************
- *
- * $Log: wctsclient.cpp,v $
- * Revision 1.3  2003/03/27 21:40:20  warmerda
- * added post support, and GMLDATA support
- *
- * Revision 1.2  2003/03/27 18:42:55  warmerda
- * support GMLURL (FileURL) request
- *
- * Revision 1.1  2003/03/27 18:34:23  warmerda
- * New
- *
- */
+ ****************************************************************************/
 
 #include <assert.h>
 #include <curl/curl.h>
@@ -46,7 +34,7 @@
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: wctsclient.cpp,v 1.3 2003/03/27 21:40:20 warmerda Exp $");
+CPL_CVSID("$Id: wctsclient.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 /************************************************************************/
 /*                   WCTSClientEmitServiceException()                   */
