@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: cpl_error.cpp,v 1.36 2006/03/07 22:05:32 fwarmerdam Exp $
+ * $Id: cpl_error.cpp 10646 2007-01-18 02:38:10Z warmerdam $
  *
  * Name:     cpl_error.cpp
  * Project:  CPL - Common Portability Library
@@ -26,49 +26,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
  * DEALINGS IN THE SOFTWARE.
- **********************************************************************
- *
- * $Log: cpl_error.cpp,v $
- * Revision 1.36  2006/03/07 22:05:32  fwarmerdam
- * fix up docs a bit
- *
- * Revision 1.35  2006/02/27 23:24:13  fwarmerdam
- * Removed printf about growing error buffer.
- *
- * Revision 1.34  2006/02/27 02:40:11  fwarmerdam
- * Dynamically grow error buffer.
- *
- * Revision 1.33  2006/02/19 21:54:34  mloskot
- * [WINCE] Changes related to Windows CE port of CPL. Most changes are #ifdef wrappers.
- *
- * Revision 1.32  2005/07/25 18:09:10  fwarmerdam
- * Made pfnErrorHandler static.
- *
- * Revision 1.31  2005/07/25 17:56:34  fwarmerdam
- * Altered so that CPLSetErrorHandler sets a handler global to all threads, but
- * that the error handler stack takes precidence over it.
- *
- * Revision 1.30  2005/07/08 14:35:56  fwarmerdam
- * restructured to use error context and TLS
- *
- * Revision 1.29  2005/05/23 03:58:51  fwarmerdam
- * make handler stack threadlocal
- *
- * Revision 1.28  2005/04/04 15:23:31  fwarmerdam
- * some functions now CPL_STDCALL
- *
- * Revision 1.27  2003/05/27 20:44:16  warmerda
- * use VSI time services
- * 
- * Revision 1.26  2003/05/08 21:51:14  warmerda
- * added CPL{G,S}etConfigOption() usage
- *
- * Revision 1.25  2003/04/04 14:57:38  dron
- * _vsnprintf() hack moved to the cpl_config.h.vc.
- *
- * Revision 1.24  2003/04/04 14:16:07  dron
- * Use _vsnprintf() in Windows environment.
- */
+ ****************************************************************************/
 
 #include "cpl_error.h"
 #include "cpl_vsi.h"
@@ -82,7 +40,7 @@
  
 #define TIMESTAMP_DEBUG
 
-CPL_CVSID("$Id: cpl_error.cpp,v 1.36 2006/03/07 22:05:32 fwarmerdam Exp $");
+CPL_CVSID("$Id: cpl_error.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
 
 static void *hErrorMutex = NULL;
 static CPLErrorHandler pfnErrorHandler = CPLDefaultErrorHandler;
@@ -190,17 +148,32 @@ void    CPLErrorV(CPLErr eErrClass, int err_no, const char *fmt, va_list args )
 #if defined(HAVE_VSNPRINTF)
     {
         int nPR;
+        va_list wrk_args;
+
+#ifdef va_copy
+        va_copy( wrk_args, args );
+#else
+        wrk_args = args;
+#endif
 
         while( ((nPR = vsnprintf( psCtx->szLastErrMsg, 
-                                 psCtx->nLastErrMsgMax, fmt, args )) == -1
+                                 psCtx->nLastErrMsgMax, fmt, wrk_args )) == -1
                 || nPR >= psCtx->nLastErrMsgMax-1)
                && psCtx->nLastErrMsgMax < 1000000 )
         {
+#ifdef va_copy
+            va_end( wrk_args );
+            va_copy( wrk_args, args );
+#else
+            wrk_args = args;
+#endif
             psCtx->nLastErrMsgMax *= 3;
             psCtx = (CPLErrorContext *) 
                 CPLRealloc(psCtx, sizeof(CPLErrorContext) - DEFAULT_LAST_ERR_MSG_SIZE + psCtx->nLastErrMsgMax + 1);
             CPLSetTLS( CTLS_ERRORCONTEXT, psCtx, TRUE );
         }
+
+        va_end( wrk_args );
     }
 #else
     vsprintf( psCtx->szLastErrMsg, fmt, args);
@@ -278,7 +251,7 @@ void CPLDebug( const char * pszCategory, const char * pszFormat, ... )
 
     if( !EQUAL(pszDebug,"ON") && !EQUAL(pszDebug,"") )
     {
-        int            i, nLen = strlen(pszCategory);
+        size_t  i, nLen = strlen(pszCategory);
 
         for( i = 0; pszDebug[i] != '\0'; i++ )
         {
@@ -529,7 +502,7 @@ void CPL_STDCALL CPLLoggingErrorHandler( CPLErr eErrClass, int nError,
                 }
                 else
                 {
-                    int pos = 0;
+                    size_t pos = 0;
                     char *cpl_log_base = strdup(cpl_log);
                     pos = strcspn(cpl_log_base, ".");
                     if (pos > 0)
