@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: cpl_minixml.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: cpl_minixml.cpp 11363 2007-04-26 19:09:35Z warmerdam $
  *
  * Project:  CPL - Common Portability Library
  * Purpose:  Implementation of MiniXML Parser and handling.
@@ -44,7 +44,7 @@
 #include "cpl_string.h"
 #include <ctype.h>
 
-CPL_CVSID("$Id: cpl_minixml.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: cpl_minixml.cpp 11363 2007-04-26 19:09:35Z warmerdam $");
 
 typedef enum {
     TNone,
@@ -201,6 +201,31 @@ static XMLTokenType ReadToken( ParseContext *psContext )
                 
                 break;
             }
+            
+            /* Skip the internal DTD subset as NOT SUPPORTED YET (Ticket #755).
+             * The markup declaration block within a DOCTYPE tag consists of:
+             * - a left square bracket [
+             * - a list of declarations
+             * - a right square bracket ]
+             * Example:
+             * <!DOCTYPE RootElement [ ...declarations... ]>
+             *
+             * We need to skip all 3 parts, until closing > 
+             */
+            if( chNext == '[' )
+            {
+                do
+                {
+                    chNext = ReadChar( psContext );
+                }
+                while( chNext != ']'
+                    && !EQUALN(psContext->pszInput+psContext->nInputOffset,"]>", 2) );
+
+                // Skip "]" character to point to the closing ">"
+                chNext = ReadChar( psContext );
+                chNext = ReadChar( psContext );
+            }
+
 
             if( chNext == '\"' )
                 bInQuotes = !bInQuotes;
@@ -1341,7 +1366,9 @@ int CPLRemoveXMLChild( CPLXMLNode *psParent, CPLXMLNode *psChild )
     if( psParent == NULL )
         return FALSE;
 
-    for( psThis = psParent->psChild; psThis != NULL; psThis = psThis->psNext )
+    for( psThis = psParent->psChild; 
+         psThis != NULL; 
+         psLast = psThis, psThis = psThis->psNext )
     {
         if( psThis == psChild )
         {
@@ -1729,6 +1756,7 @@ CPLXMLNode *CPLParseXMLFile( const char *pszFilename )
  *
  * @param psTree the document tree to write. 
  * @param pszFilename the name of the file to write to. 
+ * @return TRUE on success, FALSE otherwise.
  */
 
 int CPLSerializeXMLTreeToFile( CPLXMLNode *psTree, const char *pszFilename )
