@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: cpl_multiproc.h 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: cpl_multiproc.h 12688 2007-11-09 19:37:05Z warmerdam $
  *
  * Project:  CPL - Common Portability Library
  * Purpose:  CPL Multi-Threading, and process handling portability functions.
@@ -32,10 +32,12 @@
 
 #include "cpl_port.h"
 
-// There are three primary implementations of the multi-process support
-// controlled by one of CPL_MULTIPROC_WIN32, CPL_MULTIPROC_PTHREAD or
-// CPL_MULTIPROC_STUB being defined.  If none are defined, the stub
-// implementation will be used.
+/*
+** There are three primary implementations of the multi-process support
+** controlled by one of CPL_MULTIPROC_WIN32, CPL_MULTIPROC_PTHREAD or
+** CPL_MULTIPROC_STUB being defined.  If none are defined, the stub
+** implementation will be used.
+*/
 
 #if defined(WIN32) && !defined(CPL_MULTIPROC_STUB)
 #  define CPL_MULTIPROC_WIN32
@@ -71,7 +73,7 @@ CPL_C_END
 
 #define CPLMutexHolderD(x)  CPLMutexHolder oHolder(x,1000.0,__FILE__,__LINE__);
 
-class CPLMutexHolder
+class CPL_DLL CPLMutexHolder
 {
   private:
     void       *hMutex;
@@ -99,6 +101,7 @@ class CPLMutexHolder
 #define CTLS_FINDERINFO                 6         /* cpl_finder.cpp */
 #define CTLS_PATHBUF                    7         /* cpl_path.cpp */
 #define CTLS_SPRINTFBUF                 8         /* cpl_string.cpp */
+#define CTLS_CPLSPRINTF                10         /* cpl_string.h */
 
 #define CTLS_MAX                       32         
 
