@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: cpl_string.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: cpl_string.cpp 12688 2007-11-09 19:37:05Z warmerdam $
  *
  * Name:     cpl_string.cpp
  * Project:  CPL - Common Portability Library
@@ -47,13 +47,14 @@
 
 #include "cpl_string.h"
 #include "cpl_vsi.h"
+#include "cpl_multiproc.h"
 
 #if defined(WIN32CE)
 #  include <wce_errno.h>
 #  include <wce_string.h>
 #endif
 
-CPL_CVSID("$Id: cpl_string.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: cpl_string.cpp 12688 2007-11-09 19:37:05Z warmerdam $");
 
 /*=====================================================================
                     StringList manipulation functions.
@@ -739,28 +740,46 @@ char ** CSLTokenizeString2( const char * pszString,
  */
 #define CPLSPrintf_BUF_SIZE 8000
 #define CPLSPrintf_BUF_Count 10
-static CPL_THREADLOCAL char gszCPLSPrintfBuffer[CPLSPrintf_BUF_Count][CPLSPrintf_BUF_SIZE];
-static CPL_THREADLOCAL int gnCPLSPrintfBuffer = 0;
 
 const char *CPLSPrintf(const char *fmt, ...)
 {
     va_list args;
 
+/* -------------------------------------------------------------------- */
+/*      Get the thread local buffer ring data.                          */
+/* -------------------------------------------------------------------- */
+    char *pachBufRingInfo = (char *) CPLGetTLS( CTLS_CPLSPRINTF );
+
+    if( pachBufRingInfo == NULL )
+    {
+        pachBufRingInfo = (char *) 
+            CPLCalloc(1,sizeof(int)+CPLSPrintf_BUF_Count*CPLSPrintf_BUF_SIZE);
+        CPLSetTLS( CTLS_CPLSPRINTF, pachBufRingInfo, TRUE );
+    }
+
+/* -------------------------------------------------------------------- */
+/*      Work out which string in the "ring" we want to use this         */
+/*      time.                                                           */
+/* -------------------------------------------------------------------- */
+    int *pnBufIndex = (int *) pachBufRingInfo;
+    int nOffset = sizeof(int) + *pnBufIndex * CPLSPrintf_BUF_SIZE;
+    char *pachBuffer = pachBufRingInfo + nOffset;
+
+    *pnBufIndex = (*pnBufIndex + 1) % CPLSPrintf_BUF_Count;
+
+/* -------------------------------------------------------------------- */
+/*      Format the result.                                              */
+/* -------------------------------------------------------------------- */
+
     va_start(args, fmt);
 #if defined(HAVE_VSNPRINTF)
-    vsnprintf(gszCPLSPrintfBuffer[gnCPLSPrintfBuffer], CPLSPrintf_BUF_SIZE-1,
-              fmt, args);
+    vsnprintf(pachBuffer, CPLSPrintf_BUF_SIZE-1, fmt, args);
 #else
-    vsprintf(gszCPLSPrintfBuffer[gnCPLSPrintfBuffer], fmt, args);
+    vsprintf(pachBuffer, fmt, args);
 #endif
     va_end(args);
     
-   int nCurrent = gnCPLSPrintfBuffer;
-
-    if (++gnCPLSPrintfBuffer == CPLSPrintf_BUF_Count)
-      gnCPLSPrintfBuffer = 0;
-
-    return gszCPLSPrintfBuffer[nCurrent];
+    return pachBuffer;
 }
 
 /**********************************************************************
@@ -772,23 +791,12 @@ const char *CPLSPrintf(const char *fmt, ...)
  **********************************************************************/
 char **CSLAppendPrintf(char **papszStrList, char *fmt, ...)
 {
+    CPLString osWork;
     va_list args;
+    osWork.vPrintf( fmt, args );
+    va_end( args );
 
-    va_start(args, fmt);
-#if defined(HAVE_VSNPRINTF)
-    vsnprintf(gszCPLSPrintfBuffer[gnCPLSPrintfBuffer], CPLSPrintf_BUF_SIZE-1,
-              fmt, args);
-#else
-    vsprintf(gszCPLSPrintfBuffer[gnCPLSPrintfBuffer], fmt, args);
-#endif
-    va_end(args);
-
-    int nCurrent = gnCPLSPrintfBuffer;
-
-    if (++gnCPLSPrintfBuffer == CPLSPrintf_BUF_Count)
-      gnCPLSPrintfBuffer = 0;
-
-    return CSLAddString(papszStrList, gszCPLSPrintfBuffer[nCurrent]);
+    return CSLAddString(papszStrList, osWork);
 }
 
 /************************************************************************/
