@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: cpl_string.h,v 1.25 2006/04/12 15:10:40 fwarmerdam Exp $
+ * $Id: cpl_string.h 11196 2007-04-03 23:18:17Z mloskot $
  *
  * Name:     cpl_string.h
  * Project:  CPL - Common Portability Library
@@ -26,48 +26,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
  * DEALINGS IN THE SOFTWARE.
- **********************************************************************
- *
- * $Log: cpl_string.h,v $
- * Revision 1.25  2006/04/12 15:10:40  fwarmerdam
- * argument to InsertString should be const
- *
- * Revision 1.24  2006/03/21 20:11:54  fwarmerdam
- * fixup headers a bit
- *
- * Revision 1.23  2006/02/19 21:54:34  mloskot
- * [WINCE] Changes related to Windows CE port of CPL. Most changes are #ifdef wrappers.
- *
- * Revision 1.22  2005/10/13 01:20:16  fwarmerdam
- * added CSLMerge()
- *
- * Revision 1.21  2005/09/14 19:21:17  fwarmerdam
- * binary pointer is const in binarytohex
- *
- * Revision 1.20  2005/08/31 05:08:01  fwarmerdam
- * fixed up std::string use for vc6 compatability
- *
- * Revision 1.19  2005/08/31 03:30:51  fwarmerdam
- * added binarytohex/hextobinary, CPLString
- *
- * Revision 1.18  2005/04/04 15:23:31  fwarmerdam
- * some functions now CPL_STDCALL
- *
- * Revision 1.17  2004/08/16 20:23:46  warmerda
- * added .csv escaping
- *
- * Revision 1.16  2004/07/12 21:50:38  warmerda
- * Added SQL escaping style
- *
- * Revision 1.15  2003/07/17 10:15:40  dron
- * CSLTestBoolean() added.
- *
- * Revision 1.14  2003/03/11 21:33:03  warmerda
- * added URL encode/decode support, untested
- *
- * Revision 1.13  2003/01/30 19:15:55  warmerda
- * added some docs
- **********************************************************************/
+ ****************************************************************************/
 
 #ifndef _CPL_STRING_H_INCLUDED
 #define _CPL_STRING_H_INCLUDED
@@ -131,7 +90,7 @@ int CPL_DLL CSLTestBoolean( const char *pszValue );
 int CPL_DLL CSLFetchBoolean( char **papszStrList, const char *pszKey, 
                              int bDefault );
 
-const char CPL_DLL *CPLSPrintf(char *fmt, ...);
+const char CPL_DLL *CPLSPrintf(const char *fmt, ...);
 char CPL_DLL **CSLAppendPrintf(char **papszStrList, char *fmt, ...);
 
 const char CPL_DLL *
@@ -199,9 +158,9 @@ CPL_C_END
 # define std_string std::string
 #endif 
 
-/* Remove annoying warnings in eVC++ and VC++ 6.0 */
+/* Remove annoying warnings in Microsoft eVC++ and Microsoft Visual C++ */
 #if defined(WIN32CE)
-#  pragma warning(disable:4786)
+#  pragma warning(disable:4251 4275 4786)
 #endif
 
 
@@ -210,6 +169,7 @@ CPL_C_END
 class CPL_DLL CPLString : public std_string
 {
 public:
+    
     CPLString(void) {}
     CPLString( const std::string &oStr ) : std_string( oStr ) {}
     CPLString( const char *pszStr ) : std_string( pszStr ) {}
@@ -218,6 +178,7 @@ public:
 
     CPLString &Printf( const char *pszFormat, ... );
     CPLString &vPrintf( const char *pszFormat, va_list args );
+    CPLString &Trim();
 };
 
 #endif /* def __cplusplus */
