@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: cpl_strtod.cpp 11096 2007-03-29 02:32:06Z warmerdam $
+ * $Id: cpl_strtod.cpp 12563 2007-10-28 01:59:33Z mloskot $
  *
  * Project:  CPL - Common Portability Library
  * Purpose:  Functions to convert ASCII string to floating point number.
@@ -155,7 +155,7 @@
 
 #include "cpl_conv.h"
 
-CPL_CVSID("$Id: cpl_strtod.cpp 11096 2007-03-29 02:32:06Z warmerdam $");
+CPL_CVSID("$Id: cpl_strtod.cpp 12563 2007-10-28 01:59:33Z mloskot $");
 
 /* defines */
 
@@ -303,10 +303,7 @@ static int
 _Stold (const char *s, char **endptr, double *pld, char **pnan,
         const char point)
 {
-  static const char hexits[] = {
-    '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e',
-    'f'
-  };
+  static const char hexits[] = "0123456789abcdef";
   char *sc;
   char buf[SIG_MAX];
   char sign;
@@ -319,7 +316,6 @@ _Stold (const char *s, char **endptr, double *pld, char **pnan,
   unsigned long lo[SIG_MAX / 8 + 1], *pl;
   short sexp;
   long lexp;
-  char esign;
 
   /* Get past the spaces.  */
   for (sc = (char *)s; isspace(*sc); ++sc)
@@ -409,11 +405,11 @@ _Stold (const char *s, char **endptr, double *pld, char **pnan,
             nzero = 0;
           }
 	  else
-	    {
+	  {
 	      /* deliver zeros */
 	      for (; 0 < nzero && nsig < SIG_MAX; --nzero)
 		buf[nsig++] = 0;
-	    }
+	  }
 	  ++ndigit;
 	  if (nsig < SIG_MAX)
 	    {
@@ -422,7 +418,7 @@ _Stold (const char *s, char **endptr, double *pld, char **pnan,
 		buf[nsig++] = *sc - '0';
 	      else
 		{
-		  p = (char *) strchr (hexits, tolower (*sc));
+		  p = strchr (const_cast<char*>(hexits), tolower (*sc));
 		  buf[nsig++] = p - hexits;
 		}
 	    }
@@ -460,22 +456,24 @@ _Stold (const char *s, char **endptr, double *pld, char **pnan,
   if ((base == 10 && (*sc == 'e' || *sc == 'E'))
       || (base == 16 && (*sc == 'p' || *sc == 'P')))
     {
-      esign = *++sc == '+' || *sc == '-' ? *sc++ : '+';
-      if (isdigit (*sc))
+      char *exponent = sc; /* temporary pointer to possible exponent part */
+      char esign = *++exponent == '+' || *exponent == '-' ? *exponent++ : '+';
+      if (isdigit(*exponent))
 	{
 	  /* exponent looks valid */
-	  for (; isdigit (*sc); ++sc)
+	  for (; isdigit (*exponent); ++exponent)
 	    if (lexp < 10000)
-	      lexp = lexp * 10 + (*sc - '0');
+	      lexp = lexp * 10 + (*exponent - '0');
 	  /* else overflow */
 	  if (esign == '-')
 	    lexp = -lexp;
+          sc = exponent; /* point to part which follows parsed exponent */
 	}
     }
   if (endptr)
     *endptr = (char *) sc;
   if (opoint < 0)
-    lexp += ndigit - nsig;
+    lexp += ndigit - olead - nsig;
   else
     lexp += opoint - olead - nsig;
   sexp =
@@ -485,9 +483,9 @@ _Stold (const char *s, char **endptr, double *pld, char **pnan,
     *pld = _Ldtento (x, sexp);
   else
 #ifdef HAVE_FREXPL
-    *pld = ldexpl (x, (int) (sexp) << 2);
+    *pld = ldexpl (x, (int) sexp);
 #else
-    *pld = ldexp (x, (int) (sexp) << 2);
+    *pld = ldexp (x, (int) sexp);
 #endif
   if (sign == '-')
     *pld = -*pld;
