@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: cpl_vsi_mem.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: cpl_vsi_mem.cpp 11305 2007-04-20 16:31:38Z warmerdam $
  *
  * Project:  VSI Virtual File System
  * Purpose:  Implementation of Memory Buffer virtual IO functions.
@@ -32,7 +32,7 @@
 #  pragma warning(disable:4786)
 #endif
 
-#include "cpl_vsi_private.h"
+#include "cpl_vsi_virtual.h"
 #include "cpl_string.h"
 #include "cpl_multiproc.h"
 #include <map>
@@ -42,7 +42,7 @@
 #endif
 
 
-CPL_CVSID("$Id: cpl_vsi_mem.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: cpl_vsi_mem.cpp 11305 2007-04-20 16:31:38Z warmerdam $");
 
 /*
 ** Notes on Multithreading:
