@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: cpl_vsil_unix_stdio_64.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: cpl_vsil_unix_stdio_64.cpp 11305 2007-04-20 16:31:38Z warmerdam $
  *
  * Project:  CPL - Common Portability Library
  * Purpose:  Implement VSI large file api for Unix platforms with fseek64()
@@ -32,7 +32,7 @@
 
 #if !defined(WIN32) && !defined(WIN32CE)
 
-#include "cpl_vsi_private.h"
+#include "cpl_vsi_virtual.h"
 #include "cpl_string.h"
 
 #include <unistd.h>
@@ -40,7 +40,7 @@
 #include <sys/types.h>
 #include <dirent.h>
 
-CPL_CVSID("$Id: cpl_vsil_unix_stdio_64.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: cpl_vsil_unix_stdio_64.cpp 11305 2007-04-20 16:31:38Z warmerdam $");
 
 #if defined(UNIX_STDIO_64)
 
