@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: cpl_vsil_win32.cpp 10646 2007-01-18 02:38:10Z warmerdam $
+ * $Id: cpl_vsil_win32.cpp 11305 2007-04-20 16:31:38Z warmerdam $
  *
  * Project:  CPL - Common Portability Library
  * Purpose:  Implement VSI large file api for Win32.
@@ -27,9 +27,9 @@
  * DEALINGS IN THE SOFTWARE.
  ****************************************************************************/
 
-#include "cpl_vsi_private.h"
+#include "cpl_vsi_virtual.h"
 
-CPL_CVSID("$Id: cpl_vsil_win32.cpp 10646 2007-01-18 02:38:10Z warmerdam $");
+CPL_CVSID("$Id: cpl_vsil_win32.cpp 11305 2007-04-20 16:31:38Z warmerdam $");
 
 #if defined(WIN32)
 
