@@ -1,5 +1,5 @@
 #******************************************************************************
-#  $Id: ogr.py,v 1.53 2005/09/18 15:26:00 fwarmerdam Exp $
+#  $Id: ogr.py 11100 2007-03-30 20:07:22Z hobu $
 # 
 #  Project:  OpenGIS Simple Features Reference Implementation
 #  Purpose:  OGR Python Shadow Class Implementations
@@ -27,207 +27,8 @@
 #  DEALINGS IN THE SOFTWARE.
 #******************************************************************************
 # 
-# $Log: ogr.py,v $
-# Revision 1.53  2005/09/18 15:26:00  fwarmerdam
-# added Distance method.
-#
-# Revision 1.52  2005/07/20 02:34:52  fwarmerdam
-# fixed up AddPoint to default z
-#
-# Revision 1.51  2005/07/20 01:46:51  fwarmerdam
-# ogr coordinate dimension upgrades
-#
-# Revision 1.50  2005/05/05 22:45:33  fwarmerdam
-# Fixed Empty call ... only one argument.
-#
-# Revision 1.49  2005/03/02 17:42:46  hobu
-# First pass at a __setattr__ for Feature
-#
-# Revision 1.48  2005/02/23 20:32:56  hobu
-# retract slicing for Layers as implemented.
-#
-# Revision 1.47  2005/02/08 15:54:12  hobu
-# Added more docstrings
-#
-# Revision 1.46  2005/02/07 21:37:06  hobu
-# Docstring added to __getattr__ for Feature
-#
-# Revision 1.45  2005/02/07 16:52:28  hobu
-# Added a __copy__ method for Geometry.
-# Added capabilities constants for Driver, DataSource,
-# and Layer.  Docstrings on the TestCapability methods
-# for each as well.
-#
-# Revision 1.44  2005/02/05 18:38:42  hobu
-# Added some more docstrings
-#
-# Revision 1.43  2005/02/05 18:11:53  hobu
-# Allow the Geometry constructor to take in
-# gml, wkt, wkb, and srs as keyword argmuments.  There
-# was already a wkt argument, but no implementation behind it.
-# The srs is used in the wkb and wkt contructors, otherwise it
-# is not used
-#
-# Revision 1.42  2005/02/05 04:57:24  hobu
-# Implemented __copy__ and a basic
-# __getattr__ for Feature.  No special handling
-# is done for wonky field name characters at this point.
-#
-# Revision 1.41  2005/02/03 14:22:16  fwarmerdam
-# Added __str__ method on Geometry.
-#
-# Revision 1.40  2005/02/02 04:36:53  fwarmerdam
-# Default index to 0 in geometry GetX/Y/Z.
-# Added GetFeaturesRead() and SetNextByIndex() methods on layer.
-#
-# Revision 1.39  2005/01/22 23:47:06  hobu
-# Support for slicing and index access on DataSources and Layers:
-# for layer in ds:
-#    do something
-#
-# for feature in layer:
-#    do something
-#
-# This also means that we get list comprehension support
-# [i.GetName() for i in ds[0:4]]
-# or
-# [i..GetFID() for feature in layer[0:]]
-#
-# *Note*-- some datasources do not always have sequential
-# feature ids and slicing may not work as expected for all
-# datasources.
-#
-# Support for len(ds) or len(layer) to return the number of
-# layers in the datasource or features in the layer (these are
-# simple wrappers around GetLayerCount() and GetFeatureCount())
-#
-# A custom exception, OGRError, is now raised in many cases
-# instead of generic IndexErrors or ValueErrors when the error
-# is really coming from OGR not being able to read something.
-#
-# Reworked DataSource.GetLayer() to check the types of the input
-# value (int or string) and call the appropriate OGR function to do so.
-# __getitem__ in DataSource uses this function instead of switching
-# between it and GetLayerByName().
-#
-# Revision 1.38  2005/01/22 18:52:16  hobu
-# passing _obj instead of obj in GetSpatialFilter in the Geometry
-# constructor at the end of the function.
-#
-# Revision 1.37  2005/01/22 18:30:58  hobu
-# typo in Layer::GetSpatialFilter
-#
-# Revision 1.36  2005/01/22 06:14:57  fwarmerdam
-# added thisown support for geometry and feature
-#
-# Revision 1.35  2005/01/03 22:19:09  fwarmerdam
-# added OGRLayer::SetSpatialFilterRect()
-#
-# Revision 1.34  2004/12/16 22:13:27  hobu
-# typo in the Clone() method of Feature
-#
-# Revision 1.33  2004/11/25 20:16:30  fwarmerdam
-# Fixed TransformTo() (bug 685).
-#
-# Revision 1.32  2004/10/27 18:27:33  fwarmerdam
-# Fixed last fix?
-#
-# Revision 1.31  2004/10/25 10:07:41  dron
-# Indentation problem fixed.
-#
-# Revision 1.30  2004/10/04 21:02:07  fwarmerdam
-# Added Centroid() method
-#
-# Revision 1.29  2004/09/17 15:07:57  fwarmerdam
-# added getArea
-#
-# Revision 1.28  2004/08/19 14:08:28  warmerda
-# watch for NULL return values too in geos functions
-#
-# Revision 1.27  2004/07/12 15:10:56  warmerda
-# Fix error case in CreateLayer().
-#
-# Revision 1.26  2004/07/10 07:08:39  warmerda
-# added new GEOS methods
-#
-# Revision 1.25  2004/07/10 05:05:24  warmerda
-# added closerings
-#
-# Revision 1.24  2004/03/31 15:34:06  warmerda
-# Added "name" parameter for FeatureDefn constructor.
-#
-# Revision 1.23  2004/03/18 18:55:53  warmerda
-# Avoid using hex constants for large 25D geometry type values as it causes
-# warnings on Python 2.3 and may have compatibility issues.   See:
-# http://bugzilla.remotesensing.org/show_bug.cgi?id=521
-#
-# Revision 1.22  2004/02/25 15:14:59  warmerda
-# added GetEnvelope() method on Geometry
-#
-# Revision 1.21  2004/01/06 18:18:53  warmerda
-# improved error checking in geometry creation methods
-#
-# Revision 1.20  2003/12/09 20:09:59  warmerda
-# No such function as OGR_Fld_GetName()!
-#
-# Revision 1.19  2003/12/05 18:01:24  warmerda
-# added GetDriver() support on Datasource
-#
-# Revision 1.18  2003/10/09 15:27:53  warmerda
-# added OGRLayer::DeleteFeature() support
-#
-# Revision 1.17  2003/10/06 22:28:54  warmerda
-# Added support for GetExtent().
-#
-# Revision 1.16  2003/09/22 05:48:50  warmerda
-# added GML geometry support
-#
-# Revision 1.15  2003/09/13 04:57:06  warmerda
-# fixed up NULL support for spatial references
-#
-# Revision 1.14  2003/08/27 15:40:06  warmerda
-# added OGRSetGenerate_DB2_V72_BYTE_ORDER()
-#
-# Revision 1.13  2003/06/10 14:43:33  warmerda
-# fixed NULL support in GetGeometryRef()
-#
-# Revision 1.12  2003/04/22 17:28:55  warmerda
-# added SyncToDisk, fix DumpReadable
-#
-# Revision 1.11  2003/04/08 22:13:00  warmerda
-# added new entry poins, and listtostringlist support
-#
-# Revision 1.10  2003/04/03 19:27:55  warmerda
-# added nullable string support, fixed ogr.Layer.SetAttributeFilter()
-#
-# Revision 1.9  2003/03/20 17:53:30  warmerda
-# added OGR OpenShared and reference coutnting stuff
-#
-# Revision 1.8  2003/03/07 16:28:55  warmerda
-# lots of 'NULL' fixes
-#
-# Revision 1.7  2003/03/03 05:16:11  warmerda
-# added DeleteLayer and DeleteDataSource methods
-#
-# Revision 1.6  2003/03/03 02:46:05  warmerda
-# added ogr.Driver class
-#
-# Revision 1.5  2003/01/08 18:15:48  warmerda
-# added loads of stuff
-#
-# Revision 1.4  2003/01/02 21:41:07  warmerda
-# added GetField(), and BuildPolygonFromEdges methods
-#
-# Revision 1.3  2002/10/24 20:37:18  warmerda
-# fixed srs support in CreateFrom functions
-#
-# Revision 1.2  2002/10/24 16:51:17  warmerda
-# added lots of OGRGeometryH support
-#
-# Revision 1.1  2002/09/26 18:14:32  warmerda
-# New
-#
-#
+# $Log$
+
 
 import _gdal
 import gdal
@@ -272,6 +73,9 @@ OFTStringList = 5
 OFTWideString = 6
 OFTWideStringList = 7
 OFTBinary = 8
+OFTDate = 9
+OFTTime = 10
+OFTDateTime = 11
 
 # OGRJustification
 
@@ -317,20 +121,12 @@ def Open( filename, update = 0 ):
     """Return an OGR DataSource
 update=0,1 -- open it for update"""
 
-    drv_ptr = ptrptrcreate( 'void' )
-    ptrptrset( drv_ptr, 'NULL' )
+    ds_o = _gdal.OGROpen( filename, update, 'NULL' )
 
-    ds_o = _gdal.OGROpen( filename, update, drv_ptr )
-
-    driver_o = ptrcast(ptrptrvalue(drv_ptr),'OGRSFDriverH')
-    ptrfree( drv_ptr )
-    
     if ds_o is None or ds_o == 'NULL':
         raise OGRError, 'Unable to open: ' + filename
     else:
         ds = DataSource( ds_o )
-        ds.driver_o = driver_o
-
         return ds
 
 def OpenShared( filename, update = 0 ):
@@ -362,12 +158,11 @@ def GetDriver( driver_index ):
         return Driver( dr_o )
 
 def GetDriverByName( name ):
-    count = GetDriverCount()
-    for i in range(count):
-        dr = GetDriver( i )
-        if dr.GetName() == name:
-            return dr
-    raise OGRError, 'Unable to find ogr.Driver named "%s".' % name
+    dr_o = _gdal.OGRGetDriverByName( name )
+    if dr_o is None or dr_o == 'NULL':
+        raise OGRError, 'Unable to find ogr.Driver named "%s".' % name
+    else:
+        return Driver( dr_o )
 
 def GetOpenDSCount():
     return _gdal.OGRGetOpenDSCount()
@@ -559,7 +354,8 @@ See the constants at the top of ogr.py"""
 
     def GetDriver( self ):
         """Returns the driver of the datasource"""
-        return Driver( obj = self.driver_o )
+        return Driver( _gdal.OGR_DS_GetDriver( self._o ) )
+    
 #############################################################################
 # OGRLayer
 
@@ -1017,17 +813,28 @@ class Geometry:
             self._o = _gdal.OGR_G_CreateGeometry( type )
             self.thisown = 1
         elif wkt:
-            if srs:
-                return CreateGeometryFromWkt(wkt, srs)
+            if srs is None:
+                srs = ''
             else:
-                return CreateGeometryFromWkt(wkt)
+                srs = srs._o
+            _obj = _gdal.OGR_G_CreateFromWkt(wkt, srs)
+            if _obj is not None and _obj != 'NULL':
+                self._o = _obj
+                self.thisown = 1
         elif wkb:
-            if srs:
-                return CreateGeometryFromWkb(wkb, srs)
+            if srs is None:
+                srs = ''
             else:
-                return CreateGeometryFromWkb(wkb)
+                srs = srs._o
+            _obj = _gdal.OGR_G_CreateFromWkb(wkb, srs)
+            if _obj is not None and _obj != 'NULL':
+                self._o = _obj
+                self.thisown = 1
         elif gml:
-            return CreateGeometryFromGML(gml)
+            _obj = _gdal.OGR_G_CreateFromGML(gml)
+            if _obj is not None and _obj != 'NULL':
+                self._o = _obj
+                self.thisown = 1
         else:
             raise OGRError, 'OGRGeometry may not be directly instantiated.'
 
